// This code conforms with the UFC specification version 1.0
// and was automatically generated by FFC version 0.6.2.
//
// Warning: This code was generated with the option '-l dolfin'
// and contains DOLFIN-specific wrappers that depend on DOLFIN.

#ifndef __POISSON3D_5_H
#define __POISSON3D_5_H

#include <cmath>
#include <stdexcept>
#include <fstream>
#include <ufc.h>
    
/// This class defines the interface for a finite element.

class poisson3d_5_0_finite_element_0: public ufc::finite_element
{
public:

  /// Constructor
  poisson3d_5_0_finite_element_0() : ufc::finite_element()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_0_finite_element_0()
  {
    // Do nothing
  }

  /// Return a string identifying the finite element
  virtual const char* signature() const
  {
    return "FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return the cell shape
  virtual ufc::shape cell_shape() const
  {
    return ufc::tetrahedron;
  }

  /// Return the dimension of the finite element function space
  virtual unsigned int space_dimension() const
  {
    return 56;
  }

  /// Return the rank of the value space
  virtual unsigned int value_rank() const
  {
    return 0;
  }

  /// Return the dimension of the value space for axis i
  virtual unsigned int value_dimension(unsigned int i) const
  {
    return 1;
  }

  /// Evaluate basis function i at given point in cell
  virtual void evaluate_basis(unsigned int i,
                              double* values,
                              const double* coordinates,
                              const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Reset values
    *values = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Extract relevant coefficients
    const double coeff0_0 = coefficients0[dof][0];
    const double coeff0_1 = coefficients0[dof][1];
    const double coeff0_2 = coefficients0[dof][2];
    const double coeff0_3 = coefficients0[dof][3];
    const double coeff0_4 = coefficients0[dof][4];
    const double coeff0_5 = coefficients0[dof][5];
    const double coeff0_6 = coefficients0[dof][6];
    const double coeff0_7 = coefficients0[dof][7];
    const double coeff0_8 = coefficients0[dof][8];
    const double coeff0_9 = coefficients0[dof][9];
    const double coeff0_10 = coefficients0[dof][10];
    const double coeff0_11 = coefficients0[dof][11];
    const double coeff0_12 = coefficients0[dof][12];
    const double coeff0_13 = coefficients0[dof][13];
    const double coeff0_14 = coefficients0[dof][14];
    const double coeff0_15 = coefficients0[dof][15];
    const double coeff0_16 = coefficients0[dof][16];
    const double coeff0_17 = coefficients0[dof][17];
    const double coeff0_18 = coefficients0[dof][18];
    const double coeff0_19 = coefficients0[dof][19];
    const double coeff0_20 = coefficients0[dof][20];
    const double coeff0_21 = coefficients0[dof][21];
    const double coeff0_22 = coefficients0[dof][22];
    const double coeff0_23 = coefficients0[dof][23];
    const double coeff0_24 = coefficients0[dof][24];
    const double coeff0_25 = coefficients0[dof][25];
    const double coeff0_26 = coefficients0[dof][26];
    const double coeff0_27 = coefficients0[dof][27];
    const double coeff0_28 = coefficients0[dof][28];
    const double coeff0_29 = coefficients0[dof][29];
    const double coeff0_30 = coefficients0[dof][30];
    const double coeff0_31 = coefficients0[dof][31];
    const double coeff0_32 = coefficients0[dof][32];
    const double coeff0_33 = coefficients0[dof][33];
    const double coeff0_34 = coefficients0[dof][34];
    const double coeff0_35 = coefficients0[dof][35];
    const double coeff0_36 = coefficients0[dof][36];
    const double coeff0_37 = coefficients0[dof][37];
    const double coeff0_38 = coefficients0[dof][38];
    const double coeff0_39 = coefficients0[dof][39];
    const double coeff0_40 = coefficients0[dof][40];
    const double coeff0_41 = coefficients0[dof][41];
    const double coeff0_42 = coefficients0[dof][42];
    const double coeff0_43 = coefficients0[dof][43];
    const double coeff0_44 = coefficients0[dof][44];
    const double coeff0_45 = coefficients0[dof][45];
    const double coeff0_46 = coefficients0[dof][46];
    const double coeff0_47 = coefficients0[dof][47];
    const double coeff0_48 = coefficients0[dof][48];
    const double coeff0_49 = coefficients0[dof][49];
    const double coeff0_50 = coefficients0[dof][50];
    const double coeff0_51 = coefficients0[dof][51];
    const double coeff0_52 = coefficients0[dof][52];
    const double coeff0_53 = coefficients0[dof][53];
    const double coeff0_54 = coefficients0[dof][54];
    const double coeff0_55 = coefficients0[dof][55];
    
    // Compute value(s)
    *values = coeff0_0*basisvalue0 + coeff0_1*basisvalue1 + coeff0_2*basisvalue2 + coeff0_3*basisvalue3 + coeff0_4*basisvalue4 + coeff0_5*basisvalue5 + coeff0_6*basisvalue6 + coeff0_7*basisvalue7 + coeff0_8*basisvalue8 + coeff0_9*basisvalue9 + coeff0_10*basisvalue10 + coeff0_11*basisvalue11 + coeff0_12*basisvalue12 + coeff0_13*basisvalue13 + coeff0_14*basisvalue14 + coeff0_15*basisvalue15 + coeff0_16*basisvalue16 + coeff0_17*basisvalue17 + coeff0_18*basisvalue18 + coeff0_19*basisvalue19 + coeff0_20*basisvalue20 + coeff0_21*basisvalue21 + coeff0_22*basisvalue22 + coeff0_23*basisvalue23 + coeff0_24*basisvalue24 + coeff0_25*basisvalue25 + coeff0_26*basisvalue26 + coeff0_27*basisvalue27 + coeff0_28*basisvalue28 + coeff0_29*basisvalue29 + coeff0_30*basisvalue30 + coeff0_31*basisvalue31 + coeff0_32*basisvalue32 + coeff0_33*basisvalue33 + coeff0_34*basisvalue34 + coeff0_35*basisvalue35 + coeff0_36*basisvalue36 + coeff0_37*basisvalue37 + coeff0_38*basisvalue38 + coeff0_39*basisvalue39 + coeff0_40*basisvalue40 + coeff0_41*basisvalue41 + coeff0_42*basisvalue42 + coeff0_43*basisvalue43 + coeff0_44*basisvalue44 + coeff0_45*basisvalue45 + coeff0_46*basisvalue46 + coeff0_47*basisvalue47 + coeff0_48*basisvalue48 + coeff0_49*basisvalue49 + coeff0_50*basisvalue50 + coeff0_51*basisvalue51 + coeff0_52*basisvalue52 + coeff0_53*basisvalue53 + coeff0_54*basisvalue54 + coeff0_55*basisvalue55;
  }

  /// Evaluate all basis functions at given point in cell
  virtual void evaluate_basis_all(double* values,
                                  const double* coordinates,
                                  const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis() is not yet implemented.");
  }

  /// Evaluate order n derivatives of basis function i at given point in cell
  virtual void evaluate_basis_derivatives(unsigned int i,
                                          unsigned int n,
                                          double* values,
                                          const double* coordinates,
                                          const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Compute number of derivatives
    unsigned int num_derivatives = 1;
    
    for (unsigned int j = 0; j < n; j++)
      num_derivatives *= 3;
    
    
    // Declare pointer to two dimensional array that holds combinations of derivatives and initialise
    unsigned int **combinations = new unsigned int *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      combinations[j] = new unsigned int [n];
      for (unsigned int k = 0; k < n; k++)
        combinations[j][k] = 0;
    }
        
    // Generate combinations of derivatives
    for (unsigned int row = 1; row < num_derivatives; row++)
    {
      for (unsigned int num = 0; num < row; num++)
      {
        for (unsigned int col = n-1; col+1 > 0; col--)
        {
          if (combinations[row][col] + 1 > 2)
            combinations[row][col] = 0;
          else
          {
            combinations[row][col] += 1;
            break;
          }
        }
      }
    }
    
    // Compute inverse of Jacobian
    const double Jinv[3][3] ={{d00 / detJ, d10 / detJ, d20 / detJ}, {d01 / detJ, d11 / detJ, d21 / detJ}, {d02 / detJ, d12 / detJ, d22 / detJ}};
    
    // Declare transformation matrix
    // Declare pointer to two dimensional array and initialise
    double **transform = new double *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      transform[j] = new double [num_derivatives];
      for (unsigned int k = 0; k < num_derivatives; k++)
        transform[j][k] = 1;
    }
    
    // Construct transformation matrix
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        for (unsigned int k = 0; k < n; k++)
          transform[row][col] *= Jinv[combinations[col][k]][combinations[row][k]];
      }
    }
    
    // Reset values
    for (unsigned int j = 0; j < 1*num_derivatives; j++)
      values[j] = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Interesting (new) part
    // Tables of derivatives of the polynomial base (transpose)
    const static double dmats0[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.32455532033676, 0, -1.14376677014985e-14, 1.62513232038197e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.226276025168e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.2249721603218, 0, 0, 0, 1.51109207276003e-14, 0, 0, 1.7779939846807e-14, 0, -1.0584837800154e-14, 0, 0, 0, 0, 0, -1.00872575799093e-14, 0, 0, 1.03757106873844e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.58257569495584, 0, 8.36660026534074, -1.18321595661991, 0, -1.45923311721618e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.02203768115554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.74165738677394, 0, 0, 8.69482604771369, 0, 0, 0, 0, 1.78666554661835e-14, 0, 0, 0, 0, 0, 1.07473131066306e-14, 0, 0, 0, -1.11533477710537e-14, 2.38264269425414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.49909083394701, -1.6247766670982e-14, -3.3466401061363, -2.36643191323984, 15.4919333848297, 0, 0.692820323027544, 0, 0.565685424949235, 0.4, -1.83948951574252e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00288811754535e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.89897948556636, -1.43896667584992e-14, 0, 1.15516000140692e-14, 14.1985914794391, 0, -0.828078671210835, 2.47538399283584e-14, 0, 0, -1.83091262688552e-14, 1.02722007327841e-14, -1.56195834108856e-14, 0, 0, -1.91729044059553e-14, 0, 0, 0, 0, 0, 1.12036901882012e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.41804190462393e-14, 0, -1.19125833850358e-14, 0, 0, -1.13598572445865e-14, 0, -1.07549059979877e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.60000000000001, 0, 8.76356092008264, -1.54919333848296, 0, 0, 9.52470471983252, 0, -1.48131215963608, 0.261861468283188, 0, 0, 0, -2.03129367268393e-14, 0, 0, 2.48374782197935e-14, 0, -2.78808329533534e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.04489815276121e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00610790048597e-14, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.24264068711929, 0, 1.13239065646931e-14, 0, 0, 0, 14.3427433120127, 1.68846056927685e-14, 0, 0, 0, 0, 0, 1.92963956808162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.11769145362398, -1.38374576748428e-14, 3.16227766016837, 4.91934955049958, 0, 0, -1.29538515160783e-14, -1.04815557124913e-14, 10.690449676497, -2.41897262725904, 0, 0, 0, 0, 0, 2.10489624344795e-14, 0, -1.67945221763201e-14, -3.13102977027619e-14, 2.84355872182118e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.79907925474428e-14, 0, -1.53961627596513e-14, 1.10259024133086e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.54558441227157, 0, 0, 7.66811580507233, 0, 0, 0, 0, 2.32369836935692e-14, 10.3691851174526, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.60576914948, 0, 1.09730925298582e-14, 0, -4.20458932936042, 0, -3.43303281162797, 0, 0, 19.6214168703486, 0, 0.611677741841187, 1.15273118941668e-14, 0, 0.529728463363971, 0, 0.432521479156778, 0, 1.6058715222196e-14, 0, -1.16729361337554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.53137212479104, -1.01690618327065e-14, 3.54562104171169, -2.50713268211205, 4.78713553878169, 0, -5.56626745075489, 0, -1.04880884817015, 0.741619848709564, 0, 18.8034951158403, 0, 1.68183573174418, -0.603122387046456, 0, 0.70128378121765, 0, 0.132137494528682, -0.0934353184302471, 0, 0, 0, -1.0082826842246e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07842270669413e-14, 0, 0, 0, 0, 0, -1.43736268462506e-14, 0, 1.40644587163015e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.5951288749407, 0, 0, 0, 10.0285307284481, 0, -0.767649473578742, 0, 0, 0, 0, 16.4130361329658, -1.65111444887587e-14, 0, -1.26347611061158, 0, 0.0967147429123319, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.96647939483827, 0, 8.12403840463594, -1.64130361329659, 0, 0, 11.7728501222091, 0, -2.40312296813958, 0.48550415622761, 0, 0, 0, 10.2761860629321, 0, 0, -1.48323969741912, 0, 0.302765035409732, -0.0611677741841287, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.05298244095218, 0, -1.58564993434419, 4.48489528465109, 4.28174419288837, 0, 0.191485421551277, 0, -3.75233260785876, -4.31161222746203, 0, 0, 0, 0, 18.8807171866294, 0, 0.844371341865034, -1.40094110434133e-14, 1.18187368057056, 1.04463861754666, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.321153829896, 0, 0, 0, 3.92428337406971, 0, 5.49285249860475, 1.63666823149722e-14, 0, 0, 0, 0, -1.21592089550238e-14, 0, 17.3044631365566, -1.98459387250407e-14, -1.73008591662713, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.78485070541082e-14, 0, 0, 0, 0, -1.10973688891617e-14, 0, 2.78631828811134e-14, 0, 0, 0, 0},
    {2.65329983228432, -1.19347092313647e-14, 4.1522061999051, 2.93605316083777, 0, -1.18275179297788e-14, 2.63248931621762, 0, 9.82591326180786, -2.8226127713774, 0, 0, 0, -1.25702218603545e-14, 0, 1.56555930303565e-14, 11.6081867662439, -2.18250550506549e-14, -3.09487177319471, 0.68387650554026, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47816108620456e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.14018107676926e-14, 0, 0, 1.65626348131594e-14, 0, -2.85468388090362e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.01017818278146, 0, 1.31743415178767e-14, 0, 0, 0, 8.91928088068604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.8558564884489, 1.01802247187699e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.2978250586152, 0, 1.49829835452877, 5.50917601898538, 0, 0, 0, 0, 6.64803945320941, 4.13676892548488, 0, 0, 0, 0, 0, 1.7956276449824e-14, 0, 0, 12.5636136423842, -3.55352656109504, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.18752842449636e-14, 0, -1.81638809042383e-14, 1.41922064378353e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87616630392937, 0, 0, 6.22830929985768, 0, 0, 0, 0, 1.27788751430286e-14, 11.0541524195338, 0, 0, 0, 0, -1.24460589269538e-14, 0, 1.31323882635267e-14, 0, 0, 11.6057691494799, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.83186700722507, 0, -4.41087092453692, -3.11895674167863, 16.6749979177077, 0, 2.13065307820924, 0, 1.73967095350099, 1.23013312825382, 0, -4.3665394383501, 0, -0.557935943461974, -3.78153408023783, 0, -0.483186700722511, 0, -0.394520289089677, -0.278967971730981, 23.6981011897578, 0, 0.490653381462665, 0, 0.0626933893908993, 0, 0.438853725736261, 0, 0.05607467216716, 0.380058475033047, 0, 0.0485620906056402, 0, 0.0396507809422115, 0.028037336083582, 0, 0, 0, 0, 0, 0, -1.4054211872897e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.91050664139875, -2.39578864559553e-14, 0, 0, 10.5706241650195, 0, -2.72554057547698, -1.52585599320562e-14, 0, 4.67332857821918, 0, -7.8670586781146, -2.04874497115916e-14, 0, -2.39719223514613, 0, 0.618094504365256, 0, 0, 0, 23.10555488766, 0, 1.62065746295906, 0, -0.469687194424187, 0, 0.790669146636839, 0, 0, 0.240926884676761, 0, -0.0621208350291021, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00653548533975e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.85449644663772, 0, 5.98171817966648, -2.48806675764062, 1.90029237516522, 1.1743756718293e-14, -0.339934634239532, 0, -2.35922146606161, 0.981306762925312, 1.26408545402584e-14, 9.95226703056241, 0, -6.45364422706459, -0.430945803685666, 0, 0.0770899289327487, 1.15125419787792e-14, 0.535021138879238, -0.222539456105688, 0, 0, 21.5273297444417, 0, 2.75066129614998, 0, -1.00024047132728, 0, 0.648615649442923, 0.0433116829031338, 0, -0.00774782937530679, 0, -0.0537716476536673, 0.022366056877342, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.54523626091315, 0, 0, 0, 6.71778024562961, 0, -0.609449400220043, 0, 0, 0, 1.34513153299042e-14, 14.6593983227032, 0, 0, -1.52344936219872, 0, 0.138210132827979, 0, 0, 0, 0, 0, 18.119501277094, 0, 0, 0, -1.47332496632642, 0, 0, 0.153112421864225, 0, -0.0138906409944101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.52336024752225, 0, 7.37120708415866, -1.62882203585592, 0, 0, 12.0171306297064, 0, -2.90724328050878, 0.642416074439622, 0, 0, 0, 13.9858820944259, 0, -1.58432045778813e-14, -2.72522906732402, 0, 0.659300804656272, -0.145686271816947, 0, 0, 0, 0, 10.8043830863937, 0, 0, 0, -1.40563403846548, 0, 0, 0.273895826790425, 0, -0.066262224031037, 0.0146420212340151, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00201541731901e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.3084006188056, 0, -1.26706433592532e-14, 0, -1.52362350055011, 0, 11.1963004093827, -1.80488219855834e-14, 0, 4.26614580154031, 0, 0.132992762321602, 0, -2.81814707567137e-14, -4.72217953828916, 0, -6.6768459701302, 0, 0, 0, 0, 0, 0, 0, 23.1532444221696, 0, 0.721778878560592, 0, 0, 1.11125127955291, 0, 1.19087439227729, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.75883613229288e-14, 0, 0},
    {3.51865775274499, 0, 1.92724822331887, 2.72554057547696, 1.73472166622177, 0, -2.01705689521106, 0, 3.42052627529741, -4.03112887414929, 0, 4.08831086321549, 0, 0.365669640132029, 5.37643791520786, 0, -6.25148194071026, 0, -2.03981013744549, 1.80803322065276, 0, 0, 0, 0, 0, 0, 22.1880978975596, 0, 1.98456380761454, -1.26521523890981, 0, 1.4711357857929, 0, 0.363818136386341, -0.294009452979946, 0, 0, 0, 0, 0, 0, 0, -1.54553205611541e-14, 0, 1.15952481122279e-14, 0, 0, 1.43620668240546e-14, 0, 0, 0, 0, -1.05116925393268e-14, 0, 0, -1.5785116269651e-14},
    {0, 1.41060126129509, 0, 0, 0, 3.63405410063598, 0, 2.50356888118884, 0, 0, 0, 0, 3.56857028479907, 0, 0, 11.263055412878, 0, -1.49298814645068, 1.38190240500657e-14, 0, 0, 0, 0, 0, 0, 0, 0, 19.3673596462205, 0, 0, -2.65048896124153, 0, 0.266287609379577, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.60041438401192e-14, 0, 0, 0, -1.39285916740261e-14, 0, 0, 0, 0, -1.79660973598228e-14, 0, 0},
    {2.30350221379959, 0, 4.4158804331639, 1.78428514239954, 0, 0, 4.2661458015403, 0, 7.83741028656788, -2.63899331455874, 0, 0, 0, 2.23427840700301, 0, 0, 13.2221027072096, 0, -4.67379217909115, 1.18363558466232, 0, 0, 0, 0, 0, 0, 0, 0, 12.1258851598179, 0, 0, -3.11150358274815, 0, 0.833612074594106, -0.192474367616157, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18321633904026e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.80903542948782e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.14718316987778, 1.13474050017499e-14, -0.86189160737134, 6.09449400220041, 1.55158222708543, 0, 0.0693888666488805, 0, -3.0594117081557, 1.80277563773198, 1.20363012761808e-14, -1.0807889766904e-14, 0, 0, 9.03122156537878, 0, 0.403888506800973, -1.0302390341142e-14, -3.67461994579464, -5.49650682721195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21.7841260588564, -1.02507068376833e-14, 0.974215733960552, 0, 1.78974858569576, 1.8079190879493, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.26168012376113, 1.18273446592099e-14, 1.57200977122562e-14, 0, 1.42204860051343, 0, 4.47852016375308, 0, 0, 0, 1.10987276082662e-14, 0, 0, 0, 8.27725128825318, 0, 5.37909280973871, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.9654813226339, 0, -2.61992366301004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.24759447164935e-14, 0, 0},
    {2.06031501455084, -1.74209683534797e-14, 2.25696201807214, 3.98978286964829, 0, 0, 0.953939201416936, 0, 8.01142041980429, 1.18019368870418, 0, 0, 0, 0, 0, 1.94785199387925e-14, 5.55254896421454, -2.57142210914795e-14, 9.62241374388478, -3.59830837050572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13.3932520322736, 0, -4.68666192508058, 1.18356086726904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06752353778446e-14, 0, 0, -2.32785032194072e-14, 1.53466649110978e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.09264703862701, 0, -1.95067300612033e-14, 0, 0, 0, 5.38682254607084, 0, 0, 0, 0, 0, 0, -1.87552786673862e-14, 0, 0, 13.4377817958112, 0, -1.51672730138571e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18.907670401189, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.38196745713692e-14, 0, 0},
    {1.78428514239955, 0, 0.814411017927951, 5.06770487035908, 0, 0, 0, 0, 4.01510046524765, 6.58672305740272, 0, 0, 0, -1.66919444397739e-14, 0, 0, 0, 0, 10.0159311874144, 2.83293314500741, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14.0929454377398, -4.55552790213387, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.0397792145408e-14, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.45686271816937, 0, 0, 5.07816454066238, 0, 0, 0, 0, 0, 10.0142755247554, 0, 0, 1.12786864624392e-14, 0, 0, 2.17930072871246e-14, 0, 0, 0, 13.8784813613723, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.5535587278944, 0, 0, 0, 0, 0, 0, 0, 1.19526598856153e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats1[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.47722557505166, 0, 0, 1.40751126032068e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06911007824451e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.76376261582596, 0, 0, 0, 0, 1.14716615426708e-14, 0, -1.04150722074414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.09700660014256e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747793, 7.24568837309471, 4.18330013267037, -0.591607978309947, 0, 0, 0, 0, 1.56424483988496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-2.64575131106459, 0, 9.66091783079295, 0.683130051063975, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00911719995905e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 0, 0, 4.34741302385685, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.19132134712707e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.24037034920393, 0, 0, 7.52994023880671, 0, 0, 0, 0, 1.5531385856235e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00830684779644e-14, 2.81476231211997e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847576, -1.67332005306815, -1.18321595661991, 7.74596669241484, -1.2, 0.346410161513776, -0.979795897113268, 0.282842712474625, 0.200000000000004, -1.25790505365476e-14, 0, 0, 1.05528898544744e-14, 0, 0, 0, -1.12515066521072e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 9.16515138991169, 7.09929573971953, -2.04939015319193, -0.414039335605418, -0.478091443733742, 0.169030850945706, -1.25706005145317e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07716088515501e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.8, -5.69209978830307, 4.3817804600413, -0.774596669241499, 0, 10.998181667894, 4.76235235991625, 0.962140470884724, -0.740656079818034, 0.13093073414159, 0, -1.12401392033415e-14, 0, -3.21594604552363e-14, -1.31211420896762e-14, 0, 0, 0, -1.70767152060798e-14, -1.55264798414045e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2325574011616e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.03479319100648e-14, 0, 0, 0, 0, 0, 0},
    {5.19615242270665, 0, -3.16227766016841, -2.2360679774998, 0, 0, 13.7477270848675, 0, 0.534522483824853, 0.37796447300922, 0, 0, 0, -3.83748191193675e-14, 0, 0, 2.1315292421099e-14, 0, -1.62182060497289e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.68659168002595e-14, 0, 0, 0, 0, 1.40965823998977e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974982, 2.12132034355964, -0.40824829046386, 3.17542648054296, 0, 0, 0, 7.17137165600636, -1.38013111868469, -1.56144011671765, 0, 0, 0, 0, 1.60086230480545e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 2.73861278752582, 1.58113883008418, 2.4596747752498, 0, 0, 0, 9.25820099772551, 5.34522483824851, -1.20948631362952, 0, 0, 0, 0, 1.34977494398807e-14, 1.99156888319442e-14, 0, 0, -2.15636170105579e-14, 2.42856949828063e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16523470700075e-14, 0, 0, -1.09194628747146e-14, 1.11395268009851e-14},
    {-1.80000000000001, -1.20044841895264e-14, 3.6514837167011, -2.84018778721876, 0, -1.08976206329851e-14, -1.29819986860444e-14, 0, 12.3442679969674, 1.39659449751036, 0, 0, 0, 0, -1.50769312330474e-14, 1.13191919416064e-14, 1.11250942527182e-14, -1.93488728499311e-14, -2.44419195896427e-14, 1.02799713186386e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.16729566976785e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.23874183066048e-14, 0, -1.16953047556544e-14, 0},
    {1.27279220613579, 0, 0, 3.83405790253616, 0, 0, 0, 0, 1.22025515571026e-14, 5.18459255872629, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.20454076850486, 0, 0, 6.6407830863536, 0, 0, 0, 0, 2.01466364901978e-14, 8.97997772825746, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573302, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341419, -1.71651640581399, 0.594618725379066, 0.420458932936045, 9.8107084351743, -1.18450885369836, 0.305838870920594, -0.105945692672787, -1.02581475831037, 0.264864231681993, -0.09175166127617, 0.21626073957839, -0.0749149177264317, -0.0529728463363858, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403131, -2.78313372537745, -0.908295106229251, -0.524404424085076, 0.370809924354782, 11.1242977306435, 9.40174755792014, -2.42752078113806, 0.840917865872085, -0.301561193523232, -0.794200206656966, 0.350641890608823, 0.114434427054266, 0.0660687472643449, -0.0467176592151217, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747036, 3.74574588632197, -1.05945692672796, -8.09173593712688, 5.01426536422408, 1.80936716113936, -0.383824736789376, -1.10800657553489, 0.313391585263996, 0, 12.7134831207354, 8.2065180664829, -2.84282124887607, 1.01946290306866, -0.631738055305799, -0.227958835180076, 0.0483573714561715, 0.139595707137601, -0.0394836284566235, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 7.03562363973514, 4.06201920231798, -0.820651806648283, 0, -6.79705818718658, 5.88642506110458, -2.08116553882673, -1.2015614840698, 0.242752078113809, 0, 0, 14.8323969741913, 5.13809303146605, 0, 0.856348838577665, -0.741619848709558, 0.262202212042531, 0.151382517704873, -0.0305838870920523, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-3.42539535431071, 0, 9.38083151964686, 1.89521416591735, 0, 0, -3.39852909359328, 0, -2.77488738510233, -0.560611910581382, 0, 0, 0, 17.7988763690296, 0, 0, 0.4281744192888, 0, 0.34960294939005, 0.0706304617818509, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.19229891779162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172086, 2.24244764232556, 2.14087209644419, -0.331662479035536, 0.0957427107756383, 6.49923072370878, -1.87616630392937, -2.15580611373101, 0, 0, 0, 0, 9.4403585933147, -1.46249406456535, 0.422185670932515, -2.04706526287666, 0.590936840285285, 0.522319308773338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.05431025609327e-14, 0, 0},
    {1.71269767715535, 1.16057691494799, 1.34011878852097, 1.89521416591737, 2.53311402559511, 1.96214168703485, -0.56642151559888, 2.74642624930238, 3.17129986868838, -1.82198870938951, 0, 0, 0, 0, 11.1699829238239, 8.6522315682783, -2.49768411251823, -0.865042958313582, -0.998865569685885, 0.441440386136645, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.03475770530409e-14, 1.29209414685306e-14, 0, 0, 0, 0, 0, 0, 1.60120018608036e-14, 0, 0, -1.26160718303102e-14, 0},
    {1.32664991614215, -2.69693703815181, 2.07610309995255, 1.46802658041886, 0, 3.03973683071412, 1.3162446581088, -6.38211787508102, 4.91295663090393, -1.4113063856887, 0, 0, 0, -1.51913273054672e-14, -2.55599087474972e-14, 13.4039795085888, 5.80409338312195, 2.01017818278148, -1.54743588659735, 0.341938252770119, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2030832256185e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.39126707790871e-14, 1.05862461256535e-14, 0, 0, 0, 0, -1.27456553064636e-14, 0, 1.42541964027269e-14, 0, 0, -1.47910175216627e-14, 0},
    {3.82970843102536, 0, -1.49829835452879, 4.23782770691178, 0, 0, 3.79967103839267, 0, -3.54562104171168, -4.07409060843207, 0, 0, 0, 0, 0, 0, 16.7549743857359, 0, 1.11676565710082, 0.987090711415275, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.21705165839016e-14, 0, 0, 0, 0, 0, -1.21257170970779e-14},
    {1.48323969741913, 1.00508909139073, -0.193429485824663, 3.55615782880927, 0, 0, 0, 4.45964044034302, -0.858258202906985, 2.67027285925187, 0, 0, 0, 0, 0, 0, 0, 8.42792824422443, -1.62195554683794, -2.29379153190447, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.14891252930761, 1.29756443747035, 0.749149177264386, 2.75458800949269, 0, 0, 0, 5.75737105184054, 3.3240197266047, 2.06838446274244, 0, 0, 0, 0, 0, 1.63535268777982e-14, 0, 10.8804085776374, 6.28180682119208, -1.77676328054753, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.10314190327717e-14, 0, 0, 0},
    {-1.32664991614216, -1.36618976334274e-14, 1.73008591662712, -3.18072425757423, 0, 0, 0, 0, 7.67649473578737, -2.38836465270395, 0, 0, 0, 0, 0, 1.75825778552664e-14, -1.61250752397677e-14, -2.1076052013037e-14, 14.5072114368499, 2.05162951662072, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.938083151964686, 0, 0, 3.11415464992885, 0, 0, 0, 0, 0, 5.52707620976691, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62480768092719, 0, 0, 5.39387407630363, 0, 0, 0, 0, 1.11162283755055e-14, 9.57317681262151, 0, 0, 0, 0, -1.0778909817559e-14, 0, 1.14540099911627e-14, 0, 0, 10.0508909139073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993662, 0.86983547675049, 0.615066564126915, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.278967971730982, -1.89076704011892, 0.627677936394719, -0.241593350361255, 0.512496888990065, -0.197260144544833, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954525, -1.03851746182648, 0.219426862868131, -0.0728431359084663, 0.0280373360835797, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711053, 0.0140186680417948, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725405, 3.45525332069938, 0.997445717412069, -1.41060126129511, 3.23209352764251, 5.28531208250978, -2.8908723349783, -1.3627702877385, -0.393397896234731, 0.556348640264194, 2.3366642891096, 9.0278480722887, -3.93352933905729, 1.64018416088946, -0.732969916135167, -1.19859611757306, 0.655588223176202, 0.309047252182634, 0.0892142571199805, -0.12616801237611, 13.0996183150502, 11.55277744383, -2.44096975264614, 0.810328731479527, -0.311895674167858, -0.234843597212094, -0.907332870306511, 0.39533457331842, -0.16484471056831, 0.0736662483163195, 0.120463442338379, -0.0658890955530703, -0.0310604175145504, -0.00896637020658568, 0.0126803623514093, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066012, 2.99085908983323, -1.24403337882031, 0.950146187582609, 5.74064456311311, -0.169967317119758, -0.721110255092799, -1.17961073303081, 0.490653381462658, -10.3037210107158, 4.9761335152812, 5.78174466995658, -3.2268221135323, -0.215472901842833, -1.3018558182182, 0.0385449644663712, 0.163532434528623, 0.267510569439619, -0.111269728052842, 0, 14.555131461167, 10.7636648722209, -3.5732138395088, 1.37533064807499, 1.03556292536503, -0.500120235663637, -0.581087203147972, 0.324307824721462, 0.0216558414515678, 0.13084143273245, -0.0038739146876535, -0.0164356280722662, -0.0268858238268361, 0.011183028438671, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585591, 0.772618130456579, 3.86595114186566, -1.05140010313427, 9.1544290607646, 3.35889012281481, 3.878512233171, -0.304724700110019, -1.52475169285616, 0.414677792940096, 0, -9.46260092820841, 7.32969916135161, 0.564240504518017, -2.07602937339135, -0.761724681099362, -0.879563899362184, 0.0691050664139924, 0.345781182036189, -0.0940400840863445, 0, 0, 16.3745228938128, 9.05975063854702, -3.48709964663734, 0, 0.951027176355638, -0.736662483163211, -0.0567083043941542, 0.208648802584722, 0.0765562109321131, 0.0883994979795834, -0.006945320497205, -0.0347523163751387, 0.00945138406569424, 0, 0, 0, 0, 0, -1.0442355414814e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, -6.78263087840204, 3.68560354207932, -0.814411017927972, 0, 10.0216907612581, 6.00856531485321, 2.67510569439611, -1.45362164025439, 0.321208037219812, 0, 0, -7.5700807425667, 6.99294104721295, 0, -2.27270584034422, -1.36261453366201, -0.60665694841583, 0.329650402328123, -0.0728431359084861, 0, 0, 0, 18.7137404500718, 5.40219154319687, 0, 0, 0.760821741084505, -0.702817019232738, 0, 0.228415531250637, 0.136947913395213, 0.0609713174047677, -0.0331311120155155, 0.00732101061700594, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.13362172336404e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.09901951359279, 0, -4.65474668125631, -3.2914029430219, 0, 1.1660466779942e-14, 13.490737563232, 0, 1.83585684909537, 1.29814682728311, 0, 0, 0, -3.53270434653113, 0, -2.35369542990423e-14, -3.05941170815564, 0, -0.416333199893202, -0.294392028877585, 0, 0, 0, 0, 21.8326971917504, 0, 0, 0, 0.355050145839434, 0, 0, 0.307482445914322, 0, 0.0418430609640539, 0.0295875121532883, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.51979983923137e-14, 1.31936453578951e-14, 0, 0, 0, 1.03690494372784e-14, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.1542003094028, -1.09264703862703, 1.54523626091313, 2.95048422176041, -0.76181175027506, 0.263899331455881, 5.59815020469135, -1.93925611658552, -2.28543525082516, 2.13307290077015, -0.257539376818861, 0.0664963811608048, -0.0230350221379904, 9.14446135479764, -2.36108976914457, 0.817905488277896, -3.3384229850651, 1.1564636454577, 1.02505848514081, 0, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280294, -0.125015768949701, -2.15192884958005, 0.555625639776455, -0.192474367616153, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07577610922145e-14, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659431, 1.36277028773846, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871973, 1.7102631376487, -2.01556443707465, 2.41867732448956, 2.04415543160775, -0.527798662911745, 0.182834820066009, 2.68821895760391, 7.07977053255618, -3.12574097035514, -1.76652739792483, -1.01990506872274, 0.904016610326372, 0, 0, 0, 0, 0, 13.1266557397187, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454906, -1.66605356688628, 0.735567892896448, 0.315075748468082, 0.181909068193171, -0.147004726489972, 0, 0, 0, 0, 0, 0, 0, -1.19843614648072e-14, 0, 1.70149229231864e-14, 0, 0, 1.13549801043889e-14, 0, 0, 0, 0, 0, -1.36131053899298e-14, 0, -1.03720200830826e-14},
    {1.48690428533295, 0.705300630647538, 2.0360275448199, 1.15175110689976, -2.93221479395416, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967313, 0, 2.76420265655951, 1.78428514239953, -0.618094504365259, -9.08783875864328, 5.631527706439, 2.03210252328835, -0.746494073225345, -2.15494277062552, 0.764033484562584, 0, 0, 0, 0, 0, 0, 15.0018922739643, 9.68367982311023, -3.3545250915713, 2.13860408462396, -1.32524448062077, -0.478206411017798, 0.133143804689786, 0.384353057392894, -0.124241670058205, 0, 0, 0, 0, 0, 0, 0, -1.06952639252695e-14, 0, 1.24523903365769e-14, 0, 0, 1.13816587687308e-14, -1.06362575304491e-14, 0, 1.13288756971e-14, 0, -1.21696875531858e-14, -1.03472165536955e-14, 0, -1.2600380808192e-14},
    {1.15175110689979, 3.82426463519456, 2.20794021658195, 0.892142571199782, 0, -2.46306042692148, 2.13307290077015, 6.78739640804928, 3.91870514328393, -1.31949665727936, 0, 0, 3.22490309931941, 1.11713920350152, 1.32014938580353e-14, -7.63378455726037, 6.61105135360481, -4.04762275910198, -2.33689608954557, 0.591817792331178, 0, 0, 0, 0, 0, 0, 0, 17.5022076529583, 6.06294257990892, 0, 1.79642743108413, -1.55575179137408, 0.721929233499942, 0.416806037297049, -0.096237183808073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.27043515283634e-14, 0, 0},
    {-2.65985524643219, 1.31595766643121e-14, 5.09901951359278, -2.06031501455086, 0, 1.2454667647061e-14, -1.23153021346074, 0, 9.04986187739902, 3.04724700110024, 0, 0, 0, 3.8698837191833, 1.50559796220762e-14, -1.82444885045587e-14, -3.81689227863021, 2.48972418334491e-14, -5.39683034546926, -1.36674464685442, 0, 0, 0, 0, 1.11023026702718e-14, 0, 0, 0, 21.00264918355, 0, 0, 0.898213715542071, 0, 0.962572311333264, 0.222250255910579, 0, 0, 0, 0, 0, 0, 0, 0, 1.30048635444922e-14, 0, -2.8168247578276e-14, 0, 0, 0, 0, 0, -1.22574722556207e-14, 0, 0, 0, 0},
    {1.57359158493889, 1.49284005458437, -0.430945803685673, 3.04724700110021, 0.775791113542717, -0.120185042515475, 0.0346944333244397, 5.29905651979671, -1.52970585407785, 0.901387818865986, 0, 0, 0, 0, 4.51561078268939, -0.699555414372413, 0.201944253400488, 6.36462844462229, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980277, -3.09993548319961, 0.894874292847881, 0.903959543974646, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880569, 0.728431359084677, 2.57539376818856, 0.917928424547677, 0.71102430025671, -0.205255035576791, 2.23926008187654, 2.58567482211399, 0.761811750275056, 0, 0, 0, 0, 5.34294273196306, 4.13862564412661, -1.19471831485579, 2.68954640486934, 3.1056206816986, -2.32269806558124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.8876627769294, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.76398525469263, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, -1.46593983227033, 1.12848100903608, 1.99489143482414, 0, 1.10151410945722, 0.476969600708474, -5.20357020296093, 4.00571020990214, 0.590096844352093, 0, 0, 0, 0, -1.06679106813357e-14, 6.4115312783557, 2.77627448210726, -6.24994106094659, 4.81120687194238, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.4651953323153, 6.69662601613678, 3.0440762145518, -2.34333096254029, 0.591780433634522, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.29095028749876e-14, 0},
    {2.97380857066591, 0, -0.814411017927952, 5.75875553449896, 0, 0, 1.37689263682153, 0, -2.89087233497831, 1.70346285967311, 0, 0, 0, 0, 0, 0, 8.01441409794461, 0, -3.47218947830365, -5.19371076584693, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.3314941653941, 0, 1.69115345252877, 1.70832296330021, 0, 0, 0, 0, 0, 0, 0, 0, 1.01698699146052e-14, 0, 0, 0, 0, 0, 1.04634390793553e-14, 0, 0, -1.24951195166655e-14, 0, 0, 0},
    {1.15175110689979, 0.546323519313506, -0.105140010313426, 3.27118942773248, 0, 0, 0, 2.69341127303542, -0.518347241175112, 4.25171145123352, 0, 0, 0, 0, -1.50547813101981e-14, 0, 0, 6.71889089790563, -1.29305115618718, 1.82865048192211, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635795, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199775, 0.705300630647549, 0.407205508963978, 2.53385243517953, 0, 0, 0, 3.47717900165117, 2.00755023262382, 3.29336152870136, 0, 0, 0, 0, 0, 0, 0, 8.6740508508577, 5.0079655937072, 1.41646657250369, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.2048487632307, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.09128807146668e-14, 0, 0, 0, 0, 0, 0, 0},
    {-1.03015750727542, 0, 0.940400840863396, -2.92584077107542, 0, 0, 0, 0, 4.6362386688682, -3.80284633026898, 0, 0, 0, 0, 1.68691976659293e-14, 0, -1.57365387853084e-14, 0, 11.5654011344769, -1.63559471386627, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.2731316843076, 2.63013526059784, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.15424097657397e-14, 0, 0, -1.09417683247237e-14},
    {0.728431359084685, 0, 0, 2.53908227033119, 0, 0, 0, 0, 0, 5.00713776237767, 0, 0, 0, 0, 0, 1.10587002885661e-14, 0, 0, 0, 6.93924068068616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6.2767793639472, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376112, 0, 0, 4.39781949681095, 0, 0, 0, 0, 0, 8.67261700493487, 0, 0, 0, 0, 0, 1.88729435175678e-14, 0, 0, 0, 12.0191174248973, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8717007662564, 0, 0, 0, 0, 0, 0, 0, 1.03515041106796e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats2[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.82574185835055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.16397779494323, 0, 0, 1.29984998459287e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00622635224035e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.763762615825961, 0, 0, 0, 0, 0, 0, -1.12787476580434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.00211722600663e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747792, 1.44913767461894, 4.18330013267037, -0.591607978309952, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00245830515541e-14, 0, 0, 0, 0, -1.10514927319296e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.3228756555323, 0, 3.86436713231717, -0.341565025531983, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 7.09929573971953, 0, 4.34741302385685, 0, 1.16116958235673e-14, 0, 0, 1.97703621279534e-14, 0, 0, 0, 0, 0, 1.19025197250128e-14, 0, 0, 0, 0, 1.15385132004597e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.08012344973465, 0, 7.09929573971953, 2.50998007960224, 0, 0, 0, 0, 1.2984107062089e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.21524148795069e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18401735111452e-14, 0},
    {-3.81881307912987, 0, 1.20295604068146e-14, 8.87411967464943, 0, 1.13142405616155e-14, 0, 0, 0, 0, 0, 0, 0, 1.25032789779226e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847577, -1.67332005306815, -1.18321595661992, 7.74596669241485, -1.2, 0.346410161513777, -0.979795897113271, 0.282842712474625, 0.200000000000004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 1.30930734141596, 7.09929573971954, -2.04939015319192, -0.41403933560542, -0.47809144373374, 0.169030850945707, 0, 0, 0, -1.01115137587522e-14, 0, 0, -1.19390261962029e-14, 0, -1.01768611746272e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.80000000000001, 0.632455532033679, 4.38178046004131, -0.77459666924148, 0, 3.14233761939829, 4.76235235991626, -0.106904496764969, -0.740656079818034, 0.130930734141593, 0, 0, 0, -1.8947471087206e-14, 0, 0, 1.24782077916574e-14, 0, -1.57210017045496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03923048454133, 0, 3.16227766016837, -0.447213595499959, 0, 0, 5.89188303637179, 0, -0.534522483824846, 0.0755928946018422, 0, 0, 0, -1.32102604647237e-14, 0, 0, 1.28087199916397e-14, 0, -1.09806075799093e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974981, 2.12132034355963, -0.408248290463856, 3.17542648054296, 9.07114735222146, 0, 0, 7.17137165600636, -1.3801311186847, -1.56144011671765, 0, 0, 0, 1.05914511754833e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 0.547722557505163, 1.58113883008417, 2.45967477524979, 0, 9.07114735222145, 0, 1.85164019954509, 5.34522483824851, -1.20948631362952, 0, 0, 0, -1.11256081632663e-14, 0, 0, 0, 0, -2.1484687092401e-14, 1.51441359452775e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.03593488692865e-14, 0, -1.10855626475394e-14, 0},
    {0.900000000000005, 0, 1.46059348668043, 1.4200938936094, 0, 0, 9.07114735222145, 0, 4.93770719878695, -0.698297248755175, 0, 0, 0, 0, 0, 0, 2.13673764691668e-14, 0, -1.74964245430402e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07342779687771e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.27279220613579, -6.2609903369994, 0, 3.83405790253616, 0, -1.49065575463019e-14, 0, 10.5830052442584, 0, 5.18459255872628, 0, 0, 0, 0, 0, 1.30274753827373e-14, 0, 1.32206973351868e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.734846922834947, -1.04202290943615e-14, -6.26099033699941, 2.21359436211788, 0, 0, 0, 0, 10.5830052442584, 2.99332590941916, 0, 0, 0, 0, 0, 0, 0, 0, -1.10071029919877e-14, 1.58024635044107e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.71576766497729, 0, 0, -4.69574275274958, 0, -1.13946705425176e-14, 0, 0, 1.07947992678322e-14, 12.69960629311, 0, 0, 0, -2.12576157138471e-14, -1.14768107589579e-14, 0, 0, 0, 0, -1.45786160921091e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.11099168517849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16464450008484e-14, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573303, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341418, -1.71651640581399, 0.594618725379066, 0.420458932936047, 9.81070843517429, -1.18450885369836, 0.305838870920593, -0.105945692672788, -1.02581475831037, 0.264864231681991, -0.0917516612761725, 0.216260739578389, -0.0749149177264338, -0.0529728463363881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403132, -2.78313372537745, -0.908295106229256, -0.524404424085065, 0.370809924354784, 1.23603308118261, 9.40174755792014, -2.42752078113806, 0.840917865872082, -0.301561193523232, -0.794200206656965, 0.350641890608817, 0.114434427054266, 0.0660687472643408, -0.0467176592151232, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.09687112732375e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747035, 3.74574588632197, -1.05945692672795, 0.404586796856342, 5.01426536422407, 1.80936716113936, -0.38382473678937, -1.10800657553489, 0.313391585264001, 0, 2.82521847127454, 8.2065180664829, -2.84282124887607, -0.0509731451534336, -0.631738055305794, -0.227958835180071, 0.0483573714561653, 0.139595707137598, -0.0394836284566152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 0.335029697130247, 4.06201920231797, -0.820651806648293, 0, 1.69926454679664, 5.88642506110457, -0.0991031208965088, -1.20156148406979, 0.242752078113803, 0, 0, 4.94413232473044, 5.13809303146604, 0, -0.214087209644424, -0.741619848709556, 0.0124858196210727, 0.151382517704866, -0.030583887092065, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.856348838577677, 0, 2.68023757704196, -0.473803541479351, 0, 0, 5.09779364038993, 0, -0.792824967172094, 0.140152977645347, 0, 0, 0, 7.9106117195687, 0, 0, -0.642261628933262, 0, 0.0998865569685846, -0.0176576154454718, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172091, 2.24244764232556, 2.14087209644418, -0.331662479035544, 0.0957427107756388, 6.49923072370878, -1.87616630392938, -2.15580611373101, 11.0554159678513, 0, 0, 0, 9.44035859331469, -1.46249406456535, 0.42218567093252, -2.04706526287666, 0.590936840285289, 0.522319308773339, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.71269767715534, 1.160576914948, 1.34011878852098, 1.89521416591738, 0.361873432227874, 1.96214168703486, -0.566421515598884, 2.74642624930237, 3.17129986868839, -1.82198870938951, 0, 11.0554159678513, 0, 0, 1.59571184626056, 8.6522315682783, -2.49768411251823, -0.865042958313566, -0.99886556968588, 0.441440386136656, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.67261791825198e-14, 0, 0, 0, 0, 0, 0, 1.30794708089814e-14, 0, 0, -1.0374605283645e-14, 0},
    {1.32664991614216, 0.29965967090575, 2.07610309995255, 1.46802658041888, 0, 0.868496237346876, 1.31624465810881, 0.709124208342335, 4.91295663090393, -1.4113063856887, 0, 0, 11.0554159678513, 0, 0, 3.82970843102537, 5.80409338312195, -0.223353131420173, -1.54743588659735, 0.341938252770127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.50077495359425e-14, 0},
    {0.765941686205065, 0, 1.49829835452878, 0.84756554138235, 0, 0, 1.62843044502543, 0, 3.54562104171167, -0.81481812168641, 0, 0, -1.13658139175294e-14, 11.0554159678513, 0, 0, 7.18070330817253, 0, -1.11676565710083, 0.197418142283055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 1.00508909139074, -0.193429485824671, 3.55615782880925, -8.46157280212813, 0, 0, 4.45964044034302, -0.85825820290699, 2.67027285925187, 0, 0, 0, -1.0471287355653e-14, 12.4373429638327, 0, 0, 8.42792824422442, -1.62195554683794, -2.29379153190449, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.1489125293076, 0.259512887494065, 0.749149177264405, 2.75458800949269, 0, -8.46157280212812, 0, 1.15147421036811, 3.3240197266047, 2.06838446274243, 0, 1.28739579884012e-14, 0, 1.43483072465507e-14, 0, 12.4373429638328, 0, 2.17608171552748, 6.28180682119208, -1.77676328054752, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.1069077748037e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.66332495807107, 0, 0.692034366650861, 1.5903621287871, 0, 0, -8.46157280212812, 0, 3.07059789431495, 1.19418232635199, 0, 0, 0, 1.58467639420295e-14, 0, 1.59120238800483e-14, 12.4373429638327, -1.09120262064712e-14, 5.80288457473997, -1.02581475831036, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.17878507096849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.93808315196469, 7.62808987244124, 0, 3.11415464992885, 0, 0, 0, -7.5213980463361, 0, 5.52707620976692, -1.06609684736951e-14, 0, 0, 0, -1.38639078823126e-14, 0, 1.48563198377856e-14, 14.2141062443803, 1.67911998216622e-14, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.541602560309069, 0, 7.62808987244124, 1.79795802543454, 0, 0, 0, 0, -7.5213980463361, 3.19105893754051, 0, 0, 0, 0, 0, 0, 0, 0, 14.2141062443803, 3.35029697130244, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-5.3615918034355, 0, 0, 8.89943818451481, 0, 0, 0, 0, 0, -5.26497863243528, 0, 0, 0, 1.27752977123219e-14, 0, 0, 0, -1.16097894474412e-14, 1.10230978840132e-14, 16.583123951777, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993663, 0.86983547675049, 0.615066564126914, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.27896797173098, -1.89076704011892, 0.627677936394719, -0.241593350361254, 0.512496888990065, -0.197260144544832, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954516, -1.03851746182648, 0.219426862868131, -0.0728431359084662, 0.0280373360835794, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711051, 0.0140186680417946, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725404, 3.45525332069938, 0.997445717412055, -1.41060126129511, 3.23209352764251, 5.28531208250977, -2.8908723349783, -1.3627702877385, -0.393397896234727, 0.556348640264192, 2.33666428910959, 9.02784807228868, -3.93352933905729, 1.64018416088945, -0.732969916135173, -1.19859611757306, 0.655588223176204, 0.309047252182629, 0.0892142571199751, -0.126168012376112, 1.19087439227729, 11.55277744383, -2.44096975264613, 0.810328731479525, -0.311895674167859, -0.234843597212091, -0.907332870306511, 0.395334573318418, -0.164844710568308, 0.0736662483163234, 0.120463442338379, -0.0658890955530668, -0.0310604175145528, -0.00896637020658492, 0.012680362351411, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.04376434543615e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066013, 2.99085908983323, -1.24403337882031, 0.950146187582614, 5.74064456311311, -0.169967317119763, -0.721110255092803, -1.1796107330308, 0.490653381462655, 0.294392028877601, 4.97613351528119, 5.78174466995657, -3.2268221135323, -0.215472901842835, -1.3018558182182, 0.0385449644663701, 0.16353243452863, 0.267510569439621, -0.111269728052844, 0, 2.64638753839399, 10.7636648722209, -3.5732138395088, 1.37533064807499, -0.0295875121532872, -0.500120235663636, -0.581087203147972, 0.324307824721462, 0.0216558414515659, 0.130841432732449, -0.00387391468765372, -0.0164356280722662, -0.0268858238268349, 0.0111830284386701, 0, 0, 0, 0, -1.28026114151189e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585592, 0.772618130456574, 3.86595114186566, -1.05140010313427, 0.160604018609906, 3.35889012281481, 3.878512233171, -0.30472470011002, -1.52475169285616, 0.414677792940093, 0, 1.13551211138501, 7.32969916135161, 0.564240504518021, -0.0364215679542351, -0.761724681099363, -0.879563899362178, 0.0691050664139924, 0.345781182036181, -0.094040084086348, 0, 0, 4.46577897103986, 9.05975063854702, -3.48709964663735, 0, -0.114123261162678, -0.736662483163213, -0.0567083043941508, 0.00366050530850509, 0.076556210932112, 0.0883994979795821, -0.00694532049720509, -0.0347523163751398, 0.00945138406569354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, 0.199489143482414, 3.68560354207933, -0.814411017927961, 0, 1.0278657191034, 6.00856531485322, -0.0786795792469394, -1.45362164025439, 0.321208037219813, 0, 0, 3.02803229702669, 6.99294104721296, 0, -0.23309803490711, -1.36261453366201, 0.0178428514239989, 0.329650402328134, -0.072843135908474, 0, 0, 0, 6.80499652729884, 5.40219154319687, 0, 0, -0.304328696433804, -0.70281701923274, 0, 0.0234272339744255, 0.136947913395213, -0.00179327404131462, -0.0331311120155176, 0.00732101061700848, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.728431359084683, 0, 2.32737334062817, -0.470200420431708, 0, 0, 4.49691252107735, 0, -0.917928424547684, 0.185449546754732, 0, 0, 0, 7.06540869306229, 0, -1.02749514743743e-14, -1.01980390271856, 0, 0.208166599946621, -0.0420560041253766, 0, 0, 0, 0, 9.92395326897747, 0, 0, 0, -0.710100291678883, 0, 0, 0.102494148638111, 0, -0.0209215304820291, 0.00422678745046967, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.15420030940281, -1.09264703862702, 1.54523626091312, 2.95048422176041, -0.761811750275057, 0.263899331455879, 5.59815020469135, -1.93925611658552, -2.28543525082517, 2.13307290077016, -0.257539376818857, 0.0664963811608075, -0.0230350221379865, 9.14446135479764, -2.36108976914457, 0.817905488277892, -3.3384229850651, 1.1564636454577, 1.02505848514081, 13.0453753561106, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280297, -0.125015768949703, -2.15192884958005, 0.555625639776455, -0.192474367616155, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659433, 1.36277028773847, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871972, 1.7102631376487, -2.01556443707464, 0.268741924943282, 2.04415543160775, -0.527798662911754, 0.182834820066007, 2.68821895760393, 7.07977053255618, -3.12574097035514, -1.76652739792482, -1.01990506872274, 0.904016610326381, 0, 13.0453753561106, 0, 0, 0, 1.4585173044132, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454905, -1.66605356688628, 0.735567892896452, 0.315075748468088, 0.181909068193171, -0.14700472648997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.76253856517652e-14, 0, 0, 0, 0, 0, 0, 0, -1.02644438987504e-14, 0, 0, 0},
    {1.48690428533294, 0.705300630647549, 2.0360275448199, 1.15175110689978, 0.146610739697706, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967312, 1.19461378362765e-14, 0.614267257013224, 1.78428514239954, -0.61809450436525, 0.454391937932155, 5.631527706439, 2.03210252328835, -0.746494073225347, -2.1549427706255, 0.764033484562606, 0, 0, 13.0453753561106, 0, 0, 0, 3.33375383865873, 9.68367982311023, -3.3545250915713, -0.1069302042312, -1.32524448062077, -0.47820641101779, 0.133143804689788, 0.384353057392899, -0.124241670058195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.33133676896015e-14, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.182107839771165, 2.20794021658195, 0.892142571199765, 0, 0.615765106730381, 2.13307290077015, 0.323209352764259, 3.91870514328393, -1.31949665727937, 0, 0, 1.07496769977315, 1.11713920350151, 0, 1.90844613931509, 6.61105135360481, -0.192743940909622, -2.33689608954558, 0.591817792331162, 0, 0, 0, 13.0453753561106, 0, 0, 0, 5.83406921765277, 6.06294257990893, 0, -0.449106857771032, -1.55575179137408, 0.0343775825476156, 0.416806037297052, -0.0962371838080755, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.664963811608044, 0, 1.45686271816936, 0.515078753637704, 0, 0, 1.84729532019112, 0, 2.58567482211401, -0.761811750275049, 0, 0, 0, 1.71994831963702, 1.05069828708852e-14, -1.56804141189904e-14, 5.72533841794525, 1.28292660358282e-14, -1.54195152727692, 0.341686161713602, 0, 0, 0, 0, 13.0453753561106, 0, 0, 0, 9.33451074824443, 0, 0, -1.34732057331309, 0, 0.275020660380932, -0.0555625639776445, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.3208801604271e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.57359158493888, 1.49284005458436, -0.430945803685674, 3.04724700110019, 0.775791113542713, -0.120185042515468, 0.0346944333244412, 5.29905651979672, -1.52970585407786, 0.901387818865991, -10.576283741361, 0, 0, 0, 4.51561078268937, -0.699555414372417, 0.20194425340049, 6.36462844462228, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980274, -3.09993548319962, 0.894874292847881, 0.903959543974651, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880566, 0.72843135908468, 2.57539376818856, 0.131132632078236, 0.71102430025671, -0.205255035576782, 2.23926008187654, 2.585674822114, 0.761811750275049, 0, -10.576283741361, 0, 0, 0.763277533137571, 4.1386256441266, -1.19471831485579, 2.68954640486935, 3.1056206816986, -2.32269806558126, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 1.84109468241848, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.763985254692621, 0, 0, 0, 0, 0, 0, 0, 0, -1.35629152642122e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, 0.162882203585585, 1.12848100903607, 1.99489143482414, 0, 0.31471831698778, 0.476969600708467, 0.578174466995659, 4.00571020990214, 0.590096844352089, 0, 0, -10.576283741361, 0, -1.14841985676491e-14, 1.83186607953021, 2.77627448210727, 0.694437895660718, 4.8112068719424, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 4.41862723780437, 6.69662601613678, -0.338230690505757, -2.34333096254029, 0.591780433634517, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.594761714133188, 0, 0.814411017927947, 1.1517511068998, 0, 1.39874122938874e-14, 0.590096844352078, 0, 2.89087233497829, 0.340692571934624, 0, 0, 1.04169365895487e-14, -10.576283741361, 0, 0, 3.43474889911913, 0, 3.47218947830366, -1.03874215316938, 0, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 8.28492607088319, 0, -1.69115345252878, 0.341664592660038, 0, 0, 0, 0, 0, 0, 0, 0, 1.04348006604658e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.546323519313508, -0.105140010313428, 3.27118942773248, 9.65295620481433, 0, 0, 2.69341127303542, -0.51834724117513, 4.25171145123353, 0, 0, 0, 0, -9.91526600752599, 0, 0, 6.71889089790562, -1.29305115618718, 1.82865048192213, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635794, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199779, 0.141060126129514, 0.407205508963965, 2.53385243517954, 0, 9.65295620481433, 0, 0.695435800330239, 2.00755023262382, 3.29336152870136, 0, 0, 0, -1.35671976966506e-14, 0, -9.91526600752598, 0, 1.73481017017155, 5.00796559370719, 1.4164665725037, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 2.44096975264614, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.515078753637729, 0, 0.376160336345341, 1.46292038553772, 0, 0, 9.65295620481433, 0, 1.85449546754728, 1.90142316513449, 0, 0, 0, -2.50850100800641e-14, 0, -1.15008035787034e-14, -9.91526600752594, 0, 4.62616045379078, 0.817797356933146, 0, 0, 0, 0, -1.24919104274206e-14, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 6.50925267372303, -1.31506763029891, 0, 0, 0, 0, 0, -1.31906496265821e-14, 0, 0, 1.19318131197878e-14, -1.10848897873181e-14, 1.67436700563434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.72843135908468, -7.94708263760856, 0, 2.53908227033116, 0, 0, 0, 10.2207771580387, 0, 5.00713776237768, 0, 0, 1.91058434396028e-14, 0, -1.58541378910724e-14, 1.90136980421293e-14, -1.88766397254795e-14, -8.49879943502228, -1.97928218732183e-14, 6.93924068068615, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 0, 6.27677936394721, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47602702235557e-14, 0, 0},
    {0.420560041253711, 0, -7.94708263760856, 1.46593983227032, 0, 0, 0, 0, 10.2207771580387, 2.89087233497828, 0, 0, 0, -1.08180349039434e-14, 1.10015960051229e-14, 0, 1.60406067004907e-14, 0, -8.49879943502225, 4.00637247496576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 3.62390025541881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00860104949949e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.542378855465, 1.44235171923932e-14, 0, -6.91050664139876, 0, 0, 0, 0, -1.41976691442264e-14, 12.2649325896464, 0, 0, 1.30312779804118e-14, 0, 0, 2.24879933982623e-14, 0, 1.64486782168017e-14, -1.79783245387702e-14, -5.66586629001484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20.4998755596024, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16147208367439e-14, 0, 0, 0, 0, 0, 0, 1.28659042607863e-14, 0, 0, 0, 0}};
    
    // Compute reference derivatives
    // Declare pointer to array of derivatives on FIAT element
    double *derivatives = new double [num_derivatives];
    
    // Declare coefficients
    double coeff0_0 = 0;
    double coeff0_1 = 0;
    double coeff0_2 = 0;
    double coeff0_3 = 0;
    double coeff0_4 = 0;
    double coeff0_5 = 0;
    double coeff0_6 = 0;
    double coeff0_7 = 0;
    double coeff0_8 = 0;
    double coeff0_9 = 0;
    double coeff0_10 = 0;
    double coeff0_11 = 0;
    double coeff0_12 = 0;
    double coeff0_13 = 0;
    double coeff0_14 = 0;
    double coeff0_15 = 0;
    double coeff0_16 = 0;
    double coeff0_17 = 0;
    double coeff0_18 = 0;
    double coeff0_19 = 0;
    double coeff0_20 = 0;
    double coeff0_21 = 0;
    double coeff0_22 = 0;
    double coeff0_23 = 0;
    double coeff0_24 = 0;
    double coeff0_25 = 0;
    double coeff0_26 = 0;
    double coeff0_27 = 0;
    double coeff0_28 = 0;
    double coeff0_29 = 0;
    double coeff0_30 = 0;
    double coeff0_31 = 0;
    double coeff0_32 = 0;
    double coeff0_33 = 0;
    double coeff0_34 = 0;
    double coeff0_35 = 0;
    double coeff0_36 = 0;
    double coeff0_37 = 0;
    double coeff0_38 = 0;
    double coeff0_39 = 0;
    double coeff0_40 = 0;
    double coeff0_41 = 0;
    double coeff0_42 = 0;
    double coeff0_43 = 0;
    double coeff0_44 = 0;
    double coeff0_45 = 0;
    double coeff0_46 = 0;
    double coeff0_47 = 0;
    double coeff0_48 = 0;
    double coeff0_49 = 0;
    double coeff0_50 = 0;
    double coeff0_51 = 0;
    double coeff0_52 = 0;
    double coeff0_53 = 0;
    double coeff0_54 = 0;
    double coeff0_55 = 0;
    
    // Declare new coefficients
    double new_coeff0_0 = 0;
    double new_coeff0_1 = 0;
    double new_coeff0_2 = 0;
    double new_coeff0_3 = 0;
    double new_coeff0_4 = 0;
    double new_coeff0_5 = 0;
    double new_coeff0_6 = 0;
    double new_coeff0_7 = 0;
    double new_coeff0_8 = 0;
    double new_coeff0_9 = 0;
    double new_coeff0_10 = 0;
    double new_coeff0_11 = 0;
    double new_coeff0_12 = 0;
    double new_coeff0_13 = 0;
    double new_coeff0_14 = 0;
    double new_coeff0_15 = 0;
    double new_coeff0_16 = 0;
    double new_coeff0_17 = 0;
    double new_coeff0_18 = 0;
    double new_coeff0_19 = 0;
    double new_coeff0_20 = 0;
    double new_coeff0_21 = 0;
    double new_coeff0_22 = 0;
    double new_coeff0_23 = 0;
    double new_coeff0_24 = 0;
    double new_coeff0_25 = 0;
    double new_coeff0_26 = 0;
    double new_coeff0_27 = 0;
    double new_coeff0_28 = 0;
    double new_coeff0_29 = 0;
    double new_coeff0_30 = 0;
    double new_coeff0_31 = 0;
    double new_coeff0_32 = 0;
    double new_coeff0_33 = 0;
    double new_coeff0_34 = 0;
    double new_coeff0_35 = 0;
    double new_coeff0_36 = 0;
    double new_coeff0_37 = 0;
    double new_coeff0_38 = 0;
    double new_coeff0_39 = 0;
    double new_coeff0_40 = 0;
    double new_coeff0_41 = 0;
    double new_coeff0_42 = 0;
    double new_coeff0_43 = 0;
    double new_coeff0_44 = 0;
    double new_coeff0_45 = 0;
    double new_coeff0_46 = 0;
    double new_coeff0_47 = 0;
    double new_coeff0_48 = 0;
    double new_coeff0_49 = 0;
    double new_coeff0_50 = 0;
    double new_coeff0_51 = 0;
    double new_coeff0_52 = 0;
    double new_coeff0_53 = 0;
    double new_coeff0_54 = 0;
    double new_coeff0_55 = 0;
    
    // Loop possible derivatives
    for (unsigned int deriv_num = 0; deriv_num < num_derivatives; deriv_num++)
    {
      // Get values from coefficients array
      new_coeff0_0 = coefficients0[dof][0];
      new_coeff0_1 = coefficients0[dof][1];
      new_coeff0_2 = coefficients0[dof][2];
      new_coeff0_3 = coefficients0[dof][3];
      new_coeff0_4 = coefficients0[dof][4];
      new_coeff0_5 = coefficients0[dof][5];
      new_coeff0_6 = coefficients0[dof][6];
      new_coeff0_7 = coefficients0[dof][7];
      new_coeff0_8 = coefficients0[dof][8];
      new_coeff0_9 = coefficients0[dof][9];
      new_coeff0_10 = coefficients0[dof][10];
      new_coeff0_11 = coefficients0[dof][11];
      new_coeff0_12 = coefficients0[dof][12];
      new_coeff0_13 = coefficients0[dof][13];
      new_coeff0_14 = coefficients0[dof][14];
      new_coeff0_15 = coefficients0[dof][15];
      new_coeff0_16 = coefficients0[dof][16];
      new_coeff0_17 = coefficients0[dof][17];
      new_coeff0_18 = coefficients0[dof][18];
      new_coeff0_19 = coefficients0[dof][19];
      new_coeff0_20 = coefficients0[dof][20];
      new_coeff0_21 = coefficients0[dof][21];
      new_coeff0_22 = coefficients0[dof][22];
      new_coeff0_23 = coefficients0[dof][23];
      new_coeff0_24 = coefficients0[dof][24];
      new_coeff0_25 = coefficients0[dof][25];
      new_coeff0_26 = coefficients0[dof][26];
      new_coeff0_27 = coefficients0[dof][27];
      new_coeff0_28 = coefficients0[dof][28];
      new_coeff0_29 = coefficients0[dof][29];
      new_coeff0_30 = coefficients0[dof][30];
      new_coeff0_31 = coefficients0[dof][31];
      new_coeff0_32 = coefficients0[dof][32];
      new_coeff0_33 = coefficients0[dof][33];
      new_coeff0_34 = coefficients0[dof][34];
      new_coeff0_35 = coefficients0[dof][35];
      new_coeff0_36 = coefficients0[dof][36];
      new_coeff0_37 = coefficients0[dof][37];
      new_coeff0_38 = coefficients0[dof][38];
      new_coeff0_39 = coefficients0[dof][39];
      new_coeff0_40 = coefficients0[dof][40];
      new_coeff0_41 = coefficients0[dof][41];
      new_coeff0_42 = coefficients0[dof][42];
      new_coeff0_43 = coefficients0[dof][43];
      new_coeff0_44 = coefficients0[dof][44];
      new_coeff0_45 = coefficients0[dof][45];
      new_coeff0_46 = coefficients0[dof][46];
      new_coeff0_47 = coefficients0[dof][47];
      new_coeff0_48 = coefficients0[dof][48];
      new_coeff0_49 = coefficients0[dof][49];
      new_coeff0_50 = coefficients0[dof][50];
      new_coeff0_51 = coefficients0[dof][51];
      new_coeff0_52 = coefficients0[dof][52];
      new_coeff0_53 = coefficients0[dof][53];
      new_coeff0_54 = coefficients0[dof][54];
      new_coeff0_55 = coefficients0[dof][55];
    
      // Loop derivative order
      for (unsigned int j = 0; j < n; j++)
      {
        // Update old coefficients
        coeff0_0 = new_coeff0_0;
        coeff0_1 = new_coeff0_1;
        coeff0_2 = new_coeff0_2;
        coeff0_3 = new_coeff0_3;
        coeff0_4 = new_coeff0_4;
        coeff0_5 = new_coeff0_5;
        coeff0_6 = new_coeff0_6;
        coeff0_7 = new_coeff0_7;
        coeff0_8 = new_coeff0_8;
        coeff0_9 = new_coeff0_9;
        coeff0_10 = new_coeff0_10;
        coeff0_11 = new_coeff0_11;
        coeff0_12 = new_coeff0_12;
        coeff0_13 = new_coeff0_13;
        coeff0_14 = new_coeff0_14;
        coeff0_15 = new_coeff0_15;
        coeff0_16 = new_coeff0_16;
        coeff0_17 = new_coeff0_17;
        coeff0_18 = new_coeff0_18;
        coeff0_19 = new_coeff0_19;
        coeff0_20 = new_coeff0_20;
        coeff0_21 = new_coeff0_21;
        coeff0_22 = new_coeff0_22;
        coeff0_23 = new_coeff0_23;
        coeff0_24 = new_coeff0_24;
        coeff0_25 = new_coeff0_25;
        coeff0_26 = new_coeff0_26;
        coeff0_27 = new_coeff0_27;
        coeff0_28 = new_coeff0_28;
        coeff0_29 = new_coeff0_29;
        coeff0_30 = new_coeff0_30;
        coeff0_31 = new_coeff0_31;
        coeff0_32 = new_coeff0_32;
        coeff0_33 = new_coeff0_33;
        coeff0_34 = new_coeff0_34;
        coeff0_35 = new_coeff0_35;
        coeff0_36 = new_coeff0_36;
        coeff0_37 = new_coeff0_37;
        coeff0_38 = new_coeff0_38;
        coeff0_39 = new_coeff0_39;
        coeff0_40 = new_coeff0_40;
        coeff0_41 = new_coeff0_41;
        coeff0_42 = new_coeff0_42;
        coeff0_43 = new_coeff0_43;
        coeff0_44 = new_coeff0_44;
        coeff0_45 = new_coeff0_45;
        coeff0_46 = new_coeff0_46;
        coeff0_47 = new_coeff0_47;
        coeff0_48 = new_coeff0_48;
        coeff0_49 = new_coeff0_49;
        coeff0_50 = new_coeff0_50;
        coeff0_51 = new_coeff0_51;
        coeff0_52 = new_coeff0_52;
        coeff0_53 = new_coeff0_53;
        coeff0_54 = new_coeff0_54;
        coeff0_55 = new_coeff0_55;
    
        if(combinations[deriv_num][j] == 0)
        {
          new_coeff0_0 = coeff0_0*dmats0[0][0] + coeff0_1*dmats0[1][0] + coeff0_2*dmats0[2][0] + coeff0_3*dmats0[3][0] + coeff0_4*dmats0[4][0] + coeff0_5*dmats0[5][0] + coeff0_6*dmats0[6][0] + coeff0_7*dmats0[7][0] + coeff0_8*dmats0[8][0] + coeff0_9*dmats0[9][0] + coeff0_10*dmats0[10][0] + coeff0_11*dmats0[11][0] + coeff0_12*dmats0[12][0] + coeff0_13*dmats0[13][0] + coeff0_14*dmats0[14][0] + coeff0_15*dmats0[15][0] + coeff0_16*dmats0[16][0] + coeff0_17*dmats0[17][0] + coeff0_18*dmats0[18][0] + coeff0_19*dmats0[19][0] + coeff0_20*dmats0[20][0] + coeff0_21*dmats0[21][0] + coeff0_22*dmats0[22][0] + coeff0_23*dmats0[23][0] + coeff0_24*dmats0[24][0] + coeff0_25*dmats0[25][0] + coeff0_26*dmats0[26][0] + coeff0_27*dmats0[27][0] + coeff0_28*dmats0[28][0] + coeff0_29*dmats0[29][0] + coeff0_30*dmats0[30][0] + coeff0_31*dmats0[31][0] + coeff0_32*dmats0[32][0] + coeff0_33*dmats0[33][0] + coeff0_34*dmats0[34][0] + coeff0_35*dmats0[35][0] + coeff0_36*dmats0[36][0] + coeff0_37*dmats0[37][0] + coeff0_38*dmats0[38][0] + coeff0_39*dmats0[39][0] + coeff0_40*dmats0[40][0] + coeff0_41*dmats0[41][0] + coeff0_42*dmats0[42][0] + coeff0_43*dmats0[43][0] + coeff0_44*dmats0[44][0] + coeff0_45*dmats0[45][0] + coeff0_46*dmats0[46][0] + coeff0_47*dmats0[47][0] + coeff0_48*dmats0[48][0] + coeff0_49*dmats0[49][0] + coeff0_50*dmats0[50][0] + coeff0_51*dmats0[51][0] + coeff0_52*dmats0[52][0] + coeff0_53*dmats0[53][0] + coeff0_54*dmats0[54][0] + coeff0_55*dmats0[55][0];
          new_coeff0_1 = coeff0_0*dmats0[0][1] + coeff0_1*dmats0[1][1] + coeff0_2*dmats0[2][1] + coeff0_3*dmats0[3][1] + coeff0_4*dmats0[4][1] + coeff0_5*dmats0[5][1] + coeff0_6*dmats0[6][1] + coeff0_7*dmats0[7][1] + coeff0_8*dmats0[8][1] + coeff0_9*dmats0[9][1] + coeff0_10*dmats0[10][1] + coeff0_11*dmats0[11][1] + coeff0_12*dmats0[12][1] + coeff0_13*dmats0[13][1] + coeff0_14*dmats0[14][1] + coeff0_15*dmats0[15][1] + coeff0_16*dmats0[16][1] + coeff0_17*dmats0[17][1] + coeff0_18*dmats0[18][1] + coeff0_19*dmats0[19][1] + coeff0_20*dmats0[20][1] + coeff0_21*dmats0[21][1] + coeff0_22*dmats0[22][1] + coeff0_23*dmats0[23][1] + coeff0_24*dmats0[24][1] + coeff0_25*dmats0[25][1] + coeff0_26*dmats0[26][1] + coeff0_27*dmats0[27][1] + coeff0_28*dmats0[28][1] + coeff0_29*dmats0[29][1] + coeff0_30*dmats0[30][1] + coeff0_31*dmats0[31][1] + coeff0_32*dmats0[32][1] + coeff0_33*dmats0[33][1] + coeff0_34*dmats0[34][1] + coeff0_35*dmats0[35][1] + coeff0_36*dmats0[36][1] + coeff0_37*dmats0[37][1] + coeff0_38*dmats0[38][1] + coeff0_39*dmats0[39][1] + coeff0_40*dmats0[40][1] + coeff0_41*dmats0[41][1] + coeff0_42*dmats0[42][1] + coeff0_43*dmats0[43][1] + coeff0_44*dmats0[44][1] + coeff0_45*dmats0[45][1] + coeff0_46*dmats0[46][1] + coeff0_47*dmats0[47][1] + coeff0_48*dmats0[48][1] + coeff0_49*dmats0[49][1] + coeff0_50*dmats0[50][1] + coeff0_51*dmats0[51][1] + coeff0_52*dmats0[52][1] + coeff0_53*dmats0[53][1] + coeff0_54*dmats0[54][1] + coeff0_55*dmats0[55][1];
          new_coeff0_2 = coeff0_0*dmats0[0][2] + coeff0_1*dmats0[1][2] + coeff0_2*dmats0[2][2] + coeff0_3*dmats0[3][2] + coeff0_4*dmats0[4][2] + coeff0_5*dmats0[5][2] + coeff0_6*dmats0[6][2] + coeff0_7*dmats0[7][2] + coeff0_8*dmats0[8][2] + coeff0_9*dmats0[9][2] + coeff0_10*dmats0[10][2] + coeff0_11*dmats0[11][2] + coeff0_12*dmats0[12][2] + coeff0_13*dmats0[13][2] + coeff0_14*dmats0[14][2] + coeff0_15*dmats0[15][2] + coeff0_16*dmats0[16][2] + coeff0_17*dmats0[17][2] + coeff0_18*dmats0[18][2] + coeff0_19*dmats0[19][2] + coeff0_20*dmats0[20][2] + coeff0_21*dmats0[21][2] + coeff0_22*dmats0[22][2] + coeff0_23*dmats0[23][2] + coeff0_24*dmats0[24][2] + coeff0_25*dmats0[25][2] + coeff0_26*dmats0[26][2] + coeff0_27*dmats0[27][2] + coeff0_28*dmats0[28][2] + coeff0_29*dmats0[29][2] + coeff0_30*dmats0[30][2] + coeff0_31*dmats0[31][2] + coeff0_32*dmats0[32][2] + coeff0_33*dmats0[33][2] + coeff0_34*dmats0[34][2] + coeff0_35*dmats0[35][2] + coeff0_36*dmats0[36][2] + coeff0_37*dmats0[37][2] + coeff0_38*dmats0[38][2] + coeff0_39*dmats0[39][2] + coeff0_40*dmats0[40][2] + coeff0_41*dmats0[41][2] + coeff0_42*dmats0[42][2] + coeff0_43*dmats0[43][2] + coeff0_44*dmats0[44][2] + coeff0_45*dmats0[45][2] + coeff0_46*dmats0[46][2] + coeff0_47*dmats0[47][2] + coeff0_48*dmats0[48][2] + coeff0_49*dmats0[49][2] + coeff0_50*dmats0[50][2] + coeff0_51*dmats0[51][2] + coeff0_52*dmats0[52][2] + coeff0_53*dmats0[53][2] + coeff0_54*dmats0[54][2] + coeff0_55*dmats0[55][2];
          new_coeff0_3 = coeff0_0*dmats0[0][3] + coeff0_1*dmats0[1][3] + coeff0_2*dmats0[2][3] + coeff0_3*dmats0[3][3] + coeff0_4*dmats0[4][3] + coeff0_5*dmats0[5][3] + coeff0_6*dmats0[6][3] + coeff0_7*dmats0[7][3] + coeff0_8*dmats0[8][3] + coeff0_9*dmats0[9][3] + coeff0_10*dmats0[10][3] + coeff0_11*dmats0[11][3] + coeff0_12*dmats0[12][3] + coeff0_13*dmats0[13][3] + coeff0_14*dmats0[14][3] + coeff0_15*dmats0[15][3] + coeff0_16*dmats0[16][3] + coeff0_17*dmats0[17][3] + coeff0_18*dmats0[18][3] + coeff0_19*dmats0[19][3] + coeff0_20*dmats0[20][3] + coeff0_21*dmats0[21][3] + coeff0_22*dmats0[22][3] + coeff0_23*dmats0[23][3] + coeff0_24*dmats0[24][3] + coeff0_25*dmats0[25][3] + coeff0_26*dmats0[26][3] + coeff0_27*dmats0[27][3] + coeff0_28*dmats0[28][3] + coeff0_29*dmats0[29][3] + coeff0_30*dmats0[30][3] + coeff0_31*dmats0[31][3] + coeff0_32*dmats0[32][3] + coeff0_33*dmats0[33][3] + coeff0_34*dmats0[34][3] + coeff0_35*dmats0[35][3] + coeff0_36*dmats0[36][3] + coeff0_37*dmats0[37][3] + coeff0_38*dmats0[38][3] + coeff0_39*dmats0[39][3] + coeff0_40*dmats0[40][3] + coeff0_41*dmats0[41][3] + coeff0_42*dmats0[42][3] + coeff0_43*dmats0[43][3] + coeff0_44*dmats0[44][3] + coeff0_45*dmats0[45][3] + coeff0_46*dmats0[46][3] + coeff0_47*dmats0[47][3] + coeff0_48*dmats0[48][3] + coeff0_49*dmats0[49][3] + coeff0_50*dmats0[50][3] + coeff0_51*dmats0[51][3] + coeff0_52*dmats0[52][3] + coeff0_53*dmats0[53][3] + coeff0_54*dmats0[54][3] + coeff0_55*dmats0[55][3];
          new_coeff0_4 = coeff0_0*dmats0[0][4] + coeff0_1*dmats0[1][4] + coeff0_2*dmats0[2][4] + coeff0_3*dmats0[3][4] + coeff0_4*dmats0[4][4] + coeff0_5*dmats0[5][4] + coeff0_6*dmats0[6][4] + coeff0_7*dmats0[7][4] + coeff0_8*dmats0[8][4] + coeff0_9*dmats0[9][4] + coeff0_10*dmats0[10][4] + coeff0_11*dmats0[11][4] + coeff0_12*dmats0[12][4] + coeff0_13*dmats0[13][4] + coeff0_14*dmats0[14][4] + coeff0_15*dmats0[15][4] + coeff0_16*dmats0[16][4] + coeff0_17*dmats0[17][4] + coeff0_18*dmats0[18][4] + coeff0_19*dmats0[19][4] + coeff0_20*dmats0[20][4] + coeff0_21*dmats0[21][4] + coeff0_22*dmats0[22][4] + coeff0_23*dmats0[23][4] + coeff0_24*dmats0[24][4] + coeff0_25*dmats0[25][4] + coeff0_26*dmats0[26][4] + coeff0_27*dmats0[27][4] + coeff0_28*dmats0[28][4] + coeff0_29*dmats0[29][4] + coeff0_30*dmats0[30][4] + coeff0_31*dmats0[31][4] + coeff0_32*dmats0[32][4] + coeff0_33*dmats0[33][4] + coeff0_34*dmats0[34][4] + coeff0_35*dmats0[35][4] + coeff0_36*dmats0[36][4] + coeff0_37*dmats0[37][4] + coeff0_38*dmats0[38][4] + coeff0_39*dmats0[39][4] + coeff0_40*dmats0[40][4] + coeff0_41*dmats0[41][4] + coeff0_42*dmats0[42][4] + coeff0_43*dmats0[43][4] + coeff0_44*dmats0[44][4] + coeff0_45*dmats0[45][4] + coeff0_46*dmats0[46][4] + coeff0_47*dmats0[47][4] + coeff0_48*dmats0[48][4] + coeff0_49*dmats0[49][4] + coeff0_50*dmats0[50][4] + coeff0_51*dmats0[51][4] + coeff0_52*dmats0[52][4] + coeff0_53*dmats0[53][4] + coeff0_54*dmats0[54][4] + coeff0_55*dmats0[55][4];
          new_coeff0_5 = coeff0_0*dmats0[0][5] + coeff0_1*dmats0[1][5] + coeff0_2*dmats0[2][5] + coeff0_3*dmats0[3][5] + coeff0_4*dmats0[4][5] + coeff0_5*dmats0[5][5] + coeff0_6*dmats0[6][5] + coeff0_7*dmats0[7][5] + coeff0_8*dmats0[8][5] + coeff0_9*dmats0[9][5] + coeff0_10*dmats0[10][5] + coeff0_11*dmats0[11][5] + coeff0_12*dmats0[12][5] + coeff0_13*dmats0[13][5] + coeff0_14*dmats0[14][5] + coeff0_15*dmats0[15][5] + coeff0_16*dmats0[16][5] + coeff0_17*dmats0[17][5] + coeff0_18*dmats0[18][5] + coeff0_19*dmats0[19][5] + coeff0_20*dmats0[20][5] + coeff0_21*dmats0[21][5] + coeff0_22*dmats0[22][5] + coeff0_23*dmats0[23][5] + coeff0_24*dmats0[24][5] + coeff0_25*dmats0[25][5] + coeff0_26*dmats0[26][5] + coeff0_27*dmats0[27][5] + coeff0_28*dmats0[28][5] + coeff0_29*dmats0[29][5] + coeff0_30*dmats0[30][5] + coeff0_31*dmats0[31][5] + coeff0_32*dmats0[32][5] + coeff0_33*dmats0[33][5] + coeff0_34*dmats0[34][5] + coeff0_35*dmats0[35][5] + coeff0_36*dmats0[36][5] + coeff0_37*dmats0[37][5] + coeff0_38*dmats0[38][5] + coeff0_39*dmats0[39][5] + coeff0_40*dmats0[40][5] + coeff0_41*dmats0[41][5] + coeff0_42*dmats0[42][5] + coeff0_43*dmats0[43][5] + coeff0_44*dmats0[44][5] + coeff0_45*dmats0[45][5] + coeff0_46*dmats0[46][5] + coeff0_47*dmats0[47][5] + coeff0_48*dmats0[48][5] + coeff0_49*dmats0[49][5] + coeff0_50*dmats0[50][5] + coeff0_51*dmats0[51][5] + coeff0_52*dmats0[52][5] + coeff0_53*dmats0[53][5] + coeff0_54*dmats0[54][5] + coeff0_55*dmats0[55][5];
          new_coeff0_6 = coeff0_0*dmats0[0][6] + coeff0_1*dmats0[1][6] + coeff0_2*dmats0[2][6] + coeff0_3*dmats0[3][6] + coeff0_4*dmats0[4][6] + coeff0_5*dmats0[5][6] + coeff0_6*dmats0[6][6] + coeff0_7*dmats0[7][6] + coeff0_8*dmats0[8][6] + coeff0_9*dmats0[9][6] + coeff0_10*dmats0[10][6] + coeff0_11*dmats0[11][6] + coeff0_12*dmats0[12][6] + coeff0_13*dmats0[13][6] + coeff0_14*dmats0[14][6] + coeff0_15*dmats0[15][6] + coeff0_16*dmats0[16][6] + coeff0_17*dmats0[17][6] + coeff0_18*dmats0[18][6] + coeff0_19*dmats0[19][6] + coeff0_20*dmats0[20][6] + coeff0_21*dmats0[21][6] + coeff0_22*dmats0[22][6] + coeff0_23*dmats0[23][6] + coeff0_24*dmats0[24][6] + coeff0_25*dmats0[25][6] + coeff0_26*dmats0[26][6] + coeff0_27*dmats0[27][6] + coeff0_28*dmats0[28][6] + coeff0_29*dmats0[29][6] + coeff0_30*dmats0[30][6] + coeff0_31*dmats0[31][6] + coeff0_32*dmats0[32][6] + coeff0_33*dmats0[33][6] + coeff0_34*dmats0[34][6] + coeff0_35*dmats0[35][6] + coeff0_36*dmats0[36][6] + coeff0_37*dmats0[37][6] + coeff0_38*dmats0[38][6] + coeff0_39*dmats0[39][6] + coeff0_40*dmats0[40][6] + coeff0_41*dmats0[41][6] + coeff0_42*dmats0[42][6] + coeff0_43*dmats0[43][6] + coeff0_44*dmats0[44][6] + coeff0_45*dmats0[45][6] + coeff0_46*dmats0[46][6] + coeff0_47*dmats0[47][6] + coeff0_48*dmats0[48][6] + coeff0_49*dmats0[49][6] + coeff0_50*dmats0[50][6] + coeff0_51*dmats0[51][6] + coeff0_52*dmats0[52][6] + coeff0_53*dmats0[53][6] + coeff0_54*dmats0[54][6] + coeff0_55*dmats0[55][6];
          new_coeff0_7 = coeff0_0*dmats0[0][7] + coeff0_1*dmats0[1][7] + coeff0_2*dmats0[2][7] + coeff0_3*dmats0[3][7] + coeff0_4*dmats0[4][7] + coeff0_5*dmats0[5][7] + coeff0_6*dmats0[6][7] + coeff0_7*dmats0[7][7] + coeff0_8*dmats0[8][7] + coeff0_9*dmats0[9][7] + coeff0_10*dmats0[10][7] + coeff0_11*dmats0[11][7] + coeff0_12*dmats0[12][7] + coeff0_13*dmats0[13][7] + coeff0_14*dmats0[14][7] + coeff0_15*dmats0[15][7] + coeff0_16*dmats0[16][7] + coeff0_17*dmats0[17][7] + coeff0_18*dmats0[18][7] + coeff0_19*dmats0[19][7] + coeff0_20*dmats0[20][7] + coeff0_21*dmats0[21][7] + coeff0_22*dmats0[22][7] + coeff0_23*dmats0[23][7] + coeff0_24*dmats0[24][7] + coeff0_25*dmats0[25][7] + coeff0_26*dmats0[26][7] + coeff0_27*dmats0[27][7] + coeff0_28*dmats0[28][7] + coeff0_29*dmats0[29][7] + coeff0_30*dmats0[30][7] + coeff0_31*dmats0[31][7] + coeff0_32*dmats0[32][7] + coeff0_33*dmats0[33][7] + coeff0_34*dmats0[34][7] + coeff0_35*dmats0[35][7] + coeff0_36*dmats0[36][7] + coeff0_37*dmats0[37][7] + coeff0_38*dmats0[38][7] + coeff0_39*dmats0[39][7] + coeff0_40*dmats0[40][7] + coeff0_41*dmats0[41][7] + coeff0_42*dmats0[42][7] + coeff0_43*dmats0[43][7] + coeff0_44*dmats0[44][7] + coeff0_45*dmats0[45][7] + coeff0_46*dmats0[46][7] + coeff0_47*dmats0[47][7] + coeff0_48*dmats0[48][7] + coeff0_49*dmats0[49][7] + coeff0_50*dmats0[50][7] + coeff0_51*dmats0[51][7] + coeff0_52*dmats0[52][7] + coeff0_53*dmats0[53][7] + coeff0_54*dmats0[54][7] + coeff0_55*dmats0[55][7];
          new_coeff0_8 = coeff0_0*dmats0[0][8] + coeff0_1*dmats0[1][8] + coeff0_2*dmats0[2][8] + coeff0_3*dmats0[3][8] + coeff0_4*dmats0[4][8] + coeff0_5*dmats0[5][8] + coeff0_6*dmats0[6][8] + coeff0_7*dmats0[7][8] + coeff0_8*dmats0[8][8] + coeff0_9*dmats0[9][8] + coeff0_10*dmats0[10][8] + coeff0_11*dmats0[11][8] + coeff0_12*dmats0[12][8] + coeff0_13*dmats0[13][8] + coeff0_14*dmats0[14][8] + coeff0_15*dmats0[15][8] + coeff0_16*dmats0[16][8] + coeff0_17*dmats0[17][8] + coeff0_18*dmats0[18][8] + coeff0_19*dmats0[19][8] + coeff0_20*dmats0[20][8] + coeff0_21*dmats0[21][8] + coeff0_22*dmats0[22][8] + coeff0_23*dmats0[23][8] + coeff0_24*dmats0[24][8] + coeff0_25*dmats0[25][8] + coeff0_26*dmats0[26][8] + coeff0_27*dmats0[27][8] + coeff0_28*dmats0[28][8] + coeff0_29*dmats0[29][8] + coeff0_30*dmats0[30][8] + coeff0_31*dmats0[31][8] + coeff0_32*dmats0[32][8] + coeff0_33*dmats0[33][8] + coeff0_34*dmats0[34][8] + coeff0_35*dmats0[35][8] + coeff0_36*dmats0[36][8] + coeff0_37*dmats0[37][8] + coeff0_38*dmats0[38][8] + coeff0_39*dmats0[39][8] + coeff0_40*dmats0[40][8] + coeff0_41*dmats0[41][8] + coeff0_42*dmats0[42][8] + coeff0_43*dmats0[43][8] + coeff0_44*dmats0[44][8] + coeff0_45*dmats0[45][8] + coeff0_46*dmats0[46][8] + coeff0_47*dmats0[47][8] + coeff0_48*dmats0[48][8] + coeff0_49*dmats0[49][8] + coeff0_50*dmats0[50][8] + coeff0_51*dmats0[51][8] + coeff0_52*dmats0[52][8] + coeff0_53*dmats0[53][8] + coeff0_54*dmats0[54][8] + coeff0_55*dmats0[55][8];
          new_coeff0_9 = coeff0_0*dmats0[0][9] + coeff0_1*dmats0[1][9] + coeff0_2*dmats0[2][9] + coeff0_3*dmats0[3][9] + coeff0_4*dmats0[4][9] + coeff0_5*dmats0[5][9] + coeff0_6*dmats0[6][9] + coeff0_7*dmats0[7][9] + coeff0_8*dmats0[8][9] + coeff0_9*dmats0[9][9] + coeff0_10*dmats0[10][9] + coeff0_11*dmats0[11][9] + coeff0_12*dmats0[12][9] + coeff0_13*dmats0[13][9] + coeff0_14*dmats0[14][9] + coeff0_15*dmats0[15][9] + coeff0_16*dmats0[16][9] + coeff0_17*dmats0[17][9] + coeff0_18*dmats0[18][9] + coeff0_19*dmats0[19][9] + coeff0_20*dmats0[20][9] + coeff0_21*dmats0[21][9] + coeff0_22*dmats0[22][9] + coeff0_23*dmats0[23][9] + coeff0_24*dmats0[24][9] + coeff0_25*dmats0[25][9] + coeff0_26*dmats0[26][9] + coeff0_27*dmats0[27][9] + coeff0_28*dmats0[28][9] + coeff0_29*dmats0[29][9] + coeff0_30*dmats0[30][9] + coeff0_31*dmats0[31][9] + coeff0_32*dmats0[32][9] + coeff0_33*dmats0[33][9] + coeff0_34*dmats0[34][9] + coeff0_35*dmats0[35][9] + coeff0_36*dmats0[36][9] + coeff0_37*dmats0[37][9] + coeff0_38*dmats0[38][9] + coeff0_39*dmats0[39][9] + coeff0_40*dmats0[40][9] + coeff0_41*dmats0[41][9] + coeff0_42*dmats0[42][9] + coeff0_43*dmats0[43][9] + coeff0_44*dmats0[44][9] + coeff0_45*dmats0[45][9] + coeff0_46*dmats0[46][9] + coeff0_47*dmats0[47][9] + coeff0_48*dmats0[48][9] + coeff0_49*dmats0[49][9] + coeff0_50*dmats0[50][9] + coeff0_51*dmats0[51][9] + coeff0_52*dmats0[52][9] + coeff0_53*dmats0[53][9] + coeff0_54*dmats0[54][9] + coeff0_55*dmats0[55][9];
          new_coeff0_10 = coeff0_0*dmats0[0][10] + coeff0_1*dmats0[1][10] + coeff0_2*dmats0[2][10] + coeff0_3*dmats0[3][10] + coeff0_4*dmats0[4][10] + coeff0_5*dmats0[5][10] + coeff0_6*dmats0[6][10] + coeff0_7*dmats0[7][10] + coeff0_8*dmats0[8][10] + coeff0_9*dmats0[9][10] + coeff0_10*dmats0[10][10] + coeff0_11*dmats0[11][10] + coeff0_12*dmats0[12][10] + coeff0_13*dmats0[13][10] + coeff0_14*dmats0[14][10] + coeff0_15*dmats0[15][10] + coeff0_16*dmats0[16][10] + coeff0_17*dmats0[17][10] + coeff0_18*dmats0[18][10] + coeff0_19*dmats0[19][10] + coeff0_20*dmats0[20][10] + coeff0_21*dmats0[21][10] + coeff0_22*dmats0[22][10] + coeff0_23*dmats0[23][10] + coeff0_24*dmats0[24][10] + coeff0_25*dmats0[25][10] + coeff0_26*dmats0[26][10] + coeff0_27*dmats0[27][10] + coeff0_28*dmats0[28][10] + coeff0_29*dmats0[29][10] + coeff0_30*dmats0[30][10] + coeff0_31*dmats0[31][10] + coeff0_32*dmats0[32][10] + coeff0_33*dmats0[33][10] + coeff0_34*dmats0[34][10] + coeff0_35*dmats0[35][10] + coeff0_36*dmats0[36][10] + coeff0_37*dmats0[37][10] + coeff0_38*dmats0[38][10] + coeff0_39*dmats0[39][10] + coeff0_40*dmats0[40][10] + coeff0_41*dmats0[41][10] + coeff0_42*dmats0[42][10] + coeff0_43*dmats0[43][10] + coeff0_44*dmats0[44][10] + coeff0_45*dmats0[45][10] + coeff0_46*dmats0[46][10] + coeff0_47*dmats0[47][10] + coeff0_48*dmats0[48][10] + coeff0_49*dmats0[49][10] + coeff0_50*dmats0[50][10] + coeff0_51*dmats0[51][10] + coeff0_52*dmats0[52][10] + coeff0_53*dmats0[53][10] + coeff0_54*dmats0[54][10] + coeff0_55*dmats0[55][10];
          new_coeff0_11 = coeff0_0*dmats0[0][11] + coeff0_1*dmats0[1][11] + coeff0_2*dmats0[2][11] + coeff0_3*dmats0[3][11] + coeff0_4*dmats0[4][11] + coeff0_5*dmats0[5][11] + coeff0_6*dmats0[6][11] + coeff0_7*dmats0[7][11] + coeff0_8*dmats0[8][11] + coeff0_9*dmats0[9][11] + coeff0_10*dmats0[10][11] + coeff0_11*dmats0[11][11] + coeff0_12*dmats0[12][11] + coeff0_13*dmats0[13][11] + coeff0_14*dmats0[14][11] + coeff0_15*dmats0[15][11] + coeff0_16*dmats0[16][11] + coeff0_17*dmats0[17][11] + coeff0_18*dmats0[18][11] + coeff0_19*dmats0[19][11] + coeff0_20*dmats0[20][11] + coeff0_21*dmats0[21][11] + coeff0_22*dmats0[22][11] + coeff0_23*dmats0[23][11] + coeff0_24*dmats0[24][11] + coeff0_25*dmats0[25][11] + coeff0_26*dmats0[26][11] + coeff0_27*dmats0[27][11] + coeff0_28*dmats0[28][11] + coeff0_29*dmats0[29][11] + coeff0_30*dmats0[30][11] + coeff0_31*dmats0[31][11] + coeff0_32*dmats0[32][11] + coeff0_33*dmats0[33][11] + coeff0_34*dmats0[34][11] + coeff0_35*dmats0[35][11] + coeff0_36*dmats0[36][11] + coeff0_37*dmats0[37][11] + coeff0_38*dmats0[38][11] + coeff0_39*dmats0[39][11] + coeff0_40*dmats0[40][11] + coeff0_41*dmats0[41][11] + coeff0_42*dmats0[42][11] + coeff0_43*dmats0[43][11] + coeff0_44*dmats0[44][11] + coeff0_45*dmats0[45][11] + coeff0_46*dmats0[46][11] + coeff0_47*dmats0[47][11] + coeff0_48*dmats0[48][11] + coeff0_49*dmats0[49][11] + coeff0_50*dmats0[50][11] + coeff0_51*dmats0[51][11] + coeff0_52*dmats0[52][11] + coeff0_53*dmats0[53][11] + coeff0_54*dmats0[54][11] + coeff0_55*dmats0[55][11];
          new_coeff0_12 = coeff0_0*dmats0[0][12] + coeff0_1*dmats0[1][12] + coeff0_2*dmats0[2][12] + coeff0_3*dmats0[3][12] + coeff0_4*dmats0[4][12] + coeff0_5*dmats0[5][12] + coeff0_6*dmats0[6][12] + coeff0_7*dmats0[7][12] + coeff0_8*dmats0[8][12] + coeff0_9*dmats0[9][12] + coeff0_10*dmats0[10][12] + coeff0_11*dmats0[11][12] + coeff0_12*dmats0[12][12] + coeff0_13*dmats0[13][12] + coeff0_14*dmats0[14][12] + coeff0_15*dmats0[15][12] + coeff0_16*dmats0[16][12] + coeff0_17*dmats0[17][12] + coeff0_18*dmats0[18][12] + coeff0_19*dmats0[19][12] + coeff0_20*dmats0[20][12] + coeff0_21*dmats0[21][12] + coeff0_22*dmats0[22][12] + coeff0_23*dmats0[23][12] + coeff0_24*dmats0[24][12] + coeff0_25*dmats0[25][12] + coeff0_26*dmats0[26][12] + coeff0_27*dmats0[27][12] + coeff0_28*dmats0[28][12] + coeff0_29*dmats0[29][12] + coeff0_30*dmats0[30][12] + coeff0_31*dmats0[31][12] + coeff0_32*dmats0[32][12] + coeff0_33*dmats0[33][12] + coeff0_34*dmats0[34][12] + coeff0_35*dmats0[35][12] + coeff0_36*dmats0[36][12] + coeff0_37*dmats0[37][12] + coeff0_38*dmats0[38][12] + coeff0_39*dmats0[39][12] + coeff0_40*dmats0[40][12] + coeff0_41*dmats0[41][12] + coeff0_42*dmats0[42][12] + coeff0_43*dmats0[43][12] + coeff0_44*dmats0[44][12] + coeff0_45*dmats0[45][12] + coeff0_46*dmats0[46][12] + coeff0_47*dmats0[47][12] + coeff0_48*dmats0[48][12] + coeff0_49*dmats0[49][12] + coeff0_50*dmats0[50][12] + coeff0_51*dmats0[51][12] + coeff0_52*dmats0[52][12] + coeff0_53*dmats0[53][12] + coeff0_54*dmats0[54][12] + coeff0_55*dmats0[55][12];
          new_coeff0_13 = coeff0_0*dmats0[0][13] + coeff0_1*dmats0[1][13] + coeff0_2*dmats0[2][13] + coeff0_3*dmats0[3][13] + coeff0_4*dmats0[4][13] + coeff0_5*dmats0[5][13] + coeff0_6*dmats0[6][13] + coeff0_7*dmats0[7][13] + coeff0_8*dmats0[8][13] + coeff0_9*dmats0[9][13] + coeff0_10*dmats0[10][13] + coeff0_11*dmats0[11][13] + coeff0_12*dmats0[12][13] + coeff0_13*dmats0[13][13] + coeff0_14*dmats0[14][13] + coeff0_15*dmats0[15][13] + coeff0_16*dmats0[16][13] + coeff0_17*dmats0[17][13] + coeff0_18*dmats0[18][13] + coeff0_19*dmats0[19][13] + coeff0_20*dmats0[20][13] + coeff0_21*dmats0[21][13] + coeff0_22*dmats0[22][13] + coeff0_23*dmats0[23][13] + coeff0_24*dmats0[24][13] + coeff0_25*dmats0[25][13] + coeff0_26*dmats0[26][13] + coeff0_27*dmats0[27][13] + coeff0_28*dmats0[28][13] + coeff0_29*dmats0[29][13] + coeff0_30*dmats0[30][13] + coeff0_31*dmats0[31][13] + coeff0_32*dmats0[32][13] + coeff0_33*dmats0[33][13] + coeff0_34*dmats0[34][13] + coeff0_35*dmats0[35][13] + coeff0_36*dmats0[36][13] + coeff0_37*dmats0[37][13] + coeff0_38*dmats0[38][13] + coeff0_39*dmats0[39][13] + coeff0_40*dmats0[40][13] + coeff0_41*dmats0[41][13] + coeff0_42*dmats0[42][13] + coeff0_43*dmats0[43][13] + coeff0_44*dmats0[44][13] + coeff0_45*dmats0[45][13] + coeff0_46*dmats0[46][13] + coeff0_47*dmats0[47][13] + coeff0_48*dmats0[48][13] + coeff0_49*dmats0[49][13] + coeff0_50*dmats0[50][13] + coeff0_51*dmats0[51][13] + coeff0_52*dmats0[52][13] + coeff0_53*dmats0[53][13] + coeff0_54*dmats0[54][13] + coeff0_55*dmats0[55][13];
          new_coeff0_14 = coeff0_0*dmats0[0][14] + coeff0_1*dmats0[1][14] + coeff0_2*dmats0[2][14] + coeff0_3*dmats0[3][14] + coeff0_4*dmats0[4][14] + coeff0_5*dmats0[5][14] + coeff0_6*dmats0[6][14] + coeff0_7*dmats0[7][14] + coeff0_8*dmats0[8][14] + coeff0_9*dmats0[9][14] + coeff0_10*dmats0[10][14] + coeff0_11*dmats0[11][14] + coeff0_12*dmats0[12][14] + coeff0_13*dmats0[13][14] + coeff0_14*dmats0[14][14] + coeff0_15*dmats0[15][14] + coeff0_16*dmats0[16][14] + coeff0_17*dmats0[17][14] + coeff0_18*dmats0[18][14] + coeff0_19*dmats0[19][14] + coeff0_20*dmats0[20][14] + coeff0_21*dmats0[21][14] + coeff0_22*dmats0[22][14] + coeff0_23*dmats0[23][14] + coeff0_24*dmats0[24][14] + coeff0_25*dmats0[25][14] + coeff0_26*dmats0[26][14] + coeff0_27*dmats0[27][14] + coeff0_28*dmats0[28][14] + coeff0_29*dmats0[29][14] + coeff0_30*dmats0[30][14] + coeff0_31*dmats0[31][14] + coeff0_32*dmats0[32][14] + coeff0_33*dmats0[33][14] + coeff0_34*dmats0[34][14] + coeff0_35*dmats0[35][14] + coeff0_36*dmats0[36][14] + coeff0_37*dmats0[37][14] + coeff0_38*dmats0[38][14] + coeff0_39*dmats0[39][14] + coeff0_40*dmats0[40][14] + coeff0_41*dmats0[41][14] + coeff0_42*dmats0[42][14] + coeff0_43*dmats0[43][14] + coeff0_44*dmats0[44][14] + coeff0_45*dmats0[45][14] + coeff0_46*dmats0[46][14] + coeff0_47*dmats0[47][14] + coeff0_48*dmats0[48][14] + coeff0_49*dmats0[49][14] + coeff0_50*dmats0[50][14] + coeff0_51*dmats0[51][14] + coeff0_52*dmats0[52][14] + coeff0_53*dmats0[53][14] + coeff0_54*dmats0[54][14] + coeff0_55*dmats0[55][14];
          new_coeff0_15 = coeff0_0*dmats0[0][15] + coeff0_1*dmats0[1][15] + coeff0_2*dmats0[2][15] + coeff0_3*dmats0[3][15] + coeff0_4*dmats0[4][15] + coeff0_5*dmats0[5][15] + coeff0_6*dmats0[6][15] + coeff0_7*dmats0[7][15] + coeff0_8*dmats0[8][15] + coeff0_9*dmats0[9][15] + coeff0_10*dmats0[10][15] + coeff0_11*dmats0[11][15] + coeff0_12*dmats0[12][15] + coeff0_13*dmats0[13][15] + coeff0_14*dmats0[14][15] + coeff0_15*dmats0[15][15] + coeff0_16*dmats0[16][15] + coeff0_17*dmats0[17][15] + coeff0_18*dmats0[18][15] + coeff0_19*dmats0[19][15] + coeff0_20*dmats0[20][15] + coeff0_21*dmats0[21][15] + coeff0_22*dmats0[22][15] + coeff0_23*dmats0[23][15] + coeff0_24*dmats0[24][15] + coeff0_25*dmats0[25][15] + coeff0_26*dmats0[26][15] + coeff0_27*dmats0[27][15] + coeff0_28*dmats0[28][15] + coeff0_29*dmats0[29][15] + coeff0_30*dmats0[30][15] + coeff0_31*dmats0[31][15] + coeff0_32*dmats0[32][15] + coeff0_33*dmats0[33][15] + coeff0_34*dmats0[34][15] + coeff0_35*dmats0[35][15] + coeff0_36*dmats0[36][15] + coeff0_37*dmats0[37][15] + coeff0_38*dmats0[38][15] + coeff0_39*dmats0[39][15] + coeff0_40*dmats0[40][15] + coeff0_41*dmats0[41][15] + coeff0_42*dmats0[42][15] + coeff0_43*dmats0[43][15] + coeff0_44*dmats0[44][15] + coeff0_45*dmats0[45][15] + coeff0_46*dmats0[46][15] + coeff0_47*dmats0[47][15] + coeff0_48*dmats0[48][15] + coeff0_49*dmats0[49][15] + coeff0_50*dmats0[50][15] + coeff0_51*dmats0[51][15] + coeff0_52*dmats0[52][15] + coeff0_53*dmats0[53][15] + coeff0_54*dmats0[54][15] + coeff0_55*dmats0[55][15];
          new_coeff0_16 = coeff0_0*dmats0[0][16] + coeff0_1*dmats0[1][16] + coeff0_2*dmats0[2][16] + coeff0_3*dmats0[3][16] + coeff0_4*dmats0[4][16] + coeff0_5*dmats0[5][16] + coeff0_6*dmats0[6][16] + coeff0_7*dmats0[7][16] + coeff0_8*dmats0[8][16] + coeff0_9*dmats0[9][16] + coeff0_10*dmats0[10][16] + coeff0_11*dmats0[11][16] + coeff0_12*dmats0[12][16] + coeff0_13*dmats0[13][16] + coeff0_14*dmats0[14][16] + coeff0_15*dmats0[15][16] + coeff0_16*dmats0[16][16] + coeff0_17*dmats0[17][16] + coeff0_18*dmats0[18][16] + coeff0_19*dmats0[19][16] + coeff0_20*dmats0[20][16] + coeff0_21*dmats0[21][16] + coeff0_22*dmats0[22][16] + coeff0_23*dmats0[23][16] + coeff0_24*dmats0[24][16] + coeff0_25*dmats0[25][16] + coeff0_26*dmats0[26][16] + coeff0_27*dmats0[27][16] + coeff0_28*dmats0[28][16] + coeff0_29*dmats0[29][16] + coeff0_30*dmats0[30][16] + coeff0_31*dmats0[31][16] + coeff0_32*dmats0[32][16] + coeff0_33*dmats0[33][16] + coeff0_34*dmats0[34][16] + coeff0_35*dmats0[35][16] + coeff0_36*dmats0[36][16] + coeff0_37*dmats0[37][16] + coeff0_38*dmats0[38][16] + coeff0_39*dmats0[39][16] + coeff0_40*dmats0[40][16] + coeff0_41*dmats0[41][16] + coeff0_42*dmats0[42][16] + coeff0_43*dmats0[43][16] + coeff0_44*dmats0[44][16] + coeff0_45*dmats0[45][16] + coeff0_46*dmats0[46][16] + coeff0_47*dmats0[47][16] + coeff0_48*dmats0[48][16] + coeff0_49*dmats0[49][16] + coeff0_50*dmats0[50][16] + coeff0_51*dmats0[51][16] + coeff0_52*dmats0[52][16] + coeff0_53*dmats0[53][16] + coeff0_54*dmats0[54][16] + coeff0_55*dmats0[55][16];
          new_coeff0_17 = coeff0_0*dmats0[0][17] + coeff0_1*dmats0[1][17] + coeff0_2*dmats0[2][17] + coeff0_3*dmats0[3][17] + coeff0_4*dmats0[4][17] + coeff0_5*dmats0[5][17] + coeff0_6*dmats0[6][17] + coeff0_7*dmats0[7][17] + coeff0_8*dmats0[8][17] + coeff0_9*dmats0[9][17] + coeff0_10*dmats0[10][17] + coeff0_11*dmats0[11][17] + coeff0_12*dmats0[12][17] + coeff0_13*dmats0[13][17] + coeff0_14*dmats0[14][17] + coeff0_15*dmats0[15][17] + coeff0_16*dmats0[16][17] + coeff0_17*dmats0[17][17] + coeff0_18*dmats0[18][17] + coeff0_19*dmats0[19][17] + coeff0_20*dmats0[20][17] + coeff0_21*dmats0[21][17] + coeff0_22*dmats0[22][17] + coeff0_23*dmats0[23][17] + coeff0_24*dmats0[24][17] + coeff0_25*dmats0[25][17] + coeff0_26*dmats0[26][17] + coeff0_27*dmats0[27][17] + coeff0_28*dmats0[28][17] + coeff0_29*dmats0[29][17] + coeff0_30*dmats0[30][17] + coeff0_31*dmats0[31][17] + coeff0_32*dmats0[32][17] + coeff0_33*dmats0[33][17] + coeff0_34*dmats0[34][17] + coeff0_35*dmats0[35][17] + coeff0_36*dmats0[36][17] + coeff0_37*dmats0[37][17] + coeff0_38*dmats0[38][17] + coeff0_39*dmats0[39][17] + coeff0_40*dmats0[40][17] + coeff0_41*dmats0[41][17] + coeff0_42*dmats0[42][17] + coeff0_43*dmats0[43][17] + coeff0_44*dmats0[44][17] + coeff0_45*dmats0[45][17] + coeff0_46*dmats0[46][17] + coeff0_47*dmats0[47][17] + coeff0_48*dmats0[48][17] + coeff0_49*dmats0[49][17] + coeff0_50*dmats0[50][17] + coeff0_51*dmats0[51][17] + coeff0_52*dmats0[52][17] + coeff0_53*dmats0[53][17] + coeff0_54*dmats0[54][17] + coeff0_55*dmats0[55][17];
          new_coeff0_18 = coeff0_0*dmats0[0][18] + coeff0_1*dmats0[1][18] + coeff0_2*dmats0[2][18] + coeff0_3*dmats0[3][18] + coeff0_4*dmats0[4][18] + coeff0_5*dmats0[5][18] + coeff0_6*dmats0[6][18] + coeff0_7*dmats0[7][18] + coeff0_8*dmats0[8][18] + coeff0_9*dmats0[9][18] + coeff0_10*dmats0[10][18] + coeff0_11*dmats0[11][18] + coeff0_12*dmats0[12][18] + coeff0_13*dmats0[13][18] + coeff0_14*dmats0[14][18] + coeff0_15*dmats0[15][18] + coeff0_16*dmats0[16][18] + coeff0_17*dmats0[17][18] + coeff0_18*dmats0[18][18] + coeff0_19*dmats0[19][18] + coeff0_20*dmats0[20][18] + coeff0_21*dmats0[21][18] + coeff0_22*dmats0[22][18] + coeff0_23*dmats0[23][18] + coeff0_24*dmats0[24][18] + coeff0_25*dmats0[25][18] + coeff0_26*dmats0[26][18] + coeff0_27*dmats0[27][18] + coeff0_28*dmats0[28][18] + coeff0_29*dmats0[29][18] + coeff0_30*dmats0[30][18] + coeff0_31*dmats0[31][18] + coeff0_32*dmats0[32][18] + coeff0_33*dmats0[33][18] + coeff0_34*dmats0[34][18] + coeff0_35*dmats0[35][18] + coeff0_36*dmats0[36][18] + coeff0_37*dmats0[37][18] + coeff0_38*dmats0[38][18] + coeff0_39*dmats0[39][18] + coeff0_40*dmats0[40][18] + coeff0_41*dmats0[41][18] + coeff0_42*dmats0[42][18] + coeff0_43*dmats0[43][18] + coeff0_44*dmats0[44][18] + coeff0_45*dmats0[45][18] + coeff0_46*dmats0[46][18] + coeff0_47*dmats0[47][18] + coeff0_48*dmats0[48][18] + coeff0_49*dmats0[49][18] + coeff0_50*dmats0[50][18] + coeff0_51*dmats0[51][18] + coeff0_52*dmats0[52][18] + coeff0_53*dmats0[53][18] + coeff0_54*dmats0[54][18] + coeff0_55*dmats0[55][18];
          new_coeff0_19 = coeff0_0*dmats0[0][19] + coeff0_1*dmats0[1][19] + coeff0_2*dmats0[2][19] + coeff0_3*dmats0[3][19] + coeff0_4*dmats0[4][19] + coeff0_5*dmats0[5][19] + coeff0_6*dmats0[6][19] + coeff0_7*dmats0[7][19] + coeff0_8*dmats0[8][19] + coeff0_9*dmats0[9][19] + coeff0_10*dmats0[10][19] + coeff0_11*dmats0[11][19] + coeff0_12*dmats0[12][19] + coeff0_13*dmats0[13][19] + coeff0_14*dmats0[14][19] + coeff0_15*dmats0[15][19] + coeff0_16*dmats0[16][19] + coeff0_17*dmats0[17][19] + coeff0_18*dmats0[18][19] + coeff0_19*dmats0[19][19] + coeff0_20*dmats0[20][19] + coeff0_21*dmats0[21][19] + coeff0_22*dmats0[22][19] + coeff0_23*dmats0[23][19] + coeff0_24*dmats0[24][19] + coeff0_25*dmats0[25][19] + coeff0_26*dmats0[26][19] + coeff0_27*dmats0[27][19] + coeff0_28*dmats0[28][19] + coeff0_29*dmats0[29][19] + coeff0_30*dmats0[30][19] + coeff0_31*dmats0[31][19] + coeff0_32*dmats0[32][19] + coeff0_33*dmats0[33][19] + coeff0_34*dmats0[34][19] + coeff0_35*dmats0[35][19] + coeff0_36*dmats0[36][19] + coeff0_37*dmats0[37][19] + coeff0_38*dmats0[38][19] + coeff0_39*dmats0[39][19] + coeff0_40*dmats0[40][19] + coeff0_41*dmats0[41][19] + coeff0_42*dmats0[42][19] + coeff0_43*dmats0[43][19] + coeff0_44*dmats0[44][19] + coeff0_45*dmats0[45][19] + coeff0_46*dmats0[46][19] + coeff0_47*dmats0[47][19] + coeff0_48*dmats0[48][19] + coeff0_49*dmats0[49][19] + coeff0_50*dmats0[50][19] + coeff0_51*dmats0[51][19] + coeff0_52*dmats0[52][19] + coeff0_53*dmats0[53][19] + coeff0_54*dmats0[54][19] + coeff0_55*dmats0[55][19];
          new_coeff0_20 = coeff0_0*dmats0[0][20] + coeff0_1*dmats0[1][20] + coeff0_2*dmats0[2][20] + coeff0_3*dmats0[3][20] + coeff0_4*dmats0[4][20] + coeff0_5*dmats0[5][20] + coeff0_6*dmats0[6][20] + coeff0_7*dmats0[7][20] + coeff0_8*dmats0[8][20] + coeff0_9*dmats0[9][20] + coeff0_10*dmats0[10][20] + coeff0_11*dmats0[11][20] + coeff0_12*dmats0[12][20] + coeff0_13*dmats0[13][20] + coeff0_14*dmats0[14][20] + coeff0_15*dmats0[15][20] + coeff0_16*dmats0[16][20] + coeff0_17*dmats0[17][20] + coeff0_18*dmats0[18][20] + coeff0_19*dmats0[19][20] + coeff0_20*dmats0[20][20] + coeff0_21*dmats0[21][20] + coeff0_22*dmats0[22][20] + coeff0_23*dmats0[23][20] + coeff0_24*dmats0[24][20] + coeff0_25*dmats0[25][20] + coeff0_26*dmats0[26][20] + coeff0_27*dmats0[27][20] + coeff0_28*dmats0[28][20] + coeff0_29*dmats0[29][20] + coeff0_30*dmats0[30][20] + coeff0_31*dmats0[31][20] + coeff0_32*dmats0[32][20] + coeff0_33*dmats0[33][20] + coeff0_34*dmats0[34][20] + coeff0_35*dmats0[35][20] + coeff0_36*dmats0[36][20] + coeff0_37*dmats0[37][20] + coeff0_38*dmats0[38][20] + coeff0_39*dmats0[39][20] + coeff0_40*dmats0[40][20] + coeff0_41*dmats0[41][20] + coeff0_42*dmats0[42][20] + coeff0_43*dmats0[43][20] + coeff0_44*dmats0[44][20] + coeff0_45*dmats0[45][20] + coeff0_46*dmats0[46][20] + coeff0_47*dmats0[47][20] + coeff0_48*dmats0[48][20] + coeff0_49*dmats0[49][20] + coeff0_50*dmats0[50][20] + coeff0_51*dmats0[51][20] + coeff0_52*dmats0[52][20] + coeff0_53*dmats0[53][20] + coeff0_54*dmats0[54][20] + coeff0_55*dmats0[55][20];
          new_coeff0_21 = coeff0_0*dmats0[0][21] + coeff0_1*dmats0[1][21] + coeff0_2*dmats0[2][21] + coeff0_3*dmats0[3][21] + coeff0_4*dmats0[4][21] + coeff0_5*dmats0[5][21] + coeff0_6*dmats0[6][21] + coeff0_7*dmats0[7][21] + coeff0_8*dmats0[8][21] + coeff0_9*dmats0[9][21] + coeff0_10*dmats0[10][21] + coeff0_11*dmats0[11][21] + coeff0_12*dmats0[12][21] + coeff0_13*dmats0[13][21] + coeff0_14*dmats0[14][21] + coeff0_15*dmats0[15][21] + coeff0_16*dmats0[16][21] + coeff0_17*dmats0[17][21] + coeff0_18*dmats0[18][21] + coeff0_19*dmats0[19][21] + coeff0_20*dmats0[20][21] + coeff0_21*dmats0[21][21] + coeff0_22*dmats0[22][21] + coeff0_23*dmats0[23][21] + coeff0_24*dmats0[24][21] + coeff0_25*dmats0[25][21] + coeff0_26*dmats0[26][21] + coeff0_27*dmats0[27][21] + coeff0_28*dmats0[28][21] + coeff0_29*dmats0[29][21] + coeff0_30*dmats0[30][21] + coeff0_31*dmats0[31][21] + coeff0_32*dmats0[32][21] + coeff0_33*dmats0[33][21] + coeff0_34*dmats0[34][21] + coeff0_35*dmats0[35][21] + coeff0_36*dmats0[36][21] + coeff0_37*dmats0[37][21] + coeff0_38*dmats0[38][21] + coeff0_39*dmats0[39][21] + coeff0_40*dmats0[40][21] + coeff0_41*dmats0[41][21] + coeff0_42*dmats0[42][21] + coeff0_43*dmats0[43][21] + coeff0_44*dmats0[44][21] + coeff0_45*dmats0[45][21] + coeff0_46*dmats0[46][21] + coeff0_47*dmats0[47][21] + coeff0_48*dmats0[48][21] + coeff0_49*dmats0[49][21] + coeff0_50*dmats0[50][21] + coeff0_51*dmats0[51][21] + coeff0_52*dmats0[52][21] + coeff0_53*dmats0[53][21] + coeff0_54*dmats0[54][21] + coeff0_55*dmats0[55][21];
          new_coeff0_22 = coeff0_0*dmats0[0][22] + coeff0_1*dmats0[1][22] + coeff0_2*dmats0[2][22] + coeff0_3*dmats0[3][22] + coeff0_4*dmats0[4][22] + coeff0_5*dmats0[5][22] + coeff0_6*dmats0[6][22] + coeff0_7*dmats0[7][22] + coeff0_8*dmats0[8][22] + coeff0_9*dmats0[9][22] + coeff0_10*dmats0[10][22] + coeff0_11*dmats0[11][22] + coeff0_12*dmats0[12][22] + coeff0_13*dmats0[13][22] + coeff0_14*dmats0[14][22] + coeff0_15*dmats0[15][22] + coeff0_16*dmats0[16][22] + coeff0_17*dmats0[17][22] + coeff0_18*dmats0[18][22] + coeff0_19*dmats0[19][22] + coeff0_20*dmats0[20][22] + coeff0_21*dmats0[21][22] + coeff0_22*dmats0[22][22] + coeff0_23*dmats0[23][22] + coeff0_24*dmats0[24][22] + coeff0_25*dmats0[25][22] + coeff0_26*dmats0[26][22] + coeff0_27*dmats0[27][22] + coeff0_28*dmats0[28][22] + coeff0_29*dmats0[29][22] + coeff0_30*dmats0[30][22] + coeff0_31*dmats0[31][22] + coeff0_32*dmats0[32][22] + coeff0_33*dmats0[33][22] + coeff0_34*dmats0[34][22] + coeff0_35*dmats0[35][22] + coeff0_36*dmats0[36][22] + coeff0_37*dmats0[37][22] + coeff0_38*dmats0[38][22] + coeff0_39*dmats0[39][22] + coeff0_40*dmats0[40][22] + coeff0_41*dmats0[41][22] + coeff0_42*dmats0[42][22] + coeff0_43*dmats0[43][22] + coeff0_44*dmats0[44][22] + coeff0_45*dmats0[45][22] + coeff0_46*dmats0[46][22] + coeff0_47*dmats0[47][22] + coeff0_48*dmats0[48][22] + coeff0_49*dmats0[49][22] + coeff0_50*dmats0[50][22] + coeff0_51*dmats0[51][22] + coeff0_52*dmats0[52][22] + coeff0_53*dmats0[53][22] + coeff0_54*dmats0[54][22] + coeff0_55*dmats0[55][22];
          new_coeff0_23 = coeff0_0*dmats0[0][23] + coeff0_1*dmats0[1][23] + coeff0_2*dmats0[2][23] + coeff0_3*dmats0[3][23] + coeff0_4*dmats0[4][23] + coeff0_5*dmats0[5][23] + coeff0_6*dmats0[6][23] + coeff0_7*dmats0[7][23] + coeff0_8*dmats0[8][23] + coeff0_9*dmats0[9][23] + coeff0_10*dmats0[10][23] + coeff0_11*dmats0[11][23] + coeff0_12*dmats0[12][23] + coeff0_13*dmats0[13][23] + coeff0_14*dmats0[14][23] + coeff0_15*dmats0[15][23] + coeff0_16*dmats0[16][23] + coeff0_17*dmats0[17][23] + coeff0_18*dmats0[18][23] + coeff0_19*dmats0[19][23] + coeff0_20*dmats0[20][23] + coeff0_21*dmats0[21][23] + coeff0_22*dmats0[22][23] + coeff0_23*dmats0[23][23] + coeff0_24*dmats0[24][23] + coeff0_25*dmats0[25][23] + coeff0_26*dmats0[26][23] + coeff0_27*dmats0[27][23] + coeff0_28*dmats0[28][23] + coeff0_29*dmats0[29][23] + coeff0_30*dmats0[30][23] + coeff0_31*dmats0[31][23] + coeff0_32*dmats0[32][23] + coeff0_33*dmats0[33][23] + coeff0_34*dmats0[34][23] + coeff0_35*dmats0[35][23] + coeff0_36*dmats0[36][23] + coeff0_37*dmats0[37][23] + coeff0_38*dmats0[38][23] + coeff0_39*dmats0[39][23] + coeff0_40*dmats0[40][23] + coeff0_41*dmats0[41][23] + coeff0_42*dmats0[42][23] + coeff0_43*dmats0[43][23] + coeff0_44*dmats0[44][23] + coeff0_45*dmats0[45][23] + coeff0_46*dmats0[46][23] + coeff0_47*dmats0[47][23] + coeff0_48*dmats0[48][23] + coeff0_49*dmats0[49][23] + coeff0_50*dmats0[50][23] + coeff0_51*dmats0[51][23] + coeff0_52*dmats0[52][23] + coeff0_53*dmats0[53][23] + coeff0_54*dmats0[54][23] + coeff0_55*dmats0[55][23];
          new_coeff0_24 = coeff0_0*dmats0[0][24] + coeff0_1*dmats0[1][24] + coeff0_2*dmats0[2][24] + coeff0_3*dmats0[3][24] + coeff0_4*dmats0[4][24] + coeff0_5*dmats0[5][24] + coeff0_6*dmats0[6][24] + coeff0_7*dmats0[7][24] + coeff0_8*dmats0[8][24] + coeff0_9*dmats0[9][24] + coeff0_10*dmats0[10][24] + coeff0_11*dmats0[11][24] + coeff0_12*dmats0[12][24] + coeff0_13*dmats0[13][24] + coeff0_14*dmats0[14][24] + coeff0_15*dmats0[15][24] + coeff0_16*dmats0[16][24] + coeff0_17*dmats0[17][24] + coeff0_18*dmats0[18][24] + coeff0_19*dmats0[19][24] + coeff0_20*dmats0[20][24] + coeff0_21*dmats0[21][24] + coeff0_22*dmats0[22][24] + coeff0_23*dmats0[23][24] + coeff0_24*dmats0[24][24] + coeff0_25*dmats0[25][24] + coeff0_26*dmats0[26][24] + coeff0_27*dmats0[27][24] + coeff0_28*dmats0[28][24] + coeff0_29*dmats0[29][24] + coeff0_30*dmats0[30][24] + coeff0_31*dmats0[31][24] + coeff0_32*dmats0[32][24] + coeff0_33*dmats0[33][24] + coeff0_34*dmats0[34][24] + coeff0_35*dmats0[35][24] + coeff0_36*dmats0[36][24] + coeff0_37*dmats0[37][24] + coeff0_38*dmats0[38][24] + coeff0_39*dmats0[39][24] + coeff0_40*dmats0[40][24] + coeff0_41*dmats0[41][24] + coeff0_42*dmats0[42][24] + coeff0_43*dmats0[43][24] + coeff0_44*dmats0[44][24] + coeff0_45*dmats0[45][24] + coeff0_46*dmats0[46][24] + coeff0_47*dmats0[47][24] + coeff0_48*dmats0[48][24] + coeff0_49*dmats0[49][24] + coeff0_50*dmats0[50][24] + coeff0_51*dmats0[51][24] + coeff0_52*dmats0[52][24] + coeff0_53*dmats0[53][24] + coeff0_54*dmats0[54][24] + coeff0_55*dmats0[55][24];
          new_coeff0_25 = coeff0_0*dmats0[0][25] + coeff0_1*dmats0[1][25] + coeff0_2*dmats0[2][25] + coeff0_3*dmats0[3][25] + coeff0_4*dmats0[4][25] + coeff0_5*dmats0[5][25] + coeff0_6*dmats0[6][25] + coeff0_7*dmats0[7][25] + coeff0_8*dmats0[8][25] + coeff0_9*dmats0[9][25] + coeff0_10*dmats0[10][25] + coeff0_11*dmats0[11][25] + coeff0_12*dmats0[12][25] + coeff0_13*dmats0[13][25] + coeff0_14*dmats0[14][25] + coeff0_15*dmats0[15][25] + coeff0_16*dmats0[16][25] + coeff0_17*dmats0[17][25] + coeff0_18*dmats0[18][25] + coeff0_19*dmats0[19][25] + coeff0_20*dmats0[20][25] + coeff0_21*dmats0[21][25] + coeff0_22*dmats0[22][25] + coeff0_23*dmats0[23][25] + coeff0_24*dmats0[24][25] + coeff0_25*dmats0[25][25] + coeff0_26*dmats0[26][25] + coeff0_27*dmats0[27][25] + coeff0_28*dmats0[28][25] + coeff0_29*dmats0[29][25] + coeff0_30*dmats0[30][25] + coeff0_31*dmats0[31][25] + coeff0_32*dmats0[32][25] + coeff0_33*dmats0[33][25] + coeff0_34*dmats0[34][25] + coeff0_35*dmats0[35][25] + coeff0_36*dmats0[36][25] + coeff0_37*dmats0[37][25] + coeff0_38*dmats0[38][25] + coeff0_39*dmats0[39][25] + coeff0_40*dmats0[40][25] + coeff0_41*dmats0[41][25] + coeff0_42*dmats0[42][25] + coeff0_43*dmats0[43][25] + coeff0_44*dmats0[44][25] + coeff0_45*dmats0[45][25] + coeff0_46*dmats0[46][25] + coeff0_47*dmats0[47][25] + coeff0_48*dmats0[48][25] + coeff0_49*dmats0[49][25] + coeff0_50*dmats0[50][25] + coeff0_51*dmats0[51][25] + coeff0_52*dmats0[52][25] + coeff0_53*dmats0[53][25] + coeff0_54*dmats0[54][25] + coeff0_55*dmats0[55][25];
          new_coeff0_26 = coeff0_0*dmats0[0][26] + coeff0_1*dmats0[1][26] + coeff0_2*dmats0[2][26] + coeff0_3*dmats0[3][26] + coeff0_4*dmats0[4][26] + coeff0_5*dmats0[5][26] + coeff0_6*dmats0[6][26] + coeff0_7*dmats0[7][26] + coeff0_8*dmats0[8][26] + coeff0_9*dmats0[9][26] + coeff0_10*dmats0[10][26] + coeff0_11*dmats0[11][26] + coeff0_12*dmats0[12][26] + coeff0_13*dmats0[13][26] + coeff0_14*dmats0[14][26] + coeff0_15*dmats0[15][26] + coeff0_16*dmats0[16][26] + coeff0_17*dmats0[17][26] + coeff0_18*dmats0[18][26] + coeff0_19*dmats0[19][26] + coeff0_20*dmats0[20][26] + coeff0_21*dmats0[21][26] + coeff0_22*dmats0[22][26] + coeff0_23*dmats0[23][26] + coeff0_24*dmats0[24][26] + coeff0_25*dmats0[25][26] + coeff0_26*dmats0[26][26] + coeff0_27*dmats0[27][26] + coeff0_28*dmats0[28][26] + coeff0_29*dmats0[29][26] + coeff0_30*dmats0[30][26] + coeff0_31*dmats0[31][26] + coeff0_32*dmats0[32][26] + coeff0_33*dmats0[33][26] + coeff0_34*dmats0[34][26] + coeff0_35*dmats0[35][26] + coeff0_36*dmats0[36][26] + coeff0_37*dmats0[37][26] + coeff0_38*dmats0[38][26] + coeff0_39*dmats0[39][26] + coeff0_40*dmats0[40][26] + coeff0_41*dmats0[41][26] + coeff0_42*dmats0[42][26] + coeff0_43*dmats0[43][26] + coeff0_44*dmats0[44][26] + coeff0_45*dmats0[45][26] + coeff0_46*dmats0[46][26] + coeff0_47*dmats0[47][26] + coeff0_48*dmats0[48][26] + coeff0_49*dmats0[49][26] + coeff0_50*dmats0[50][26] + coeff0_51*dmats0[51][26] + coeff0_52*dmats0[52][26] + coeff0_53*dmats0[53][26] + coeff0_54*dmats0[54][26] + coeff0_55*dmats0[55][26];
          new_coeff0_27 = coeff0_0*dmats0[0][27] + coeff0_1*dmats0[1][27] + coeff0_2*dmats0[2][27] + coeff0_3*dmats0[3][27] + coeff0_4*dmats0[4][27] + coeff0_5*dmats0[5][27] + coeff0_6*dmats0[6][27] + coeff0_7*dmats0[7][27] + coeff0_8*dmats0[8][27] + coeff0_9*dmats0[9][27] + coeff0_10*dmats0[10][27] + coeff0_11*dmats0[11][27] + coeff0_12*dmats0[12][27] + coeff0_13*dmats0[13][27] + coeff0_14*dmats0[14][27] + coeff0_15*dmats0[15][27] + coeff0_16*dmats0[16][27] + coeff0_17*dmats0[17][27] + coeff0_18*dmats0[18][27] + coeff0_19*dmats0[19][27] + coeff0_20*dmats0[20][27] + coeff0_21*dmats0[21][27] + coeff0_22*dmats0[22][27] + coeff0_23*dmats0[23][27] + coeff0_24*dmats0[24][27] + coeff0_25*dmats0[25][27] + coeff0_26*dmats0[26][27] + coeff0_27*dmats0[27][27] + coeff0_28*dmats0[28][27] + coeff0_29*dmats0[29][27] + coeff0_30*dmats0[30][27] + coeff0_31*dmats0[31][27] + coeff0_32*dmats0[32][27] + coeff0_33*dmats0[33][27] + coeff0_34*dmats0[34][27] + coeff0_35*dmats0[35][27] + coeff0_36*dmats0[36][27] + coeff0_37*dmats0[37][27] + coeff0_38*dmats0[38][27] + coeff0_39*dmats0[39][27] + coeff0_40*dmats0[40][27] + coeff0_41*dmats0[41][27] + coeff0_42*dmats0[42][27] + coeff0_43*dmats0[43][27] + coeff0_44*dmats0[44][27] + coeff0_45*dmats0[45][27] + coeff0_46*dmats0[46][27] + coeff0_47*dmats0[47][27] + coeff0_48*dmats0[48][27] + coeff0_49*dmats0[49][27] + coeff0_50*dmats0[50][27] + coeff0_51*dmats0[51][27] + coeff0_52*dmats0[52][27] + coeff0_53*dmats0[53][27] + coeff0_54*dmats0[54][27] + coeff0_55*dmats0[55][27];
          new_coeff0_28 = coeff0_0*dmats0[0][28] + coeff0_1*dmats0[1][28] + coeff0_2*dmats0[2][28] + coeff0_3*dmats0[3][28] + coeff0_4*dmats0[4][28] + coeff0_5*dmats0[5][28] + coeff0_6*dmats0[6][28] + coeff0_7*dmats0[7][28] + coeff0_8*dmats0[8][28] + coeff0_9*dmats0[9][28] + coeff0_10*dmats0[10][28] + coeff0_11*dmats0[11][28] + coeff0_12*dmats0[12][28] + coeff0_13*dmats0[13][28] + coeff0_14*dmats0[14][28] + coeff0_15*dmats0[15][28] + coeff0_16*dmats0[16][28] + coeff0_17*dmats0[17][28] + coeff0_18*dmats0[18][28] + coeff0_19*dmats0[19][28] + coeff0_20*dmats0[20][28] + coeff0_21*dmats0[21][28] + coeff0_22*dmats0[22][28] + coeff0_23*dmats0[23][28] + coeff0_24*dmats0[24][28] + coeff0_25*dmats0[25][28] + coeff0_26*dmats0[26][28] + coeff0_27*dmats0[27][28] + coeff0_28*dmats0[28][28] + coeff0_29*dmats0[29][28] + coeff0_30*dmats0[30][28] + coeff0_31*dmats0[31][28] + coeff0_32*dmats0[32][28] + coeff0_33*dmats0[33][28] + coeff0_34*dmats0[34][28] + coeff0_35*dmats0[35][28] + coeff0_36*dmats0[36][28] + coeff0_37*dmats0[37][28] + coeff0_38*dmats0[38][28] + coeff0_39*dmats0[39][28] + coeff0_40*dmats0[40][28] + coeff0_41*dmats0[41][28] + coeff0_42*dmats0[42][28] + coeff0_43*dmats0[43][28] + coeff0_44*dmats0[44][28] + coeff0_45*dmats0[45][28] + coeff0_46*dmats0[46][28] + coeff0_47*dmats0[47][28] + coeff0_48*dmats0[48][28] + coeff0_49*dmats0[49][28] + coeff0_50*dmats0[50][28] + coeff0_51*dmats0[51][28] + coeff0_52*dmats0[52][28] + coeff0_53*dmats0[53][28] + coeff0_54*dmats0[54][28] + coeff0_55*dmats0[55][28];
          new_coeff0_29 = coeff0_0*dmats0[0][29] + coeff0_1*dmats0[1][29] + coeff0_2*dmats0[2][29] + coeff0_3*dmats0[3][29] + coeff0_4*dmats0[4][29] + coeff0_5*dmats0[5][29] + coeff0_6*dmats0[6][29] + coeff0_7*dmats0[7][29] + coeff0_8*dmats0[8][29] + coeff0_9*dmats0[9][29] + coeff0_10*dmats0[10][29] + coeff0_11*dmats0[11][29] + coeff0_12*dmats0[12][29] + coeff0_13*dmats0[13][29] + coeff0_14*dmats0[14][29] + coeff0_15*dmats0[15][29] + coeff0_16*dmats0[16][29] + coeff0_17*dmats0[17][29] + coeff0_18*dmats0[18][29] + coeff0_19*dmats0[19][29] + coeff0_20*dmats0[20][29] + coeff0_21*dmats0[21][29] + coeff0_22*dmats0[22][29] + coeff0_23*dmats0[23][29] + coeff0_24*dmats0[24][29] + coeff0_25*dmats0[25][29] + coeff0_26*dmats0[26][29] + coeff0_27*dmats0[27][29] + coeff0_28*dmats0[28][29] + coeff0_29*dmats0[29][29] + coeff0_30*dmats0[30][29] + coeff0_31*dmats0[31][29] + coeff0_32*dmats0[32][29] + coeff0_33*dmats0[33][29] + coeff0_34*dmats0[34][29] + coeff0_35*dmats0[35][29] + coeff0_36*dmats0[36][29] + coeff0_37*dmats0[37][29] + coeff0_38*dmats0[38][29] + coeff0_39*dmats0[39][29] + coeff0_40*dmats0[40][29] + coeff0_41*dmats0[41][29] + coeff0_42*dmats0[42][29] + coeff0_43*dmats0[43][29] + coeff0_44*dmats0[44][29] + coeff0_45*dmats0[45][29] + coeff0_46*dmats0[46][29] + coeff0_47*dmats0[47][29] + coeff0_48*dmats0[48][29] + coeff0_49*dmats0[49][29] + coeff0_50*dmats0[50][29] + coeff0_51*dmats0[51][29] + coeff0_52*dmats0[52][29] + coeff0_53*dmats0[53][29] + coeff0_54*dmats0[54][29] + coeff0_55*dmats0[55][29];
          new_coeff0_30 = coeff0_0*dmats0[0][30] + coeff0_1*dmats0[1][30] + coeff0_2*dmats0[2][30] + coeff0_3*dmats0[3][30] + coeff0_4*dmats0[4][30] + coeff0_5*dmats0[5][30] + coeff0_6*dmats0[6][30] + coeff0_7*dmats0[7][30] + coeff0_8*dmats0[8][30] + coeff0_9*dmats0[9][30] + coeff0_10*dmats0[10][30] + coeff0_11*dmats0[11][30] + coeff0_12*dmats0[12][30] + coeff0_13*dmats0[13][30] + coeff0_14*dmats0[14][30] + coeff0_15*dmats0[15][30] + coeff0_16*dmats0[16][30] + coeff0_17*dmats0[17][30] + coeff0_18*dmats0[18][30] + coeff0_19*dmats0[19][30] + coeff0_20*dmats0[20][30] + coeff0_21*dmats0[21][30] + coeff0_22*dmats0[22][30] + coeff0_23*dmats0[23][30] + coeff0_24*dmats0[24][30] + coeff0_25*dmats0[25][30] + coeff0_26*dmats0[26][30] + coeff0_27*dmats0[27][30] + coeff0_28*dmats0[28][30] + coeff0_29*dmats0[29][30] + coeff0_30*dmats0[30][30] + coeff0_31*dmats0[31][30] + coeff0_32*dmats0[32][30] + coeff0_33*dmats0[33][30] + coeff0_34*dmats0[34][30] + coeff0_35*dmats0[35][30] + coeff0_36*dmats0[36][30] + coeff0_37*dmats0[37][30] + coeff0_38*dmats0[38][30] + coeff0_39*dmats0[39][30] + coeff0_40*dmats0[40][30] + coeff0_41*dmats0[41][30] + coeff0_42*dmats0[42][30] + coeff0_43*dmats0[43][30] + coeff0_44*dmats0[44][30] + coeff0_45*dmats0[45][30] + coeff0_46*dmats0[46][30] + coeff0_47*dmats0[47][30] + coeff0_48*dmats0[48][30] + coeff0_49*dmats0[49][30] + coeff0_50*dmats0[50][30] + coeff0_51*dmats0[51][30] + coeff0_52*dmats0[52][30] + coeff0_53*dmats0[53][30] + coeff0_54*dmats0[54][30] + coeff0_55*dmats0[55][30];
          new_coeff0_31 = coeff0_0*dmats0[0][31] + coeff0_1*dmats0[1][31] + coeff0_2*dmats0[2][31] + coeff0_3*dmats0[3][31] + coeff0_4*dmats0[4][31] + coeff0_5*dmats0[5][31] + coeff0_6*dmats0[6][31] + coeff0_7*dmats0[7][31] + coeff0_8*dmats0[8][31] + coeff0_9*dmats0[9][31] + coeff0_10*dmats0[10][31] + coeff0_11*dmats0[11][31] + coeff0_12*dmats0[12][31] + coeff0_13*dmats0[13][31] + coeff0_14*dmats0[14][31] + coeff0_15*dmats0[15][31] + coeff0_16*dmats0[16][31] + coeff0_17*dmats0[17][31] + coeff0_18*dmats0[18][31] + coeff0_19*dmats0[19][31] + coeff0_20*dmats0[20][31] + coeff0_21*dmats0[21][31] + coeff0_22*dmats0[22][31] + coeff0_23*dmats0[23][31] + coeff0_24*dmats0[24][31] + coeff0_25*dmats0[25][31] + coeff0_26*dmats0[26][31] + coeff0_27*dmats0[27][31] + coeff0_28*dmats0[28][31] + coeff0_29*dmats0[29][31] + coeff0_30*dmats0[30][31] + coeff0_31*dmats0[31][31] + coeff0_32*dmats0[32][31] + coeff0_33*dmats0[33][31] + coeff0_34*dmats0[34][31] + coeff0_35*dmats0[35][31] + coeff0_36*dmats0[36][31] + coeff0_37*dmats0[37][31] + coeff0_38*dmats0[38][31] + coeff0_39*dmats0[39][31] + coeff0_40*dmats0[40][31] + coeff0_41*dmats0[41][31] + coeff0_42*dmats0[42][31] + coeff0_43*dmats0[43][31] + coeff0_44*dmats0[44][31] + coeff0_45*dmats0[45][31] + coeff0_46*dmats0[46][31] + coeff0_47*dmats0[47][31] + coeff0_48*dmats0[48][31] + coeff0_49*dmats0[49][31] + coeff0_50*dmats0[50][31] + coeff0_51*dmats0[51][31] + coeff0_52*dmats0[52][31] + coeff0_53*dmats0[53][31] + coeff0_54*dmats0[54][31] + coeff0_55*dmats0[55][31];
          new_coeff0_32 = coeff0_0*dmats0[0][32] + coeff0_1*dmats0[1][32] + coeff0_2*dmats0[2][32] + coeff0_3*dmats0[3][32] + coeff0_4*dmats0[4][32] + coeff0_5*dmats0[5][32] + coeff0_6*dmats0[6][32] + coeff0_7*dmats0[7][32] + coeff0_8*dmats0[8][32] + coeff0_9*dmats0[9][32] + coeff0_10*dmats0[10][32] + coeff0_11*dmats0[11][32] + coeff0_12*dmats0[12][32] + coeff0_13*dmats0[13][32] + coeff0_14*dmats0[14][32] + coeff0_15*dmats0[15][32] + coeff0_16*dmats0[16][32] + coeff0_17*dmats0[17][32] + coeff0_18*dmats0[18][32] + coeff0_19*dmats0[19][32] + coeff0_20*dmats0[20][32] + coeff0_21*dmats0[21][32] + coeff0_22*dmats0[22][32] + coeff0_23*dmats0[23][32] + coeff0_24*dmats0[24][32] + coeff0_25*dmats0[25][32] + coeff0_26*dmats0[26][32] + coeff0_27*dmats0[27][32] + coeff0_28*dmats0[28][32] + coeff0_29*dmats0[29][32] + coeff0_30*dmats0[30][32] + coeff0_31*dmats0[31][32] + coeff0_32*dmats0[32][32] + coeff0_33*dmats0[33][32] + coeff0_34*dmats0[34][32] + coeff0_35*dmats0[35][32] + coeff0_36*dmats0[36][32] + coeff0_37*dmats0[37][32] + coeff0_38*dmats0[38][32] + coeff0_39*dmats0[39][32] + coeff0_40*dmats0[40][32] + coeff0_41*dmats0[41][32] + coeff0_42*dmats0[42][32] + coeff0_43*dmats0[43][32] + coeff0_44*dmats0[44][32] + coeff0_45*dmats0[45][32] + coeff0_46*dmats0[46][32] + coeff0_47*dmats0[47][32] + coeff0_48*dmats0[48][32] + coeff0_49*dmats0[49][32] + coeff0_50*dmats0[50][32] + coeff0_51*dmats0[51][32] + coeff0_52*dmats0[52][32] + coeff0_53*dmats0[53][32] + coeff0_54*dmats0[54][32] + coeff0_55*dmats0[55][32];
          new_coeff0_33 = coeff0_0*dmats0[0][33] + coeff0_1*dmats0[1][33] + coeff0_2*dmats0[2][33] + coeff0_3*dmats0[3][33] + coeff0_4*dmats0[4][33] + coeff0_5*dmats0[5][33] + coeff0_6*dmats0[6][33] + coeff0_7*dmats0[7][33] + coeff0_8*dmats0[8][33] + coeff0_9*dmats0[9][33] + coeff0_10*dmats0[10][33] + coeff0_11*dmats0[11][33] + coeff0_12*dmats0[12][33] + coeff0_13*dmats0[13][33] + coeff0_14*dmats0[14][33] + coeff0_15*dmats0[15][33] + coeff0_16*dmats0[16][33] + coeff0_17*dmats0[17][33] + coeff0_18*dmats0[18][33] + coeff0_19*dmats0[19][33] + coeff0_20*dmats0[20][33] + coeff0_21*dmats0[21][33] + coeff0_22*dmats0[22][33] + coeff0_23*dmats0[23][33] + coeff0_24*dmats0[24][33] + coeff0_25*dmats0[25][33] + coeff0_26*dmats0[26][33] + coeff0_27*dmats0[27][33] + coeff0_28*dmats0[28][33] + coeff0_29*dmats0[29][33] + coeff0_30*dmats0[30][33] + coeff0_31*dmats0[31][33] + coeff0_32*dmats0[32][33] + coeff0_33*dmats0[33][33] + coeff0_34*dmats0[34][33] + coeff0_35*dmats0[35][33] + coeff0_36*dmats0[36][33] + coeff0_37*dmats0[37][33] + coeff0_38*dmats0[38][33] + coeff0_39*dmats0[39][33] + coeff0_40*dmats0[40][33] + coeff0_41*dmats0[41][33] + coeff0_42*dmats0[42][33] + coeff0_43*dmats0[43][33] + coeff0_44*dmats0[44][33] + coeff0_45*dmats0[45][33] + coeff0_46*dmats0[46][33] + coeff0_47*dmats0[47][33] + coeff0_48*dmats0[48][33] + coeff0_49*dmats0[49][33] + coeff0_50*dmats0[50][33] + coeff0_51*dmats0[51][33] + coeff0_52*dmats0[52][33] + coeff0_53*dmats0[53][33] + coeff0_54*dmats0[54][33] + coeff0_55*dmats0[55][33];
          new_coeff0_34 = coeff0_0*dmats0[0][34] + coeff0_1*dmats0[1][34] + coeff0_2*dmats0[2][34] + coeff0_3*dmats0[3][34] + coeff0_4*dmats0[4][34] + coeff0_5*dmats0[5][34] + coeff0_6*dmats0[6][34] + coeff0_7*dmats0[7][34] + coeff0_8*dmats0[8][34] + coeff0_9*dmats0[9][34] + coeff0_10*dmats0[10][34] + coeff0_11*dmats0[11][34] + coeff0_12*dmats0[12][34] + coeff0_13*dmats0[13][34] + coeff0_14*dmats0[14][34] + coeff0_15*dmats0[15][34] + coeff0_16*dmats0[16][34] + coeff0_17*dmats0[17][34] + coeff0_18*dmats0[18][34] + coeff0_19*dmats0[19][34] + coeff0_20*dmats0[20][34] + coeff0_21*dmats0[21][34] + coeff0_22*dmats0[22][34] + coeff0_23*dmats0[23][34] + coeff0_24*dmats0[24][34] + coeff0_25*dmats0[25][34] + coeff0_26*dmats0[26][34] + coeff0_27*dmats0[27][34] + coeff0_28*dmats0[28][34] + coeff0_29*dmats0[29][34] + coeff0_30*dmats0[30][34] + coeff0_31*dmats0[31][34] + coeff0_32*dmats0[32][34] + coeff0_33*dmats0[33][34] + coeff0_34*dmats0[34][34] + coeff0_35*dmats0[35][34] + coeff0_36*dmats0[36][34] + coeff0_37*dmats0[37][34] + coeff0_38*dmats0[38][34] + coeff0_39*dmats0[39][34] + coeff0_40*dmats0[40][34] + coeff0_41*dmats0[41][34] + coeff0_42*dmats0[42][34] + coeff0_43*dmats0[43][34] + coeff0_44*dmats0[44][34] + coeff0_45*dmats0[45][34] + coeff0_46*dmats0[46][34] + coeff0_47*dmats0[47][34] + coeff0_48*dmats0[48][34] + coeff0_49*dmats0[49][34] + coeff0_50*dmats0[50][34] + coeff0_51*dmats0[51][34] + coeff0_52*dmats0[52][34] + coeff0_53*dmats0[53][34] + coeff0_54*dmats0[54][34] + coeff0_55*dmats0[55][34];
          new_coeff0_35 = coeff0_0*dmats0[0][35] + coeff0_1*dmats0[1][35] + coeff0_2*dmats0[2][35] + coeff0_3*dmats0[3][35] + coeff0_4*dmats0[4][35] + coeff0_5*dmats0[5][35] + coeff0_6*dmats0[6][35] + coeff0_7*dmats0[7][35] + coeff0_8*dmats0[8][35] + coeff0_9*dmats0[9][35] + coeff0_10*dmats0[10][35] + coeff0_11*dmats0[11][35] + coeff0_12*dmats0[12][35] + coeff0_13*dmats0[13][35] + coeff0_14*dmats0[14][35] + coeff0_15*dmats0[15][35] + coeff0_16*dmats0[16][35] + coeff0_17*dmats0[17][35] + coeff0_18*dmats0[18][35] + coeff0_19*dmats0[19][35] + coeff0_20*dmats0[20][35] + coeff0_21*dmats0[21][35] + coeff0_22*dmats0[22][35] + coeff0_23*dmats0[23][35] + coeff0_24*dmats0[24][35] + coeff0_25*dmats0[25][35] + coeff0_26*dmats0[26][35] + coeff0_27*dmats0[27][35] + coeff0_28*dmats0[28][35] + coeff0_29*dmats0[29][35] + coeff0_30*dmats0[30][35] + coeff0_31*dmats0[31][35] + coeff0_32*dmats0[32][35] + coeff0_33*dmats0[33][35] + coeff0_34*dmats0[34][35] + coeff0_35*dmats0[35][35] + coeff0_36*dmats0[36][35] + coeff0_37*dmats0[37][35] + coeff0_38*dmats0[38][35] + coeff0_39*dmats0[39][35] + coeff0_40*dmats0[40][35] + coeff0_41*dmats0[41][35] + coeff0_42*dmats0[42][35] + coeff0_43*dmats0[43][35] + coeff0_44*dmats0[44][35] + coeff0_45*dmats0[45][35] + coeff0_46*dmats0[46][35] + coeff0_47*dmats0[47][35] + coeff0_48*dmats0[48][35] + coeff0_49*dmats0[49][35] + coeff0_50*dmats0[50][35] + coeff0_51*dmats0[51][35] + coeff0_52*dmats0[52][35] + coeff0_53*dmats0[53][35] + coeff0_54*dmats0[54][35] + coeff0_55*dmats0[55][35];
          new_coeff0_36 = coeff0_0*dmats0[0][36] + coeff0_1*dmats0[1][36] + coeff0_2*dmats0[2][36] + coeff0_3*dmats0[3][36] + coeff0_4*dmats0[4][36] + coeff0_5*dmats0[5][36] + coeff0_6*dmats0[6][36] + coeff0_7*dmats0[7][36] + coeff0_8*dmats0[8][36] + coeff0_9*dmats0[9][36] + coeff0_10*dmats0[10][36] + coeff0_11*dmats0[11][36] + coeff0_12*dmats0[12][36] + coeff0_13*dmats0[13][36] + coeff0_14*dmats0[14][36] + coeff0_15*dmats0[15][36] + coeff0_16*dmats0[16][36] + coeff0_17*dmats0[17][36] + coeff0_18*dmats0[18][36] + coeff0_19*dmats0[19][36] + coeff0_20*dmats0[20][36] + coeff0_21*dmats0[21][36] + coeff0_22*dmats0[22][36] + coeff0_23*dmats0[23][36] + coeff0_24*dmats0[24][36] + coeff0_25*dmats0[25][36] + coeff0_26*dmats0[26][36] + coeff0_27*dmats0[27][36] + coeff0_28*dmats0[28][36] + coeff0_29*dmats0[29][36] + coeff0_30*dmats0[30][36] + coeff0_31*dmats0[31][36] + coeff0_32*dmats0[32][36] + coeff0_33*dmats0[33][36] + coeff0_34*dmats0[34][36] + coeff0_35*dmats0[35][36] + coeff0_36*dmats0[36][36] + coeff0_37*dmats0[37][36] + coeff0_38*dmats0[38][36] + coeff0_39*dmats0[39][36] + coeff0_40*dmats0[40][36] + coeff0_41*dmats0[41][36] + coeff0_42*dmats0[42][36] + coeff0_43*dmats0[43][36] + coeff0_44*dmats0[44][36] + coeff0_45*dmats0[45][36] + coeff0_46*dmats0[46][36] + coeff0_47*dmats0[47][36] + coeff0_48*dmats0[48][36] + coeff0_49*dmats0[49][36] + coeff0_50*dmats0[50][36] + coeff0_51*dmats0[51][36] + coeff0_52*dmats0[52][36] + coeff0_53*dmats0[53][36] + coeff0_54*dmats0[54][36] + coeff0_55*dmats0[55][36];
          new_coeff0_37 = coeff0_0*dmats0[0][37] + coeff0_1*dmats0[1][37] + coeff0_2*dmats0[2][37] + coeff0_3*dmats0[3][37] + coeff0_4*dmats0[4][37] + coeff0_5*dmats0[5][37] + coeff0_6*dmats0[6][37] + coeff0_7*dmats0[7][37] + coeff0_8*dmats0[8][37] + coeff0_9*dmats0[9][37] + coeff0_10*dmats0[10][37] + coeff0_11*dmats0[11][37] + coeff0_12*dmats0[12][37] + coeff0_13*dmats0[13][37] + coeff0_14*dmats0[14][37] + coeff0_15*dmats0[15][37] + coeff0_16*dmats0[16][37] + coeff0_17*dmats0[17][37] + coeff0_18*dmats0[18][37] + coeff0_19*dmats0[19][37] + coeff0_20*dmats0[20][37] + coeff0_21*dmats0[21][37] + coeff0_22*dmats0[22][37] + coeff0_23*dmats0[23][37] + coeff0_24*dmats0[24][37] + coeff0_25*dmats0[25][37] + coeff0_26*dmats0[26][37] + coeff0_27*dmats0[27][37] + coeff0_28*dmats0[28][37] + coeff0_29*dmats0[29][37] + coeff0_30*dmats0[30][37] + coeff0_31*dmats0[31][37] + coeff0_32*dmats0[32][37] + coeff0_33*dmats0[33][37] + coeff0_34*dmats0[34][37] + coeff0_35*dmats0[35][37] + coeff0_36*dmats0[36][37] + coeff0_37*dmats0[37][37] + coeff0_38*dmats0[38][37] + coeff0_39*dmats0[39][37] + coeff0_40*dmats0[40][37] + coeff0_41*dmats0[41][37] + coeff0_42*dmats0[42][37] + coeff0_43*dmats0[43][37] + coeff0_44*dmats0[44][37] + coeff0_45*dmats0[45][37] + coeff0_46*dmats0[46][37] + coeff0_47*dmats0[47][37] + coeff0_48*dmats0[48][37] + coeff0_49*dmats0[49][37] + coeff0_50*dmats0[50][37] + coeff0_51*dmats0[51][37] + coeff0_52*dmats0[52][37] + coeff0_53*dmats0[53][37] + coeff0_54*dmats0[54][37] + coeff0_55*dmats0[55][37];
          new_coeff0_38 = coeff0_0*dmats0[0][38] + coeff0_1*dmats0[1][38] + coeff0_2*dmats0[2][38] + coeff0_3*dmats0[3][38] + coeff0_4*dmats0[4][38] + coeff0_5*dmats0[5][38] + coeff0_6*dmats0[6][38] + coeff0_7*dmats0[7][38] + coeff0_8*dmats0[8][38] + coeff0_9*dmats0[9][38] + coeff0_10*dmats0[10][38] + coeff0_11*dmats0[11][38] + coeff0_12*dmats0[12][38] + coeff0_13*dmats0[13][38] + coeff0_14*dmats0[14][38] + coeff0_15*dmats0[15][38] + coeff0_16*dmats0[16][38] + coeff0_17*dmats0[17][38] + coeff0_18*dmats0[18][38] + coeff0_19*dmats0[19][38] + coeff0_20*dmats0[20][38] + coeff0_21*dmats0[21][38] + coeff0_22*dmats0[22][38] + coeff0_23*dmats0[23][38] + coeff0_24*dmats0[24][38] + coeff0_25*dmats0[25][38] + coeff0_26*dmats0[26][38] + coeff0_27*dmats0[27][38] + coeff0_28*dmats0[28][38] + coeff0_29*dmats0[29][38] + coeff0_30*dmats0[30][38] + coeff0_31*dmats0[31][38] + coeff0_32*dmats0[32][38] + coeff0_33*dmats0[33][38] + coeff0_34*dmats0[34][38] + coeff0_35*dmats0[35][38] + coeff0_36*dmats0[36][38] + coeff0_37*dmats0[37][38] + coeff0_38*dmats0[38][38] + coeff0_39*dmats0[39][38] + coeff0_40*dmats0[40][38] + coeff0_41*dmats0[41][38] + coeff0_42*dmats0[42][38] + coeff0_43*dmats0[43][38] + coeff0_44*dmats0[44][38] + coeff0_45*dmats0[45][38] + coeff0_46*dmats0[46][38] + coeff0_47*dmats0[47][38] + coeff0_48*dmats0[48][38] + coeff0_49*dmats0[49][38] + coeff0_50*dmats0[50][38] + coeff0_51*dmats0[51][38] + coeff0_52*dmats0[52][38] + coeff0_53*dmats0[53][38] + coeff0_54*dmats0[54][38] + coeff0_55*dmats0[55][38];
          new_coeff0_39 = coeff0_0*dmats0[0][39] + coeff0_1*dmats0[1][39] + coeff0_2*dmats0[2][39] + coeff0_3*dmats0[3][39] + coeff0_4*dmats0[4][39] + coeff0_5*dmats0[5][39] + coeff0_6*dmats0[6][39] + coeff0_7*dmats0[7][39] + coeff0_8*dmats0[8][39] + coeff0_9*dmats0[9][39] + coeff0_10*dmats0[10][39] + coeff0_11*dmats0[11][39] + coeff0_12*dmats0[12][39] + coeff0_13*dmats0[13][39] + coeff0_14*dmats0[14][39] + coeff0_15*dmats0[15][39] + coeff0_16*dmats0[16][39] + coeff0_17*dmats0[17][39] + coeff0_18*dmats0[18][39] + coeff0_19*dmats0[19][39] + coeff0_20*dmats0[20][39] + coeff0_21*dmats0[21][39] + coeff0_22*dmats0[22][39] + coeff0_23*dmats0[23][39] + coeff0_24*dmats0[24][39] + coeff0_25*dmats0[25][39] + coeff0_26*dmats0[26][39] + coeff0_27*dmats0[27][39] + coeff0_28*dmats0[28][39] + coeff0_29*dmats0[29][39] + coeff0_30*dmats0[30][39] + coeff0_31*dmats0[31][39] + coeff0_32*dmats0[32][39] + coeff0_33*dmats0[33][39] + coeff0_34*dmats0[34][39] + coeff0_35*dmats0[35][39] + coeff0_36*dmats0[36][39] + coeff0_37*dmats0[37][39] + coeff0_38*dmats0[38][39] + coeff0_39*dmats0[39][39] + coeff0_40*dmats0[40][39] + coeff0_41*dmats0[41][39] + coeff0_42*dmats0[42][39] + coeff0_43*dmats0[43][39] + coeff0_44*dmats0[44][39] + coeff0_45*dmats0[45][39] + coeff0_46*dmats0[46][39] + coeff0_47*dmats0[47][39] + coeff0_48*dmats0[48][39] + coeff0_49*dmats0[49][39] + coeff0_50*dmats0[50][39] + coeff0_51*dmats0[51][39] + coeff0_52*dmats0[52][39] + coeff0_53*dmats0[53][39] + coeff0_54*dmats0[54][39] + coeff0_55*dmats0[55][39];
          new_coeff0_40 = coeff0_0*dmats0[0][40] + coeff0_1*dmats0[1][40] + coeff0_2*dmats0[2][40] + coeff0_3*dmats0[3][40] + coeff0_4*dmats0[4][40] + coeff0_5*dmats0[5][40] + coeff0_6*dmats0[6][40] + coeff0_7*dmats0[7][40] + coeff0_8*dmats0[8][40] + coeff0_9*dmats0[9][40] + coeff0_10*dmats0[10][40] + coeff0_11*dmats0[11][40] + coeff0_12*dmats0[12][40] + coeff0_13*dmats0[13][40] + coeff0_14*dmats0[14][40] + coeff0_15*dmats0[15][40] + coeff0_16*dmats0[16][40] + coeff0_17*dmats0[17][40] + coeff0_18*dmats0[18][40] + coeff0_19*dmats0[19][40] + coeff0_20*dmats0[20][40] + coeff0_21*dmats0[21][40] + coeff0_22*dmats0[22][40] + coeff0_23*dmats0[23][40] + coeff0_24*dmats0[24][40] + coeff0_25*dmats0[25][40] + coeff0_26*dmats0[26][40] + coeff0_27*dmats0[27][40] + coeff0_28*dmats0[28][40] + coeff0_29*dmats0[29][40] + coeff0_30*dmats0[30][40] + coeff0_31*dmats0[31][40] + coeff0_32*dmats0[32][40] + coeff0_33*dmats0[33][40] + coeff0_34*dmats0[34][40] + coeff0_35*dmats0[35][40] + coeff0_36*dmats0[36][40] + coeff0_37*dmats0[37][40] + coeff0_38*dmats0[38][40] + coeff0_39*dmats0[39][40] + coeff0_40*dmats0[40][40] + coeff0_41*dmats0[41][40] + coeff0_42*dmats0[42][40] + coeff0_43*dmats0[43][40] + coeff0_44*dmats0[44][40] + coeff0_45*dmats0[45][40] + coeff0_46*dmats0[46][40] + coeff0_47*dmats0[47][40] + coeff0_48*dmats0[48][40] + coeff0_49*dmats0[49][40] + coeff0_50*dmats0[50][40] + coeff0_51*dmats0[51][40] + coeff0_52*dmats0[52][40] + coeff0_53*dmats0[53][40] + coeff0_54*dmats0[54][40] + coeff0_55*dmats0[55][40];
          new_coeff0_41 = coeff0_0*dmats0[0][41] + coeff0_1*dmats0[1][41] + coeff0_2*dmats0[2][41] + coeff0_3*dmats0[3][41] + coeff0_4*dmats0[4][41] + coeff0_5*dmats0[5][41] + coeff0_6*dmats0[6][41] + coeff0_7*dmats0[7][41] + coeff0_8*dmats0[8][41] + coeff0_9*dmats0[9][41] + coeff0_10*dmats0[10][41] + coeff0_11*dmats0[11][41] + coeff0_12*dmats0[12][41] + coeff0_13*dmats0[13][41] + coeff0_14*dmats0[14][41] + coeff0_15*dmats0[15][41] + coeff0_16*dmats0[16][41] + coeff0_17*dmats0[17][41] + coeff0_18*dmats0[18][41] + coeff0_19*dmats0[19][41] + coeff0_20*dmats0[20][41] + coeff0_21*dmats0[21][41] + coeff0_22*dmats0[22][41] + coeff0_23*dmats0[23][41] + coeff0_24*dmats0[24][41] + coeff0_25*dmats0[25][41] + coeff0_26*dmats0[26][41] + coeff0_27*dmats0[27][41] + coeff0_28*dmats0[28][41] + coeff0_29*dmats0[29][41] + coeff0_30*dmats0[30][41] + coeff0_31*dmats0[31][41] + coeff0_32*dmats0[32][41] + coeff0_33*dmats0[33][41] + coeff0_34*dmats0[34][41] + coeff0_35*dmats0[35][41] + coeff0_36*dmats0[36][41] + coeff0_37*dmats0[37][41] + coeff0_38*dmats0[38][41] + coeff0_39*dmats0[39][41] + coeff0_40*dmats0[40][41] + coeff0_41*dmats0[41][41] + coeff0_42*dmats0[42][41] + coeff0_43*dmats0[43][41] + coeff0_44*dmats0[44][41] + coeff0_45*dmats0[45][41] + coeff0_46*dmats0[46][41] + coeff0_47*dmats0[47][41] + coeff0_48*dmats0[48][41] + coeff0_49*dmats0[49][41] + coeff0_50*dmats0[50][41] + coeff0_51*dmats0[51][41] + coeff0_52*dmats0[52][41] + coeff0_53*dmats0[53][41] + coeff0_54*dmats0[54][41] + coeff0_55*dmats0[55][41];
          new_coeff0_42 = coeff0_0*dmats0[0][42] + coeff0_1*dmats0[1][42] + coeff0_2*dmats0[2][42] + coeff0_3*dmats0[3][42] + coeff0_4*dmats0[4][42] + coeff0_5*dmats0[5][42] + coeff0_6*dmats0[6][42] + coeff0_7*dmats0[7][42] + coeff0_8*dmats0[8][42] + coeff0_9*dmats0[9][42] + coeff0_10*dmats0[10][42] + coeff0_11*dmats0[11][42] + coeff0_12*dmats0[12][42] + coeff0_13*dmats0[13][42] + coeff0_14*dmats0[14][42] + coeff0_15*dmats0[15][42] + coeff0_16*dmats0[16][42] + coeff0_17*dmats0[17][42] + coeff0_18*dmats0[18][42] + coeff0_19*dmats0[19][42] + coeff0_20*dmats0[20][42] + coeff0_21*dmats0[21][42] + coeff0_22*dmats0[22][42] + coeff0_23*dmats0[23][42] + coeff0_24*dmats0[24][42] + coeff0_25*dmats0[25][42] + coeff0_26*dmats0[26][42] + coeff0_27*dmats0[27][42] + coeff0_28*dmats0[28][42] + coeff0_29*dmats0[29][42] + coeff0_30*dmats0[30][42] + coeff0_31*dmats0[31][42] + coeff0_32*dmats0[32][42] + coeff0_33*dmats0[33][42] + coeff0_34*dmats0[34][42] + coeff0_35*dmats0[35][42] + coeff0_36*dmats0[36][42] + coeff0_37*dmats0[37][42] + coeff0_38*dmats0[38][42] + coeff0_39*dmats0[39][42] + coeff0_40*dmats0[40][42] + coeff0_41*dmats0[41][42] + coeff0_42*dmats0[42][42] + coeff0_43*dmats0[43][42] + coeff0_44*dmats0[44][42] + coeff0_45*dmats0[45][42] + coeff0_46*dmats0[46][42] + coeff0_47*dmats0[47][42] + coeff0_48*dmats0[48][42] + coeff0_49*dmats0[49][42] + coeff0_50*dmats0[50][42] + coeff0_51*dmats0[51][42] + coeff0_52*dmats0[52][42] + coeff0_53*dmats0[53][42] + coeff0_54*dmats0[54][42] + coeff0_55*dmats0[55][42];
          new_coeff0_43 = coeff0_0*dmats0[0][43] + coeff0_1*dmats0[1][43] + coeff0_2*dmats0[2][43] + coeff0_3*dmats0[3][43] + coeff0_4*dmats0[4][43] + coeff0_5*dmats0[5][43] + coeff0_6*dmats0[6][43] + coeff0_7*dmats0[7][43] + coeff0_8*dmats0[8][43] + coeff0_9*dmats0[9][43] + coeff0_10*dmats0[10][43] + coeff0_11*dmats0[11][43] + coeff0_12*dmats0[12][43] + coeff0_13*dmats0[13][43] + coeff0_14*dmats0[14][43] + coeff0_15*dmats0[15][43] + coeff0_16*dmats0[16][43] + coeff0_17*dmats0[17][43] + coeff0_18*dmats0[18][43] + coeff0_19*dmats0[19][43] + coeff0_20*dmats0[20][43] + coeff0_21*dmats0[21][43] + coeff0_22*dmats0[22][43] + coeff0_23*dmats0[23][43] + coeff0_24*dmats0[24][43] + coeff0_25*dmats0[25][43] + coeff0_26*dmats0[26][43] + coeff0_27*dmats0[27][43] + coeff0_28*dmats0[28][43] + coeff0_29*dmats0[29][43] + coeff0_30*dmats0[30][43] + coeff0_31*dmats0[31][43] + coeff0_32*dmats0[32][43] + coeff0_33*dmats0[33][43] + coeff0_34*dmats0[34][43] + coeff0_35*dmats0[35][43] + coeff0_36*dmats0[36][43] + coeff0_37*dmats0[37][43] + coeff0_38*dmats0[38][43] + coeff0_39*dmats0[39][43] + coeff0_40*dmats0[40][43] + coeff0_41*dmats0[41][43] + coeff0_42*dmats0[42][43] + coeff0_43*dmats0[43][43] + coeff0_44*dmats0[44][43] + coeff0_45*dmats0[45][43] + coeff0_46*dmats0[46][43] + coeff0_47*dmats0[47][43] + coeff0_48*dmats0[48][43] + coeff0_49*dmats0[49][43] + coeff0_50*dmats0[50][43] + coeff0_51*dmats0[51][43] + coeff0_52*dmats0[52][43] + coeff0_53*dmats0[53][43] + coeff0_54*dmats0[54][43] + coeff0_55*dmats0[55][43];
          new_coeff0_44 = coeff0_0*dmats0[0][44] + coeff0_1*dmats0[1][44] + coeff0_2*dmats0[2][44] + coeff0_3*dmats0[3][44] + coeff0_4*dmats0[4][44] + coeff0_5*dmats0[5][44] + coeff0_6*dmats0[6][44] + coeff0_7*dmats0[7][44] + coeff0_8*dmats0[8][44] + coeff0_9*dmats0[9][44] + coeff0_10*dmats0[10][44] + coeff0_11*dmats0[11][44] + coeff0_12*dmats0[12][44] + coeff0_13*dmats0[13][44] + coeff0_14*dmats0[14][44] + coeff0_15*dmats0[15][44] + coeff0_16*dmats0[16][44] + coeff0_17*dmats0[17][44] + coeff0_18*dmats0[18][44] + coeff0_19*dmats0[19][44] + coeff0_20*dmats0[20][44] + coeff0_21*dmats0[21][44] + coeff0_22*dmats0[22][44] + coeff0_23*dmats0[23][44] + coeff0_24*dmats0[24][44] + coeff0_25*dmats0[25][44] + coeff0_26*dmats0[26][44] + coeff0_27*dmats0[27][44] + coeff0_28*dmats0[28][44] + coeff0_29*dmats0[29][44] + coeff0_30*dmats0[30][44] + coeff0_31*dmats0[31][44] + coeff0_32*dmats0[32][44] + coeff0_33*dmats0[33][44] + coeff0_34*dmats0[34][44] + coeff0_35*dmats0[35][44] + coeff0_36*dmats0[36][44] + coeff0_37*dmats0[37][44] + coeff0_38*dmats0[38][44] + coeff0_39*dmats0[39][44] + coeff0_40*dmats0[40][44] + coeff0_41*dmats0[41][44] + coeff0_42*dmats0[42][44] + coeff0_43*dmats0[43][44] + coeff0_44*dmats0[44][44] + coeff0_45*dmats0[45][44] + coeff0_46*dmats0[46][44] + coeff0_47*dmats0[47][44] + coeff0_48*dmats0[48][44] + coeff0_49*dmats0[49][44] + coeff0_50*dmats0[50][44] + coeff0_51*dmats0[51][44] + coeff0_52*dmats0[52][44] + coeff0_53*dmats0[53][44] + coeff0_54*dmats0[54][44] + coeff0_55*dmats0[55][44];
          new_coeff0_45 = coeff0_0*dmats0[0][45] + coeff0_1*dmats0[1][45] + coeff0_2*dmats0[2][45] + coeff0_3*dmats0[3][45] + coeff0_4*dmats0[4][45] + coeff0_5*dmats0[5][45] + coeff0_6*dmats0[6][45] + coeff0_7*dmats0[7][45] + coeff0_8*dmats0[8][45] + coeff0_9*dmats0[9][45] + coeff0_10*dmats0[10][45] + coeff0_11*dmats0[11][45] + coeff0_12*dmats0[12][45] + coeff0_13*dmats0[13][45] + coeff0_14*dmats0[14][45] + coeff0_15*dmats0[15][45] + coeff0_16*dmats0[16][45] + coeff0_17*dmats0[17][45] + coeff0_18*dmats0[18][45] + coeff0_19*dmats0[19][45] + coeff0_20*dmats0[20][45] + coeff0_21*dmats0[21][45] + coeff0_22*dmats0[22][45] + coeff0_23*dmats0[23][45] + coeff0_24*dmats0[24][45] + coeff0_25*dmats0[25][45] + coeff0_26*dmats0[26][45] + coeff0_27*dmats0[27][45] + coeff0_28*dmats0[28][45] + coeff0_29*dmats0[29][45] + coeff0_30*dmats0[30][45] + coeff0_31*dmats0[31][45] + coeff0_32*dmats0[32][45] + coeff0_33*dmats0[33][45] + coeff0_34*dmats0[34][45] + coeff0_35*dmats0[35][45] + coeff0_36*dmats0[36][45] + coeff0_37*dmats0[37][45] + coeff0_38*dmats0[38][45] + coeff0_39*dmats0[39][45] + coeff0_40*dmats0[40][45] + coeff0_41*dmats0[41][45] + coeff0_42*dmats0[42][45] + coeff0_43*dmats0[43][45] + coeff0_44*dmats0[44][45] + coeff0_45*dmats0[45][45] + coeff0_46*dmats0[46][45] + coeff0_47*dmats0[47][45] + coeff0_48*dmats0[48][45] + coeff0_49*dmats0[49][45] + coeff0_50*dmats0[50][45] + coeff0_51*dmats0[51][45] + coeff0_52*dmats0[52][45] + coeff0_53*dmats0[53][45] + coeff0_54*dmats0[54][45] + coeff0_55*dmats0[55][45];
          new_coeff0_46 = coeff0_0*dmats0[0][46] + coeff0_1*dmats0[1][46] + coeff0_2*dmats0[2][46] + coeff0_3*dmats0[3][46] + coeff0_4*dmats0[4][46] + coeff0_5*dmats0[5][46] + coeff0_6*dmats0[6][46] + coeff0_7*dmats0[7][46] + coeff0_8*dmats0[8][46] + coeff0_9*dmats0[9][46] + coeff0_10*dmats0[10][46] + coeff0_11*dmats0[11][46] + coeff0_12*dmats0[12][46] + coeff0_13*dmats0[13][46] + coeff0_14*dmats0[14][46] + coeff0_15*dmats0[15][46] + coeff0_16*dmats0[16][46] + coeff0_17*dmats0[17][46] + coeff0_18*dmats0[18][46] + coeff0_19*dmats0[19][46] + coeff0_20*dmats0[20][46] + coeff0_21*dmats0[21][46] + coeff0_22*dmats0[22][46] + coeff0_23*dmats0[23][46] + coeff0_24*dmats0[24][46] + coeff0_25*dmats0[25][46] + coeff0_26*dmats0[26][46] + coeff0_27*dmats0[27][46] + coeff0_28*dmats0[28][46] + coeff0_29*dmats0[29][46] + coeff0_30*dmats0[30][46] + coeff0_31*dmats0[31][46] + coeff0_32*dmats0[32][46] + coeff0_33*dmats0[33][46] + coeff0_34*dmats0[34][46] + coeff0_35*dmats0[35][46] + coeff0_36*dmats0[36][46] + coeff0_37*dmats0[37][46] + coeff0_38*dmats0[38][46] + coeff0_39*dmats0[39][46] + coeff0_40*dmats0[40][46] + coeff0_41*dmats0[41][46] + coeff0_42*dmats0[42][46] + coeff0_43*dmats0[43][46] + coeff0_44*dmats0[44][46] + coeff0_45*dmats0[45][46] + coeff0_46*dmats0[46][46] + coeff0_47*dmats0[47][46] + coeff0_48*dmats0[48][46] + coeff0_49*dmats0[49][46] + coeff0_50*dmats0[50][46] + coeff0_51*dmats0[51][46] + coeff0_52*dmats0[52][46] + coeff0_53*dmats0[53][46] + coeff0_54*dmats0[54][46] + coeff0_55*dmats0[55][46];
          new_coeff0_47 = coeff0_0*dmats0[0][47] + coeff0_1*dmats0[1][47] + coeff0_2*dmats0[2][47] + coeff0_3*dmats0[3][47] + coeff0_4*dmats0[4][47] + coeff0_5*dmats0[5][47] + coeff0_6*dmats0[6][47] + coeff0_7*dmats0[7][47] + coeff0_8*dmats0[8][47] + coeff0_9*dmats0[9][47] + coeff0_10*dmats0[10][47] + coeff0_11*dmats0[11][47] + coeff0_12*dmats0[12][47] + coeff0_13*dmats0[13][47] + coeff0_14*dmats0[14][47] + coeff0_15*dmats0[15][47] + coeff0_16*dmats0[16][47] + coeff0_17*dmats0[17][47] + coeff0_18*dmats0[18][47] + coeff0_19*dmats0[19][47] + coeff0_20*dmats0[20][47] + coeff0_21*dmats0[21][47] + coeff0_22*dmats0[22][47] + coeff0_23*dmats0[23][47] + coeff0_24*dmats0[24][47] + coeff0_25*dmats0[25][47] + coeff0_26*dmats0[26][47] + coeff0_27*dmats0[27][47] + coeff0_28*dmats0[28][47] + coeff0_29*dmats0[29][47] + coeff0_30*dmats0[30][47] + coeff0_31*dmats0[31][47] + coeff0_32*dmats0[32][47] + coeff0_33*dmats0[33][47] + coeff0_34*dmats0[34][47] + coeff0_35*dmats0[35][47] + coeff0_36*dmats0[36][47] + coeff0_37*dmats0[37][47] + coeff0_38*dmats0[38][47] + coeff0_39*dmats0[39][47] + coeff0_40*dmats0[40][47] + coeff0_41*dmats0[41][47] + coeff0_42*dmats0[42][47] + coeff0_43*dmats0[43][47] + coeff0_44*dmats0[44][47] + coeff0_45*dmats0[45][47] + coeff0_46*dmats0[46][47] + coeff0_47*dmats0[47][47] + coeff0_48*dmats0[48][47] + coeff0_49*dmats0[49][47] + coeff0_50*dmats0[50][47] + coeff0_51*dmats0[51][47] + coeff0_52*dmats0[52][47] + coeff0_53*dmats0[53][47] + coeff0_54*dmats0[54][47] + coeff0_55*dmats0[55][47];
          new_coeff0_48 = coeff0_0*dmats0[0][48] + coeff0_1*dmats0[1][48] + coeff0_2*dmats0[2][48] + coeff0_3*dmats0[3][48] + coeff0_4*dmats0[4][48] + coeff0_5*dmats0[5][48] + coeff0_6*dmats0[6][48] + coeff0_7*dmats0[7][48] + coeff0_8*dmats0[8][48] + coeff0_9*dmats0[9][48] + coeff0_10*dmats0[10][48] + coeff0_11*dmats0[11][48] + coeff0_12*dmats0[12][48] + coeff0_13*dmats0[13][48] + coeff0_14*dmats0[14][48] + coeff0_15*dmats0[15][48] + coeff0_16*dmats0[16][48] + coeff0_17*dmats0[17][48] + coeff0_18*dmats0[18][48] + coeff0_19*dmats0[19][48] + coeff0_20*dmats0[20][48] + coeff0_21*dmats0[21][48] + coeff0_22*dmats0[22][48] + coeff0_23*dmats0[23][48] + coeff0_24*dmats0[24][48] + coeff0_25*dmats0[25][48] + coeff0_26*dmats0[26][48] + coeff0_27*dmats0[27][48] + coeff0_28*dmats0[28][48] + coeff0_29*dmats0[29][48] + coeff0_30*dmats0[30][48] + coeff0_31*dmats0[31][48] + coeff0_32*dmats0[32][48] + coeff0_33*dmats0[33][48] + coeff0_34*dmats0[34][48] + coeff0_35*dmats0[35][48] + coeff0_36*dmats0[36][48] + coeff0_37*dmats0[37][48] + coeff0_38*dmats0[38][48] + coeff0_39*dmats0[39][48] + coeff0_40*dmats0[40][48] + coeff0_41*dmats0[41][48] + coeff0_42*dmats0[42][48] + coeff0_43*dmats0[43][48] + coeff0_44*dmats0[44][48] + coeff0_45*dmats0[45][48] + coeff0_46*dmats0[46][48] + coeff0_47*dmats0[47][48] + coeff0_48*dmats0[48][48] + coeff0_49*dmats0[49][48] + coeff0_50*dmats0[50][48] + coeff0_51*dmats0[51][48] + coeff0_52*dmats0[52][48] + coeff0_53*dmats0[53][48] + coeff0_54*dmats0[54][48] + coeff0_55*dmats0[55][48];
          new_coeff0_49 = coeff0_0*dmats0[0][49] + coeff0_1*dmats0[1][49] + coeff0_2*dmats0[2][49] + coeff0_3*dmats0[3][49] + coeff0_4*dmats0[4][49] + coeff0_5*dmats0[5][49] + coeff0_6*dmats0[6][49] + coeff0_7*dmats0[7][49] + coeff0_8*dmats0[8][49] + coeff0_9*dmats0[9][49] + coeff0_10*dmats0[10][49] + coeff0_11*dmats0[11][49] + coeff0_12*dmats0[12][49] + coeff0_13*dmats0[13][49] + coeff0_14*dmats0[14][49] + coeff0_15*dmats0[15][49] + coeff0_16*dmats0[16][49] + coeff0_17*dmats0[17][49] + coeff0_18*dmats0[18][49] + coeff0_19*dmats0[19][49] + coeff0_20*dmats0[20][49] + coeff0_21*dmats0[21][49] + coeff0_22*dmats0[22][49] + coeff0_23*dmats0[23][49] + coeff0_24*dmats0[24][49] + coeff0_25*dmats0[25][49] + coeff0_26*dmats0[26][49] + coeff0_27*dmats0[27][49] + coeff0_28*dmats0[28][49] + coeff0_29*dmats0[29][49] + coeff0_30*dmats0[30][49] + coeff0_31*dmats0[31][49] + coeff0_32*dmats0[32][49] + coeff0_33*dmats0[33][49] + coeff0_34*dmats0[34][49] + coeff0_35*dmats0[35][49] + coeff0_36*dmats0[36][49] + coeff0_37*dmats0[37][49] + coeff0_38*dmats0[38][49] + coeff0_39*dmats0[39][49] + coeff0_40*dmats0[40][49] + coeff0_41*dmats0[41][49] + coeff0_42*dmats0[42][49] + coeff0_43*dmats0[43][49] + coeff0_44*dmats0[44][49] + coeff0_45*dmats0[45][49] + coeff0_46*dmats0[46][49] + coeff0_47*dmats0[47][49] + coeff0_48*dmats0[48][49] + coeff0_49*dmats0[49][49] + coeff0_50*dmats0[50][49] + coeff0_51*dmats0[51][49] + coeff0_52*dmats0[52][49] + coeff0_53*dmats0[53][49] + coeff0_54*dmats0[54][49] + coeff0_55*dmats0[55][49];
          new_coeff0_50 = coeff0_0*dmats0[0][50] + coeff0_1*dmats0[1][50] + coeff0_2*dmats0[2][50] + coeff0_3*dmats0[3][50] + coeff0_4*dmats0[4][50] + coeff0_5*dmats0[5][50] + coeff0_6*dmats0[6][50] + coeff0_7*dmats0[7][50] + coeff0_8*dmats0[8][50] + coeff0_9*dmats0[9][50] + coeff0_10*dmats0[10][50] + coeff0_11*dmats0[11][50] + coeff0_12*dmats0[12][50] + coeff0_13*dmats0[13][50] + coeff0_14*dmats0[14][50] + coeff0_15*dmats0[15][50] + coeff0_16*dmats0[16][50] + coeff0_17*dmats0[17][50] + coeff0_18*dmats0[18][50] + coeff0_19*dmats0[19][50] + coeff0_20*dmats0[20][50] + coeff0_21*dmats0[21][50] + coeff0_22*dmats0[22][50] + coeff0_23*dmats0[23][50] + coeff0_24*dmats0[24][50] + coeff0_25*dmats0[25][50] + coeff0_26*dmats0[26][50] + coeff0_27*dmats0[27][50] + coeff0_28*dmats0[28][50] + coeff0_29*dmats0[29][50] + coeff0_30*dmats0[30][50] + coeff0_31*dmats0[31][50] + coeff0_32*dmats0[32][50] + coeff0_33*dmats0[33][50] + coeff0_34*dmats0[34][50] + coeff0_35*dmats0[35][50] + coeff0_36*dmats0[36][50] + coeff0_37*dmats0[37][50] + coeff0_38*dmats0[38][50] + coeff0_39*dmats0[39][50] + coeff0_40*dmats0[40][50] + coeff0_41*dmats0[41][50] + coeff0_42*dmats0[42][50] + coeff0_43*dmats0[43][50] + coeff0_44*dmats0[44][50] + coeff0_45*dmats0[45][50] + coeff0_46*dmats0[46][50] + coeff0_47*dmats0[47][50] + coeff0_48*dmats0[48][50] + coeff0_49*dmats0[49][50] + coeff0_50*dmats0[50][50] + coeff0_51*dmats0[51][50] + coeff0_52*dmats0[52][50] + coeff0_53*dmats0[53][50] + coeff0_54*dmats0[54][50] + coeff0_55*dmats0[55][50];
          new_coeff0_51 = coeff0_0*dmats0[0][51] + coeff0_1*dmats0[1][51] + coeff0_2*dmats0[2][51] + coeff0_3*dmats0[3][51] + coeff0_4*dmats0[4][51] + coeff0_5*dmats0[5][51] + coeff0_6*dmats0[6][51] + coeff0_7*dmats0[7][51] + coeff0_8*dmats0[8][51] + coeff0_9*dmats0[9][51] + coeff0_10*dmats0[10][51] + coeff0_11*dmats0[11][51] + coeff0_12*dmats0[12][51] + coeff0_13*dmats0[13][51] + coeff0_14*dmats0[14][51] + coeff0_15*dmats0[15][51] + coeff0_16*dmats0[16][51] + coeff0_17*dmats0[17][51] + coeff0_18*dmats0[18][51] + coeff0_19*dmats0[19][51] + coeff0_20*dmats0[20][51] + coeff0_21*dmats0[21][51] + coeff0_22*dmats0[22][51] + coeff0_23*dmats0[23][51] + coeff0_24*dmats0[24][51] + coeff0_25*dmats0[25][51] + coeff0_26*dmats0[26][51] + coeff0_27*dmats0[27][51] + coeff0_28*dmats0[28][51] + coeff0_29*dmats0[29][51] + coeff0_30*dmats0[30][51] + coeff0_31*dmats0[31][51] + coeff0_32*dmats0[32][51] + coeff0_33*dmats0[33][51] + coeff0_34*dmats0[34][51] + coeff0_35*dmats0[35][51] + coeff0_36*dmats0[36][51] + coeff0_37*dmats0[37][51] + coeff0_38*dmats0[38][51] + coeff0_39*dmats0[39][51] + coeff0_40*dmats0[40][51] + coeff0_41*dmats0[41][51] + coeff0_42*dmats0[42][51] + coeff0_43*dmats0[43][51] + coeff0_44*dmats0[44][51] + coeff0_45*dmats0[45][51] + coeff0_46*dmats0[46][51] + coeff0_47*dmats0[47][51] + coeff0_48*dmats0[48][51] + coeff0_49*dmats0[49][51] + coeff0_50*dmats0[50][51] + coeff0_51*dmats0[51][51] + coeff0_52*dmats0[52][51] + coeff0_53*dmats0[53][51] + coeff0_54*dmats0[54][51] + coeff0_55*dmats0[55][51];
          new_coeff0_52 = coeff0_0*dmats0[0][52] + coeff0_1*dmats0[1][52] + coeff0_2*dmats0[2][52] + coeff0_3*dmats0[3][52] + coeff0_4*dmats0[4][52] + coeff0_5*dmats0[5][52] + coeff0_6*dmats0[6][52] + coeff0_7*dmats0[7][52] + coeff0_8*dmats0[8][52] + coeff0_9*dmats0[9][52] + coeff0_10*dmats0[10][52] + coeff0_11*dmats0[11][52] + coeff0_12*dmats0[12][52] + coeff0_13*dmats0[13][52] + coeff0_14*dmats0[14][52] + coeff0_15*dmats0[15][52] + coeff0_16*dmats0[16][52] + coeff0_17*dmats0[17][52] + coeff0_18*dmats0[18][52] + coeff0_19*dmats0[19][52] + coeff0_20*dmats0[20][52] + coeff0_21*dmats0[21][52] + coeff0_22*dmats0[22][52] + coeff0_23*dmats0[23][52] + coeff0_24*dmats0[24][52] + coeff0_25*dmats0[25][52] + coeff0_26*dmats0[26][52] + coeff0_27*dmats0[27][52] + coeff0_28*dmats0[28][52] + coeff0_29*dmats0[29][52] + coeff0_30*dmats0[30][52] + coeff0_31*dmats0[31][52] + coeff0_32*dmats0[32][52] + coeff0_33*dmats0[33][52] + coeff0_34*dmats0[34][52] + coeff0_35*dmats0[35][52] + coeff0_36*dmats0[36][52] + coeff0_37*dmats0[37][52] + coeff0_38*dmats0[38][52] + coeff0_39*dmats0[39][52] + coeff0_40*dmats0[40][52] + coeff0_41*dmats0[41][52] + coeff0_42*dmats0[42][52] + coeff0_43*dmats0[43][52] + coeff0_44*dmats0[44][52] + coeff0_45*dmats0[45][52] + coeff0_46*dmats0[46][52] + coeff0_47*dmats0[47][52] + coeff0_48*dmats0[48][52] + coeff0_49*dmats0[49][52] + coeff0_50*dmats0[50][52] + coeff0_51*dmats0[51][52] + coeff0_52*dmats0[52][52] + coeff0_53*dmats0[53][52] + coeff0_54*dmats0[54][52] + coeff0_55*dmats0[55][52];
          new_coeff0_53 = coeff0_0*dmats0[0][53] + coeff0_1*dmats0[1][53] + coeff0_2*dmats0[2][53] + coeff0_3*dmats0[3][53] + coeff0_4*dmats0[4][53] + coeff0_5*dmats0[5][53] + coeff0_6*dmats0[6][53] + coeff0_7*dmats0[7][53] + coeff0_8*dmats0[8][53] + coeff0_9*dmats0[9][53] + coeff0_10*dmats0[10][53] + coeff0_11*dmats0[11][53] + coeff0_12*dmats0[12][53] + coeff0_13*dmats0[13][53] + coeff0_14*dmats0[14][53] + coeff0_15*dmats0[15][53] + coeff0_16*dmats0[16][53] + coeff0_17*dmats0[17][53] + coeff0_18*dmats0[18][53] + coeff0_19*dmats0[19][53] + coeff0_20*dmats0[20][53] + coeff0_21*dmats0[21][53] + coeff0_22*dmats0[22][53] + coeff0_23*dmats0[23][53] + coeff0_24*dmats0[24][53] + coeff0_25*dmats0[25][53] + coeff0_26*dmats0[26][53] + coeff0_27*dmats0[27][53] + coeff0_28*dmats0[28][53] + coeff0_29*dmats0[29][53] + coeff0_30*dmats0[30][53] + coeff0_31*dmats0[31][53] + coeff0_32*dmats0[32][53] + coeff0_33*dmats0[33][53] + coeff0_34*dmats0[34][53] + coeff0_35*dmats0[35][53] + coeff0_36*dmats0[36][53] + coeff0_37*dmats0[37][53] + coeff0_38*dmats0[38][53] + coeff0_39*dmats0[39][53] + coeff0_40*dmats0[40][53] + coeff0_41*dmats0[41][53] + coeff0_42*dmats0[42][53] + coeff0_43*dmats0[43][53] + coeff0_44*dmats0[44][53] + coeff0_45*dmats0[45][53] + coeff0_46*dmats0[46][53] + coeff0_47*dmats0[47][53] + coeff0_48*dmats0[48][53] + coeff0_49*dmats0[49][53] + coeff0_50*dmats0[50][53] + coeff0_51*dmats0[51][53] + coeff0_52*dmats0[52][53] + coeff0_53*dmats0[53][53] + coeff0_54*dmats0[54][53] + coeff0_55*dmats0[55][53];
          new_coeff0_54 = coeff0_0*dmats0[0][54] + coeff0_1*dmats0[1][54] + coeff0_2*dmats0[2][54] + coeff0_3*dmats0[3][54] + coeff0_4*dmats0[4][54] + coeff0_5*dmats0[5][54] + coeff0_6*dmats0[6][54] + coeff0_7*dmats0[7][54] + coeff0_8*dmats0[8][54] + coeff0_9*dmats0[9][54] + coeff0_10*dmats0[10][54] + coeff0_11*dmats0[11][54] + coeff0_12*dmats0[12][54] + coeff0_13*dmats0[13][54] + coeff0_14*dmats0[14][54] + coeff0_15*dmats0[15][54] + coeff0_16*dmats0[16][54] + coeff0_17*dmats0[17][54] + coeff0_18*dmats0[18][54] + coeff0_19*dmats0[19][54] + coeff0_20*dmats0[20][54] + coeff0_21*dmats0[21][54] + coeff0_22*dmats0[22][54] + coeff0_23*dmats0[23][54] + coeff0_24*dmats0[24][54] + coeff0_25*dmats0[25][54] + coeff0_26*dmats0[26][54] + coeff0_27*dmats0[27][54] + coeff0_28*dmats0[28][54] + coeff0_29*dmats0[29][54] + coeff0_30*dmats0[30][54] + coeff0_31*dmats0[31][54] + coeff0_32*dmats0[32][54] + coeff0_33*dmats0[33][54] + coeff0_34*dmats0[34][54] + coeff0_35*dmats0[35][54] + coeff0_36*dmats0[36][54] + coeff0_37*dmats0[37][54] + coeff0_38*dmats0[38][54] + coeff0_39*dmats0[39][54] + coeff0_40*dmats0[40][54] + coeff0_41*dmats0[41][54] + coeff0_42*dmats0[42][54] + coeff0_43*dmats0[43][54] + coeff0_44*dmats0[44][54] + coeff0_45*dmats0[45][54] + coeff0_46*dmats0[46][54] + coeff0_47*dmats0[47][54] + coeff0_48*dmats0[48][54] + coeff0_49*dmats0[49][54] + coeff0_50*dmats0[50][54] + coeff0_51*dmats0[51][54] + coeff0_52*dmats0[52][54] + coeff0_53*dmats0[53][54] + coeff0_54*dmats0[54][54] + coeff0_55*dmats0[55][54];
          new_coeff0_55 = coeff0_0*dmats0[0][55] + coeff0_1*dmats0[1][55] + coeff0_2*dmats0[2][55] + coeff0_3*dmats0[3][55] + coeff0_4*dmats0[4][55] + coeff0_5*dmats0[5][55] + coeff0_6*dmats0[6][55] + coeff0_7*dmats0[7][55] + coeff0_8*dmats0[8][55] + coeff0_9*dmats0[9][55] + coeff0_10*dmats0[10][55] + coeff0_11*dmats0[11][55] + coeff0_12*dmats0[12][55] + coeff0_13*dmats0[13][55] + coeff0_14*dmats0[14][55] + coeff0_15*dmats0[15][55] + coeff0_16*dmats0[16][55] + coeff0_17*dmats0[17][55] + coeff0_18*dmats0[18][55] + coeff0_19*dmats0[19][55] + coeff0_20*dmats0[20][55] + coeff0_21*dmats0[21][55] + coeff0_22*dmats0[22][55] + coeff0_23*dmats0[23][55] + coeff0_24*dmats0[24][55] + coeff0_25*dmats0[25][55] + coeff0_26*dmats0[26][55] + coeff0_27*dmats0[27][55] + coeff0_28*dmats0[28][55] + coeff0_29*dmats0[29][55] + coeff0_30*dmats0[30][55] + coeff0_31*dmats0[31][55] + coeff0_32*dmats0[32][55] + coeff0_33*dmats0[33][55] + coeff0_34*dmats0[34][55] + coeff0_35*dmats0[35][55] + coeff0_36*dmats0[36][55] + coeff0_37*dmats0[37][55] + coeff0_38*dmats0[38][55] + coeff0_39*dmats0[39][55] + coeff0_40*dmats0[40][55] + coeff0_41*dmats0[41][55] + coeff0_42*dmats0[42][55] + coeff0_43*dmats0[43][55] + coeff0_44*dmats0[44][55] + coeff0_45*dmats0[45][55] + coeff0_46*dmats0[46][55] + coeff0_47*dmats0[47][55] + coeff0_48*dmats0[48][55] + coeff0_49*dmats0[49][55] + coeff0_50*dmats0[50][55] + coeff0_51*dmats0[51][55] + coeff0_52*dmats0[52][55] + coeff0_53*dmats0[53][55] + coeff0_54*dmats0[54][55] + coeff0_55*dmats0[55][55];
        }
        if(combinations[deriv_num][j] == 1)
        {
          new_coeff0_0 = coeff0_0*dmats1[0][0] + coeff0_1*dmats1[1][0] + coeff0_2*dmats1[2][0] + coeff0_3*dmats1[3][0] + coeff0_4*dmats1[4][0] + coeff0_5*dmats1[5][0] + coeff0_6*dmats1[6][0] + coeff0_7*dmats1[7][0] + coeff0_8*dmats1[8][0] + coeff0_9*dmats1[9][0] + coeff0_10*dmats1[10][0] + coeff0_11*dmats1[11][0] + coeff0_12*dmats1[12][0] + coeff0_13*dmats1[13][0] + coeff0_14*dmats1[14][0] + coeff0_15*dmats1[15][0] + coeff0_16*dmats1[16][0] + coeff0_17*dmats1[17][0] + coeff0_18*dmats1[18][0] + coeff0_19*dmats1[19][0] + coeff0_20*dmats1[20][0] + coeff0_21*dmats1[21][0] + coeff0_22*dmats1[22][0] + coeff0_23*dmats1[23][0] + coeff0_24*dmats1[24][0] + coeff0_25*dmats1[25][0] + coeff0_26*dmats1[26][0] + coeff0_27*dmats1[27][0] + coeff0_28*dmats1[28][0] + coeff0_29*dmats1[29][0] + coeff0_30*dmats1[30][0] + coeff0_31*dmats1[31][0] + coeff0_32*dmats1[32][0] + coeff0_33*dmats1[33][0] + coeff0_34*dmats1[34][0] + coeff0_35*dmats1[35][0] + coeff0_36*dmats1[36][0] + coeff0_37*dmats1[37][0] + coeff0_38*dmats1[38][0] + coeff0_39*dmats1[39][0] + coeff0_40*dmats1[40][0] + coeff0_41*dmats1[41][0] + coeff0_42*dmats1[42][0] + coeff0_43*dmats1[43][0] + coeff0_44*dmats1[44][0] + coeff0_45*dmats1[45][0] + coeff0_46*dmats1[46][0] + coeff0_47*dmats1[47][0] + coeff0_48*dmats1[48][0] + coeff0_49*dmats1[49][0] + coeff0_50*dmats1[50][0] + coeff0_51*dmats1[51][0] + coeff0_52*dmats1[52][0] + coeff0_53*dmats1[53][0] + coeff0_54*dmats1[54][0] + coeff0_55*dmats1[55][0];
          new_coeff0_1 = coeff0_0*dmats1[0][1] + coeff0_1*dmats1[1][1] + coeff0_2*dmats1[2][1] + coeff0_3*dmats1[3][1] + coeff0_4*dmats1[4][1] + coeff0_5*dmats1[5][1] + coeff0_6*dmats1[6][1] + coeff0_7*dmats1[7][1] + coeff0_8*dmats1[8][1] + coeff0_9*dmats1[9][1] + coeff0_10*dmats1[10][1] + coeff0_11*dmats1[11][1] + coeff0_12*dmats1[12][1] + coeff0_13*dmats1[13][1] + coeff0_14*dmats1[14][1] + coeff0_15*dmats1[15][1] + coeff0_16*dmats1[16][1] + coeff0_17*dmats1[17][1] + coeff0_18*dmats1[18][1] + coeff0_19*dmats1[19][1] + coeff0_20*dmats1[20][1] + coeff0_21*dmats1[21][1] + coeff0_22*dmats1[22][1] + coeff0_23*dmats1[23][1] + coeff0_24*dmats1[24][1] + coeff0_25*dmats1[25][1] + coeff0_26*dmats1[26][1] + coeff0_27*dmats1[27][1] + coeff0_28*dmats1[28][1] + coeff0_29*dmats1[29][1] + coeff0_30*dmats1[30][1] + coeff0_31*dmats1[31][1] + coeff0_32*dmats1[32][1] + coeff0_33*dmats1[33][1] + coeff0_34*dmats1[34][1] + coeff0_35*dmats1[35][1] + coeff0_36*dmats1[36][1] + coeff0_37*dmats1[37][1] + coeff0_38*dmats1[38][1] + coeff0_39*dmats1[39][1] + coeff0_40*dmats1[40][1] + coeff0_41*dmats1[41][1] + coeff0_42*dmats1[42][1] + coeff0_43*dmats1[43][1] + coeff0_44*dmats1[44][1] + coeff0_45*dmats1[45][1] + coeff0_46*dmats1[46][1] + coeff0_47*dmats1[47][1] + coeff0_48*dmats1[48][1] + coeff0_49*dmats1[49][1] + coeff0_50*dmats1[50][1] + coeff0_51*dmats1[51][1] + coeff0_52*dmats1[52][1] + coeff0_53*dmats1[53][1] + coeff0_54*dmats1[54][1] + coeff0_55*dmats1[55][1];
          new_coeff0_2 = coeff0_0*dmats1[0][2] + coeff0_1*dmats1[1][2] + coeff0_2*dmats1[2][2] + coeff0_3*dmats1[3][2] + coeff0_4*dmats1[4][2] + coeff0_5*dmats1[5][2] + coeff0_6*dmats1[6][2] + coeff0_7*dmats1[7][2] + coeff0_8*dmats1[8][2] + coeff0_9*dmats1[9][2] + coeff0_10*dmats1[10][2] + coeff0_11*dmats1[11][2] + coeff0_12*dmats1[12][2] + coeff0_13*dmats1[13][2] + coeff0_14*dmats1[14][2] + coeff0_15*dmats1[15][2] + coeff0_16*dmats1[16][2] + coeff0_17*dmats1[17][2] + coeff0_18*dmats1[18][2] + coeff0_19*dmats1[19][2] + coeff0_20*dmats1[20][2] + coeff0_21*dmats1[21][2] + coeff0_22*dmats1[22][2] + coeff0_23*dmats1[23][2] + coeff0_24*dmats1[24][2] + coeff0_25*dmats1[25][2] + coeff0_26*dmats1[26][2] + coeff0_27*dmats1[27][2] + coeff0_28*dmats1[28][2] + coeff0_29*dmats1[29][2] + coeff0_30*dmats1[30][2] + coeff0_31*dmats1[31][2] + coeff0_32*dmats1[32][2] + coeff0_33*dmats1[33][2] + coeff0_34*dmats1[34][2] + coeff0_35*dmats1[35][2] + coeff0_36*dmats1[36][2] + coeff0_37*dmats1[37][2] + coeff0_38*dmats1[38][2] + coeff0_39*dmats1[39][2] + coeff0_40*dmats1[40][2] + coeff0_41*dmats1[41][2] + coeff0_42*dmats1[42][2] + coeff0_43*dmats1[43][2] + coeff0_44*dmats1[44][2] + coeff0_45*dmats1[45][2] + coeff0_46*dmats1[46][2] + coeff0_47*dmats1[47][2] + coeff0_48*dmats1[48][2] + coeff0_49*dmats1[49][2] + coeff0_50*dmats1[50][2] + coeff0_51*dmats1[51][2] + coeff0_52*dmats1[52][2] + coeff0_53*dmats1[53][2] + coeff0_54*dmats1[54][2] + coeff0_55*dmats1[55][2];
          new_coeff0_3 = coeff0_0*dmats1[0][3] + coeff0_1*dmats1[1][3] + coeff0_2*dmats1[2][3] + coeff0_3*dmats1[3][3] + coeff0_4*dmats1[4][3] + coeff0_5*dmats1[5][3] + coeff0_6*dmats1[6][3] + coeff0_7*dmats1[7][3] + coeff0_8*dmats1[8][3] + coeff0_9*dmats1[9][3] + coeff0_10*dmats1[10][3] + coeff0_11*dmats1[11][3] + coeff0_12*dmats1[12][3] + coeff0_13*dmats1[13][3] + coeff0_14*dmats1[14][3] + coeff0_15*dmats1[15][3] + coeff0_16*dmats1[16][3] + coeff0_17*dmats1[17][3] + coeff0_18*dmats1[18][3] + coeff0_19*dmats1[19][3] + coeff0_20*dmats1[20][3] + coeff0_21*dmats1[21][3] + coeff0_22*dmats1[22][3] + coeff0_23*dmats1[23][3] + coeff0_24*dmats1[24][3] + coeff0_25*dmats1[25][3] + coeff0_26*dmats1[26][3] + coeff0_27*dmats1[27][3] + coeff0_28*dmats1[28][3] + coeff0_29*dmats1[29][3] + coeff0_30*dmats1[30][3] + coeff0_31*dmats1[31][3] + coeff0_32*dmats1[32][3] + coeff0_33*dmats1[33][3] + coeff0_34*dmats1[34][3] + coeff0_35*dmats1[35][3] + coeff0_36*dmats1[36][3] + coeff0_37*dmats1[37][3] + coeff0_38*dmats1[38][3] + coeff0_39*dmats1[39][3] + coeff0_40*dmats1[40][3] + coeff0_41*dmats1[41][3] + coeff0_42*dmats1[42][3] + coeff0_43*dmats1[43][3] + coeff0_44*dmats1[44][3] + coeff0_45*dmats1[45][3] + coeff0_46*dmats1[46][3] + coeff0_47*dmats1[47][3] + coeff0_48*dmats1[48][3] + coeff0_49*dmats1[49][3] + coeff0_50*dmats1[50][3] + coeff0_51*dmats1[51][3] + coeff0_52*dmats1[52][3] + coeff0_53*dmats1[53][3] + coeff0_54*dmats1[54][3] + coeff0_55*dmats1[55][3];
          new_coeff0_4 = coeff0_0*dmats1[0][4] + coeff0_1*dmats1[1][4] + coeff0_2*dmats1[2][4] + coeff0_3*dmats1[3][4] + coeff0_4*dmats1[4][4] + coeff0_5*dmats1[5][4] + coeff0_6*dmats1[6][4] + coeff0_7*dmats1[7][4] + coeff0_8*dmats1[8][4] + coeff0_9*dmats1[9][4] + coeff0_10*dmats1[10][4] + coeff0_11*dmats1[11][4] + coeff0_12*dmats1[12][4] + coeff0_13*dmats1[13][4] + coeff0_14*dmats1[14][4] + coeff0_15*dmats1[15][4] + coeff0_16*dmats1[16][4] + coeff0_17*dmats1[17][4] + coeff0_18*dmats1[18][4] + coeff0_19*dmats1[19][4] + coeff0_20*dmats1[20][4] + coeff0_21*dmats1[21][4] + coeff0_22*dmats1[22][4] + coeff0_23*dmats1[23][4] + coeff0_24*dmats1[24][4] + coeff0_25*dmats1[25][4] + coeff0_26*dmats1[26][4] + coeff0_27*dmats1[27][4] + coeff0_28*dmats1[28][4] + coeff0_29*dmats1[29][4] + coeff0_30*dmats1[30][4] + coeff0_31*dmats1[31][4] + coeff0_32*dmats1[32][4] + coeff0_33*dmats1[33][4] + coeff0_34*dmats1[34][4] + coeff0_35*dmats1[35][4] + coeff0_36*dmats1[36][4] + coeff0_37*dmats1[37][4] + coeff0_38*dmats1[38][4] + coeff0_39*dmats1[39][4] + coeff0_40*dmats1[40][4] + coeff0_41*dmats1[41][4] + coeff0_42*dmats1[42][4] + coeff0_43*dmats1[43][4] + coeff0_44*dmats1[44][4] + coeff0_45*dmats1[45][4] + coeff0_46*dmats1[46][4] + coeff0_47*dmats1[47][4] + coeff0_48*dmats1[48][4] + coeff0_49*dmats1[49][4] + coeff0_50*dmats1[50][4] + coeff0_51*dmats1[51][4] + coeff0_52*dmats1[52][4] + coeff0_53*dmats1[53][4] + coeff0_54*dmats1[54][4] + coeff0_55*dmats1[55][4];
          new_coeff0_5 = coeff0_0*dmats1[0][5] + coeff0_1*dmats1[1][5] + coeff0_2*dmats1[2][5] + coeff0_3*dmats1[3][5] + coeff0_4*dmats1[4][5] + coeff0_5*dmats1[5][5] + coeff0_6*dmats1[6][5] + coeff0_7*dmats1[7][5] + coeff0_8*dmats1[8][5] + coeff0_9*dmats1[9][5] + coeff0_10*dmats1[10][5] + coeff0_11*dmats1[11][5] + coeff0_12*dmats1[12][5] + coeff0_13*dmats1[13][5] + coeff0_14*dmats1[14][5] + coeff0_15*dmats1[15][5] + coeff0_16*dmats1[16][5] + coeff0_17*dmats1[17][5] + coeff0_18*dmats1[18][5] + coeff0_19*dmats1[19][5] + coeff0_20*dmats1[20][5] + coeff0_21*dmats1[21][5] + coeff0_22*dmats1[22][5] + coeff0_23*dmats1[23][5] + coeff0_24*dmats1[24][5] + coeff0_25*dmats1[25][5] + coeff0_26*dmats1[26][5] + coeff0_27*dmats1[27][5] + coeff0_28*dmats1[28][5] + coeff0_29*dmats1[29][5] + coeff0_30*dmats1[30][5] + coeff0_31*dmats1[31][5] + coeff0_32*dmats1[32][5] + coeff0_33*dmats1[33][5] + coeff0_34*dmats1[34][5] + coeff0_35*dmats1[35][5] + coeff0_36*dmats1[36][5] + coeff0_37*dmats1[37][5] + coeff0_38*dmats1[38][5] + coeff0_39*dmats1[39][5] + coeff0_40*dmats1[40][5] + coeff0_41*dmats1[41][5] + coeff0_42*dmats1[42][5] + coeff0_43*dmats1[43][5] + coeff0_44*dmats1[44][5] + coeff0_45*dmats1[45][5] + coeff0_46*dmats1[46][5] + coeff0_47*dmats1[47][5] + coeff0_48*dmats1[48][5] + coeff0_49*dmats1[49][5] + coeff0_50*dmats1[50][5] + coeff0_51*dmats1[51][5] + coeff0_52*dmats1[52][5] + coeff0_53*dmats1[53][5] + coeff0_54*dmats1[54][5] + coeff0_55*dmats1[55][5];
          new_coeff0_6 = coeff0_0*dmats1[0][6] + coeff0_1*dmats1[1][6] + coeff0_2*dmats1[2][6] + coeff0_3*dmats1[3][6] + coeff0_4*dmats1[4][6] + coeff0_5*dmats1[5][6] + coeff0_6*dmats1[6][6] + coeff0_7*dmats1[7][6] + coeff0_8*dmats1[8][6] + coeff0_9*dmats1[9][6] + coeff0_10*dmats1[10][6] + coeff0_11*dmats1[11][6] + coeff0_12*dmats1[12][6] + coeff0_13*dmats1[13][6] + coeff0_14*dmats1[14][6] + coeff0_15*dmats1[15][6] + coeff0_16*dmats1[16][6] + coeff0_17*dmats1[17][6] + coeff0_18*dmats1[18][6] + coeff0_19*dmats1[19][6] + coeff0_20*dmats1[20][6] + coeff0_21*dmats1[21][6] + coeff0_22*dmats1[22][6] + coeff0_23*dmats1[23][6] + coeff0_24*dmats1[24][6] + coeff0_25*dmats1[25][6] + coeff0_26*dmats1[26][6] + coeff0_27*dmats1[27][6] + coeff0_28*dmats1[28][6] + coeff0_29*dmats1[29][6] + coeff0_30*dmats1[30][6] + coeff0_31*dmats1[31][6] + coeff0_32*dmats1[32][6] + coeff0_33*dmats1[33][6] + coeff0_34*dmats1[34][6] + coeff0_35*dmats1[35][6] + coeff0_36*dmats1[36][6] + coeff0_37*dmats1[37][6] + coeff0_38*dmats1[38][6] + coeff0_39*dmats1[39][6] + coeff0_40*dmats1[40][6] + coeff0_41*dmats1[41][6] + coeff0_42*dmats1[42][6] + coeff0_43*dmats1[43][6] + coeff0_44*dmats1[44][6] + coeff0_45*dmats1[45][6] + coeff0_46*dmats1[46][6] + coeff0_47*dmats1[47][6] + coeff0_48*dmats1[48][6] + coeff0_49*dmats1[49][6] + coeff0_50*dmats1[50][6] + coeff0_51*dmats1[51][6] + coeff0_52*dmats1[52][6] + coeff0_53*dmats1[53][6] + coeff0_54*dmats1[54][6] + coeff0_55*dmats1[55][6];
          new_coeff0_7 = coeff0_0*dmats1[0][7] + coeff0_1*dmats1[1][7] + coeff0_2*dmats1[2][7] + coeff0_3*dmats1[3][7] + coeff0_4*dmats1[4][7] + coeff0_5*dmats1[5][7] + coeff0_6*dmats1[6][7] + coeff0_7*dmats1[7][7] + coeff0_8*dmats1[8][7] + coeff0_9*dmats1[9][7] + coeff0_10*dmats1[10][7] + coeff0_11*dmats1[11][7] + coeff0_12*dmats1[12][7] + coeff0_13*dmats1[13][7] + coeff0_14*dmats1[14][7] + coeff0_15*dmats1[15][7] + coeff0_16*dmats1[16][7] + coeff0_17*dmats1[17][7] + coeff0_18*dmats1[18][7] + coeff0_19*dmats1[19][7] + coeff0_20*dmats1[20][7] + coeff0_21*dmats1[21][7] + coeff0_22*dmats1[22][7] + coeff0_23*dmats1[23][7] + coeff0_24*dmats1[24][7] + coeff0_25*dmats1[25][7] + coeff0_26*dmats1[26][7] + coeff0_27*dmats1[27][7] + coeff0_28*dmats1[28][7] + coeff0_29*dmats1[29][7] + coeff0_30*dmats1[30][7] + coeff0_31*dmats1[31][7] + coeff0_32*dmats1[32][7] + coeff0_33*dmats1[33][7] + coeff0_34*dmats1[34][7] + coeff0_35*dmats1[35][7] + coeff0_36*dmats1[36][7] + coeff0_37*dmats1[37][7] + coeff0_38*dmats1[38][7] + coeff0_39*dmats1[39][7] + coeff0_40*dmats1[40][7] + coeff0_41*dmats1[41][7] + coeff0_42*dmats1[42][7] + coeff0_43*dmats1[43][7] + coeff0_44*dmats1[44][7] + coeff0_45*dmats1[45][7] + coeff0_46*dmats1[46][7] + coeff0_47*dmats1[47][7] + coeff0_48*dmats1[48][7] + coeff0_49*dmats1[49][7] + coeff0_50*dmats1[50][7] + coeff0_51*dmats1[51][7] + coeff0_52*dmats1[52][7] + coeff0_53*dmats1[53][7] + coeff0_54*dmats1[54][7] + coeff0_55*dmats1[55][7];
          new_coeff0_8 = coeff0_0*dmats1[0][8] + coeff0_1*dmats1[1][8] + coeff0_2*dmats1[2][8] + coeff0_3*dmats1[3][8] + coeff0_4*dmats1[4][8] + coeff0_5*dmats1[5][8] + coeff0_6*dmats1[6][8] + coeff0_7*dmats1[7][8] + coeff0_8*dmats1[8][8] + coeff0_9*dmats1[9][8] + coeff0_10*dmats1[10][8] + coeff0_11*dmats1[11][8] + coeff0_12*dmats1[12][8] + coeff0_13*dmats1[13][8] + coeff0_14*dmats1[14][8] + coeff0_15*dmats1[15][8] + coeff0_16*dmats1[16][8] + coeff0_17*dmats1[17][8] + coeff0_18*dmats1[18][8] + coeff0_19*dmats1[19][8] + coeff0_20*dmats1[20][8] + coeff0_21*dmats1[21][8] + coeff0_22*dmats1[22][8] + coeff0_23*dmats1[23][8] + coeff0_24*dmats1[24][8] + coeff0_25*dmats1[25][8] + coeff0_26*dmats1[26][8] + coeff0_27*dmats1[27][8] + coeff0_28*dmats1[28][8] + coeff0_29*dmats1[29][8] + coeff0_30*dmats1[30][8] + coeff0_31*dmats1[31][8] + coeff0_32*dmats1[32][8] + coeff0_33*dmats1[33][8] + coeff0_34*dmats1[34][8] + coeff0_35*dmats1[35][8] + coeff0_36*dmats1[36][8] + coeff0_37*dmats1[37][8] + coeff0_38*dmats1[38][8] + coeff0_39*dmats1[39][8] + coeff0_40*dmats1[40][8] + coeff0_41*dmats1[41][8] + coeff0_42*dmats1[42][8] + coeff0_43*dmats1[43][8] + coeff0_44*dmats1[44][8] + coeff0_45*dmats1[45][8] + coeff0_46*dmats1[46][8] + coeff0_47*dmats1[47][8] + coeff0_48*dmats1[48][8] + coeff0_49*dmats1[49][8] + coeff0_50*dmats1[50][8] + coeff0_51*dmats1[51][8] + coeff0_52*dmats1[52][8] + coeff0_53*dmats1[53][8] + coeff0_54*dmats1[54][8] + coeff0_55*dmats1[55][8];
          new_coeff0_9 = coeff0_0*dmats1[0][9] + coeff0_1*dmats1[1][9] + coeff0_2*dmats1[2][9] + coeff0_3*dmats1[3][9] + coeff0_4*dmats1[4][9] + coeff0_5*dmats1[5][9] + coeff0_6*dmats1[6][9] + coeff0_7*dmats1[7][9] + coeff0_8*dmats1[8][9] + coeff0_9*dmats1[9][9] + coeff0_10*dmats1[10][9] + coeff0_11*dmats1[11][9] + coeff0_12*dmats1[12][9] + coeff0_13*dmats1[13][9] + coeff0_14*dmats1[14][9] + coeff0_15*dmats1[15][9] + coeff0_16*dmats1[16][9] + coeff0_17*dmats1[17][9] + coeff0_18*dmats1[18][9] + coeff0_19*dmats1[19][9] + coeff0_20*dmats1[20][9] + coeff0_21*dmats1[21][9] + coeff0_22*dmats1[22][9] + coeff0_23*dmats1[23][9] + coeff0_24*dmats1[24][9] + coeff0_25*dmats1[25][9] + coeff0_26*dmats1[26][9] + coeff0_27*dmats1[27][9] + coeff0_28*dmats1[28][9] + coeff0_29*dmats1[29][9] + coeff0_30*dmats1[30][9] + coeff0_31*dmats1[31][9] + coeff0_32*dmats1[32][9] + coeff0_33*dmats1[33][9] + coeff0_34*dmats1[34][9] + coeff0_35*dmats1[35][9] + coeff0_36*dmats1[36][9] + coeff0_37*dmats1[37][9] + coeff0_38*dmats1[38][9] + coeff0_39*dmats1[39][9] + coeff0_40*dmats1[40][9] + coeff0_41*dmats1[41][9] + coeff0_42*dmats1[42][9] + coeff0_43*dmats1[43][9] + coeff0_44*dmats1[44][9] + coeff0_45*dmats1[45][9] + coeff0_46*dmats1[46][9] + coeff0_47*dmats1[47][9] + coeff0_48*dmats1[48][9] + coeff0_49*dmats1[49][9] + coeff0_50*dmats1[50][9] + coeff0_51*dmats1[51][9] + coeff0_52*dmats1[52][9] + coeff0_53*dmats1[53][9] + coeff0_54*dmats1[54][9] + coeff0_55*dmats1[55][9];
          new_coeff0_10 = coeff0_0*dmats1[0][10] + coeff0_1*dmats1[1][10] + coeff0_2*dmats1[2][10] + coeff0_3*dmats1[3][10] + coeff0_4*dmats1[4][10] + coeff0_5*dmats1[5][10] + coeff0_6*dmats1[6][10] + coeff0_7*dmats1[7][10] + coeff0_8*dmats1[8][10] + coeff0_9*dmats1[9][10] + coeff0_10*dmats1[10][10] + coeff0_11*dmats1[11][10] + coeff0_12*dmats1[12][10] + coeff0_13*dmats1[13][10] + coeff0_14*dmats1[14][10] + coeff0_15*dmats1[15][10] + coeff0_16*dmats1[16][10] + coeff0_17*dmats1[17][10] + coeff0_18*dmats1[18][10] + coeff0_19*dmats1[19][10] + coeff0_20*dmats1[20][10] + coeff0_21*dmats1[21][10] + coeff0_22*dmats1[22][10] + coeff0_23*dmats1[23][10] + coeff0_24*dmats1[24][10] + coeff0_25*dmats1[25][10] + coeff0_26*dmats1[26][10] + coeff0_27*dmats1[27][10] + coeff0_28*dmats1[28][10] + coeff0_29*dmats1[29][10] + coeff0_30*dmats1[30][10] + coeff0_31*dmats1[31][10] + coeff0_32*dmats1[32][10] + coeff0_33*dmats1[33][10] + coeff0_34*dmats1[34][10] + coeff0_35*dmats1[35][10] + coeff0_36*dmats1[36][10] + coeff0_37*dmats1[37][10] + coeff0_38*dmats1[38][10] + coeff0_39*dmats1[39][10] + coeff0_40*dmats1[40][10] + coeff0_41*dmats1[41][10] + coeff0_42*dmats1[42][10] + coeff0_43*dmats1[43][10] + coeff0_44*dmats1[44][10] + coeff0_45*dmats1[45][10] + coeff0_46*dmats1[46][10] + coeff0_47*dmats1[47][10] + coeff0_48*dmats1[48][10] + coeff0_49*dmats1[49][10] + coeff0_50*dmats1[50][10] + coeff0_51*dmats1[51][10] + coeff0_52*dmats1[52][10] + coeff0_53*dmats1[53][10] + coeff0_54*dmats1[54][10] + coeff0_55*dmats1[55][10];
          new_coeff0_11 = coeff0_0*dmats1[0][11] + coeff0_1*dmats1[1][11] + coeff0_2*dmats1[2][11] + coeff0_3*dmats1[3][11] + coeff0_4*dmats1[4][11] + coeff0_5*dmats1[5][11] + coeff0_6*dmats1[6][11] + coeff0_7*dmats1[7][11] + coeff0_8*dmats1[8][11] + coeff0_9*dmats1[9][11] + coeff0_10*dmats1[10][11] + coeff0_11*dmats1[11][11] + coeff0_12*dmats1[12][11] + coeff0_13*dmats1[13][11] + coeff0_14*dmats1[14][11] + coeff0_15*dmats1[15][11] + coeff0_16*dmats1[16][11] + coeff0_17*dmats1[17][11] + coeff0_18*dmats1[18][11] + coeff0_19*dmats1[19][11] + coeff0_20*dmats1[20][11] + coeff0_21*dmats1[21][11] + coeff0_22*dmats1[22][11] + coeff0_23*dmats1[23][11] + coeff0_24*dmats1[24][11] + coeff0_25*dmats1[25][11] + coeff0_26*dmats1[26][11] + coeff0_27*dmats1[27][11] + coeff0_28*dmats1[28][11] + coeff0_29*dmats1[29][11] + coeff0_30*dmats1[30][11] + coeff0_31*dmats1[31][11] + coeff0_32*dmats1[32][11] + coeff0_33*dmats1[33][11] + coeff0_34*dmats1[34][11] + coeff0_35*dmats1[35][11] + coeff0_36*dmats1[36][11] + coeff0_37*dmats1[37][11] + coeff0_38*dmats1[38][11] + coeff0_39*dmats1[39][11] + coeff0_40*dmats1[40][11] + coeff0_41*dmats1[41][11] + coeff0_42*dmats1[42][11] + coeff0_43*dmats1[43][11] + coeff0_44*dmats1[44][11] + coeff0_45*dmats1[45][11] + coeff0_46*dmats1[46][11] + coeff0_47*dmats1[47][11] + coeff0_48*dmats1[48][11] + coeff0_49*dmats1[49][11] + coeff0_50*dmats1[50][11] + coeff0_51*dmats1[51][11] + coeff0_52*dmats1[52][11] + coeff0_53*dmats1[53][11] + coeff0_54*dmats1[54][11] + coeff0_55*dmats1[55][11];
          new_coeff0_12 = coeff0_0*dmats1[0][12] + coeff0_1*dmats1[1][12] + coeff0_2*dmats1[2][12] + coeff0_3*dmats1[3][12] + coeff0_4*dmats1[4][12] + coeff0_5*dmats1[5][12] + coeff0_6*dmats1[6][12] + coeff0_7*dmats1[7][12] + coeff0_8*dmats1[8][12] + coeff0_9*dmats1[9][12] + coeff0_10*dmats1[10][12] + coeff0_11*dmats1[11][12] + coeff0_12*dmats1[12][12] + coeff0_13*dmats1[13][12] + coeff0_14*dmats1[14][12] + coeff0_15*dmats1[15][12] + coeff0_16*dmats1[16][12] + coeff0_17*dmats1[17][12] + coeff0_18*dmats1[18][12] + coeff0_19*dmats1[19][12] + coeff0_20*dmats1[20][12] + coeff0_21*dmats1[21][12] + coeff0_22*dmats1[22][12] + coeff0_23*dmats1[23][12] + coeff0_24*dmats1[24][12] + coeff0_25*dmats1[25][12] + coeff0_26*dmats1[26][12] + coeff0_27*dmats1[27][12] + coeff0_28*dmats1[28][12] + coeff0_29*dmats1[29][12] + coeff0_30*dmats1[30][12] + coeff0_31*dmats1[31][12] + coeff0_32*dmats1[32][12] + coeff0_33*dmats1[33][12] + coeff0_34*dmats1[34][12] + coeff0_35*dmats1[35][12] + coeff0_36*dmats1[36][12] + coeff0_37*dmats1[37][12] + coeff0_38*dmats1[38][12] + coeff0_39*dmats1[39][12] + coeff0_40*dmats1[40][12] + coeff0_41*dmats1[41][12] + coeff0_42*dmats1[42][12] + coeff0_43*dmats1[43][12] + coeff0_44*dmats1[44][12] + coeff0_45*dmats1[45][12] + coeff0_46*dmats1[46][12] + coeff0_47*dmats1[47][12] + coeff0_48*dmats1[48][12] + coeff0_49*dmats1[49][12] + coeff0_50*dmats1[50][12] + coeff0_51*dmats1[51][12] + coeff0_52*dmats1[52][12] + coeff0_53*dmats1[53][12] + coeff0_54*dmats1[54][12] + coeff0_55*dmats1[55][12];
          new_coeff0_13 = coeff0_0*dmats1[0][13] + coeff0_1*dmats1[1][13] + coeff0_2*dmats1[2][13] + coeff0_3*dmats1[3][13] + coeff0_4*dmats1[4][13] + coeff0_5*dmats1[5][13] + coeff0_6*dmats1[6][13] + coeff0_7*dmats1[7][13] + coeff0_8*dmats1[8][13] + coeff0_9*dmats1[9][13] + coeff0_10*dmats1[10][13] + coeff0_11*dmats1[11][13] + coeff0_12*dmats1[12][13] + coeff0_13*dmats1[13][13] + coeff0_14*dmats1[14][13] + coeff0_15*dmats1[15][13] + coeff0_16*dmats1[16][13] + coeff0_17*dmats1[17][13] + coeff0_18*dmats1[18][13] + coeff0_19*dmats1[19][13] + coeff0_20*dmats1[20][13] + coeff0_21*dmats1[21][13] + coeff0_22*dmats1[22][13] + coeff0_23*dmats1[23][13] + coeff0_24*dmats1[24][13] + coeff0_25*dmats1[25][13] + coeff0_26*dmats1[26][13] + coeff0_27*dmats1[27][13] + coeff0_28*dmats1[28][13] + coeff0_29*dmats1[29][13] + coeff0_30*dmats1[30][13] + coeff0_31*dmats1[31][13] + coeff0_32*dmats1[32][13] + coeff0_33*dmats1[33][13] + coeff0_34*dmats1[34][13] + coeff0_35*dmats1[35][13] + coeff0_36*dmats1[36][13] + coeff0_37*dmats1[37][13] + coeff0_38*dmats1[38][13] + coeff0_39*dmats1[39][13] + coeff0_40*dmats1[40][13] + coeff0_41*dmats1[41][13] + coeff0_42*dmats1[42][13] + coeff0_43*dmats1[43][13] + coeff0_44*dmats1[44][13] + coeff0_45*dmats1[45][13] + coeff0_46*dmats1[46][13] + coeff0_47*dmats1[47][13] + coeff0_48*dmats1[48][13] + coeff0_49*dmats1[49][13] + coeff0_50*dmats1[50][13] + coeff0_51*dmats1[51][13] + coeff0_52*dmats1[52][13] + coeff0_53*dmats1[53][13] + coeff0_54*dmats1[54][13] + coeff0_55*dmats1[55][13];
          new_coeff0_14 = coeff0_0*dmats1[0][14] + coeff0_1*dmats1[1][14] + coeff0_2*dmats1[2][14] + coeff0_3*dmats1[3][14] + coeff0_4*dmats1[4][14] + coeff0_5*dmats1[5][14] + coeff0_6*dmats1[6][14] + coeff0_7*dmats1[7][14] + coeff0_8*dmats1[8][14] + coeff0_9*dmats1[9][14] + coeff0_10*dmats1[10][14] + coeff0_11*dmats1[11][14] + coeff0_12*dmats1[12][14] + coeff0_13*dmats1[13][14] + coeff0_14*dmats1[14][14] + coeff0_15*dmats1[15][14] + coeff0_16*dmats1[16][14] + coeff0_17*dmats1[17][14] + coeff0_18*dmats1[18][14] + coeff0_19*dmats1[19][14] + coeff0_20*dmats1[20][14] + coeff0_21*dmats1[21][14] + coeff0_22*dmats1[22][14] + coeff0_23*dmats1[23][14] + coeff0_24*dmats1[24][14] + coeff0_25*dmats1[25][14] + coeff0_26*dmats1[26][14] + coeff0_27*dmats1[27][14] + coeff0_28*dmats1[28][14] + coeff0_29*dmats1[29][14] + coeff0_30*dmats1[30][14] + coeff0_31*dmats1[31][14] + coeff0_32*dmats1[32][14] + coeff0_33*dmats1[33][14] + coeff0_34*dmats1[34][14] + coeff0_35*dmats1[35][14] + coeff0_36*dmats1[36][14] + coeff0_37*dmats1[37][14] + coeff0_38*dmats1[38][14] + coeff0_39*dmats1[39][14] + coeff0_40*dmats1[40][14] + coeff0_41*dmats1[41][14] + coeff0_42*dmats1[42][14] + coeff0_43*dmats1[43][14] + coeff0_44*dmats1[44][14] + coeff0_45*dmats1[45][14] + coeff0_46*dmats1[46][14] + coeff0_47*dmats1[47][14] + coeff0_48*dmats1[48][14] + coeff0_49*dmats1[49][14] + coeff0_50*dmats1[50][14] + coeff0_51*dmats1[51][14] + coeff0_52*dmats1[52][14] + coeff0_53*dmats1[53][14] + coeff0_54*dmats1[54][14] + coeff0_55*dmats1[55][14];
          new_coeff0_15 = coeff0_0*dmats1[0][15] + coeff0_1*dmats1[1][15] + coeff0_2*dmats1[2][15] + coeff0_3*dmats1[3][15] + coeff0_4*dmats1[4][15] + coeff0_5*dmats1[5][15] + coeff0_6*dmats1[6][15] + coeff0_7*dmats1[7][15] + coeff0_8*dmats1[8][15] + coeff0_9*dmats1[9][15] + coeff0_10*dmats1[10][15] + coeff0_11*dmats1[11][15] + coeff0_12*dmats1[12][15] + coeff0_13*dmats1[13][15] + coeff0_14*dmats1[14][15] + coeff0_15*dmats1[15][15] + coeff0_16*dmats1[16][15] + coeff0_17*dmats1[17][15] + coeff0_18*dmats1[18][15] + coeff0_19*dmats1[19][15] + coeff0_20*dmats1[20][15] + coeff0_21*dmats1[21][15] + coeff0_22*dmats1[22][15] + coeff0_23*dmats1[23][15] + coeff0_24*dmats1[24][15] + coeff0_25*dmats1[25][15] + coeff0_26*dmats1[26][15] + coeff0_27*dmats1[27][15] + coeff0_28*dmats1[28][15] + coeff0_29*dmats1[29][15] + coeff0_30*dmats1[30][15] + coeff0_31*dmats1[31][15] + coeff0_32*dmats1[32][15] + coeff0_33*dmats1[33][15] + coeff0_34*dmats1[34][15] + coeff0_35*dmats1[35][15] + coeff0_36*dmats1[36][15] + coeff0_37*dmats1[37][15] + coeff0_38*dmats1[38][15] + coeff0_39*dmats1[39][15] + coeff0_40*dmats1[40][15] + coeff0_41*dmats1[41][15] + coeff0_42*dmats1[42][15] + coeff0_43*dmats1[43][15] + coeff0_44*dmats1[44][15] + coeff0_45*dmats1[45][15] + coeff0_46*dmats1[46][15] + coeff0_47*dmats1[47][15] + coeff0_48*dmats1[48][15] + coeff0_49*dmats1[49][15] + coeff0_50*dmats1[50][15] + coeff0_51*dmats1[51][15] + coeff0_52*dmats1[52][15] + coeff0_53*dmats1[53][15] + coeff0_54*dmats1[54][15] + coeff0_55*dmats1[55][15];
          new_coeff0_16 = coeff0_0*dmats1[0][16] + coeff0_1*dmats1[1][16] + coeff0_2*dmats1[2][16] + coeff0_3*dmats1[3][16] + coeff0_4*dmats1[4][16] + coeff0_5*dmats1[5][16] + coeff0_6*dmats1[6][16] + coeff0_7*dmats1[7][16] + coeff0_8*dmats1[8][16] + coeff0_9*dmats1[9][16] + coeff0_10*dmats1[10][16] + coeff0_11*dmats1[11][16] + coeff0_12*dmats1[12][16] + coeff0_13*dmats1[13][16] + coeff0_14*dmats1[14][16] + coeff0_15*dmats1[15][16] + coeff0_16*dmats1[16][16] + coeff0_17*dmats1[17][16] + coeff0_18*dmats1[18][16] + coeff0_19*dmats1[19][16] + coeff0_20*dmats1[20][16] + coeff0_21*dmats1[21][16] + coeff0_22*dmats1[22][16] + coeff0_23*dmats1[23][16] + coeff0_24*dmats1[24][16] + coeff0_25*dmats1[25][16] + coeff0_26*dmats1[26][16] + coeff0_27*dmats1[27][16] + coeff0_28*dmats1[28][16] + coeff0_29*dmats1[29][16] + coeff0_30*dmats1[30][16] + coeff0_31*dmats1[31][16] + coeff0_32*dmats1[32][16] + coeff0_33*dmats1[33][16] + coeff0_34*dmats1[34][16] + coeff0_35*dmats1[35][16] + coeff0_36*dmats1[36][16] + coeff0_37*dmats1[37][16] + coeff0_38*dmats1[38][16] + coeff0_39*dmats1[39][16] + coeff0_40*dmats1[40][16] + coeff0_41*dmats1[41][16] + coeff0_42*dmats1[42][16] + coeff0_43*dmats1[43][16] + coeff0_44*dmats1[44][16] + coeff0_45*dmats1[45][16] + coeff0_46*dmats1[46][16] + coeff0_47*dmats1[47][16] + coeff0_48*dmats1[48][16] + coeff0_49*dmats1[49][16] + coeff0_50*dmats1[50][16] + coeff0_51*dmats1[51][16] + coeff0_52*dmats1[52][16] + coeff0_53*dmats1[53][16] + coeff0_54*dmats1[54][16] + coeff0_55*dmats1[55][16];
          new_coeff0_17 = coeff0_0*dmats1[0][17] + coeff0_1*dmats1[1][17] + coeff0_2*dmats1[2][17] + coeff0_3*dmats1[3][17] + coeff0_4*dmats1[4][17] + coeff0_5*dmats1[5][17] + coeff0_6*dmats1[6][17] + coeff0_7*dmats1[7][17] + coeff0_8*dmats1[8][17] + coeff0_9*dmats1[9][17] + coeff0_10*dmats1[10][17] + coeff0_11*dmats1[11][17] + coeff0_12*dmats1[12][17] + coeff0_13*dmats1[13][17] + coeff0_14*dmats1[14][17] + coeff0_15*dmats1[15][17] + coeff0_16*dmats1[16][17] + coeff0_17*dmats1[17][17] + coeff0_18*dmats1[18][17] + coeff0_19*dmats1[19][17] + coeff0_20*dmats1[20][17] + coeff0_21*dmats1[21][17] + coeff0_22*dmats1[22][17] + coeff0_23*dmats1[23][17] + coeff0_24*dmats1[24][17] + coeff0_25*dmats1[25][17] + coeff0_26*dmats1[26][17] + coeff0_27*dmats1[27][17] + coeff0_28*dmats1[28][17] + coeff0_29*dmats1[29][17] + coeff0_30*dmats1[30][17] + coeff0_31*dmats1[31][17] + coeff0_32*dmats1[32][17] + coeff0_33*dmats1[33][17] + coeff0_34*dmats1[34][17] + coeff0_35*dmats1[35][17] + coeff0_36*dmats1[36][17] + coeff0_37*dmats1[37][17] + coeff0_38*dmats1[38][17] + coeff0_39*dmats1[39][17] + coeff0_40*dmats1[40][17] + coeff0_41*dmats1[41][17] + coeff0_42*dmats1[42][17] + coeff0_43*dmats1[43][17] + coeff0_44*dmats1[44][17] + coeff0_45*dmats1[45][17] + coeff0_46*dmats1[46][17] + coeff0_47*dmats1[47][17] + coeff0_48*dmats1[48][17] + coeff0_49*dmats1[49][17] + coeff0_50*dmats1[50][17] + coeff0_51*dmats1[51][17] + coeff0_52*dmats1[52][17] + coeff0_53*dmats1[53][17] + coeff0_54*dmats1[54][17] + coeff0_55*dmats1[55][17];
          new_coeff0_18 = coeff0_0*dmats1[0][18] + coeff0_1*dmats1[1][18] + coeff0_2*dmats1[2][18] + coeff0_3*dmats1[3][18] + coeff0_4*dmats1[4][18] + coeff0_5*dmats1[5][18] + coeff0_6*dmats1[6][18] + coeff0_7*dmats1[7][18] + coeff0_8*dmats1[8][18] + coeff0_9*dmats1[9][18] + coeff0_10*dmats1[10][18] + coeff0_11*dmats1[11][18] + coeff0_12*dmats1[12][18] + coeff0_13*dmats1[13][18] + coeff0_14*dmats1[14][18] + coeff0_15*dmats1[15][18] + coeff0_16*dmats1[16][18] + coeff0_17*dmats1[17][18] + coeff0_18*dmats1[18][18] + coeff0_19*dmats1[19][18] + coeff0_20*dmats1[20][18] + coeff0_21*dmats1[21][18] + coeff0_22*dmats1[22][18] + coeff0_23*dmats1[23][18] + coeff0_24*dmats1[24][18] + coeff0_25*dmats1[25][18] + coeff0_26*dmats1[26][18] + coeff0_27*dmats1[27][18] + coeff0_28*dmats1[28][18] + coeff0_29*dmats1[29][18] + coeff0_30*dmats1[30][18] + coeff0_31*dmats1[31][18] + coeff0_32*dmats1[32][18] + coeff0_33*dmats1[33][18] + coeff0_34*dmats1[34][18] + coeff0_35*dmats1[35][18] + coeff0_36*dmats1[36][18] + coeff0_37*dmats1[37][18] + coeff0_38*dmats1[38][18] + coeff0_39*dmats1[39][18] + coeff0_40*dmats1[40][18] + coeff0_41*dmats1[41][18] + coeff0_42*dmats1[42][18] + coeff0_43*dmats1[43][18] + coeff0_44*dmats1[44][18] + coeff0_45*dmats1[45][18] + coeff0_46*dmats1[46][18] + coeff0_47*dmats1[47][18] + coeff0_48*dmats1[48][18] + coeff0_49*dmats1[49][18] + coeff0_50*dmats1[50][18] + coeff0_51*dmats1[51][18] + coeff0_52*dmats1[52][18] + coeff0_53*dmats1[53][18] + coeff0_54*dmats1[54][18] + coeff0_55*dmats1[55][18];
          new_coeff0_19 = coeff0_0*dmats1[0][19] + coeff0_1*dmats1[1][19] + coeff0_2*dmats1[2][19] + coeff0_3*dmats1[3][19] + coeff0_4*dmats1[4][19] + coeff0_5*dmats1[5][19] + coeff0_6*dmats1[6][19] + coeff0_7*dmats1[7][19] + coeff0_8*dmats1[8][19] + coeff0_9*dmats1[9][19] + coeff0_10*dmats1[10][19] + coeff0_11*dmats1[11][19] + coeff0_12*dmats1[12][19] + coeff0_13*dmats1[13][19] + coeff0_14*dmats1[14][19] + coeff0_15*dmats1[15][19] + coeff0_16*dmats1[16][19] + coeff0_17*dmats1[17][19] + coeff0_18*dmats1[18][19] + coeff0_19*dmats1[19][19] + coeff0_20*dmats1[20][19] + coeff0_21*dmats1[21][19] + coeff0_22*dmats1[22][19] + coeff0_23*dmats1[23][19] + coeff0_24*dmats1[24][19] + coeff0_25*dmats1[25][19] + coeff0_26*dmats1[26][19] + coeff0_27*dmats1[27][19] + coeff0_28*dmats1[28][19] + coeff0_29*dmats1[29][19] + coeff0_30*dmats1[30][19] + coeff0_31*dmats1[31][19] + coeff0_32*dmats1[32][19] + coeff0_33*dmats1[33][19] + coeff0_34*dmats1[34][19] + coeff0_35*dmats1[35][19] + coeff0_36*dmats1[36][19] + coeff0_37*dmats1[37][19] + coeff0_38*dmats1[38][19] + coeff0_39*dmats1[39][19] + coeff0_40*dmats1[40][19] + coeff0_41*dmats1[41][19] + coeff0_42*dmats1[42][19] + coeff0_43*dmats1[43][19] + coeff0_44*dmats1[44][19] + coeff0_45*dmats1[45][19] + coeff0_46*dmats1[46][19] + coeff0_47*dmats1[47][19] + coeff0_48*dmats1[48][19] + coeff0_49*dmats1[49][19] + coeff0_50*dmats1[50][19] + coeff0_51*dmats1[51][19] + coeff0_52*dmats1[52][19] + coeff0_53*dmats1[53][19] + coeff0_54*dmats1[54][19] + coeff0_55*dmats1[55][19];
          new_coeff0_20 = coeff0_0*dmats1[0][20] + coeff0_1*dmats1[1][20] + coeff0_2*dmats1[2][20] + coeff0_3*dmats1[3][20] + coeff0_4*dmats1[4][20] + coeff0_5*dmats1[5][20] + coeff0_6*dmats1[6][20] + coeff0_7*dmats1[7][20] + coeff0_8*dmats1[8][20] + coeff0_9*dmats1[9][20] + coeff0_10*dmats1[10][20] + coeff0_11*dmats1[11][20] + coeff0_12*dmats1[12][20] + coeff0_13*dmats1[13][20] + coeff0_14*dmats1[14][20] + coeff0_15*dmats1[15][20] + coeff0_16*dmats1[16][20] + coeff0_17*dmats1[17][20] + coeff0_18*dmats1[18][20] + coeff0_19*dmats1[19][20] + coeff0_20*dmats1[20][20] + coeff0_21*dmats1[21][20] + coeff0_22*dmats1[22][20] + coeff0_23*dmats1[23][20] + coeff0_24*dmats1[24][20] + coeff0_25*dmats1[25][20] + coeff0_26*dmats1[26][20] + coeff0_27*dmats1[27][20] + coeff0_28*dmats1[28][20] + coeff0_29*dmats1[29][20] + coeff0_30*dmats1[30][20] + coeff0_31*dmats1[31][20] + coeff0_32*dmats1[32][20] + coeff0_33*dmats1[33][20] + coeff0_34*dmats1[34][20] + coeff0_35*dmats1[35][20] + coeff0_36*dmats1[36][20] + coeff0_37*dmats1[37][20] + coeff0_38*dmats1[38][20] + coeff0_39*dmats1[39][20] + coeff0_40*dmats1[40][20] + coeff0_41*dmats1[41][20] + coeff0_42*dmats1[42][20] + coeff0_43*dmats1[43][20] + coeff0_44*dmats1[44][20] + coeff0_45*dmats1[45][20] + coeff0_46*dmats1[46][20] + coeff0_47*dmats1[47][20] + coeff0_48*dmats1[48][20] + coeff0_49*dmats1[49][20] + coeff0_50*dmats1[50][20] + coeff0_51*dmats1[51][20] + coeff0_52*dmats1[52][20] + coeff0_53*dmats1[53][20] + coeff0_54*dmats1[54][20] + coeff0_55*dmats1[55][20];
          new_coeff0_21 = coeff0_0*dmats1[0][21] + coeff0_1*dmats1[1][21] + coeff0_2*dmats1[2][21] + coeff0_3*dmats1[3][21] + coeff0_4*dmats1[4][21] + coeff0_5*dmats1[5][21] + coeff0_6*dmats1[6][21] + coeff0_7*dmats1[7][21] + coeff0_8*dmats1[8][21] + coeff0_9*dmats1[9][21] + coeff0_10*dmats1[10][21] + coeff0_11*dmats1[11][21] + coeff0_12*dmats1[12][21] + coeff0_13*dmats1[13][21] + coeff0_14*dmats1[14][21] + coeff0_15*dmats1[15][21] + coeff0_16*dmats1[16][21] + coeff0_17*dmats1[17][21] + coeff0_18*dmats1[18][21] + coeff0_19*dmats1[19][21] + coeff0_20*dmats1[20][21] + coeff0_21*dmats1[21][21] + coeff0_22*dmats1[22][21] + coeff0_23*dmats1[23][21] + coeff0_24*dmats1[24][21] + coeff0_25*dmats1[25][21] + coeff0_26*dmats1[26][21] + coeff0_27*dmats1[27][21] + coeff0_28*dmats1[28][21] + coeff0_29*dmats1[29][21] + coeff0_30*dmats1[30][21] + coeff0_31*dmats1[31][21] + coeff0_32*dmats1[32][21] + coeff0_33*dmats1[33][21] + coeff0_34*dmats1[34][21] + coeff0_35*dmats1[35][21] + coeff0_36*dmats1[36][21] + coeff0_37*dmats1[37][21] + coeff0_38*dmats1[38][21] + coeff0_39*dmats1[39][21] + coeff0_40*dmats1[40][21] + coeff0_41*dmats1[41][21] + coeff0_42*dmats1[42][21] + coeff0_43*dmats1[43][21] + coeff0_44*dmats1[44][21] + coeff0_45*dmats1[45][21] + coeff0_46*dmats1[46][21] + coeff0_47*dmats1[47][21] + coeff0_48*dmats1[48][21] + coeff0_49*dmats1[49][21] + coeff0_50*dmats1[50][21] + coeff0_51*dmats1[51][21] + coeff0_52*dmats1[52][21] + coeff0_53*dmats1[53][21] + coeff0_54*dmats1[54][21] + coeff0_55*dmats1[55][21];
          new_coeff0_22 = coeff0_0*dmats1[0][22] + coeff0_1*dmats1[1][22] + coeff0_2*dmats1[2][22] + coeff0_3*dmats1[3][22] + coeff0_4*dmats1[4][22] + coeff0_5*dmats1[5][22] + coeff0_6*dmats1[6][22] + coeff0_7*dmats1[7][22] + coeff0_8*dmats1[8][22] + coeff0_9*dmats1[9][22] + coeff0_10*dmats1[10][22] + coeff0_11*dmats1[11][22] + coeff0_12*dmats1[12][22] + coeff0_13*dmats1[13][22] + coeff0_14*dmats1[14][22] + coeff0_15*dmats1[15][22] + coeff0_16*dmats1[16][22] + coeff0_17*dmats1[17][22] + coeff0_18*dmats1[18][22] + coeff0_19*dmats1[19][22] + coeff0_20*dmats1[20][22] + coeff0_21*dmats1[21][22] + coeff0_22*dmats1[22][22] + coeff0_23*dmats1[23][22] + coeff0_24*dmats1[24][22] + coeff0_25*dmats1[25][22] + coeff0_26*dmats1[26][22] + coeff0_27*dmats1[27][22] + coeff0_28*dmats1[28][22] + coeff0_29*dmats1[29][22] + coeff0_30*dmats1[30][22] + coeff0_31*dmats1[31][22] + coeff0_32*dmats1[32][22] + coeff0_33*dmats1[33][22] + coeff0_34*dmats1[34][22] + coeff0_35*dmats1[35][22] + coeff0_36*dmats1[36][22] + coeff0_37*dmats1[37][22] + coeff0_38*dmats1[38][22] + coeff0_39*dmats1[39][22] + coeff0_40*dmats1[40][22] + coeff0_41*dmats1[41][22] + coeff0_42*dmats1[42][22] + coeff0_43*dmats1[43][22] + coeff0_44*dmats1[44][22] + coeff0_45*dmats1[45][22] + coeff0_46*dmats1[46][22] + coeff0_47*dmats1[47][22] + coeff0_48*dmats1[48][22] + coeff0_49*dmats1[49][22] + coeff0_50*dmats1[50][22] + coeff0_51*dmats1[51][22] + coeff0_52*dmats1[52][22] + coeff0_53*dmats1[53][22] + coeff0_54*dmats1[54][22] + coeff0_55*dmats1[55][22];
          new_coeff0_23 = coeff0_0*dmats1[0][23] + coeff0_1*dmats1[1][23] + coeff0_2*dmats1[2][23] + coeff0_3*dmats1[3][23] + coeff0_4*dmats1[4][23] + coeff0_5*dmats1[5][23] + coeff0_6*dmats1[6][23] + coeff0_7*dmats1[7][23] + coeff0_8*dmats1[8][23] + coeff0_9*dmats1[9][23] + coeff0_10*dmats1[10][23] + coeff0_11*dmats1[11][23] + coeff0_12*dmats1[12][23] + coeff0_13*dmats1[13][23] + coeff0_14*dmats1[14][23] + coeff0_15*dmats1[15][23] + coeff0_16*dmats1[16][23] + coeff0_17*dmats1[17][23] + coeff0_18*dmats1[18][23] + coeff0_19*dmats1[19][23] + coeff0_20*dmats1[20][23] + coeff0_21*dmats1[21][23] + coeff0_22*dmats1[22][23] + coeff0_23*dmats1[23][23] + coeff0_24*dmats1[24][23] + coeff0_25*dmats1[25][23] + coeff0_26*dmats1[26][23] + coeff0_27*dmats1[27][23] + coeff0_28*dmats1[28][23] + coeff0_29*dmats1[29][23] + coeff0_30*dmats1[30][23] + coeff0_31*dmats1[31][23] + coeff0_32*dmats1[32][23] + coeff0_33*dmats1[33][23] + coeff0_34*dmats1[34][23] + coeff0_35*dmats1[35][23] + coeff0_36*dmats1[36][23] + coeff0_37*dmats1[37][23] + coeff0_38*dmats1[38][23] + coeff0_39*dmats1[39][23] + coeff0_40*dmats1[40][23] + coeff0_41*dmats1[41][23] + coeff0_42*dmats1[42][23] + coeff0_43*dmats1[43][23] + coeff0_44*dmats1[44][23] + coeff0_45*dmats1[45][23] + coeff0_46*dmats1[46][23] + coeff0_47*dmats1[47][23] + coeff0_48*dmats1[48][23] + coeff0_49*dmats1[49][23] + coeff0_50*dmats1[50][23] + coeff0_51*dmats1[51][23] + coeff0_52*dmats1[52][23] + coeff0_53*dmats1[53][23] + coeff0_54*dmats1[54][23] + coeff0_55*dmats1[55][23];
          new_coeff0_24 = coeff0_0*dmats1[0][24] + coeff0_1*dmats1[1][24] + coeff0_2*dmats1[2][24] + coeff0_3*dmats1[3][24] + coeff0_4*dmats1[4][24] + coeff0_5*dmats1[5][24] + coeff0_6*dmats1[6][24] + coeff0_7*dmats1[7][24] + coeff0_8*dmats1[8][24] + coeff0_9*dmats1[9][24] + coeff0_10*dmats1[10][24] + coeff0_11*dmats1[11][24] + coeff0_12*dmats1[12][24] + coeff0_13*dmats1[13][24] + coeff0_14*dmats1[14][24] + coeff0_15*dmats1[15][24] + coeff0_16*dmats1[16][24] + coeff0_17*dmats1[17][24] + coeff0_18*dmats1[18][24] + coeff0_19*dmats1[19][24] + coeff0_20*dmats1[20][24] + coeff0_21*dmats1[21][24] + coeff0_22*dmats1[22][24] + coeff0_23*dmats1[23][24] + coeff0_24*dmats1[24][24] + coeff0_25*dmats1[25][24] + coeff0_26*dmats1[26][24] + coeff0_27*dmats1[27][24] + coeff0_28*dmats1[28][24] + coeff0_29*dmats1[29][24] + coeff0_30*dmats1[30][24] + coeff0_31*dmats1[31][24] + coeff0_32*dmats1[32][24] + coeff0_33*dmats1[33][24] + coeff0_34*dmats1[34][24] + coeff0_35*dmats1[35][24] + coeff0_36*dmats1[36][24] + coeff0_37*dmats1[37][24] + coeff0_38*dmats1[38][24] + coeff0_39*dmats1[39][24] + coeff0_40*dmats1[40][24] + coeff0_41*dmats1[41][24] + coeff0_42*dmats1[42][24] + coeff0_43*dmats1[43][24] + coeff0_44*dmats1[44][24] + coeff0_45*dmats1[45][24] + coeff0_46*dmats1[46][24] + coeff0_47*dmats1[47][24] + coeff0_48*dmats1[48][24] + coeff0_49*dmats1[49][24] + coeff0_50*dmats1[50][24] + coeff0_51*dmats1[51][24] + coeff0_52*dmats1[52][24] + coeff0_53*dmats1[53][24] + coeff0_54*dmats1[54][24] + coeff0_55*dmats1[55][24];
          new_coeff0_25 = coeff0_0*dmats1[0][25] + coeff0_1*dmats1[1][25] + coeff0_2*dmats1[2][25] + coeff0_3*dmats1[3][25] + coeff0_4*dmats1[4][25] + coeff0_5*dmats1[5][25] + coeff0_6*dmats1[6][25] + coeff0_7*dmats1[7][25] + coeff0_8*dmats1[8][25] + coeff0_9*dmats1[9][25] + coeff0_10*dmats1[10][25] + coeff0_11*dmats1[11][25] + coeff0_12*dmats1[12][25] + coeff0_13*dmats1[13][25] + coeff0_14*dmats1[14][25] + coeff0_15*dmats1[15][25] + coeff0_16*dmats1[16][25] + coeff0_17*dmats1[17][25] + coeff0_18*dmats1[18][25] + coeff0_19*dmats1[19][25] + coeff0_20*dmats1[20][25] + coeff0_21*dmats1[21][25] + coeff0_22*dmats1[22][25] + coeff0_23*dmats1[23][25] + coeff0_24*dmats1[24][25] + coeff0_25*dmats1[25][25] + coeff0_26*dmats1[26][25] + coeff0_27*dmats1[27][25] + coeff0_28*dmats1[28][25] + coeff0_29*dmats1[29][25] + coeff0_30*dmats1[30][25] + coeff0_31*dmats1[31][25] + coeff0_32*dmats1[32][25] + coeff0_33*dmats1[33][25] + coeff0_34*dmats1[34][25] + coeff0_35*dmats1[35][25] + coeff0_36*dmats1[36][25] + coeff0_37*dmats1[37][25] + coeff0_38*dmats1[38][25] + coeff0_39*dmats1[39][25] + coeff0_40*dmats1[40][25] + coeff0_41*dmats1[41][25] + coeff0_42*dmats1[42][25] + coeff0_43*dmats1[43][25] + coeff0_44*dmats1[44][25] + coeff0_45*dmats1[45][25] + coeff0_46*dmats1[46][25] + coeff0_47*dmats1[47][25] + coeff0_48*dmats1[48][25] + coeff0_49*dmats1[49][25] + coeff0_50*dmats1[50][25] + coeff0_51*dmats1[51][25] + coeff0_52*dmats1[52][25] + coeff0_53*dmats1[53][25] + coeff0_54*dmats1[54][25] + coeff0_55*dmats1[55][25];
          new_coeff0_26 = coeff0_0*dmats1[0][26] + coeff0_1*dmats1[1][26] + coeff0_2*dmats1[2][26] + coeff0_3*dmats1[3][26] + coeff0_4*dmats1[4][26] + coeff0_5*dmats1[5][26] + coeff0_6*dmats1[6][26] + coeff0_7*dmats1[7][26] + coeff0_8*dmats1[8][26] + coeff0_9*dmats1[9][26] + coeff0_10*dmats1[10][26] + coeff0_11*dmats1[11][26] + coeff0_12*dmats1[12][26] + coeff0_13*dmats1[13][26] + coeff0_14*dmats1[14][26] + coeff0_15*dmats1[15][26] + coeff0_16*dmats1[16][26] + coeff0_17*dmats1[17][26] + coeff0_18*dmats1[18][26] + coeff0_19*dmats1[19][26] + coeff0_20*dmats1[20][26] + coeff0_21*dmats1[21][26] + coeff0_22*dmats1[22][26] + coeff0_23*dmats1[23][26] + coeff0_24*dmats1[24][26] + coeff0_25*dmats1[25][26] + coeff0_26*dmats1[26][26] + coeff0_27*dmats1[27][26] + coeff0_28*dmats1[28][26] + coeff0_29*dmats1[29][26] + coeff0_30*dmats1[30][26] + coeff0_31*dmats1[31][26] + coeff0_32*dmats1[32][26] + coeff0_33*dmats1[33][26] + coeff0_34*dmats1[34][26] + coeff0_35*dmats1[35][26] + coeff0_36*dmats1[36][26] + coeff0_37*dmats1[37][26] + coeff0_38*dmats1[38][26] + coeff0_39*dmats1[39][26] + coeff0_40*dmats1[40][26] + coeff0_41*dmats1[41][26] + coeff0_42*dmats1[42][26] + coeff0_43*dmats1[43][26] + coeff0_44*dmats1[44][26] + coeff0_45*dmats1[45][26] + coeff0_46*dmats1[46][26] + coeff0_47*dmats1[47][26] + coeff0_48*dmats1[48][26] + coeff0_49*dmats1[49][26] + coeff0_50*dmats1[50][26] + coeff0_51*dmats1[51][26] + coeff0_52*dmats1[52][26] + coeff0_53*dmats1[53][26] + coeff0_54*dmats1[54][26] + coeff0_55*dmats1[55][26];
          new_coeff0_27 = coeff0_0*dmats1[0][27] + coeff0_1*dmats1[1][27] + coeff0_2*dmats1[2][27] + coeff0_3*dmats1[3][27] + coeff0_4*dmats1[4][27] + coeff0_5*dmats1[5][27] + coeff0_6*dmats1[6][27] + coeff0_7*dmats1[7][27] + coeff0_8*dmats1[8][27] + coeff0_9*dmats1[9][27] + coeff0_10*dmats1[10][27] + coeff0_11*dmats1[11][27] + coeff0_12*dmats1[12][27] + coeff0_13*dmats1[13][27] + coeff0_14*dmats1[14][27] + coeff0_15*dmats1[15][27] + coeff0_16*dmats1[16][27] + coeff0_17*dmats1[17][27] + coeff0_18*dmats1[18][27] + coeff0_19*dmats1[19][27] + coeff0_20*dmats1[20][27] + coeff0_21*dmats1[21][27] + coeff0_22*dmats1[22][27] + coeff0_23*dmats1[23][27] + coeff0_24*dmats1[24][27] + coeff0_25*dmats1[25][27] + coeff0_26*dmats1[26][27] + coeff0_27*dmats1[27][27] + coeff0_28*dmats1[28][27] + coeff0_29*dmats1[29][27] + coeff0_30*dmats1[30][27] + coeff0_31*dmats1[31][27] + coeff0_32*dmats1[32][27] + coeff0_33*dmats1[33][27] + coeff0_34*dmats1[34][27] + coeff0_35*dmats1[35][27] + coeff0_36*dmats1[36][27] + coeff0_37*dmats1[37][27] + coeff0_38*dmats1[38][27] + coeff0_39*dmats1[39][27] + coeff0_40*dmats1[40][27] + coeff0_41*dmats1[41][27] + coeff0_42*dmats1[42][27] + coeff0_43*dmats1[43][27] + coeff0_44*dmats1[44][27] + coeff0_45*dmats1[45][27] + coeff0_46*dmats1[46][27] + coeff0_47*dmats1[47][27] + coeff0_48*dmats1[48][27] + coeff0_49*dmats1[49][27] + coeff0_50*dmats1[50][27] + coeff0_51*dmats1[51][27] + coeff0_52*dmats1[52][27] + coeff0_53*dmats1[53][27] + coeff0_54*dmats1[54][27] + coeff0_55*dmats1[55][27];
          new_coeff0_28 = coeff0_0*dmats1[0][28] + coeff0_1*dmats1[1][28] + coeff0_2*dmats1[2][28] + coeff0_3*dmats1[3][28] + coeff0_4*dmats1[4][28] + coeff0_5*dmats1[5][28] + coeff0_6*dmats1[6][28] + coeff0_7*dmats1[7][28] + coeff0_8*dmats1[8][28] + coeff0_9*dmats1[9][28] + coeff0_10*dmats1[10][28] + coeff0_11*dmats1[11][28] + coeff0_12*dmats1[12][28] + coeff0_13*dmats1[13][28] + coeff0_14*dmats1[14][28] + coeff0_15*dmats1[15][28] + coeff0_16*dmats1[16][28] + coeff0_17*dmats1[17][28] + coeff0_18*dmats1[18][28] + coeff0_19*dmats1[19][28] + coeff0_20*dmats1[20][28] + coeff0_21*dmats1[21][28] + coeff0_22*dmats1[22][28] + coeff0_23*dmats1[23][28] + coeff0_24*dmats1[24][28] + coeff0_25*dmats1[25][28] + coeff0_26*dmats1[26][28] + coeff0_27*dmats1[27][28] + coeff0_28*dmats1[28][28] + coeff0_29*dmats1[29][28] + coeff0_30*dmats1[30][28] + coeff0_31*dmats1[31][28] + coeff0_32*dmats1[32][28] + coeff0_33*dmats1[33][28] + coeff0_34*dmats1[34][28] + coeff0_35*dmats1[35][28] + coeff0_36*dmats1[36][28] + coeff0_37*dmats1[37][28] + coeff0_38*dmats1[38][28] + coeff0_39*dmats1[39][28] + coeff0_40*dmats1[40][28] + coeff0_41*dmats1[41][28] + coeff0_42*dmats1[42][28] + coeff0_43*dmats1[43][28] + coeff0_44*dmats1[44][28] + coeff0_45*dmats1[45][28] + coeff0_46*dmats1[46][28] + coeff0_47*dmats1[47][28] + coeff0_48*dmats1[48][28] + coeff0_49*dmats1[49][28] + coeff0_50*dmats1[50][28] + coeff0_51*dmats1[51][28] + coeff0_52*dmats1[52][28] + coeff0_53*dmats1[53][28] + coeff0_54*dmats1[54][28] + coeff0_55*dmats1[55][28];
          new_coeff0_29 = coeff0_0*dmats1[0][29] + coeff0_1*dmats1[1][29] + coeff0_2*dmats1[2][29] + coeff0_3*dmats1[3][29] + coeff0_4*dmats1[4][29] + coeff0_5*dmats1[5][29] + coeff0_6*dmats1[6][29] + coeff0_7*dmats1[7][29] + coeff0_8*dmats1[8][29] + coeff0_9*dmats1[9][29] + coeff0_10*dmats1[10][29] + coeff0_11*dmats1[11][29] + coeff0_12*dmats1[12][29] + coeff0_13*dmats1[13][29] + coeff0_14*dmats1[14][29] + coeff0_15*dmats1[15][29] + coeff0_16*dmats1[16][29] + coeff0_17*dmats1[17][29] + coeff0_18*dmats1[18][29] + coeff0_19*dmats1[19][29] + coeff0_20*dmats1[20][29] + coeff0_21*dmats1[21][29] + coeff0_22*dmats1[22][29] + coeff0_23*dmats1[23][29] + coeff0_24*dmats1[24][29] + coeff0_25*dmats1[25][29] + coeff0_26*dmats1[26][29] + coeff0_27*dmats1[27][29] + coeff0_28*dmats1[28][29] + coeff0_29*dmats1[29][29] + coeff0_30*dmats1[30][29] + coeff0_31*dmats1[31][29] + coeff0_32*dmats1[32][29] + coeff0_33*dmats1[33][29] + coeff0_34*dmats1[34][29] + coeff0_35*dmats1[35][29] + coeff0_36*dmats1[36][29] + coeff0_37*dmats1[37][29] + coeff0_38*dmats1[38][29] + coeff0_39*dmats1[39][29] + coeff0_40*dmats1[40][29] + coeff0_41*dmats1[41][29] + coeff0_42*dmats1[42][29] + coeff0_43*dmats1[43][29] + coeff0_44*dmats1[44][29] + coeff0_45*dmats1[45][29] + coeff0_46*dmats1[46][29] + coeff0_47*dmats1[47][29] + coeff0_48*dmats1[48][29] + coeff0_49*dmats1[49][29] + coeff0_50*dmats1[50][29] + coeff0_51*dmats1[51][29] + coeff0_52*dmats1[52][29] + coeff0_53*dmats1[53][29] + coeff0_54*dmats1[54][29] + coeff0_55*dmats1[55][29];
          new_coeff0_30 = coeff0_0*dmats1[0][30] + coeff0_1*dmats1[1][30] + coeff0_2*dmats1[2][30] + coeff0_3*dmats1[3][30] + coeff0_4*dmats1[4][30] + coeff0_5*dmats1[5][30] + coeff0_6*dmats1[6][30] + coeff0_7*dmats1[7][30] + coeff0_8*dmats1[8][30] + coeff0_9*dmats1[9][30] + coeff0_10*dmats1[10][30] + coeff0_11*dmats1[11][30] + coeff0_12*dmats1[12][30] + coeff0_13*dmats1[13][30] + coeff0_14*dmats1[14][30] + coeff0_15*dmats1[15][30] + coeff0_16*dmats1[16][30] + coeff0_17*dmats1[17][30] + coeff0_18*dmats1[18][30] + coeff0_19*dmats1[19][30] + coeff0_20*dmats1[20][30] + coeff0_21*dmats1[21][30] + coeff0_22*dmats1[22][30] + coeff0_23*dmats1[23][30] + coeff0_24*dmats1[24][30] + coeff0_25*dmats1[25][30] + coeff0_26*dmats1[26][30] + coeff0_27*dmats1[27][30] + coeff0_28*dmats1[28][30] + coeff0_29*dmats1[29][30] + coeff0_30*dmats1[30][30] + coeff0_31*dmats1[31][30] + coeff0_32*dmats1[32][30] + coeff0_33*dmats1[33][30] + coeff0_34*dmats1[34][30] + coeff0_35*dmats1[35][30] + coeff0_36*dmats1[36][30] + coeff0_37*dmats1[37][30] + coeff0_38*dmats1[38][30] + coeff0_39*dmats1[39][30] + coeff0_40*dmats1[40][30] + coeff0_41*dmats1[41][30] + coeff0_42*dmats1[42][30] + coeff0_43*dmats1[43][30] + coeff0_44*dmats1[44][30] + coeff0_45*dmats1[45][30] + coeff0_46*dmats1[46][30] + coeff0_47*dmats1[47][30] + coeff0_48*dmats1[48][30] + coeff0_49*dmats1[49][30] + coeff0_50*dmats1[50][30] + coeff0_51*dmats1[51][30] + coeff0_52*dmats1[52][30] + coeff0_53*dmats1[53][30] + coeff0_54*dmats1[54][30] + coeff0_55*dmats1[55][30];
          new_coeff0_31 = coeff0_0*dmats1[0][31] + coeff0_1*dmats1[1][31] + coeff0_2*dmats1[2][31] + coeff0_3*dmats1[3][31] + coeff0_4*dmats1[4][31] + coeff0_5*dmats1[5][31] + coeff0_6*dmats1[6][31] + coeff0_7*dmats1[7][31] + coeff0_8*dmats1[8][31] + coeff0_9*dmats1[9][31] + coeff0_10*dmats1[10][31] + coeff0_11*dmats1[11][31] + coeff0_12*dmats1[12][31] + coeff0_13*dmats1[13][31] + coeff0_14*dmats1[14][31] + coeff0_15*dmats1[15][31] + coeff0_16*dmats1[16][31] + coeff0_17*dmats1[17][31] + coeff0_18*dmats1[18][31] + coeff0_19*dmats1[19][31] + coeff0_20*dmats1[20][31] + coeff0_21*dmats1[21][31] + coeff0_22*dmats1[22][31] + coeff0_23*dmats1[23][31] + coeff0_24*dmats1[24][31] + coeff0_25*dmats1[25][31] + coeff0_26*dmats1[26][31] + coeff0_27*dmats1[27][31] + coeff0_28*dmats1[28][31] + coeff0_29*dmats1[29][31] + coeff0_30*dmats1[30][31] + coeff0_31*dmats1[31][31] + coeff0_32*dmats1[32][31] + coeff0_33*dmats1[33][31] + coeff0_34*dmats1[34][31] + coeff0_35*dmats1[35][31] + coeff0_36*dmats1[36][31] + coeff0_37*dmats1[37][31] + coeff0_38*dmats1[38][31] + coeff0_39*dmats1[39][31] + coeff0_40*dmats1[40][31] + coeff0_41*dmats1[41][31] + coeff0_42*dmats1[42][31] + coeff0_43*dmats1[43][31] + coeff0_44*dmats1[44][31] + coeff0_45*dmats1[45][31] + coeff0_46*dmats1[46][31] + coeff0_47*dmats1[47][31] + coeff0_48*dmats1[48][31] + coeff0_49*dmats1[49][31] + coeff0_50*dmats1[50][31] + coeff0_51*dmats1[51][31] + coeff0_52*dmats1[52][31] + coeff0_53*dmats1[53][31] + coeff0_54*dmats1[54][31] + coeff0_55*dmats1[55][31];
          new_coeff0_32 = coeff0_0*dmats1[0][32] + coeff0_1*dmats1[1][32] + coeff0_2*dmats1[2][32] + coeff0_3*dmats1[3][32] + coeff0_4*dmats1[4][32] + coeff0_5*dmats1[5][32] + coeff0_6*dmats1[6][32] + coeff0_7*dmats1[7][32] + coeff0_8*dmats1[8][32] + coeff0_9*dmats1[9][32] + coeff0_10*dmats1[10][32] + coeff0_11*dmats1[11][32] + coeff0_12*dmats1[12][32] + coeff0_13*dmats1[13][32] + coeff0_14*dmats1[14][32] + coeff0_15*dmats1[15][32] + coeff0_16*dmats1[16][32] + coeff0_17*dmats1[17][32] + coeff0_18*dmats1[18][32] + coeff0_19*dmats1[19][32] + coeff0_20*dmats1[20][32] + coeff0_21*dmats1[21][32] + coeff0_22*dmats1[22][32] + coeff0_23*dmats1[23][32] + coeff0_24*dmats1[24][32] + coeff0_25*dmats1[25][32] + coeff0_26*dmats1[26][32] + coeff0_27*dmats1[27][32] + coeff0_28*dmats1[28][32] + coeff0_29*dmats1[29][32] + coeff0_30*dmats1[30][32] + coeff0_31*dmats1[31][32] + coeff0_32*dmats1[32][32] + coeff0_33*dmats1[33][32] + coeff0_34*dmats1[34][32] + coeff0_35*dmats1[35][32] + coeff0_36*dmats1[36][32] + coeff0_37*dmats1[37][32] + coeff0_38*dmats1[38][32] + coeff0_39*dmats1[39][32] + coeff0_40*dmats1[40][32] + coeff0_41*dmats1[41][32] + coeff0_42*dmats1[42][32] + coeff0_43*dmats1[43][32] + coeff0_44*dmats1[44][32] + coeff0_45*dmats1[45][32] + coeff0_46*dmats1[46][32] + coeff0_47*dmats1[47][32] + coeff0_48*dmats1[48][32] + coeff0_49*dmats1[49][32] + coeff0_50*dmats1[50][32] + coeff0_51*dmats1[51][32] + coeff0_52*dmats1[52][32] + coeff0_53*dmats1[53][32] + coeff0_54*dmats1[54][32] + coeff0_55*dmats1[55][32];
          new_coeff0_33 = coeff0_0*dmats1[0][33] + coeff0_1*dmats1[1][33] + coeff0_2*dmats1[2][33] + coeff0_3*dmats1[3][33] + coeff0_4*dmats1[4][33] + coeff0_5*dmats1[5][33] + coeff0_6*dmats1[6][33] + coeff0_7*dmats1[7][33] + coeff0_8*dmats1[8][33] + coeff0_9*dmats1[9][33] + coeff0_10*dmats1[10][33] + coeff0_11*dmats1[11][33] + coeff0_12*dmats1[12][33] + coeff0_13*dmats1[13][33] + coeff0_14*dmats1[14][33] + coeff0_15*dmats1[15][33] + coeff0_16*dmats1[16][33] + coeff0_17*dmats1[17][33] + coeff0_18*dmats1[18][33] + coeff0_19*dmats1[19][33] + coeff0_20*dmats1[20][33] + coeff0_21*dmats1[21][33] + coeff0_22*dmats1[22][33] + coeff0_23*dmats1[23][33] + coeff0_24*dmats1[24][33] + coeff0_25*dmats1[25][33] + coeff0_26*dmats1[26][33] + coeff0_27*dmats1[27][33] + coeff0_28*dmats1[28][33] + coeff0_29*dmats1[29][33] + coeff0_30*dmats1[30][33] + coeff0_31*dmats1[31][33] + coeff0_32*dmats1[32][33] + coeff0_33*dmats1[33][33] + coeff0_34*dmats1[34][33] + coeff0_35*dmats1[35][33] + coeff0_36*dmats1[36][33] + coeff0_37*dmats1[37][33] + coeff0_38*dmats1[38][33] + coeff0_39*dmats1[39][33] + coeff0_40*dmats1[40][33] + coeff0_41*dmats1[41][33] + coeff0_42*dmats1[42][33] + coeff0_43*dmats1[43][33] + coeff0_44*dmats1[44][33] + coeff0_45*dmats1[45][33] + coeff0_46*dmats1[46][33] + coeff0_47*dmats1[47][33] + coeff0_48*dmats1[48][33] + coeff0_49*dmats1[49][33] + coeff0_50*dmats1[50][33] + coeff0_51*dmats1[51][33] + coeff0_52*dmats1[52][33] + coeff0_53*dmats1[53][33] + coeff0_54*dmats1[54][33] + coeff0_55*dmats1[55][33];
          new_coeff0_34 = coeff0_0*dmats1[0][34] + coeff0_1*dmats1[1][34] + coeff0_2*dmats1[2][34] + coeff0_3*dmats1[3][34] + coeff0_4*dmats1[4][34] + coeff0_5*dmats1[5][34] + coeff0_6*dmats1[6][34] + coeff0_7*dmats1[7][34] + coeff0_8*dmats1[8][34] + coeff0_9*dmats1[9][34] + coeff0_10*dmats1[10][34] + coeff0_11*dmats1[11][34] + coeff0_12*dmats1[12][34] + coeff0_13*dmats1[13][34] + coeff0_14*dmats1[14][34] + coeff0_15*dmats1[15][34] + coeff0_16*dmats1[16][34] + coeff0_17*dmats1[17][34] + coeff0_18*dmats1[18][34] + coeff0_19*dmats1[19][34] + coeff0_20*dmats1[20][34] + coeff0_21*dmats1[21][34] + coeff0_22*dmats1[22][34] + coeff0_23*dmats1[23][34] + coeff0_24*dmats1[24][34] + coeff0_25*dmats1[25][34] + coeff0_26*dmats1[26][34] + coeff0_27*dmats1[27][34] + coeff0_28*dmats1[28][34] + coeff0_29*dmats1[29][34] + coeff0_30*dmats1[30][34] + coeff0_31*dmats1[31][34] + coeff0_32*dmats1[32][34] + coeff0_33*dmats1[33][34] + coeff0_34*dmats1[34][34] + coeff0_35*dmats1[35][34] + coeff0_36*dmats1[36][34] + coeff0_37*dmats1[37][34] + coeff0_38*dmats1[38][34] + coeff0_39*dmats1[39][34] + coeff0_40*dmats1[40][34] + coeff0_41*dmats1[41][34] + coeff0_42*dmats1[42][34] + coeff0_43*dmats1[43][34] + coeff0_44*dmats1[44][34] + coeff0_45*dmats1[45][34] + coeff0_46*dmats1[46][34] + coeff0_47*dmats1[47][34] + coeff0_48*dmats1[48][34] + coeff0_49*dmats1[49][34] + coeff0_50*dmats1[50][34] + coeff0_51*dmats1[51][34] + coeff0_52*dmats1[52][34] + coeff0_53*dmats1[53][34] + coeff0_54*dmats1[54][34] + coeff0_55*dmats1[55][34];
          new_coeff0_35 = coeff0_0*dmats1[0][35] + coeff0_1*dmats1[1][35] + coeff0_2*dmats1[2][35] + coeff0_3*dmats1[3][35] + coeff0_4*dmats1[4][35] + coeff0_5*dmats1[5][35] + coeff0_6*dmats1[6][35] + coeff0_7*dmats1[7][35] + coeff0_8*dmats1[8][35] + coeff0_9*dmats1[9][35] + coeff0_10*dmats1[10][35] + coeff0_11*dmats1[11][35] + coeff0_12*dmats1[12][35] + coeff0_13*dmats1[13][35] + coeff0_14*dmats1[14][35] + coeff0_15*dmats1[15][35] + coeff0_16*dmats1[16][35] + coeff0_17*dmats1[17][35] + coeff0_18*dmats1[18][35] + coeff0_19*dmats1[19][35] + coeff0_20*dmats1[20][35] + coeff0_21*dmats1[21][35] + coeff0_22*dmats1[22][35] + coeff0_23*dmats1[23][35] + coeff0_24*dmats1[24][35] + coeff0_25*dmats1[25][35] + coeff0_26*dmats1[26][35] + coeff0_27*dmats1[27][35] + coeff0_28*dmats1[28][35] + coeff0_29*dmats1[29][35] + coeff0_30*dmats1[30][35] + coeff0_31*dmats1[31][35] + coeff0_32*dmats1[32][35] + coeff0_33*dmats1[33][35] + coeff0_34*dmats1[34][35] + coeff0_35*dmats1[35][35] + coeff0_36*dmats1[36][35] + coeff0_37*dmats1[37][35] + coeff0_38*dmats1[38][35] + coeff0_39*dmats1[39][35] + coeff0_40*dmats1[40][35] + coeff0_41*dmats1[41][35] + coeff0_42*dmats1[42][35] + coeff0_43*dmats1[43][35] + coeff0_44*dmats1[44][35] + coeff0_45*dmats1[45][35] + coeff0_46*dmats1[46][35] + coeff0_47*dmats1[47][35] + coeff0_48*dmats1[48][35] + coeff0_49*dmats1[49][35] + coeff0_50*dmats1[50][35] + coeff0_51*dmats1[51][35] + coeff0_52*dmats1[52][35] + coeff0_53*dmats1[53][35] + coeff0_54*dmats1[54][35] + coeff0_55*dmats1[55][35];
          new_coeff0_36 = coeff0_0*dmats1[0][36] + coeff0_1*dmats1[1][36] + coeff0_2*dmats1[2][36] + coeff0_3*dmats1[3][36] + coeff0_4*dmats1[4][36] + coeff0_5*dmats1[5][36] + coeff0_6*dmats1[6][36] + coeff0_7*dmats1[7][36] + coeff0_8*dmats1[8][36] + coeff0_9*dmats1[9][36] + coeff0_10*dmats1[10][36] + coeff0_11*dmats1[11][36] + coeff0_12*dmats1[12][36] + coeff0_13*dmats1[13][36] + coeff0_14*dmats1[14][36] + coeff0_15*dmats1[15][36] + coeff0_16*dmats1[16][36] + coeff0_17*dmats1[17][36] + coeff0_18*dmats1[18][36] + coeff0_19*dmats1[19][36] + coeff0_20*dmats1[20][36] + coeff0_21*dmats1[21][36] + coeff0_22*dmats1[22][36] + coeff0_23*dmats1[23][36] + coeff0_24*dmats1[24][36] + coeff0_25*dmats1[25][36] + coeff0_26*dmats1[26][36] + coeff0_27*dmats1[27][36] + coeff0_28*dmats1[28][36] + coeff0_29*dmats1[29][36] + coeff0_30*dmats1[30][36] + coeff0_31*dmats1[31][36] + coeff0_32*dmats1[32][36] + coeff0_33*dmats1[33][36] + coeff0_34*dmats1[34][36] + coeff0_35*dmats1[35][36] + coeff0_36*dmats1[36][36] + coeff0_37*dmats1[37][36] + coeff0_38*dmats1[38][36] + coeff0_39*dmats1[39][36] + coeff0_40*dmats1[40][36] + coeff0_41*dmats1[41][36] + coeff0_42*dmats1[42][36] + coeff0_43*dmats1[43][36] + coeff0_44*dmats1[44][36] + coeff0_45*dmats1[45][36] + coeff0_46*dmats1[46][36] + coeff0_47*dmats1[47][36] + coeff0_48*dmats1[48][36] + coeff0_49*dmats1[49][36] + coeff0_50*dmats1[50][36] + coeff0_51*dmats1[51][36] + coeff0_52*dmats1[52][36] + coeff0_53*dmats1[53][36] + coeff0_54*dmats1[54][36] + coeff0_55*dmats1[55][36];
          new_coeff0_37 = coeff0_0*dmats1[0][37] + coeff0_1*dmats1[1][37] + coeff0_2*dmats1[2][37] + coeff0_3*dmats1[3][37] + coeff0_4*dmats1[4][37] + coeff0_5*dmats1[5][37] + coeff0_6*dmats1[6][37] + coeff0_7*dmats1[7][37] + coeff0_8*dmats1[8][37] + coeff0_9*dmats1[9][37] + coeff0_10*dmats1[10][37] + coeff0_11*dmats1[11][37] + coeff0_12*dmats1[12][37] + coeff0_13*dmats1[13][37] + coeff0_14*dmats1[14][37] + coeff0_15*dmats1[15][37] + coeff0_16*dmats1[16][37] + coeff0_17*dmats1[17][37] + coeff0_18*dmats1[18][37] + coeff0_19*dmats1[19][37] + coeff0_20*dmats1[20][37] + coeff0_21*dmats1[21][37] + coeff0_22*dmats1[22][37] + coeff0_23*dmats1[23][37] + coeff0_24*dmats1[24][37] + coeff0_25*dmats1[25][37] + coeff0_26*dmats1[26][37] + coeff0_27*dmats1[27][37] + coeff0_28*dmats1[28][37] + coeff0_29*dmats1[29][37] + coeff0_30*dmats1[30][37] + coeff0_31*dmats1[31][37] + coeff0_32*dmats1[32][37] + coeff0_33*dmats1[33][37] + coeff0_34*dmats1[34][37] + coeff0_35*dmats1[35][37] + coeff0_36*dmats1[36][37] + coeff0_37*dmats1[37][37] + coeff0_38*dmats1[38][37] + coeff0_39*dmats1[39][37] + coeff0_40*dmats1[40][37] + coeff0_41*dmats1[41][37] + coeff0_42*dmats1[42][37] + coeff0_43*dmats1[43][37] + coeff0_44*dmats1[44][37] + coeff0_45*dmats1[45][37] + coeff0_46*dmats1[46][37] + coeff0_47*dmats1[47][37] + coeff0_48*dmats1[48][37] + coeff0_49*dmats1[49][37] + coeff0_50*dmats1[50][37] + coeff0_51*dmats1[51][37] + coeff0_52*dmats1[52][37] + coeff0_53*dmats1[53][37] + coeff0_54*dmats1[54][37] + coeff0_55*dmats1[55][37];
          new_coeff0_38 = coeff0_0*dmats1[0][38] + coeff0_1*dmats1[1][38] + coeff0_2*dmats1[2][38] + coeff0_3*dmats1[3][38] + coeff0_4*dmats1[4][38] + coeff0_5*dmats1[5][38] + coeff0_6*dmats1[6][38] + coeff0_7*dmats1[7][38] + coeff0_8*dmats1[8][38] + coeff0_9*dmats1[9][38] + coeff0_10*dmats1[10][38] + coeff0_11*dmats1[11][38] + coeff0_12*dmats1[12][38] + coeff0_13*dmats1[13][38] + coeff0_14*dmats1[14][38] + coeff0_15*dmats1[15][38] + coeff0_16*dmats1[16][38] + coeff0_17*dmats1[17][38] + coeff0_18*dmats1[18][38] + coeff0_19*dmats1[19][38] + coeff0_20*dmats1[20][38] + coeff0_21*dmats1[21][38] + coeff0_22*dmats1[22][38] + coeff0_23*dmats1[23][38] + coeff0_24*dmats1[24][38] + coeff0_25*dmats1[25][38] + coeff0_26*dmats1[26][38] + coeff0_27*dmats1[27][38] + coeff0_28*dmats1[28][38] + coeff0_29*dmats1[29][38] + coeff0_30*dmats1[30][38] + coeff0_31*dmats1[31][38] + coeff0_32*dmats1[32][38] + coeff0_33*dmats1[33][38] + coeff0_34*dmats1[34][38] + coeff0_35*dmats1[35][38] + coeff0_36*dmats1[36][38] + coeff0_37*dmats1[37][38] + coeff0_38*dmats1[38][38] + coeff0_39*dmats1[39][38] + coeff0_40*dmats1[40][38] + coeff0_41*dmats1[41][38] + coeff0_42*dmats1[42][38] + coeff0_43*dmats1[43][38] + coeff0_44*dmats1[44][38] + coeff0_45*dmats1[45][38] + coeff0_46*dmats1[46][38] + coeff0_47*dmats1[47][38] + coeff0_48*dmats1[48][38] + coeff0_49*dmats1[49][38] + coeff0_50*dmats1[50][38] + coeff0_51*dmats1[51][38] + coeff0_52*dmats1[52][38] + coeff0_53*dmats1[53][38] + coeff0_54*dmats1[54][38] + coeff0_55*dmats1[55][38];
          new_coeff0_39 = coeff0_0*dmats1[0][39] + coeff0_1*dmats1[1][39] + coeff0_2*dmats1[2][39] + coeff0_3*dmats1[3][39] + coeff0_4*dmats1[4][39] + coeff0_5*dmats1[5][39] + coeff0_6*dmats1[6][39] + coeff0_7*dmats1[7][39] + coeff0_8*dmats1[8][39] + coeff0_9*dmats1[9][39] + coeff0_10*dmats1[10][39] + coeff0_11*dmats1[11][39] + coeff0_12*dmats1[12][39] + coeff0_13*dmats1[13][39] + coeff0_14*dmats1[14][39] + coeff0_15*dmats1[15][39] + coeff0_16*dmats1[16][39] + coeff0_17*dmats1[17][39] + coeff0_18*dmats1[18][39] + coeff0_19*dmats1[19][39] + coeff0_20*dmats1[20][39] + coeff0_21*dmats1[21][39] + coeff0_22*dmats1[22][39] + coeff0_23*dmats1[23][39] + coeff0_24*dmats1[24][39] + coeff0_25*dmats1[25][39] + coeff0_26*dmats1[26][39] + coeff0_27*dmats1[27][39] + coeff0_28*dmats1[28][39] + coeff0_29*dmats1[29][39] + coeff0_30*dmats1[30][39] + coeff0_31*dmats1[31][39] + coeff0_32*dmats1[32][39] + coeff0_33*dmats1[33][39] + coeff0_34*dmats1[34][39] + coeff0_35*dmats1[35][39] + coeff0_36*dmats1[36][39] + coeff0_37*dmats1[37][39] + coeff0_38*dmats1[38][39] + coeff0_39*dmats1[39][39] + coeff0_40*dmats1[40][39] + coeff0_41*dmats1[41][39] + coeff0_42*dmats1[42][39] + coeff0_43*dmats1[43][39] + coeff0_44*dmats1[44][39] + coeff0_45*dmats1[45][39] + coeff0_46*dmats1[46][39] + coeff0_47*dmats1[47][39] + coeff0_48*dmats1[48][39] + coeff0_49*dmats1[49][39] + coeff0_50*dmats1[50][39] + coeff0_51*dmats1[51][39] + coeff0_52*dmats1[52][39] + coeff0_53*dmats1[53][39] + coeff0_54*dmats1[54][39] + coeff0_55*dmats1[55][39];
          new_coeff0_40 = coeff0_0*dmats1[0][40] + coeff0_1*dmats1[1][40] + coeff0_2*dmats1[2][40] + coeff0_3*dmats1[3][40] + coeff0_4*dmats1[4][40] + coeff0_5*dmats1[5][40] + coeff0_6*dmats1[6][40] + coeff0_7*dmats1[7][40] + coeff0_8*dmats1[8][40] + coeff0_9*dmats1[9][40] + coeff0_10*dmats1[10][40] + coeff0_11*dmats1[11][40] + coeff0_12*dmats1[12][40] + coeff0_13*dmats1[13][40] + coeff0_14*dmats1[14][40] + coeff0_15*dmats1[15][40] + coeff0_16*dmats1[16][40] + coeff0_17*dmats1[17][40] + coeff0_18*dmats1[18][40] + coeff0_19*dmats1[19][40] + coeff0_20*dmats1[20][40] + coeff0_21*dmats1[21][40] + coeff0_22*dmats1[22][40] + coeff0_23*dmats1[23][40] + coeff0_24*dmats1[24][40] + coeff0_25*dmats1[25][40] + coeff0_26*dmats1[26][40] + coeff0_27*dmats1[27][40] + coeff0_28*dmats1[28][40] + coeff0_29*dmats1[29][40] + coeff0_30*dmats1[30][40] + coeff0_31*dmats1[31][40] + coeff0_32*dmats1[32][40] + coeff0_33*dmats1[33][40] + coeff0_34*dmats1[34][40] + coeff0_35*dmats1[35][40] + coeff0_36*dmats1[36][40] + coeff0_37*dmats1[37][40] + coeff0_38*dmats1[38][40] + coeff0_39*dmats1[39][40] + coeff0_40*dmats1[40][40] + coeff0_41*dmats1[41][40] + coeff0_42*dmats1[42][40] + coeff0_43*dmats1[43][40] + coeff0_44*dmats1[44][40] + coeff0_45*dmats1[45][40] + coeff0_46*dmats1[46][40] + coeff0_47*dmats1[47][40] + coeff0_48*dmats1[48][40] + coeff0_49*dmats1[49][40] + coeff0_50*dmats1[50][40] + coeff0_51*dmats1[51][40] + coeff0_52*dmats1[52][40] + coeff0_53*dmats1[53][40] + coeff0_54*dmats1[54][40] + coeff0_55*dmats1[55][40];
          new_coeff0_41 = coeff0_0*dmats1[0][41] + coeff0_1*dmats1[1][41] + coeff0_2*dmats1[2][41] + coeff0_3*dmats1[3][41] + coeff0_4*dmats1[4][41] + coeff0_5*dmats1[5][41] + coeff0_6*dmats1[6][41] + coeff0_7*dmats1[7][41] + coeff0_8*dmats1[8][41] + coeff0_9*dmats1[9][41] + coeff0_10*dmats1[10][41] + coeff0_11*dmats1[11][41] + coeff0_12*dmats1[12][41] + coeff0_13*dmats1[13][41] + coeff0_14*dmats1[14][41] + coeff0_15*dmats1[15][41] + coeff0_16*dmats1[16][41] + coeff0_17*dmats1[17][41] + coeff0_18*dmats1[18][41] + coeff0_19*dmats1[19][41] + coeff0_20*dmats1[20][41] + coeff0_21*dmats1[21][41] + coeff0_22*dmats1[22][41] + coeff0_23*dmats1[23][41] + coeff0_24*dmats1[24][41] + coeff0_25*dmats1[25][41] + coeff0_26*dmats1[26][41] + coeff0_27*dmats1[27][41] + coeff0_28*dmats1[28][41] + coeff0_29*dmats1[29][41] + coeff0_30*dmats1[30][41] + coeff0_31*dmats1[31][41] + coeff0_32*dmats1[32][41] + coeff0_33*dmats1[33][41] + coeff0_34*dmats1[34][41] + coeff0_35*dmats1[35][41] + coeff0_36*dmats1[36][41] + coeff0_37*dmats1[37][41] + coeff0_38*dmats1[38][41] + coeff0_39*dmats1[39][41] + coeff0_40*dmats1[40][41] + coeff0_41*dmats1[41][41] + coeff0_42*dmats1[42][41] + coeff0_43*dmats1[43][41] + coeff0_44*dmats1[44][41] + coeff0_45*dmats1[45][41] + coeff0_46*dmats1[46][41] + coeff0_47*dmats1[47][41] + coeff0_48*dmats1[48][41] + coeff0_49*dmats1[49][41] + coeff0_50*dmats1[50][41] + coeff0_51*dmats1[51][41] + coeff0_52*dmats1[52][41] + coeff0_53*dmats1[53][41] + coeff0_54*dmats1[54][41] + coeff0_55*dmats1[55][41];
          new_coeff0_42 = coeff0_0*dmats1[0][42] + coeff0_1*dmats1[1][42] + coeff0_2*dmats1[2][42] + coeff0_3*dmats1[3][42] + coeff0_4*dmats1[4][42] + coeff0_5*dmats1[5][42] + coeff0_6*dmats1[6][42] + coeff0_7*dmats1[7][42] + coeff0_8*dmats1[8][42] + coeff0_9*dmats1[9][42] + coeff0_10*dmats1[10][42] + coeff0_11*dmats1[11][42] + coeff0_12*dmats1[12][42] + coeff0_13*dmats1[13][42] + coeff0_14*dmats1[14][42] + coeff0_15*dmats1[15][42] + coeff0_16*dmats1[16][42] + coeff0_17*dmats1[17][42] + coeff0_18*dmats1[18][42] + coeff0_19*dmats1[19][42] + coeff0_20*dmats1[20][42] + coeff0_21*dmats1[21][42] + coeff0_22*dmats1[22][42] + coeff0_23*dmats1[23][42] + coeff0_24*dmats1[24][42] + coeff0_25*dmats1[25][42] + coeff0_26*dmats1[26][42] + coeff0_27*dmats1[27][42] + coeff0_28*dmats1[28][42] + coeff0_29*dmats1[29][42] + coeff0_30*dmats1[30][42] + coeff0_31*dmats1[31][42] + coeff0_32*dmats1[32][42] + coeff0_33*dmats1[33][42] + coeff0_34*dmats1[34][42] + coeff0_35*dmats1[35][42] + coeff0_36*dmats1[36][42] + coeff0_37*dmats1[37][42] + coeff0_38*dmats1[38][42] + coeff0_39*dmats1[39][42] + coeff0_40*dmats1[40][42] + coeff0_41*dmats1[41][42] + coeff0_42*dmats1[42][42] + coeff0_43*dmats1[43][42] + coeff0_44*dmats1[44][42] + coeff0_45*dmats1[45][42] + coeff0_46*dmats1[46][42] + coeff0_47*dmats1[47][42] + coeff0_48*dmats1[48][42] + coeff0_49*dmats1[49][42] + coeff0_50*dmats1[50][42] + coeff0_51*dmats1[51][42] + coeff0_52*dmats1[52][42] + coeff0_53*dmats1[53][42] + coeff0_54*dmats1[54][42] + coeff0_55*dmats1[55][42];
          new_coeff0_43 = coeff0_0*dmats1[0][43] + coeff0_1*dmats1[1][43] + coeff0_2*dmats1[2][43] + coeff0_3*dmats1[3][43] + coeff0_4*dmats1[4][43] + coeff0_5*dmats1[5][43] + coeff0_6*dmats1[6][43] + coeff0_7*dmats1[7][43] + coeff0_8*dmats1[8][43] + coeff0_9*dmats1[9][43] + coeff0_10*dmats1[10][43] + coeff0_11*dmats1[11][43] + coeff0_12*dmats1[12][43] + coeff0_13*dmats1[13][43] + coeff0_14*dmats1[14][43] + coeff0_15*dmats1[15][43] + coeff0_16*dmats1[16][43] + coeff0_17*dmats1[17][43] + coeff0_18*dmats1[18][43] + coeff0_19*dmats1[19][43] + coeff0_20*dmats1[20][43] + coeff0_21*dmats1[21][43] + coeff0_22*dmats1[22][43] + coeff0_23*dmats1[23][43] + coeff0_24*dmats1[24][43] + coeff0_25*dmats1[25][43] + coeff0_26*dmats1[26][43] + coeff0_27*dmats1[27][43] + coeff0_28*dmats1[28][43] + coeff0_29*dmats1[29][43] + coeff0_30*dmats1[30][43] + coeff0_31*dmats1[31][43] + coeff0_32*dmats1[32][43] + coeff0_33*dmats1[33][43] + coeff0_34*dmats1[34][43] + coeff0_35*dmats1[35][43] + coeff0_36*dmats1[36][43] + coeff0_37*dmats1[37][43] + coeff0_38*dmats1[38][43] + coeff0_39*dmats1[39][43] + coeff0_40*dmats1[40][43] + coeff0_41*dmats1[41][43] + coeff0_42*dmats1[42][43] + coeff0_43*dmats1[43][43] + coeff0_44*dmats1[44][43] + coeff0_45*dmats1[45][43] + coeff0_46*dmats1[46][43] + coeff0_47*dmats1[47][43] + coeff0_48*dmats1[48][43] + coeff0_49*dmats1[49][43] + coeff0_50*dmats1[50][43] + coeff0_51*dmats1[51][43] + coeff0_52*dmats1[52][43] + coeff0_53*dmats1[53][43] + coeff0_54*dmats1[54][43] + coeff0_55*dmats1[55][43];
          new_coeff0_44 = coeff0_0*dmats1[0][44] + coeff0_1*dmats1[1][44] + coeff0_2*dmats1[2][44] + coeff0_3*dmats1[3][44] + coeff0_4*dmats1[4][44] + coeff0_5*dmats1[5][44] + coeff0_6*dmats1[6][44] + coeff0_7*dmats1[7][44] + coeff0_8*dmats1[8][44] + coeff0_9*dmats1[9][44] + coeff0_10*dmats1[10][44] + coeff0_11*dmats1[11][44] + coeff0_12*dmats1[12][44] + coeff0_13*dmats1[13][44] + coeff0_14*dmats1[14][44] + coeff0_15*dmats1[15][44] + coeff0_16*dmats1[16][44] + coeff0_17*dmats1[17][44] + coeff0_18*dmats1[18][44] + coeff0_19*dmats1[19][44] + coeff0_20*dmats1[20][44] + coeff0_21*dmats1[21][44] + coeff0_22*dmats1[22][44] + coeff0_23*dmats1[23][44] + coeff0_24*dmats1[24][44] + coeff0_25*dmats1[25][44] + coeff0_26*dmats1[26][44] + coeff0_27*dmats1[27][44] + coeff0_28*dmats1[28][44] + coeff0_29*dmats1[29][44] + coeff0_30*dmats1[30][44] + coeff0_31*dmats1[31][44] + coeff0_32*dmats1[32][44] + coeff0_33*dmats1[33][44] + coeff0_34*dmats1[34][44] + coeff0_35*dmats1[35][44] + coeff0_36*dmats1[36][44] + coeff0_37*dmats1[37][44] + coeff0_38*dmats1[38][44] + coeff0_39*dmats1[39][44] + coeff0_40*dmats1[40][44] + coeff0_41*dmats1[41][44] + coeff0_42*dmats1[42][44] + coeff0_43*dmats1[43][44] + coeff0_44*dmats1[44][44] + coeff0_45*dmats1[45][44] + coeff0_46*dmats1[46][44] + coeff0_47*dmats1[47][44] + coeff0_48*dmats1[48][44] + coeff0_49*dmats1[49][44] + coeff0_50*dmats1[50][44] + coeff0_51*dmats1[51][44] + coeff0_52*dmats1[52][44] + coeff0_53*dmats1[53][44] + coeff0_54*dmats1[54][44] + coeff0_55*dmats1[55][44];
          new_coeff0_45 = coeff0_0*dmats1[0][45] + coeff0_1*dmats1[1][45] + coeff0_2*dmats1[2][45] + coeff0_3*dmats1[3][45] + coeff0_4*dmats1[4][45] + coeff0_5*dmats1[5][45] + coeff0_6*dmats1[6][45] + coeff0_7*dmats1[7][45] + coeff0_8*dmats1[8][45] + coeff0_9*dmats1[9][45] + coeff0_10*dmats1[10][45] + coeff0_11*dmats1[11][45] + coeff0_12*dmats1[12][45] + coeff0_13*dmats1[13][45] + coeff0_14*dmats1[14][45] + coeff0_15*dmats1[15][45] + coeff0_16*dmats1[16][45] + coeff0_17*dmats1[17][45] + coeff0_18*dmats1[18][45] + coeff0_19*dmats1[19][45] + coeff0_20*dmats1[20][45] + coeff0_21*dmats1[21][45] + coeff0_22*dmats1[22][45] + coeff0_23*dmats1[23][45] + coeff0_24*dmats1[24][45] + coeff0_25*dmats1[25][45] + coeff0_26*dmats1[26][45] + coeff0_27*dmats1[27][45] + coeff0_28*dmats1[28][45] + coeff0_29*dmats1[29][45] + coeff0_30*dmats1[30][45] + coeff0_31*dmats1[31][45] + coeff0_32*dmats1[32][45] + coeff0_33*dmats1[33][45] + coeff0_34*dmats1[34][45] + coeff0_35*dmats1[35][45] + coeff0_36*dmats1[36][45] + coeff0_37*dmats1[37][45] + coeff0_38*dmats1[38][45] + coeff0_39*dmats1[39][45] + coeff0_40*dmats1[40][45] + coeff0_41*dmats1[41][45] + coeff0_42*dmats1[42][45] + coeff0_43*dmats1[43][45] + coeff0_44*dmats1[44][45] + coeff0_45*dmats1[45][45] + coeff0_46*dmats1[46][45] + coeff0_47*dmats1[47][45] + coeff0_48*dmats1[48][45] + coeff0_49*dmats1[49][45] + coeff0_50*dmats1[50][45] + coeff0_51*dmats1[51][45] + coeff0_52*dmats1[52][45] + coeff0_53*dmats1[53][45] + coeff0_54*dmats1[54][45] + coeff0_55*dmats1[55][45];
          new_coeff0_46 = coeff0_0*dmats1[0][46] + coeff0_1*dmats1[1][46] + coeff0_2*dmats1[2][46] + coeff0_3*dmats1[3][46] + coeff0_4*dmats1[4][46] + coeff0_5*dmats1[5][46] + coeff0_6*dmats1[6][46] + coeff0_7*dmats1[7][46] + coeff0_8*dmats1[8][46] + coeff0_9*dmats1[9][46] + coeff0_10*dmats1[10][46] + coeff0_11*dmats1[11][46] + coeff0_12*dmats1[12][46] + coeff0_13*dmats1[13][46] + coeff0_14*dmats1[14][46] + coeff0_15*dmats1[15][46] + coeff0_16*dmats1[16][46] + coeff0_17*dmats1[17][46] + coeff0_18*dmats1[18][46] + coeff0_19*dmats1[19][46] + coeff0_20*dmats1[20][46] + coeff0_21*dmats1[21][46] + coeff0_22*dmats1[22][46] + coeff0_23*dmats1[23][46] + coeff0_24*dmats1[24][46] + coeff0_25*dmats1[25][46] + coeff0_26*dmats1[26][46] + coeff0_27*dmats1[27][46] + coeff0_28*dmats1[28][46] + coeff0_29*dmats1[29][46] + coeff0_30*dmats1[30][46] + coeff0_31*dmats1[31][46] + coeff0_32*dmats1[32][46] + coeff0_33*dmats1[33][46] + coeff0_34*dmats1[34][46] + coeff0_35*dmats1[35][46] + coeff0_36*dmats1[36][46] + coeff0_37*dmats1[37][46] + coeff0_38*dmats1[38][46] + coeff0_39*dmats1[39][46] + coeff0_40*dmats1[40][46] + coeff0_41*dmats1[41][46] + coeff0_42*dmats1[42][46] + coeff0_43*dmats1[43][46] + coeff0_44*dmats1[44][46] + coeff0_45*dmats1[45][46] + coeff0_46*dmats1[46][46] + coeff0_47*dmats1[47][46] + coeff0_48*dmats1[48][46] + coeff0_49*dmats1[49][46] + coeff0_50*dmats1[50][46] + coeff0_51*dmats1[51][46] + coeff0_52*dmats1[52][46] + coeff0_53*dmats1[53][46] + coeff0_54*dmats1[54][46] + coeff0_55*dmats1[55][46];
          new_coeff0_47 = coeff0_0*dmats1[0][47] + coeff0_1*dmats1[1][47] + coeff0_2*dmats1[2][47] + coeff0_3*dmats1[3][47] + coeff0_4*dmats1[4][47] + coeff0_5*dmats1[5][47] + coeff0_6*dmats1[6][47] + coeff0_7*dmats1[7][47] + coeff0_8*dmats1[8][47] + coeff0_9*dmats1[9][47] + coeff0_10*dmats1[10][47] + coeff0_11*dmats1[11][47] + coeff0_12*dmats1[12][47] + coeff0_13*dmats1[13][47] + coeff0_14*dmats1[14][47] + coeff0_15*dmats1[15][47] + coeff0_16*dmats1[16][47] + coeff0_17*dmats1[17][47] + coeff0_18*dmats1[18][47] + coeff0_19*dmats1[19][47] + coeff0_20*dmats1[20][47] + coeff0_21*dmats1[21][47] + coeff0_22*dmats1[22][47] + coeff0_23*dmats1[23][47] + coeff0_24*dmats1[24][47] + coeff0_25*dmats1[25][47] + coeff0_26*dmats1[26][47] + coeff0_27*dmats1[27][47] + coeff0_28*dmats1[28][47] + coeff0_29*dmats1[29][47] + coeff0_30*dmats1[30][47] + coeff0_31*dmats1[31][47] + coeff0_32*dmats1[32][47] + coeff0_33*dmats1[33][47] + coeff0_34*dmats1[34][47] + coeff0_35*dmats1[35][47] + coeff0_36*dmats1[36][47] + coeff0_37*dmats1[37][47] + coeff0_38*dmats1[38][47] + coeff0_39*dmats1[39][47] + coeff0_40*dmats1[40][47] + coeff0_41*dmats1[41][47] + coeff0_42*dmats1[42][47] + coeff0_43*dmats1[43][47] + coeff0_44*dmats1[44][47] + coeff0_45*dmats1[45][47] + coeff0_46*dmats1[46][47] + coeff0_47*dmats1[47][47] + coeff0_48*dmats1[48][47] + coeff0_49*dmats1[49][47] + coeff0_50*dmats1[50][47] + coeff0_51*dmats1[51][47] + coeff0_52*dmats1[52][47] + coeff0_53*dmats1[53][47] + coeff0_54*dmats1[54][47] + coeff0_55*dmats1[55][47];
          new_coeff0_48 = coeff0_0*dmats1[0][48] + coeff0_1*dmats1[1][48] + coeff0_2*dmats1[2][48] + coeff0_3*dmats1[3][48] + coeff0_4*dmats1[4][48] + coeff0_5*dmats1[5][48] + coeff0_6*dmats1[6][48] + coeff0_7*dmats1[7][48] + coeff0_8*dmats1[8][48] + coeff0_9*dmats1[9][48] + coeff0_10*dmats1[10][48] + coeff0_11*dmats1[11][48] + coeff0_12*dmats1[12][48] + coeff0_13*dmats1[13][48] + coeff0_14*dmats1[14][48] + coeff0_15*dmats1[15][48] + coeff0_16*dmats1[16][48] + coeff0_17*dmats1[17][48] + coeff0_18*dmats1[18][48] + coeff0_19*dmats1[19][48] + coeff0_20*dmats1[20][48] + coeff0_21*dmats1[21][48] + coeff0_22*dmats1[22][48] + coeff0_23*dmats1[23][48] + coeff0_24*dmats1[24][48] + coeff0_25*dmats1[25][48] + coeff0_26*dmats1[26][48] + coeff0_27*dmats1[27][48] + coeff0_28*dmats1[28][48] + coeff0_29*dmats1[29][48] + coeff0_30*dmats1[30][48] + coeff0_31*dmats1[31][48] + coeff0_32*dmats1[32][48] + coeff0_33*dmats1[33][48] + coeff0_34*dmats1[34][48] + coeff0_35*dmats1[35][48] + coeff0_36*dmats1[36][48] + coeff0_37*dmats1[37][48] + coeff0_38*dmats1[38][48] + coeff0_39*dmats1[39][48] + coeff0_40*dmats1[40][48] + coeff0_41*dmats1[41][48] + coeff0_42*dmats1[42][48] + coeff0_43*dmats1[43][48] + coeff0_44*dmats1[44][48] + coeff0_45*dmats1[45][48] + coeff0_46*dmats1[46][48] + coeff0_47*dmats1[47][48] + coeff0_48*dmats1[48][48] + coeff0_49*dmats1[49][48] + coeff0_50*dmats1[50][48] + coeff0_51*dmats1[51][48] + coeff0_52*dmats1[52][48] + coeff0_53*dmats1[53][48] + coeff0_54*dmats1[54][48] + coeff0_55*dmats1[55][48];
          new_coeff0_49 = coeff0_0*dmats1[0][49] + coeff0_1*dmats1[1][49] + coeff0_2*dmats1[2][49] + coeff0_3*dmats1[3][49] + coeff0_4*dmats1[4][49] + coeff0_5*dmats1[5][49] + coeff0_6*dmats1[6][49] + coeff0_7*dmats1[7][49] + coeff0_8*dmats1[8][49] + coeff0_9*dmats1[9][49] + coeff0_10*dmats1[10][49] + coeff0_11*dmats1[11][49] + coeff0_12*dmats1[12][49] + coeff0_13*dmats1[13][49] + coeff0_14*dmats1[14][49] + coeff0_15*dmats1[15][49] + coeff0_16*dmats1[16][49] + coeff0_17*dmats1[17][49] + coeff0_18*dmats1[18][49] + coeff0_19*dmats1[19][49] + coeff0_20*dmats1[20][49] + coeff0_21*dmats1[21][49] + coeff0_22*dmats1[22][49] + coeff0_23*dmats1[23][49] + coeff0_24*dmats1[24][49] + coeff0_25*dmats1[25][49] + coeff0_26*dmats1[26][49] + coeff0_27*dmats1[27][49] + coeff0_28*dmats1[28][49] + coeff0_29*dmats1[29][49] + coeff0_30*dmats1[30][49] + coeff0_31*dmats1[31][49] + coeff0_32*dmats1[32][49] + coeff0_33*dmats1[33][49] + coeff0_34*dmats1[34][49] + coeff0_35*dmats1[35][49] + coeff0_36*dmats1[36][49] + coeff0_37*dmats1[37][49] + coeff0_38*dmats1[38][49] + coeff0_39*dmats1[39][49] + coeff0_40*dmats1[40][49] + coeff0_41*dmats1[41][49] + coeff0_42*dmats1[42][49] + coeff0_43*dmats1[43][49] + coeff0_44*dmats1[44][49] + coeff0_45*dmats1[45][49] + coeff0_46*dmats1[46][49] + coeff0_47*dmats1[47][49] + coeff0_48*dmats1[48][49] + coeff0_49*dmats1[49][49] + coeff0_50*dmats1[50][49] + coeff0_51*dmats1[51][49] + coeff0_52*dmats1[52][49] + coeff0_53*dmats1[53][49] + coeff0_54*dmats1[54][49] + coeff0_55*dmats1[55][49];
          new_coeff0_50 = coeff0_0*dmats1[0][50] + coeff0_1*dmats1[1][50] + coeff0_2*dmats1[2][50] + coeff0_3*dmats1[3][50] + coeff0_4*dmats1[4][50] + coeff0_5*dmats1[5][50] + coeff0_6*dmats1[6][50] + coeff0_7*dmats1[7][50] + coeff0_8*dmats1[8][50] + coeff0_9*dmats1[9][50] + coeff0_10*dmats1[10][50] + coeff0_11*dmats1[11][50] + coeff0_12*dmats1[12][50] + coeff0_13*dmats1[13][50] + coeff0_14*dmats1[14][50] + coeff0_15*dmats1[15][50] + coeff0_16*dmats1[16][50] + coeff0_17*dmats1[17][50] + coeff0_18*dmats1[18][50] + coeff0_19*dmats1[19][50] + coeff0_20*dmats1[20][50] + coeff0_21*dmats1[21][50] + coeff0_22*dmats1[22][50] + coeff0_23*dmats1[23][50] + coeff0_24*dmats1[24][50] + coeff0_25*dmats1[25][50] + coeff0_26*dmats1[26][50] + coeff0_27*dmats1[27][50] + coeff0_28*dmats1[28][50] + coeff0_29*dmats1[29][50] + coeff0_30*dmats1[30][50] + coeff0_31*dmats1[31][50] + coeff0_32*dmats1[32][50] + coeff0_33*dmats1[33][50] + coeff0_34*dmats1[34][50] + coeff0_35*dmats1[35][50] + coeff0_36*dmats1[36][50] + coeff0_37*dmats1[37][50] + coeff0_38*dmats1[38][50] + coeff0_39*dmats1[39][50] + coeff0_40*dmats1[40][50] + coeff0_41*dmats1[41][50] + coeff0_42*dmats1[42][50] + coeff0_43*dmats1[43][50] + coeff0_44*dmats1[44][50] + coeff0_45*dmats1[45][50] + coeff0_46*dmats1[46][50] + coeff0_47*dmats1[47][50] + coeff0_48*dmats1[48][50] + coeff0_49*dmats1[49][50] + coeff0_50*dmats1[50][50] + coeff0_51*dmats1[51][50] + coeff0_52*dmats1[52][50] + coeff0_53*dmats1[53][50] + coeff0_54*dmats1[54][50] + coeff0_55*dmats1[55][50];
          new_coeff0_51 = coeff0_0*dmats1[0][51] + coeff0_1*dmats1[1][51] + coeff0_2*dmats1[2][51] + coeff0_3*dmats1[3][51] + coeff0_4*dmats1[4][51] + coeff0_5*dmats1[5][51] + coeff0_6*dmats1[6][51] + coeff0_7*dmats1[7][51] + coeff0_8*dmats1[8][51] + coeff0_9*dmats1[9][51] + coeff0_10*dmats1[10][51] + coeff0_11*dmats1[11][51] + coeff0_12*dmats1[12][51] + coeff0_13*dmats1[13][51] + coeff0_14*dmats1[14][51] + coeff0_15*dmats1[15][51] + coeff0_16*dmats1[16][51] + coeff0_17*dmats1[17][51] + coeff0_18*dmats1[18][51] + coeff0_19*dmats1[19][51] + coeff0_20*dmats1[20][51] + coeff0_21*dmats1[21][51] + coeff0_22*dmats1[22][51] + coeff0_23*dmats1[23][51] + coeff0_24*dmats1[24][51] + coeff0_25*dmats1[25][51] + coeff0_26*dmats1[26][51] + coeff0_27*dmats1[27][51] + coeff0_28*dmats1[28][51] + coeff0_29*dmats1[29][51] + coeff0_30*dmats1[30][51] + coeff0_31*dmats1[31][51] + coeff0_32*dmats1[32][51] + coeff0_33*dmats1[33][51] + coeff0_34*dmats1[34][51] + coeff0_35*dmats1[35][51] + coeff0_36*dmats1[36][51] + coeff0_37*dmats1[37][51] + coeff0_38*dmats1[38][51] + coeff0_39*dmats1[39][51] + coeff0_40*dmats1[40][51] + coeff0_41*dmats1[41][51] + coeff0_42*dmats1[42][51] + coeff0_43*dmats1[43][51] + coeff0_44*dmats1[44][51] + coeff0_45*dmats1[45][51] + coeff0_46*dmats1[46][51] + coeff0_47*dmats1[47][51] + coeff0_48*dmats1[48][51] + coeff0_49*dmats1[49][51] + coeff0_50*dmats1[50][51] + coeff0_51*dmats1[51][51] + coeff0_52*dmats1[52][51] + coeff0_53*dmats1[53][51] + coeff0_54*dmats1[54][51] + coeff0_55*dmats1[55][51];
          new_coeff0_52 = coeff0_0*dmats1[0][52] + coeff0_1*dmats1[1][52] + coeff0_2*dmats1[2][52] + coeff0_3*dmats1[3][52] + coeff0_4*dmats1[4][52] + coeff0_5*dmats1[5][52] + coeff0_6*dmats1[6][52] + coeff0_7*dmats1[7][52] + coeff0_8*dmats1[8][52] + coeff0_9*dmats1[9][52] + coeff0_10*dmats1[10][52] + coeff0_11*dmats1[11][52] + coeff0_12*dmats1[12][52] + coeff0_13*dmats1[13][52] + coeff0_14*dmats1[14][52] + coeff0_15*dmats1[15][52] + coeff0_16*dmats1[16][52] + coeff0_17*dmats1[17][52] + coeff0_18*dmats1[18][52] + coeff0_19*dmats1[19][52] + coeff0_20*dmats1[20][52] + coeff0_21*dmats1[21][52] + coeff0_22*dmats1[22][52] + coeff0_23*dmats1[23][52] + coeff0_24*dmats1[24][52] + coeff0_25*dmats1[25][52] + coeff0_26*dmats1[26][52] + coeff0_27*dmats1[27][52] + coeff0_28*dmats1[28][52] + coeff0_29*dmats1[29][52] + coeff0_30*dmats1[30][52] + coeff0_31*dmats1[31][52] + coeff0_32*dmats1[32][52] + coeff0_33*dmats1[33][52] + coeff0_34*dmats1[34][52] + coeff0_35*dmats1[35][52] + coeff0_36*dmats1[36][52] + coeff0_37*dmats1[37][52] + coeff0_38*dmats1[38][52] + coeff0_39*dmats1[39][52] + coeff0_40*dmats1[40][52] + coeff0_41*dmats1[41][52] + coeff0_42*dmats1[42][52] + coeff0_43*dmats1[43][52] + coeff0_44*dmats1[44][52] + coeff0_45*dmats1[45][52] + coeff0_46*dmats1[46][52] + coeff0_47*dmats1[47][52] + coeff0_48*dmats1[48][52] + coeff0_49*dmats1[49][52] + coeff0_50*dmats1[50][52] + coeff0_51*dmats1[51][52] + coeff0_52*dmats1[52][52] + coeff0_53*dmats1[53][52] + coeff0_54*dmats1[54][52] + coeff0_55*dmats1[55][52];
          new_coeff0_53 = coeff0_0*dmats1[0][53] + coeff0_1*dmats1[1][53] + coeff0_2*dmats1[2][53] + coeff0_3*dmats1[3][53] + coeff0_4*dmats1[4][53] + coeff0_5*dmats1[5][53] + coeff0_6*dmats1[6][53] + coeff0_7*dmats1[7][53] + coeff0_8*dmats1[8][53] + coeff0_9*dmats1[9][53] + coeff0_10*dmats1[10][53] + coeff0_11*dmats1[11][53] + coeff0_12*dmats1[12][53] + coeff0_13*dmats1[13][53] + coeff0_14*dmats1[14][53] + coeff0_15*dmats1[15][53] + coeff0_16*dmats1[16][53] + coeff0_17*dmats1[17][53] + coeff0_18*dmats1[18][53] + coeff0_19*dmats1[19][53] + coeff0_20*dmats1[20][53] + coeff0_21*dmats1[21][53] + coeff0_22*dmats1[22][53] + coeff0_23*dmats1[23][53] + coeff0_24*dmats1[24][53] + coeff0_25*dmats1[25][53] + coeff0_26*dmats1[26][53] + coeff0_27*dmats1[27][53] + coeff0_28*dmats1[28][53] + coeff0_29*dmats1[29][53] + coeff0_30*dmats1[30][53] + coeff0_31*dmats1[31][53] + coeff0_32*dmats1[32][53] + coeff0_33*dmats1[33][53] + coeff0_34*dmats1[34][53] + coeff0_35*dmats1[35][53] + coeff0_36*dmats1[36][53] + coeff0_37*dmats1[37][53] + coeff0_38*dmats1[38][53] + coeff0_39*dmats1[39][53] + coeff0_40*dmats1[40][53] + coeff0_41*dmats1[41][53] + coeff0_42*dmats1[42][53] + coeff0_43*dmats1[43][53] + coeff0_44*dmats1[44][53] + coeff0_45*dmats1[45][53] + coeff0_46*dmats1[46][53] + coeff0_47*dmats1[47][53] + coeff0_48*dmats1[48][53] + coeff0_49*dmats1[49][53] + coeff0_50*dmats1[50][53] + coeff0_51*dmats1[51][53] + coeff0_52*dmats1[52][53] + coeff0_53*dmats1[53][53] + coeff0_54*dmats1[54][53] + coeff0_55*dmats1[55][53];
          new_coeff0_54 = coeff0_0*dmats1[0][54] + coeff0_1*dmats1[1][54] + coeff0_2*dmats1[2][54] + coeff0_3*dmats1[3][54] + coeff0_4*dmats1[4][54] + coeff0_5*dmats1[5][54] + coeff0_6*dmats1[6][54] + coeff0_7*dmats1[7][54] + coeff0_8*dmats1[8][54] + coeff0_9*dmats1[9][54] + coeff0_10*dmats1[10][54] + coeff0_11*dmats1[11][54] + coeff0_12*dmats1[12][54] + coeff0_13*dmats1[13][54] + coeff0_14*dmats1[14][54] + coeff0_15*dmats1[15][54] + coeff0_16*dmats1[16][54] + coeff0_17*dmats1[17][54] + coeff0_18*dmats1[18][54] + coeff0_19*dmats1[19][54] + coeff0_20*dmats1[20][54] + coeff0_21*dmats1[21][54] + coeff0_22*dmats1[22][54] + coeff0_23*dmats1[23][54] + coeff0_24*dmats1[24][54] + coeff0_25*dmats1[25][54] + coeff0_26*dmats1[26][54] + coeff0_27*dmats1[27][54] + coeff0_28*dmats1[28][54] + coeff0_29*dmats1[29][54] + coeff0_30*dmats1[30][54] + coeff0_31*dmats1[31][54] + coeff0_32*dmats1[32][54] + coeff0_33*dmats1[33][54] + coeff0_34*dmats1[34][54] + coeff0_35*dmats1[35][54] + coeff0_36*dmats1[36][54] + coeff0_37*dmats1[37][54] + coeff0_38*dmats1[38][54] + coeff0_39*dmats1[39][54] + coeff0_40*dmats1[40][54] + coeff0_41*dmats1[41][54] + coeff0_42*dmats1[42][54] + coeff0_43*dmats1[43][54] + coeff0_44*dmats1[44][54] + coeff0_45*dmats1[45][54] + coeff0_46*dmats1[46][54] + coeff0_47*dmats1[47][54] + coeff0_48*dmats1[48][54] + coeff0_49*dmats1[49][54] + coeff0_50*dmats1[50][54] + coeff0_51*dmats1[51][54] + coeff0_52*dmats1[52][54] + coeff0_53*dmats1[53][54] + coeff0_54*dmats1[54][54] + coeff0_55*dmats1[55][54];
          new_coeff0_55 = coeff0_0*dmats1[0][55] + coeff0_1*dmats1[1][55] + coeff0_2*dmats1[2][55] + coeff0_3*dmats1[3][55] + coeff0_4*dmats1[4][55] + coeff0_5*dmats1[5][55] + coeff0_6*dmats1[6][55] + coeff0_7*dmats1[7][55] + coeff0_8*dmats1[8][55] + coeff0_9*dmats1[9][55] + coeff0_10*dmats1[10][55] + coeff0_11*dmats1[11][55] + coeff0_12*dmats1[12][55] + coeff0_13*dmats1[13][55] + coeff0_14*dmats1[14][55] + coeff0_15*dmats1[15][55] + coeff0_16*dmats1[16][55] + coeff0_17*dmats1[17][55] + coeff0_18*dmats1[18][55] + coeff0_19*dmats1[19][55] + coeff0_20*dmats1[20][55] + coeff0_21*dmats1[21][55] + coeff0_22*dmats1[22][55] + coeff0_23*dmats1[23][55] + coeff0_24*dmats1[24][55] + coeff0_25*dmats1[25][55] + coeff0_26*dmats1[26][55] + coeff0_27*dmats1[27][55] + coeff0_28*dmats1[28][55] + coeff0_29*dmats1[29][55] + coeff0_30*dmats1[30][55] + coeff0_31*dmats1[31][55] + coeff0_32*dmats1[32][55] + coeff0_33*dmats1[33][55] + coeff0_34*dmats1[34][55] + coeff0_35*dmats1[35][55] + coeff0_36*dmats1[36][55] + coeff0_37*dmats1[37][55] + coeff0_38*dmats1[38][55] + coeff0_39*dmats1[39][55] + coeff0_40*dmats1[40][55] + coeff0_41*dmats1[41][55] + coeff0_42*dmats1[42][55] + coeff0_43*dmats1[43][55] + coeff0_44*dmats1[44][55] + coeff0_45*dmats1[45][55] + coeff0_46*dmats1[46][55] + coeff0_47*dmats1[47][55] + coeff0_48*dmats1[48][55] + coeff0_49*dmats1[49][55] + coeff0_50*dmats1[50][55] + coeff0_51*dmats1[51][55] + coeff0_52*dmats1[52][55] + coeff0_53*dmats1[53][55] + coeff0_54*dmats1[54][55] + coeff0_55*dmats1[55][55];
        }
        if(combinations[deriv_num][j] == 2)
        {
          new_coeff0_0 = coeff0_0*dmats2[0][0] + coeff0_1*dmats2[1][0] + coeff0_2*dmats2[2][0] + coeff0_3*dmats2[3][0] + coeff0_4*dmats2[4][0] + coeff0_5*dmats2[5][0] + coeff0_6*dmats2[6][0] + coeff0_7*dmats2[7][0] + coeff0_8*dmats2[8][0] + coeff0_9*dmats2[9][0] + coeff0_10*dmats2[10][0] + coeff0_11*dmats2[11][0] + coeff0_12*dmats2[12][0] + coeff0_13*dmats2[13][0] + coeff0_14*dmats2[14][0] + coeff0_15*dmats2[15][0] + coeff0_16*dmats2[16][0] + coeff0_17*dmats2[17][0] + coeff0_18*dmats2[18][0] + coeff0_19*dmats2[19][0] + coeff0_20*dmats2[20][0] + coeff0_21*dmats2[21][0] + coeff0_22*dmats2[22][0] + coeff0_23*dmats2[23][0] + coeff0_24*dmats2[24][0] + coeff0_25*dmats2[25][0] + coeff0_26*dmats2[26][0] + coeff0_27*dmats2[27][0] + coeff0_28*dmats2[28][0] + coeff0_29*dmats2[29][0] + coeff0_30*dmats2[30][0] + coeff0_31*dmats2[31][0] + coeff0_32*dmats2[32][0] + coeff0_33*dmats2[33][0] + coeff0_34*dmats2[34][0] + coeff0_35*dmats2[35][0] + coeff0_36*dmats2[36][0] + coeff0_37*dmats2[37][0] + coeff0_38*dmats2[38][0] + coeff0_39*dmats2[39][0] + coeff0_40*dmats2[40][0] + coeff0_41*dmats2[41][0] + coeff0_42*dmats2[42][0] + coeff0_43*dmats2[43][0] + coeff0_44*dmats2[44][0] + coeff0_45*dmats2[45][0] + coeff0_46*dmats2[46][0] + coeff0_47*dmats2[47][0] + coeff0_48*dmats2[48][0] + coeff0_49*dmats2[49][0] + coeff0_50*dmats2[50][0] + coeff0_51*dmats2[51][0] + coeff0_52*dmats2[52][0] + coeff0_53*dmats2[53][0] + coeff0_54*dmats2[54][0] + coeff0_55*dmats2[55][0];
          new_coeff0_1 = coeff0_0*dmats2[0][1] + coeff0_1*dmats2[1][1] + coeff0_2*dmats2[2][1] + coeff0_3*dmats2[3][1] + coeff0_4*dmats2[4][1] + coeff0_5*dmats2[5][1] + coeff0_6*dmats2[6][1] + coeff0_7*dmats2[7][1] + coeff0_8*dmats2[8][1] + coeff0_9*dmats2[9][1] + coeff0_10*dmats2[10][1] + coeff0_11*dmats2[11][1] + coeff0_12*dmats2[12][1] + coeff0_13*dmats2[13][1] + coeff0_14*dmats2[14][1] + coeff0_15*dmats2[15][1] + coeff0_16*dmats2[16][1] + coeff0_17*dmats2[17][1] + coeff0_18*dmats2[18][1] + coeff0_19*dmats2[19][1] + coeff0_20*dmats2[20][1] + coeff0_21*dmats2[21][1] + coeff0_22*dmats2[22][1] + coeff0_23*dmats2[23][1] + coeff0_24*dmats2[24][1] + coeff0_25*dmats2[25][1] + coeff0_26*dmats2[26][1] + coeff0_27*dmats2[27][1] + coeff0_28*dmats2[28][1] + coeff0_29*dmats2[29][1] + coeff0_30*dmats2[30][1] + coeff0_31*dmats2[31][1] + coeff0_32*dmats2[32][1] + coeff0_33*dmats2[33][1] + coeff0_34*dmats2[34][1] + coeff0_35*dmats2[35][1] + coeff0_36*dmats2[36][1] + coeff0_37*dmats2[37][1] + coeff0_38*dmats2[38][1] + coeff0_39*dmats2[39][1] + coeff0_40*dmats2[40][1] + coeff0_41*dmats2[41][1] + coeff0_42*dmats2[42][1] + coeff0_43*dmats2[43][1] + coeff0_44*dmats2[44][1] + coeff0_45*dmats2[45][1] + coeff0_46*dmats2[46][1] + coeff0_47*dmats2[47][1] + coeff0_48*dmats2[48][1] + coeff0_49*dmats2[49][1] + coeff0_50*dmats2[50][1] + coeff0_51*dmats2[51][1] + coeff0_52*dmats2[52][1] + coeff0_53*dmats2[53][1] + coeff0_54*dmats2[54][1] + coeff0_55*dmats2[55][1];
          new_coeff0_2 = coeff0_0*dmats2[0][2] + coeff0_1*dmats2[1][2] + coeff0_2*dmats2[2][2] + coeff0_3*dmats2[3][2] + coeff0_4*dmats2[4][2] + coeff0_5*dmats2[5][2] + coeff0_6*dmats2[6][2] + coeff0_7*dmats2[7][2] + coeff0_8*dmats2[8][2] + coeff0_9*dmats2[9][2] + coeff0_10*dmats2[10][2] + coeff0_11*dmats2[11][2] + coeff0_12*dmats2[12][2] + coeff0_13*dmats2[13][2] + coeff0_14*dmats2[14][2] + coeff0_15*dmats2[15][2] + coeff0_16*dmats2[16][2] + coeff0_17*dmats2[17][2] + coeff0_18*dmats2[18][2] + coeff0_19*dmats2[19][2] + coeff0_20*dmats2[20][2] + coeff0_21*dmats2[21][2] + coeff0_22*dmats2[22][2] + coeff0_23*dmats2[23][2] + coeff0_24*dmats2[24][2] + coeff0_25*dmats2[25][2] + coeff0_26*dmats2[26][2] + coeff0_27*dmats2[27][2] + coeff0_28*dmats2[28][2] + coeff0_29*dmats2[29][2] + coeff0_30*dmats2[30][2] + coeff0_31*dmats2[31][2] + coeff0_32*dmats2[32][2] + coeff0_33*dmats2[33][2] + coeff0_34*dmats2[34][2] + coeff0_35*dmats2[35][2] + coeff0_36*dmats2[36][2] + coeff0_37*dmats2[37][2] + coeff0_38*dmats2[38][2] + coeff0_39*dmats2[39][2] + coeff0_40*dmats2[40][2] + coeff0_41*dmats2[41][2] + coeff0_42*dmats2[42][2] + coeff0_43*dmats2[43][2] + coeff0_44*dmats2[44][2] + coeff0_45*dmats2[45][2] + coeff0_46*dmats2[46][2] + coeff0_47*dmats2[47][2] + coeff0_48*dmats2[48][2] + coeff0_49*dmats2[49][2] + coeff0_50*dmats2[50][2] + coeff0_51*dmats2[51][2] + coeff0_52*dmats2[52][2] + coeff0_53*dmats2[53][2] + coeff0_54*dmats2[54][2] + coeff0_55*dmats2[55][2];
          new_coeff0_3 = coeff0_0*dmats2[0][3] + coeff0_1*dmats2[1][3] + coeff0_2*dmats2[2][3] + coeff0_3*dmats2[3][3] + coeff0_4*dmats2[4][3] + coeff0_5*dmats2[5][3] + coeff0_6*dmats2[6][3] + coeff0_7*dmats2[7][3] + coeff0_8*dmats2[8][3] + coeff0_9*dmats2[9][3] + coeff0_10*dmats2[10][3] + coeff0_11*dmats2[11][3] + coeff0_12*dmats2[12][3] + coeff0_13*dmats2[13][3] + coeff0_14*dmats2[14][3] + coeff0_15*dmats2[15][3] + coeff0_16*dmats2[16][3] + coeff0_17*dmats2[17][3] + coeff0_18*dmats2[18][3] + coeff0_19*dmats2[19][3] + coeff0_20*dmats2[20][3] + coeff0_21*dmats2[21][3] + coeff0_22*dmats2[22][3] + coeff0_23*dmats2[23][3] + coeff0_24*dmats2[24][3] + coeff0_25*dmats2[25][3] + coeff0_26*dmats2[26][3] + coeff0_27*dmats2[27][3] + coeff0_28*dmats2[28][3] + coeff0_29*dmats2[29][3] + coeff0_30*dmats2[30][3] + coeff0_31*dmats2[31][3] + coeff0_32*dmats2[32][3] + coeff0_33*dmats2[33][3] + coeff0_34*dmats2[34][3] + coeff0_35*dmats2[35][3] + coeff0_36*dmats2[36][3] + coeff0_37*dmats2[37][3] + coeff0_38*dmats2[38][3] + coeff0_39*dmats2[39][3] + coeff0_40*dmats2[40][3] + coeff0_41*dmats2[41][3] + coeff0_42*dmats2[42][3] + coeff0_43*dmats2[43][3] + coeff0_44*dmats2[44][3] + coeff0_45*dmats2[45][3] + coeff0_46*dmats2[46][3] + coeff0_47*dmats2[47][3] + coeff0_48*dmats2[48][3] + coeff0_49*dmats2[49][3] + coeff0_50*dmats2[50][3] + coeff0_51*dmats2[51][3] + coeff0_52*dmats2[52][3] + coeff0_53*dmats2[53][3] + coeff0_54*dmats2[54][3] + coeff0_55*dmats2[55][3];
          new_coeff0_4 = coeff0_0*dmats2[0][4] + coeff0_1*dmats2[1][4] + coeff0_2*dmats2[2][4] + coeff0_3*dmats2[3][4] + coeff0_4*dmats2[4][4] + coeff0_5*dmats2[5][4] + coeff0_6*dmats2[6][4] + coeff0_7*dmats2[7][4] + coeff0_8*dmats2[8][4] + coeff0_9*dmats2[9][4] + coeff0_10*dmats2[10][4] + coeff0_11*dmats2[11][4] + coeff0_12*dmats2[12][4] + coeff0_13*dmats2[13][4] + coeff0_14*dmats2[14][4] + coeff0_15*dmats2[15][4] + coeff0_16*dmats2[16][4] + coeff0_17*dmats2[17][4] + coeff0_18*dmats2[18][4] + coeff0_19*dmats2[19][4] + coeff0_20*dmats2[20][4] + coeff0_21*dmats2[21][4] + coeff0_22*dmats2[22][4] + coeff0_23*dmats2[23][4] + coeff0_24*dmats2[24][4] + coeff0_25*dmats2[25][4] + coeff0_26*dmats2[26][4] + coeff0_27*dmats2[27][4] + coeff0_28*dmats2[28][4] + coeff0_29*dmats2[29][4] + coeff0_30*dmats2[30][4] + coeff0_31*dmats2[31][4] + coeff0_32*dmats2[32][4] + coeff0_33*dmats2[33][4] + coeff0_34*dmats2[34][4] + coeff0_35*dmats2[35][4] + coeff0_36*dmats2[36][4] + coeff0_37*dmats2[37][4] + coeff0_38*dmats2[38][4] + coeff0_39*dmats2[39][4] + coeff0_40*dmats2[40][4] + coeff0_41*dmats2[41][4] + coeff0_42*dmats2[42][4] + coeff0_43*dmats2[43][4] + coeff0_44*dmats2[44][4] + coeff0_45*dmats2[45][4] + coeff0_46*dmats2[46][4] + coeff0_47*dmats2[47][4] + coeff0_48*dmats2[48][4] + coeff0_49*dmats2[49][4] + coeff0_50*dmats2[50][4] + coeff0_51*dmats2[51][4] + coeff0_52*dmats2[52][4] + coeff0_53*dmats2[53][4] + coeff0_54*dmats2[54][4] + coeff0_55*dmats2[55][4];
          new_coeff0_5 = coeff0_0*dmats2[0][5] + coeff0_1*dmats2[1][5] + coeff0_2*dmats2[2][5] + coeff0_3*dmats2[3][5] + coeff0_4*dmats2[4][5] + coeff0_5*dmats2[5][5] + coeff0_6*dmats2[6][5] + coeff0_7*dmats2[7][5] + coeff0_8*dmats2[8][5] + coeff0_9*dmats2[9][5] + coeff0_10*dmats2[10][5] + coeff0_11*dmats2[11][5] + coeff0_12*dmats2[12][5] + coeff0_13*dmats2[13][5] + coeff0_14*dmats2[14][5] + coeff0_15*dmats2[15][5] + coeff0_16*dmats2[16][5] + coeff0_17*dmats2[17][5] + coeff0_18*dmats2[18][5] + coeff0_19*dmats2[19][5] + coeff0_20*dmats2[20][5] + coeff0_21*dmats2[21][5] + coeff0_22*dmats2[22][5] + coeff0_23*dmats2[23][5] + coeff0_24*dmats2[24][5] + coeff0_25*dmats2[25][5] + coeff0_26*dmats2[26][5] + coeff0_27*dmats2[27][5] + coeff0_28*dmats2[28][5] + coeff0_29*dmats2[29][5] + coeff0_30*dmats2[30][5] + coeff0_31*dmats2[31][5] + coeff0_32*dmats2[32][5] + coeff0_33*dmats2[33][5] + coeff0_34*dmats2[34][5] + coeff0_35*dmats2[35][5] + coeff0_36*dmats2[36][5] + coeff0_37*dmats2[37][5] + coeff0_38*dmats2[38][5] + coeff0_39*dmats2[39][5] + coeff0_40*dmats2[40][5] + coeff0_41*dmats2[41][5] + coeff0_42*dmats2[42][5] + coeff0_43*dmats2[43][5] + coeff0_44*dmats2[44][5] + coeff0_45*dmats2[45][5] + coeff0_46*dmats2[46][5] + coeff0_47*dmats2[47][5] + coeff0_48*dmats2[48][5] + coeff0_49*dmats2[49][5] + coeff0_50*dmats2[50][5] + coeff0_51*dmats2[51][5] + coeff0_52*dmats2[52][5] + coeff0_53*dmats2[53][5] + coeff0_54*dmats2[54][5] + coeff0_55*dmats2[55][5];
          new_coeff0_6 = coeff0_0*dmats2[0][6] + coeff0_1*dmats2[1][6] + coeff0_2*dmats2[2][6] + coeff0_3*dmats2[3][6] + coeff0_4*dmats2[4][6] + coeff0_5*dmats2[5][6] + coeff0_6*dmats2[6][6] + coeff0_7*dmats2[7][6] + coeff0_8*dmats2[8][6] + coeff0_9*dmats2[9][6] + coeff0_10*dmats2[10][6] + coeff0_11*dmats2[11][6] + coeff0_12*dmats2[12][6] + coeff0_13*dmats2[13][6] + coeff0_14*dmats2[14][6] + coeff0_15*dmats2[15][6] + coeff0_16*dmats2[16][6] + coeff0_17*dmats2[17][6] + coeff0_18*dmats2[18][6] + coeff0_19*dmats2[19][6] + coeff0_20*dmats2[20][6] + coeff0_21*dmats2[21][6] + coeff0_22*dmats2[22][6] + coeff0_23*dmats2[23][6] + coeff0_24*dmats2[24][6] + coeff0_25*dmats2[25][6] + coeff0_26*dmats2[26][6] + coeff0_27*dmats2[27][6] + coeff0_28*dmats2[28][6] + coeff0_29*dmats2[29][6] + coeff0_30*dmats2[30][6] + coeff0_31*dmats2[31][6] + coeff0_32*dmats2[32][6] + coeff0_33*dmats2[33][6] + coeff0_34*dmats2[34][6] + coeff0_35*dmats2[35][6] + coeff0_36*dmats2[36][6] + coeff0_37*dmats2[37][6] + coeff0_38*dmats2[38][6] + coeff0_39*dmats2[39][6] + coeff0_40*dmats2[40][6] + coeff0_41*dmats2[41][6] + coeff0_42*dmats2[42][6] + coeff0_43*dmats2[43][6] + coeff0_44*dmats2[44][6] + coeff0_45*dmats2[45][6] + coeff0_46*dmats2[46][6] + coeff0_47*dmats2[47][6] + coeff0_48*dmats2[48][6] + coeff0_49*dmats2[49][6] + coeff0_50*dmats2[50][6] + coeff0_51*dmats2[51][6] + coeff0_52*dmats2[52][6] + coeff0_53*dmats2[53][6] + coeff0_54*dmats2[54][6] + coeff0_55*dmats2[55][6];
          new_coeff0_7 = coeff0_0*dmats2[0][7] + coeff0_1*dmats2[1][7] + coeff0_2*dmats2[2][7] + coeff0_3*dmats2[3][7] + coeff0_4*dmats2[4][7] + coeff0_5*dmats2[5][7] + coeff0_6*dmats2[6][7] + coeff0_7*dmats2[7][7] + coeff0_8*dmats2[8][7] + coeff0_9*dmats2[9][7] + coeff0_10*dmats2[10][7] + coeff0_11*dmats2[11][7] + coeff0_12*dmats2[12][7] + coeff0_13*dmats2[13][7] + coeff0_14*dmats2[14][7] + coeff0_15*dmats2[15][7] + coeff0_16*dmats2[16][7] + coeff0_17*dmats2[17][7] + coeff0_18*dmats2[18][7] + coeff0_19*dmats2[19][7] + coeff0_20*dmats2[20][7] + coeff0_21*dmats2[21][7] + coeff0_22*dmats2[22][7] + coeff0_23*dmats2[23][7] + coeff0_24*dmats2[24][7] + coeff0_25*dmats2[25][7] + coeff0_26*dmats2[26][7] + coeff0_27*dmats2[27][7] + coeff0_28*dmats2[28][7] + coeff0_29*dmats2[29][7] + coeff0_30*dmats2[30][7] + coeff0_31*dmats2[31][7] + coeff0_32*dmats2[32][7] + coeff0_33*dmats2[33][7] + coeff0_34*dmats2[34][7] + coeff0_35*dmats2[35][7] + coeff0_36*dmats2[36][7] + coeff0_37*dmats2[37][7] + coeff0_38*dmats2[38][7] + coeff0_39*dmats2[39][7] + coeff0_40*dmats2[40][7] + coeff0_41*dmats2[41][7] + coeff0_42*dmats2[42][7] + coeff0_43*dmats2[43][7] + coeff0_44*dmats2[44][7] + coeff0_45*dmats2[45][7] + coeff0_46*dmats2[46][7] + coeff0_47*dmats2[47][7] + coeff0_48*dmats2[48][7] + coeff0_49*dmats2[49][7] + coeff0_50*dmats2[50][7] + coeff0_51*dmats2[51][7] + coeff0_52*dmats2[52][7] + coeff0_53*dmats2[53][7] + coeff0_54*dmats2[54][7] + coeff0_55*dmats2[55][7];
          new_coeff0_8 = coeff0_0*dmats2[0][8] + coeff0_1*dmats2[1][8] + coeff0_2*dmats2[2][8] + coeff0_3*dmats2[3][8] + coeff0_4*dmats2[4][8] + coeff0_5*dmats2[5][8] + coeff0_6*dmats2[6][8] + coeff0_7*dmats2[7][8] + coeff0_8*dmats2[8][8] + coeff0_9*dmats2[9][8] + coeff0_10*dmats2[10][8] + coeff0_11*dmats2[11][8] + coeff0_12*dmats2[12][8] + coeff0_13*dmats2[13][8] + coeff0_14*dmats2[14][8] + coeff0_15*dmats2[15][8] + coeff0_16*dmats2[16][8] + coeff0_17*dmats2[17][8] + coeff0_18*dmats2[18][8] + coeff0_19*dmats2[19][8] + coeff0_20*dmats2[20][8] + coeff0_21*dmats2[21][8] + coeff0_22*dmats2[22][8] + coeff0_23*dmats2[23][8] + coeff0_24*dmats2[24][8] + coeff0_25*dmats2[25][8] + coeff0_26*dmats2[26][8] + coeff0_27*dmats2[27][8] + coeff0_28*dmats2[28][8] + coeff0_29*dmats2[29][8] + coeff0_30*dmats2[30][8] + coeff0_31*dmats2[31][8] + coeff0_32*dmats2[32][8] + coeff0_33*dmats2[33][8] + coeff0_34*dmats2[34][8] + coeff0_35*dmats2[35][8] + coeff0_36*dmats2[36][8] + coeff0_37*dmats2[37][8] + coeff0_38*dmats2[38][8] + coeff0_39*dmats2[39][8] + coeff0_40*dmats2[40][8] + coeff0_41*dmats2[41][8] + coeff0_42*dmats2[42][8] + coeff0_43*dmats2[43][8] + coeff0_44*dmats2[44][8] + coeff0_45*dmats2[45][8] + coeff0_46*dmats2[46][8] + coeff0_47*dmats2[47][8] + coeff0_48*dmats2[48][8] + coeff0_49*dmats2[49][8] + coeff0_50*dmats2[50][8] + coeff0_51*dmats2[51][8] + coeff0_52*dmats2[52][8] + coeff0_53*dmats2[53][8] + coeff0_54*dmats2[54][8] + coeff0_55*dmats2[55][8];
          new_coeff0_9 = coeff0_0*dmats2[0][9] + coeff0_1*dmats2[1][9] + coeff0_2*dmats2[2][9] + coeff0_3*dmats2[3][9] + coeff0_4*dmats2[4][9] + coeff0_5*dmats2[5][9] + coeff0_6*dmats2[6][9] + coeff0_7*dmats2[7][9] + coeff0_8*dmats2[8][9] + coeff0_9*dmats2[9][9] + coeff0_10*dmats2[10][9] + coeff0_11*dmats2[11][9] + coeff0_12*dmats2[12][9] + coeff0_13*dmats2[13][9] + coeff0_14*dmats2[14][9] + coeff0_15*dmats2[15][9] + coeff0_16*dmats2[16][9] + coeff0_17*dmats2[17][9] + coeff0_18*dmats2[18][9] + coeff0_19*dmats2[19][9] + coeff0_20*dmats2[20][9] + coeff0_21*dmats2[21][9] + coeff0_22*dmats2[22][9] + coeff0_23*dmats2[23][9] + coeff0_24*dmats2[24][9] + coeff0_25*dmats2[25][9] + coeff0_26*dmats2[26][9] + coeff0_27*dmats2[27][9] + coeff0_28*dmats2[28][9] + coeff0_29*dmats2[29][9] + coeff0_30*dmats2[30][9] + coeff0_31*dmats2[31][9] + coeff0_32*dmats2[32][9] + coeff0_33*dmats2[33][9] + coeff0_34*dmats2[34][9] + coeff0_35*dmats2[35][9] + coeff0_36*dmats2[36][9] + coeff0_37*dmats2[37][9] + coeff0_38*dmats2[38][9] + coeff0_39*dmats2[39][9] + coeff0_40*dmats2[40][9] + coeff0_41*dmats2[41][9] + coeff0_42*dmats2[42][9] + coeff0_43*dmats2[43][9] + coeff0_44*dmats2[44][9] + coeff0_45*dmats2[45][9] + coeff0_46*dmats2[46][9] + coeff0_47*dmats2[47][9] + coeff0_48*dmats2[48][9] + coeff0_49*dmats2[49][9] + coeff0_50*dmats2[50][9] + coeff0_51*dmats2[51][9] + coeff0_52*dmats2[52][9] + coeff0_53*dmats2[53][9] + coeff0_54*dmats2[54][9] + coeff0_55*dmats2[55][9];
          new_coeff0_10 = coeff0_0*dmats2[0][10] + coeff0_1*dmats2[1][10] + coeff0_2*dmats2[2][10] + coeff0_3*dmats2[3][10] + coeff0_4*dmats2[4][10] + coeff0_5*dmats2[5][10] + coeff0_6*dmats2[6][10] + coeff0_7*dmats2[7][10] + coeff0_8*dmats2[8][10] + coeff0_9*dmats2[9][10] + coeff0_10*dmats2[10][10] + coeff0_11*dmats2[11][10] + coeff0_12*dmats2[12][10] + coeff0_13*dmats2[13][10] + coeff0_14*dmats2[14][10] + coeff0_15*dmats2[15][10] + coeff0_16*dmats2[16][10] + coeff0_17*dmats2[17][10] + coeff0_18*dmats2[18][10] + coeff0_19*dmats2[19][10] + coeff0_20*dmats2[20][10] + coeff0_21*dmats2[21][10] + coeff0_22*dmats2[22][10] + coeff0_23*dmats2[23][10] + coeff0_24*dmats2[24][10] + coeff0_25*dmats2[25][10] + coeff0_26*dmats2[26][10] + coeff0_27*dmats2[27][10] + coeff0_28*dmats2[28][10] + coeff0_29*dmats2[29][10] + coeff0_30*dmats2[30][10] + coeff0_31*dmats2[31][10] + coeff0_32*dmats2[32][10] + coeff0_33*dmats2[33][10] + coeff0_34*dmats2[34][10] + coeff0_35*dmats2[35][10] + coeff0_36*dmats2[36][10] + coeff0_37*dmats2[37][10] + coeff0_38*dmats2[38][10] + coeff0_39*dmats2[39][10] + coeff0_40*dmats2[40][10] + coeff0_41*dmats2[41][10] + coeff0_42*dmats2[42][10] + coeff0_43*dmats2[43][10] + coeff0_44*dmats2[44][10] + coeff0_45*dmats2[45][10] + coeff0_46*dmats2[46][10] + coeff0_47*dmats2[47][10] + coeff0_48*dmats2[48][10] + coeff0_49*dmats2[49][10] + coeff0_50*dmats2[50][10] + coeff0_51*dmats2[51][10] + coeff0_52*dmats2[52][10] + coeff0_53*dmats2[53][10] + coeff0_54*dmats2[54][10] + coeff0_55*dmats2[55][10];
          new_coeff0_11 = coeff0_0*dmats2[0][11] + coeff0_1*dmats2[1][11] + coeff0_2*dmats2[2][11] + coeff0_3*dmats2[3][11] + coeff0_4*dmats2[4][11] + coeff0_5*dmats2[5][11] + coeff0_6*dmats2[6][11] + coeff0_7*dmats2[7][11] + coeff0_8*dmats2[8][11] + coeff0_9*dmats2[9][11] + coeff0_10*dmats2[10][11] + coeff0_11*dmats2[11][11] + coeff0_12*dmats2[12][11] + coeff0_13*dmats2[13][11] + coeff0_14*dmats2[14][11] + coeff0_15*dmats2[15][11] + coeff0_16*dmats2[16][11] + coeff0_17*dmats2[17][11] + coeff0_18*dmats2[18][11] + coeff0_19*dmats2[19][11] + coeff0_20*dmats2[20][11] + coeff0_21*dmats2[21][11] + coeff0_22*dmats2[22][11] + coeff0_23*dmats2[23][11] + coeff0_24*dmats2[24][11] + coeff0_25*dmats2[25][11] + coeff0_26*dmats2[26][11] + coeff0_27*dmats2[27][11] + coeff0_28*dmats2[28][11] + coeff0_29*dmats2[29][11] + coeff0_30*dmats2[30][11] + coeff0_31*dmats2[31][11] + coeff0_32*dmats2[32][11] + coeff0_33*dmats2[33][11] + coeff0_34*dmats2[34][11] + coeff0_35*dmats2[35][11] + coeff0_36*dmats2[36][11] + coeff0_37*dmats2[37][11] + coeff0_38*dmats2[38][11] + coeff0_39*dmats2[39][11] + coeff0_40*dmats2[40][11] + coeff0_41*dmats2[41][11] + coeff0_42*dmats2[42][11] + coeff0_43*dmats2[43][11] + coeff0_44*dmats2[44][11] + coeff0_45*dmats2[45][11] + coeff0_46*dmats2[46][11] + coeff0_47*dmats2[47][11] + coeff0_48*dmats2[48][11] + coeff0_49*dmats2[49][11] + coeff0_50*dmats2[50][11] + coeff0_51*dmats2[51][11] + coeff0_52*dmats2[52][11] + coeff0_53*dmats2[53][11] + coeff0_54*dmats2[54][11] + coeff0_55*dmats2[55][11];
          new_coeff0_12 = coeff0_0*dmats2[0][12] + coeff0_1*dmats2[1][12] + coeff0_2*dmats2[2][12] + coeff0_3*dmats2[3][12] + coeff0_4*dmats2[4][12] + coeff0_5*dmats2[5][12] + coeff0_6*dmats2[6][12] + coeff0_7*dmats2[7][12] + coeff0_8*dmats2[8][12] + coeff0_9*dmats2[9][12] + coeff0_10*dmats2[10][12] + coeff0_11*dmats2[11][12] + coeff0_12*dmats2[12][12] + coeff0_13*dmats2[13][12] + coeff0_14*dmats2[14][12] + coeff0_15*dmats2[15][12] + coeff0_16*dmats2[16][12] + coeff0_17*dmats2[17][12] + coeff0_18*dmats2[18][12] + coeff0_19*dmats2[19][12] + coeff0_20*dmats2[20][12] + coeff0_21*dmats2[21][12] + coeff0_22*dmats2[22][12] + coeff0_23*dmats2[23][12] + coeff0_24*dmats2[24][12] + coeff0_25*dmats2[25][12] + coeff0_26*dmats2[26][12] + coeff0_27*dmats2[27][12] + coeff0_28*dmats2[28][12] + coeff0_29*dmats2[29][12] + coeff0_30*dmats2[30][12] + coeff0_31*dmats2[31][12] + coeff0_32*dmats2[32][12] + coeff0_33*dmats2[33][12] + coeff0_34*dmats2[34][12] + coeff0_35*dmats2[35][12] + coeff0_36*dmats2[36][12] + coeff0_37*dmats2[37][12] + coeff0_38*dmats2[38][12] + coeff0_39*dmats2[39][12] + coeff0_40*dmats2[40][12] + coeff0_41*dmats2[41][12] + coeff0_42*dmats2[42][12] + coeff0_43*dmats2[43][12] + coeff0_44*dmats2[44][12] + coeff0_45*dmats2[45][12] + coeff0_46*dmats2[46][12] + coeff0_47*dmats2[47][12] + coeff0_48*dmats2[48][12] + coeff0_49*dmats2[49][12] + coeff0_50*dmats2[50][12] + coeff0_51*dmats2[51][12] + coeff0_52*dmats2[52][12] + coeff0_53*dmats2[53][12] + coeff0_54*dmats2[54][12] + coeff0_55*dmats2[55][12];
          new_coeff0_13 = coeff0_0*dmats2[0][13] + coeff0_1*dmats2[1][13] + coeff0_2*dmats2[2][13] + coeff0_3*dmats2[3][13] + coeff0_4*dmats2[4][13] + coeff0_5*dmats2[5][13] + coeff0_6*dmats2[6][13] + coeff0_7*dmats2[7][13] + coeff0_8*dmats2[8][13] + coeff0_9*dmats2[9][13] + coeff0_10*dmats2[10][13] + coeff0_11*dmats2[11][13] + coeff0_12*dmats2[12][13] + coeff0_13*dmats2[13][13] + coeff0_14*dmats2[14][13] + coeff0_15*dmats2[15][13] + coeff0_16*dmats2[16][13] + coeff0_17*dmats2[17][13] + coeff0_18*dmats2[18][13] + coeff0_19*dmats2[19][13] + coeff0_20*dmats2[20][13] + coeff0_21*dmats2[21][13] + coeff0_22*dmats2[22][13] + coeff0_23*dmats2[23][13] + coeff0_24*dmats2[24][13] + coeff0_25*dmats2[25][13] + coeff0_26*dmats2[26][13] + coeff0_27*dmats2[27][13] + coeff0_28*dmats2[28][13] + coeff0_29*dmats2[29][13] + coeff0_30*dmats2[30][13] + coeff0_31*dmats2[31][13] + coeff0_32*dmats2[32][13] + coeff0_33*dmats2[33][13] + coeff0_34*dmats2[34][13] + coeff0_35*dmats2[35][13] + coeff0_36*dmats2[36][13] + coeff0_37*dmats2[37][13] + coeff0_38*dmats2[38][13] + coeff0_39*dmats2[39][13] + coeff0_40*dmats2[40][13] + coeff0_41*dmats2[41][13] + coeff0_42*dmats2[42][13] + coeff0_43*dmats2[43][13] + coeff0_44*dmats2[44][13] + coeff0_45*dmats2[45][13] + coeff0_46*dmats2[46][13] + coeff0_47*dmats2[47][13] + coeff0_48*dmats2[48][13] + coeff0_49*dmats2[49][13] + coeff0_50*dmats2[50][13] + coeff0_51*dmats2[51][13] + coeff0_52*dmats2[52][13] + coeff0_53*dmats2[53][13] + coeff0_54*dmats2[54][13] + coeff0_55*dmats2[55][13];
          new_coeff0_14 = coeff0_0*dmats2[0][14] + coeff0_1*dmats2[1][14] + coeff0_2*dmats2[2][14] + coeff0_3*dmats2[3][14] + coeff0_4*dmats2[4][14] + coeff0_5*dmats2[5][14] + coeff0_6*dmats2[6][14] + coeff0_7*dmats2[7][14] + coeff0_8*dmats2[8][14] + coeff0_9*dmats2[9][14] + coeff0_10*dmats2[10][14] + coeff0_11*dmats2[11][14] + coeff0_12*dmats2[12][14] + coeff0_13*dmats2[13][14] + coeff0_14*dmats2[14][14] + coeff0_15*dmats2[15][14] + coeff0_16*dmats2[16][14] + coeff0_17*dmats2[17][14] + coeff0_18*dmats2[18][14] + coeff0_19*dmats2[19][14] + coeff0_20*dmats2[20][14] + coeff0_21*dmats2[21][14] + coeff0_22*dmats2[22][14] + coeff0_23*dmats2[23][14] + coeff0_24*dmats2[24][14] + coeff0_25*dmats2[25][14] + coeff0_26*dmats2[26][14] + coeff0_27*dmats2[27][14] + coeff0_28*dmats2[28][14] + coeff0_29*dmats2[29][14] + coeff0_30*dmats2[30][14] + coeff0_31*dmats2[31][14] + coeff0_32*dmats2[32][14] + coeff0_33*dmats2[33][14] + coeff0_34*dmats2[34][14] + coeff0_35*dmats2[35][14] + coeff0_36*dmats2[36][14] + coeff0_37*dmats2[37][14] + coeff0_38*dmats2[38][14] + coeff0_39*dmats2[39][14] + coeff0_40*dmats2[40][14] + coeff0_41*dmats2[41][14] + coeff0_42*dmats2[42][14] + coeff0_43*dmats2[43][14] + coeff0_44*dmats2[44][14] + coeff0_45*dmats2[45][14] + coeff0_46*dmats2[46][14] + coeff0_47*dmats2[47][14] + coeff0_48*dmats2[48][14] + coeff0_49*dmats2[49][14] + coeff0_50*dmats2[50][14] + coeff0_51*dmats2[51][14] + coeff0_52*dmats2[52][14] + coeff0_53*dmats2[53][14] + coeff0_54*dmats2[54][14] + coeff0_55*dmats2[55][14];
          new_coeff0_15 = coeff0_0*dmats2[0][15] + coeff0_1*dmats2[1][15] + coeff0_2*dmats2[2][15] + coeff0_3*dmats2[3][15] + coeff0_4*dmats2[4][15] + coeff0_5*dmats2[5][15] + coeff0_6*dmats2[6][15] + coeff0_7*dmats2[7][15] + coeff0_8*dmats2[8][15] + coeff0_9*dmats2[9][15] + coeff0_10*dmats2[10][15] + coeff0_11*dmats2[11][15] + coeff0_12*dmats2[12][15] + coeff0_13*dmats2[13][15] + coeff0_14*dmats2[14][15] + coeff0_15*dmats2[15][15] + coeff0_16*dmats2[16][15] + coeff0_17*dmats2[17][15] + coeff0_18*dmats2[18][15] + coeff0_19*dmats2[19][15] + coeff0_20*dmats2[20][15] + coeff0_21*dmats2[21][15] + coeff0_22*dmats2[22][15] + coeff0_23*dmats2[23][15] + coeff0_24*dmats2[24][15] + coeff0_25*dmats2[25][15] + coeff0_26*dmats2[26][15] + coeff0_27*dmats2[27][15] + coeff0_28*dmats2[28][15] + coeff0_29*dmats2[29][15] + coeff0_30*dmats2[30][15] + coeff0_31*dmats2[31][15] + coeff0_32*dmats2[32][15] + coeff0_33*dmats2[33][15] + coeff0_34*dmats2[34][15] + coeff0_35*dmats2[35][15] + coeff0_36*dmats2[36][15] + coeff0_37*dmats2[37][15] + coeff0_38*dmats2[38][15] + coeff0_39*dmats2[39][15] + coeff0_40*dmats2[40][15] + coeff0_41*dmats2[41][15] + coeff0_42*dmats2[42][15] + coeff0_43*dmats2[43][15] + coeff0_44*dmats2[44][15] + coeff0_45*dmats2[45][15] + coeff0_46*dmats2[46][15] + coeff0_47*dmats2[47][15] + coeff0_48*dmats2[48][15] + coeff0_49*dmats2[49][15] + coeff0_50*dmats2[50][15] + coeff0_51*dmats2[51][15] + coeff0_52*dmats2[52][15] + coeff0_53*dmats2[53][15] + coeff0_54*dmats2[54][15] + coeff0_55*dmats2[55][15];
          new_coeff0_16 = coeff0_0*dmats2[0][16] + coeff0_1*dmats2[1][16] + coeff0_2*dmats2[2][16] + coeff0_3*dmats2[3][16] + coeff0_4*dmats2[4][16] + coeff0_5*dmats2[5][16] + coeff0_6*dmats2[6][16] + coeff0_7*dmats2[7][16] + coeff0_8*dmats2[8][16] + coeff0_9*dmats2[9][16] + coeff0_10*dmats2[10][16] + coeff0_11*dmats2[11][16] + coeff0_12*dmats2[12][16] + coeff0_13*dmats2[13][16] + coeff0_14*dmats2[14][16] + coeff0_15*dmats2[15][16] + coeff0_16*dmats2[16][16] + coeff0_17*dmats2[17][16] + coeff0_18*dmats2[18][16] + coeff0_19*dmats2[19][16] + coeff0_20*dmats2[20][16] + coeff0_21*dmats2[21][16] + coeff0_22*dmats2[22][16] + coeff0_23*dmats2[23][16] + coeff0_24*dmats2[24][16] + coeff0_25*dmats2[25][16] + coeff0_26*dmats2[26][16] + coeff0_27*dmats2[27][16] + coeff0_28*dmats2[28][16] + coeff0_29*dmats2[29][16] + coeff0_30*dmats2[30][16] + coeff0_31*dmats2[31][16] + coeff0_32*dmats2[32][16] + coeff0_33*dmats2[33][16] + coeff0_34*dmats2[34][16] + coeff0_35*dmats2[35][16] + coeff0_36*dmats2[36][16] + coeff0_37*dmats2[37][16] + coeff0_38*dmats2[38][16] + coeff0_39*dmats2[39][16] + coeff0_40*dmats2[40][16] + coeff0_41*dmats2[41][16] + coeff0_42*dmats2[42][16] + coeff0_43*dmats2[43][16] + coeff0_44*dmats2[44][16] + coeff0_45*dmats2[45][16] + coeff0_46*dmats2[46][16] + coeff0_47*dmats2[47][16] + coeff0_48*dmats2[48][16] + coeff0_49*dmats2[49][16] + coeff0_50*dmats2[50][16] + coeff0_51*dmats2[51][16] + coeff0_52*dmats2[52][16] + coeff0_53*dmats2[53][16] + coeff0_54*dmats2[54][16] + coeff0_55*dmats2[55][16];
          new_coeff0_17 = coeff0_0*dmats2[0][17] + coeff0_1*dmats2[1][17] + coeff0_2*dmats2[2][17] + coeff0_3*dmats2[3][17] + coeff0_4*dmats2[4][17] + coeff0_5*dmats2[5][17] + coeff0_6*dmats2[6][17] + coeff0_7*dmats2[7][17] + coeff0_8*dmats2[8][17] + coeff0_9*dmats2[9][17] + coeff0_10*dmats2[10][17] + coeff0_11*dmats2[11][17] + coeff0_12*dmats2[12][17] + coeff0_13*dmats2[13][17] + coeff0_14*dmats2[14][17] + coeff0_15*dmats2[15][17] + coeff0_16*dmats2[16][17] + coeff0_17*dmats2[17][17] + coeff0_18*dmats2[18][17] + coeff0_19*dmats2[19][17] + coeff0_20*dmats2[20][17] + coeff0_21*dmats2[21][17] + coeff0_22*dmats2[22][17] + coeff0_23*dmats2[23][17] + coeff0_24*dmats2[24][17] + coeff0_25*dmats2[25][17] + coeff0_26*dmats2[26][17] + coeff0_27*dmats2[27][17] + coeff0_28*dmats2[28][17] + coeff0_29*dmats2[29][17] + coeff0_30*dmats2[30][17] + coeff0_31*dmats2[31][17] + coeff0_32*dmats2[32][17] + coeff0_33*dmats2[33][17] + coeff0_34*dmats2[34][17] + coeff0_35*dmats2[35][17] + coeff0_36*dmats2[36][17] + coeff0_37*dmats2[37][17] + coeff0_38*dmats2[38][17] + coeff0_39*dmats2[39][17] + coeff0_40*dmats2[40][17] + coeff0_41*dmats2[41][17] + coeff0_42*dmats2[42][17] + coeff0_43*dmats2[43][17] + coeff0_44*dmats2[44][17] + coeff0_45*dmats2[45][17] + coeff0_46*dmats2[46][17] + coeff0_47*dmats2[47][17] + coeff0_48*dmats2[48][17] + coeff0_49*dmats2[49][17] + coeff0_50*dmats2[50][17] + coeff0_51*dmats2[51][17] + coeff0_52*dmats2[52][17] + coeff0_53*dmats2[53][17] + coeff0_54*dmats2[54][17] + coeff0_55*dmats2[55][17];
          new_coeff0_18 = coeff0_0*dmats2[0][18] + coeff0_1*dmats2[1][18] + coeff0_2*dmats2[2][18] + coeff0_3*dmats2[3][18] + coeff0_4*dmats2[4][18] + coeff0_5*dmats2[5][18] + coeff0_6*dmats2[6][18] + coeff0_7*dmats2[7][18] + coeff0_8*dmats2[8][18] + coeff0_9*dmats2[9][18] + coeff0_10*dmats2[10][18] + coeff0_11*dmats2[11][18] + coeff0_12*dmats2[12][18] + coeff0_13*dmats2[13][18] + coeff0_14*dmats2[14][18] + coeff0_15*dmats2[15][18] + coeff0_16*dmats2[16][18] + coeff0_17*dmats2[17][18] + coeff0_18*dmats2[18][18] + coeff0_19*dmats2[19][18] + coeff0_20*dmats2[20][18] + coeff0_21*dmats2[21][18] + coeff0_22*dmats2[22][18] + coeff0_23*dmats2[23][18] + coeff0_24*dmats2[24][18] + coeff0_25*dmats2[25][18] + coeff0_26*dmats2[26][18] + coeff0_27*dmats2[27][18] + coeff0_28*dmats2[28][18] + coeff0_29*dmats2[29][18] + coeff0_30*dmats2[30][18] + coeff0_31*dmats2[31][18] + coeff0_32*dmats2[32][18] + coeff0_33*dmats2[33][18] + coeff0_34*dmats2[34][18] + coeff0_35*dmats2[35][18] + coeff0_36*dmats2[36][18] + coeff0_37*dmats2[37][18] + coeff0_38*dmats2[38][18] + coeff0_39*dmats2[39][18] + coeff0_40*dmats2[40][18] + coeff0_41*dmats2[41][18] + coeff0_42*dmats2[42][18] + coeff0_43*dmats2[43][18] + coeff0_44*dmats2[44][18] + coeff0_45*dmats2[45][18] + coeff0_46*dmats2[46][18] + coeff0_47*dmats2[47][18] + coeff0_48*dmats2[48][18] + coeff0_49*dmats2[49][18] + coeff0_50*dmats2[50][18] + coeff0_51*dmats2[51][18] + coeff0_52*dmats2[52][18] + coeff0_53*dmats2[53][18] + coeff0_54*dmats2[54][18] + coeff0_55*dmats2[55][18];
          new_coeff0_19 = coeff0_0*dmats2[0][19] + coeff0_1*dmats2[1][19] + coeff0_2*dmats2[2][19] + coeff0_3*dmats2[3][19] + coeff0_4*dmats2[4][19] + coeff0_5*dmats2[5][19] + coeff0_6*dmats2[6][19] + coeff0_7*dmats2[7][19] + coeff0_8*dmats2[8][19] + coeff0_9*dmats2[9][19] + coeff0_10*dmats2[10][19] + coeff0_11*dmats2[11][19] + coeff0_12*dmats2[12][19] + coeff0_13*dmats2[13][19] + coeff0_14*dmats2[14][19] + coeff0_15*dmats2[15][19] + coeff0_16*dmats2[16][19] + coeff0_17*dmats2[17][19] + coeff0_18*dmats2[18][19] + coeff0_19*dmats2[19][19] + coeff0_20*dmats2[20][19] + coeff0_21*dmats2[21][19] + coeff0_22*dmats2[22][19] + coeff0_23*dmats2[23][19] + coeff0_24*dmats2[24][19] + coeff0_25*dmats2[25][19] + coeff0_26*dmats2[26][19] + coeff0_27*dmats2[27][19] + coeff0_28*dmats2[28][19] + coeff0_29*dmats2[29][19] + coeff0_30*dmats2[30][19] + coeff0_31*dmats2[31][19] + coeff0_32*dmats2[32][19] + coeff0_33*dmats2[33][19] + coeff0_34*dmats2[34][19] + coeff0_35*dmats2[35][19] + coeff0_36*dmats2[36][19] + coeff0_37*dmats2[37][19] + coeff0_38*dmats2[38][19] + coeff0_39*dmats2[39][19] + coeff0_40*dmats2[40][19] + coeff0_41*dmats2[41][19] + coeff0_42*dmats2[42][19] + coeff0_43*dmats2[43][19] + coeff0_44*dmats2[44][19] + coeff0_45*dmats2[45][19] + coeff0_46*dmats2[46][19] + coeff0_47*dmats2[47][19] + coeff0_48*dmats2[48][19] + coeff0_49*dmats2[49][19] + coeff0_50*dmats2[50][19] + coeff0_51*dmats2[51][19] + coeff0_52*dmats2[52][19] + coeff0_53*dmats2[53][19] + coeff0_54*dmats2[54][19] + coeff0_55*dmats2[55][19];
          new_coeff0_20 = coeff0_0*dmats2[0][20] + coeff0_1*dmats2[1][20] + coeff0_2*dmats2[2][20] + coeff0_3*dmats2[3][20] + coeff0_4*dmats2[4][20] + coeff0_5*dmats2[5][20] + coeff0_6*dmats2[6][20] + coeff0_7*dmats2[7][20] + coeff0_8*dmats2[8][20] + coeff0_9*dmats2[9][20] + coeff0_10*dmats2[10][20] + coeff0_11*dmats2[11][20] + coeff0_12*dmats2[12][20] + coeff0_13*dmats2[13][20] + coeff0_14*dmats2[14][20] + coeff0_15*dmats2[15][20] + coeff0_16*dmats2[16][20] + coeff0_17*dmats2[17][20] + coeff0_18*dmats2[18][20] + coeff0_19*dmats2[19][20] + coeff0_20*dmats2[20][20] + coeff0_21*dmats2[21][20] + coeff0_22*dmats2[22][20] + coeff0_23*dmats2[23][20] + coeff0_24*dmats2[24][20] + coeff0_25*dmats2[25][20] + coeff0_26*dmats2[26][20] + coeff0_27*dmats2[27][20] + coeff0_28*dmats2[28][20] + coeff0_29*dmats2[29][20] + coeff0_30*dmats2[30][20] + coeff0_31*dmats2[31][20] + coeff0_32*dmats2[32][20] + coeff0_33*dmats2[33][20] + coeff0_34*dmats2[34][20] + coeff0_35*dmats2[35][20] + coeff0_36*dmats2[36][20] + coeff0_37*dmats2[37][20] + coeff0_38*dmats2[38][20] + coeff0_39*dmats2[39][20] + coeff0_40*dmats2[40][20] + coeff0_41*dmats2[41][20] + coeff0_42*dmats2[42][20] + coeff0_43*dmats2[43][20] + coeff0_44*dmats2[44][20] + coeff0_45*dmats2[45][20] + coeff0_46*dmats2[46][20] + coeff0_47*dmats2[47][20] + coeff0_48*dmats2[48][20] + coeff0_49*dmats2[49][20] + coeff0_50*dmats2[50][20] + coeff0_51*dmats2[51][20] + coeff0_52*dmats2[52][20] + coeff0_53*dmats2[53][20] + coeff0_54*dmats2[54][20] + coeff0_55*dmats2[55][20];
          new_coeff0_21 = coeff0_0*dmats2[0][21] + coeff0_1*dmats2[1][21] + coeff0_2*dmats2[2][21] + coeff0_3*dmats2[3][21] + coeff0_4*dmats2[4][21] + coeff0_5*dmats2[5][21] + coeff0_6*dmats2[6][21] + coeff0_7*dmats2[7][21] + coeff0_8*dmats2[8][21] + coeff0_9*dmats2[9][21] + coeff0_10*dmats2[10][21] + coeff0_11*dmats2[11][21] + coeff0_12*dmats2[12][21] + coeff0_13*dmats2[13][21] + coeff0_14*dmats2[14][21] + coeff0_15*dmats2[15][21] + coeff0_16*dmats2[16][21] + coeff0_17*dmats2[17][21] + coeff0_18*dmats2[18][21] + coeff0_19*dmats2[19][21] + coeff0_20*dmats2[20][21] + coeff0_21*dmats2[21][21] + coeff0_22*dmats2[22][21] + coeff0_23*dmats2[23][21] + coeff0_24*dmats2[24][21] + coeff0_25*dmats2[25][21] + coeff0_26*dmats2[26][21] + coeff0_27*dmats2[27][21] + coeff0_28*dmats2[28][21] + coeff0_29*dmats2[29][21] + coeff0_30*dmats2[30][21] + coeff0_31*dmats2[31][21] + coeff0_32*dmats2[32][21] + coeff0_33*dmats2[33][21] + coeff0_34*dmats2[34][21] + coeff0_35*dmats2[35][21] + coeff0_36*dmats2[36][21] + coeff0_37*dmats2[37][21] + coeff0_38*dmats2[38][21] + coeff0_39*dmats2[39][21] + coeff0_40*dmats2[40][21] + coeff0_41*dmats2[41][21] + coeff0_42*dmats2[42][21] + coeff0_43*dmats2[43][21] + coeff0_44*dmats2[44][21] + coeff0_45*dmats2[45][21] + coeff0_46*dmats2[46][21] + coeff0_47*dmats2[47][21] + coeff0_48*dmats2[48][21] + coeff0_49*dmats2[49][21] + coeff0_50*dmats2[50][21] + coeff0_51*dmats2[51][21] + coeff0_52*dmats2[52][21] + coeff0_53*dmats2[53][21] + coeff0_54*dmats2[54][21] + coeff0_55*dmats2[55][21];
          new_coeff0_22 = coeff0_0*dmats2[0][22] + coeff0_1*dmats2[1][22] + coeff0_2*dmats2[2][22] + coeff0_3*dmats2[3][22] + coeff0_4*dmats2[4][22] + coeff0_5*dmats2[5][22] + coeff0_6*dmats2[6][22] + coeff0_7*dmats2[7][22] + coeff0_8*dmats2[8][22] + coeff0_9*dmats2[9][22] + coeff0_10*dmats2[10][22] + coeff0_11*dmats2[11][22] + coeff0_12*dmats2[12][22] + coeff0_13*dmats2[13][22] + coeff0_14*dmats2[14][22] + coeff0_15*dmats2[15][22] + coeff0_16*dmats2[16][22] + coeff0_17*dmats2[17][22] + coeff0_18*dmats2[18][22] + coeff0_19*dmats2[19][22] + coeff0_20*dmats2[20][22] + coeff0_21*dmats2[21][22] + coeff0_22*dmats2[22][22] + coeff0_23*dmats2[23][22] + coeff0_24*dmats2[24][22] + coeff0_25*dmats2[25][22] + coeff0_26*dmats2[26][22] + coeff0_27*dmats2[27][22] + coeff0_28*dmats2[28][22] + coeff0_29*dmats2[29][22] + coeff0_30*dmats2[30][22] + coeff0_31*dmats2[31][22] + coeff0_32*dmats2[32][22] + coeff0_33*dmats2[33][22] + coeff0_34*dmats2[34][22] + coeff0_35*dmats2[35][22] + coeff0_36*dmats2[36][22] + coeff0_37*dmats2[37][22] + coeff0_38*dmats2[38][22] + coeff0_39*dmats2[39][22] + coeff0_40*dmats2[40][22] + coeff0_41*dmats2[41][22] + coeff0_42*dmats2[42][22] + coeff0_43*dmats2[43][22] + coeff0_44*dmats2[44][22] + coeff0_45*dmats2[45][22] + coeff0_46*dmats2[46][22] + coeff0_47*dmats2[47][22] + coeff0_48*dmats2[48][22] + coeff0_49*dmats2[49][22] + coeff0_50*dmats2[50][22] + coeff0_51*dmats2[51][22] + coeff0_52*dmats2[52][22] + coeff0_53*dmats2[53][22] + coeff0_54*dmats2[54][22] + coeff0_55*dmats2[55][22];
          new_coeff0_23 = coeff0_0*dmats2[0][23] + coeff0_1*dmats2[1][23] + coeff0_2*dmats2[2][23] + coeff0_3*dmats2[3][23] + coeff0_4*dmats2[4][23] + coeff0_5*dmats2[5][23] + coeff0_6*dmats2[6][23] + coeff0_7*dmats2[7][23] + coeff0_8*dmats2[8][23] + coeff0_9*dmats2[9][23] + coeff0_10*dmats2[10][23] + coeff0_11*dmats2[11][23] + coeff0_12*dmats2[12][23] + coeff0_13*dmats2[13][23] + coeff0_14*dmats2[14][23] + coeff0_15*dmats2[15][23] + coeff0_16*dmats2[16][23] + coeff0_17*dmats2[17][23] + coeff0_18*dmats2[18][23] + coeff0_19*dmats2[19][23] + coeff0_20*dmats2[20][23] + coeff0_21*dmats2[21][23] + coeff0_22*dmats2[22][23] + coeff0_23*dmats2[23][23] + coeff0_24*dmats2[24][23] + coeff0_25*dmats2[25][23] + coeff0_26*dmats2[26][23] + coeff0_27*dmats2[27][23] + coeff0_28*dmats2[28][23] + coeff0_29*dmats2[29][23] + coeff0_30*dmats2[30][23] + coeff0_31*dmats2[31][23] + coeff0_32*dmats2[32][23] + coeff0_33*dmats2[33][23] + coeff0_34*dmats2[34][23] + coeff0_35*dmats2[35][23] + coeff0_36*dmats2[36][23] + coeff0_37*dmats2[37][23] + coeff0_38*dmats2[38][23] + coeff0_39*dmats2[39][23] + coeff0_40*dmats2[40][23] + coeff0_41*dmats2[41][23] + coeff0_42*dmats2[42][23] + coeff0_43*dmats2[43][23] + coeff0_44*dmats2[44][23] + coeff0_45*dmats2[45][23] + coeff0_46*dmats2[46][23] + coeff0_47*dmats2[47][23] + coeff0_48*dmats2[48][23] + coeff0_49*dmats2[49][23] + coeff0_50*dmats2[50][23] + coeff0_51*dmats2[51][23] + coeff0_52*dmats2[52][23] + coeff0_53*dmats2[53][23] + coeff0_54*dmats2[54][23] + coeff0_55*dmats2[55][23];
          new_coeff0_24 = coeff0_0*dmats2[0][24] + coeff0_1*dmats2[1][24] + coeff0_2*dmats2[2][24] + coeff0_3*dmats2[3][24] + coeff0_4*dmats2[4][24] + coeff0_5*dmats2[5][24] + coeff0_6*dmats2[6][24] + coeff0_7*dmats2[7][24] + coeff0_8*dmats2[8][24] + coeff0_9*dmats2[9][24] + coeff0_10*dmats2[10][24] + coeff0_11*dmats2[11][24] + coeff0_12*dmats2[12][24] + coeff0_13*dmats2[13][24] + coeff0_14*dmats2[14][24] + coeff0_15*dmats2[15][24] + coeff0_16*dmats2[16][24] + coeff0_17*dmats2[17][24] + coeff0_18*dmats2[18][24] + coeff0_19*dmats2[19][24] + coeff0_20*dmats2[20][24] + coeff0_21*dmats2[21][24] + coeff0_22*dmats2[22][24] + coeff0_23*dmats2[23][24] + coeff0_24*dmats2[24][24] + coeff0_25*dmats2[25][24] + coeff0_26*dmats2[26][24] + coeff0_27*dmats2[27][24] + coeff0_28*dmats2[28][24] + coeff0_29*dmats2[29][24] + coeff0_30*dmats2[30][24] + coeff0_31*dmats2[31][24] + coeff0_32*dmats2[32][24] + coeff0_33*dmats2[33][24] + coeff0_34*dmats2[34][24] + coeff0_35*dmats2[35][24] + coeff0_36*dmats2[36][24] + coeff0_37*dmats2[37][24] + coeff0_38*dmats2[38][24] + coeff0_39*dmats2[39][24] + coeff0_40*dmats2[40][24] + coeff0_41*dmats2[41][24] + coeff0_42*dmats2[42][24] + coeff0_43*dmats2[43][24] + coeff0_44*dmats2[44][24] + coeff0_45*dmats2[45][24] + coeff0_46*dmats2[46][24] + coeff0_47*dmats2[47][24] + coeff0_48*dmats2[48][24] + coeff0_49*dmats2[49][24] + coeff0_50*dmats2[50][24] + coeff0_51*dmats2[51][24] + coeff0_52*dmats2[52][24] + coeff0_53*dmats2[53][24] + coeff0_54*dmats2[54][24] + coeff0_55*dmats2[55][24];
          new_coeff0_25 = coeff0_0*dmats2[0][25] + coeff0_1*dmats2[1][25] + coeff0_2*dmats2[2][25] + coeff0_3*dmats2[3][25] + coeff0_4*dmats2[4][25] + coeff0_5*dmats2[5][25] + coeff0_6*dmats2[6][25] + coeff0_7*dmats2[7][25] + coeff0_8*dmats2[8][25] + coeff0_9*dmats2[9][25] + coeff0_10*dmats2[10][25] + coeff0_11*dmats2[11][25] + coeff0_12*dmats2[12][25] + coeff0_13*dmats2[13][25] + coeff0_14*dmats2[14][25] + coeff0_15*dmats2[15][25] + coeff0_16*dmats2[16][25] + coeff0_17*dmats2[17][25] + coeff0_18*dmats2[18][25] + coeff0_19*dmats2[19][25] + coeff0_20*dmats2[20][25] + coeff0_21*dmats2[21][25] + coeff0_22*dmats2[22][25] + coeff0_23*dmats2[23][25] + coeff0_24*dmats2[24][25] + coeff0_25*dmats2[25][25] + coeff0_26*dmats2[26][25] + coeff0_27*dmats2[27][25] + coeff0_28*dmats2[28][25] + coeff0_29*dmats2[29][25] + coeff0_30*dmats2[30][25] + coeff0_31*dmats2[31][25] + coeff0_32*dmats2[32][25] + coeff0_33*dmats2[33][25] + coeff0_34*dmats2[34][25] + coeff0_35*dmats2[35][25] + coeff0_36*dmats2[36][25] + coeff0_37*dmats2[37][25] + coeff0_38*dmats2[38][25] + coeff0_39*dmats2[39][25] + coeff0_40*dmats2[40][25] + coeff0_41*dmats2[41][25] + coeff0_42*dmats2[42][25] + coeff0_43*dmats2[43][25] + coeff0_44*dmats2[44][25] + coeff0_45*dmats2[45][25] + coeff0_46*dmats2[46][25] + coeff0_47*dmats2[47][25] + coeff0_48*dmats2[48][25] + coeff0_49*dmats2[49][25] + coeff0_50*dmats2[50][25] + coeff0_51*dmats2[51][25] + coeff0_52*dmats2[52][25] + coeff0_53*dmats2[53][25] + coeff0_54*dmats2[54][25] + coeff0_55*dmats2[55][25];
          new_coeff0_26 = coeff0_0*dmats2[0][26] + coeff0_1*dmats2[1][26] + coeff0_2*dmats2[2][26] + coeff0_3*dmats2[3][26] + coeff0_4*dmats2[4][26] + coeff0_5*dmats2[5][26] + coeff0_6*dmats2[6][26] + coeff0_7*dmats2[7][26] + coeff0_8*dmats2[8][26] + coeff0_9*dmats2[9][26] + coeff0_10*dmats2[10][26] + coeff0_11*dmats2[11][26] + coeff0_12*dmats2[12][26] + coeff0_13*dmats2[13][26] + coeff0_14*dmats2[14][26] + coeff0_15*dmats2[15][26] + coeff0_16*dmats2[16][26] + coeff0_17*dmats2[17][26] + coeff0_18*dmats2[18][26] + coeff0_19*dmats2[19][26] + coeff0_20*dmats2[20][26] + coeff0_21*dmats2[21][26] + coeff0_22*dmats2[22][26] + coeff0_23*dmats2[23][26] + coeff0_24*dmats2[24][26] + coeff0_25*dmats2[25][26] + coeff0_26*dmats2[26][26] + coeff0_27*dmats2[27][26] + coeff0_28*dmats2[28][26] + coeff0_29*dmats2[29][26] + coeff0_30*dmats2[30][26] + coeff0_31*dmats2[31][26] + coeff0_32*dmats2[32][26] + coeff0_33*dmats2[33][26] + coeff0_34*dmats2[34][26] + coeff0_35*dmats2[35][26] + coeff0_36*dmats2[36][26] + coeff0_37*dmats2[37][26] + coeff0_38*dmats2[38][26] + coeff0_39*dmats2[39][26] + coeff0_40*dmats2[40][26] + coeff0_41*dmats2[41][26] + coeff0_42*dmats2[42][26] + coeff0_43*dmats2[43][26] + coeff0_44*dmats2[44][26] + coeff0_45*dmats2[45][26] + coeff0_46*dmats2[46][26] + coeff0_47*dmats2[47][26] + coeff0_48*dmats2[48][26] + coeff0_49*dmats2[49][26] + coeff0_50*dmats2[50][26] + coeff0_51*dmats2[51][26] + coeff0_52*dmats2[52][26] + coeff0_53*dmats2[53][26] + coeff0_54*dmats2[54][26] + coeff0_55*dmats2[55][26];
          new_coeff0_27 = coeff0_0*dmats2[0][27] + coeff0_1*dmats2[1][27] + coeff0_2*dmats2[2][27] + coeff0_3*dmats2[3][27] + coeff0_4*dmats2[4][27] + coeff0_5*dmats2[5][27] + coeff0_6*dmats2[6][27] + coeff0_7*dmats2[7][27] + coeff0_8*dmats2[8][27] + coeff0_9*dmats2[9][27] + coeff0_10*dmats2[10][27] + coeff0_11*dmats2[11][27] + coeff0_12*dmats2[12][27] + coeff0_13*dmats2[13][27] + coeff0_14*dmats2[14][27] + coeff0_15*dmats2[15][27] + coeff0_16*dmats2[16][27] + coeff0_17*dmats2[17][27] + coeff0_18*dmats2[18][27] + coeff0_19*dmats2[19][27] + coeff0_20*dmats2[20][27] + coeff0_21*dmats2[21][27] + coeff0_22*dmats2[22][27] + coeff0_23*dmats2[23][27] + coeff0_24*dmats2[24][27] + coeff0_25*dmats2[25][27] + coeff0_26*dmats2[26][27] + coeff0_27*dmats2[27][27] + coeff0_28*dmats2[28][27] + coeff0_29*dmats2[29][27] + coeff0_30*dmats2[30][27] + coeff0_31*dmats2[31][27] + coeff0_32*dmats2[32][27] + coeff0_33*dmats2[33][27] + coeff0_34*dmats2[34][27] + coeff0_35*dmats2[35][27] + coeff0_36*dmats2[36][27] + coeff0_37*dmats2[37][27] + coeff0_38*dmats2[38][27] + coeff0_39*dmats2[39][27] + coeff0_40*dmats2[40][27] + coeff0_41*dmats2[41][27] + coeff0_42*dmats2[42][27] + coeff0_43*dmats2[43][27] + coeff0_44*dmats2[44][27] + coeff0_45*dmats2[45][27] + coeff0_46*dmats2[46][27] + coeff0_47*dmats2[47][27] + coeff0_48*dmats2[48][27] + coeff0_49*dmats2[49][27] + coeff0_50*dmats2[50][27] + coeff0_51*dmats2[51][27] + coeff0_52*dmats2[52][27] + coeff0_53*dmats2[53][27] + coeff0_54*dmats2[54][27] + coeff0_55*dmats2[55][27];
          new_coeff0_28 = coeff0_0*dmats2[0][28] + coeff0_1*dmats2[1][28] + coeff0_2*dmats2[2][28] + coeff0_3*dmats2[3][28] + coeff0_4*dmats2[4][28] + coeff0_5*dmats2[5][28] + coeff0_6*dmats2[6][28] + coeff0_7*dmats2[7][28] + coeff0_8*dmats2[8][28] + coeff0_9*dmats2[9][28] + coeff0_10*dmats2[10][28] + coeff0_11*dmats2[11][28] + coeff0_12*dmats2[12][28] + coeff0_13*dmats2[13][28] + coeff0_14*dmats2[14][28] + coeff0_15*dmats2[15][28] + coeff0_16*dmats2[16][28] + coeff0_17*dmats2[17][28] + coeff0_18*dmats2[18][28] + coeff0_19*dmats2[19][28] + coeff0_20*dmats2[20][28] + coeff0_21*dmats2[21][28] + coeff0_22*dmats2[22][28] + coeff0_23*dmats2[23][28] + coeff0_24*dmats2[24][28] + coeff0_25*dmats2[25][28] + coeff0_26*dmats2[26][28] + coeff0_27*dmats2[27][28] + coeff0_28*dmats2[28][28] + coeff0_29*dmats2[29][28] + coeff0_30*dmats2[30][28] + coeff0_31*dmats2[31][28] + coeff0_32*dmats2[32][28] + coeff0_33*dmats2[33][28] + coeff0_34*dmats2[34][28] + coeff0_35*dmats2[35][28] + coeff0_36*dmats2[36][28] + coeff0_37*dmats2[37][28] + coeff0_38*dmats2[38][28] + coeff0_39*dmats2[39][28] + coeff0_40*dmats2[40][28] + coeff0_41*dmats2[41][28] + coeff0_42*dmats2[42][28] + coeff0_43*dmats2[43][28] + coeff0_44*dmats2[44][28] + coeff0_45*dmats2[45][28] + coeff0_46*dmats2[46][28] + coeff0_47*dmats2[47][28] + coeff0_48*dmats2[48][28] + coeff0_49*dmats2[49][28] + coeff0_50*dmats2[50][28] + coeff0_51*dmats2[51][28] + coeff0_52*dmats2[52][28] + coeff0_53*dmats2[53][28] + coeff0_54*dmats2[54][28] + coeff0_55*dmats2[55][28];
          new_coeff0_29 = coeff0_0*dmats2[0][29] + coeff0_1*dmats2[1][29] + coeff0_2*dmats2[2][29] + coeff0_3*dmats2[3][29] + coeff0_4*dmats2[4][29] + coeff0_5*dmats2[5][29] + coeff0_6*dmats2[6][29] + coeff0_7*dmats2[7][29] + coeff0_8*dmats2[8][29] + coeff0_9*dmats2[9][29] + coeff0_10*dmats2[10][29] + coeff0_11*dmats2[11][29] + coeff0_12*dmats2[12][29] + coeff0_13*dmats2[13][29] + coeff0_14*dmats2[14][29] + coeff0_15*dmats2[15][29] + coeff0_16*dmats2[16][29] + coeff0_17*dmats2[17][29] + coeff0_18*dmats2[18][29] + coeff0_19*dmats2[19][29] + coeff0_20*dmats2[20][29] + coeff0_21*dmats2[21][29] + coeff0_22*dmats2[22][29] + coeff0_23*dmats2[23][29] + coeff0_24*dmats2[24][29] + coeff0_25*dmats2[25][29] + coeff0_26*dmats2[26][29] + coeff0_27*dmats2[27][29] + coeff0_28*dmats2[28][29] + coeff0_29*dmats2[29][29] + coeff0_30*dmats2[30][29] + coeff0_31*dmats2[31][29] + coeff0_32*dmats2[32][29] + coeff0_33*dmats2[33][29] + coeff0_34*dmats2[34][29] + coeff0_35*dmats2[35][29] + coeff0_36*dmats2[36][29] + coeff0_37*dmats2[37][29] + coeff0_38*dmats2[38][29] + coeff0_39*dmats2[39][29] + coeff0_40*dmats2[40][29] + coeff0_41*dmats2[41][29] + coeff0_42*dmats2[42][29] + coeff0_43*dmats2[43][29] + coeff0_44*dmats2[44][29] + coeff0_45*dmats2[45][29] + coeff0_46*dmats2[46][29] + coeff0_47*dmats2[47][29] + coeff0_48*dmats2[48][29] + coeff0_49*dmats2[49][29] + coeff0_50*dmats2[50][29] + coeff0_51*dmats2[51][29] + coeff0_52*dmats2[52][29] + coeff0_53*dmats2[53][29] + coeff0_54*dmats2[54][29] + coeff0_55*dmats2[55][29];
          new_coeff0_30 = coeff0_0*dmats2[0][30] + coeff0_1*dmats2[1][30] + coeff0_2*dmats2[2][30] + coeff0_3*dmats2[3][30] + coeff0_4*dmats2[4][30] + coeff0_5*dmats2[5][30] + coeff0_6*dmats2[6][30] + coeff0_7*dmats2[7][30] + coeff0_8*dmats2[8][30] + coeff0_9*dmats2[9][30] + coeff0_10*dmats2[10][30] + coeff0_11*dmats2[11][30] + coeff0_12*dmats2[12][30] + coeff0_13*dmats2[13][30] + coeff0_14*dmats2[14][30] + coeff0_15*dmats2[15][30] + coeff0_16*dmats2[16][30] + coeff0_17*dmats2[17][30] + coeff0_18*dmats2[18][30] + coeff0_19*dmats2[19][30] + coeff0_20*dmats2[20][30] + coeff0_21*dmats2[21][30] + coeff0_22*dmats2[22][30] + coeff0_23*dmats2[23][30] + coeff0_24*dmats2[24][30] + coeff0_25*dmats2[25][30] + coeff0_26*dmats2[26][30] + coeff0_27*dmats2[27][30] + coeff0_28*dmats2[28][30] + coeff0_29*dmats2[29][30] + coeff0_30*dmats2[30][30] + coeff0_31*dmats2[31][30] + coeff0_32*dmats2[32][30] + coeff0_33*dmats2[33][30] + coeff0_34*dmats2[34][30] + coeff0_35*dmats2[35][30] + coeff0_36*dmats2[36][30] + coeff0_37*dmats2[37][30] + coeff0_38*dmats2[38][30] + coeff0_39*dmats2[39][30] + coeff0_40*dmats2[40][30] + coeff0_41*dmats2[41][30] + coeff0_42*dmats2[42][30] + coeff0_43*dmats2[43][30] + coeff0_44*dmats2[44][30] + coeff0_45*dmats2[45][30] + coeff0_46*dmats2[46][30] + coeff0_47*dmats2[47][30] + coeff0_48*dmats2[48][30] + coeff0_49*dmats2[49][30] + coeff0_50*dmats2[50][30] + coeff0_51*dmats2[51][30] + coeff0_52*dmats2[52][30] + coeff0_53*dmats2[53][30] + coeff0_54*dmats2[54][30] + coeff0_55*dmats2[55][30];
          new_coeff0_31 = coeff0_0*dmats2[0][31] + coeff0_1*dmats2[1][31] + coeff0_2*dmats2[2][31] + coeff0_3*dmats2[3][31] + coeff0_4*dmats2[4][31] + coeff0_5*dmats2[5][31] + coeff0_6*dmats2[6][31] + coeff0_7*dmats2[7][31] + coeff0_8*dmats2[8][31] + coeff0_9*dmats2[9][31] + coeff0_10*dmats2[10][31] + coeff0_11*dmats2[11][31] + coeff0_12*dmats2[12][31] + coeff0_13*dmats2[13][31] + coeff0_14*dmats2[14][31] + coeff0_15*dmats2[15][31] + coeff0_16*dmats2[16][31] + coeff0_17*dmats2[17][31] + coeff0_18*dmats2[18][31] + coeff0_19*dmats2[19][31] + coeff0_20*dmats2[20][31] + coeff0_21*dmats2[21][31] + coeff0_22*dmats2[22][31] + coeff0_23*dmats2[23][31] + coeff0_24*dmats2[24][31] + coeff0_25*dmats2[25][31] + coeff0_26*dmats2[26][31] + coeff0_27*dmats2[27][31] + coeff0_28*dmats2[28][31] + coeff0_29*dmats2[29][31] + coeff0_30*dmats2[30][31] + coeff0_31*dmats2[31][31] + coeff0_32*dmats2[32][31] + coeff0_33*dmats2[33][31] + coeff0_34*dmats2[34][31] + coeff0_35*dmats2[35][31] + coeff0_36*dmats2[36][31] + coeff0_37*dmats2[37][31] + coeff0_38*dmats2[38][31] + coeff0_39*dmats2[39][31] + coeff0_40*dmats2[40][31] + coeff0_41*dmats2[41][31] + coeff0_42*dmats2[42][31] + coeff0_43*dmats2[43][31] + coeff0_44*dmats2[44][31] + coeff0_45*dmats2[45][31] + coeff0_46*dmats2[46][31] + coeff0_47*dmats2[47][31] + coeff0_48*dmats2[48][31] + coeff0_49*dmats2[49][31] + coeff0_50*dmats2[50][31] + coeff0_51*dmats2[51][31] + coeff0_52*dmats2[52][31] + coeff0_53*dmats2[53][31] + coeff0_54*dmats2[54][31] + coeff0_55*dmats2[55][31];
          new_coeff0_32 = coeff0_0*dmats2[0][32] + coeff0_1*dmats2[1][32] + coeff0_2*dmats2[2][32] + coeff0_3*dmats2[3][32] + coeff0_4*dmats2[4][32] + coeff0_5*dmats2[5][32] + coeff0_6*dmats2[6][32] + coeff0_7*dmats2[7][32] + coeff0_8*dmats2[8][32] + coeff0_9*dmats2[9][32] + coeff0_10*dmats2[10][32] + coeff0_11*dmats2[11][32] + coeff0_12*dmats2[12][32] + coeff0_13*dmats2[13][32] + coeff0_14*dmats2[14][32] + coeff0_15*dmats2[15][32] + coeff0_16*dmats2[16][32] + coeff0_17*dmats2[17][32] + coeff0_18*dmats2[18][32] + coeff0_19*dmats2[19][32] + coeff0_20*dmats2[20][32] + coeff0_21*dmats2[21][32] + coeff0_22*dmats2[22][32] + coeff0_23*dmats2[23][32] + coeff0_24*dmats2[24][32] + coeff0_25*dmats2[25][32] + coeff0_26*dmats2[26][32] + coeff0_27*dmats2[27][32] + coeff0_28*dmats2[28][32] + coeff0_29*dmats2[29][32] + coeff0_30*dmats2[30][32] + coeff0_31*dmats2[31][32] + coeff0_32*dmats2[32][32] + coeff0_33*dmats2[33][32] + coeff0_34*dmats2[34][32] + coeff0_35*dmats2[35][32] + coeff0_36*dmats2[36][32] + coeff0_37*dmats2[37][32] + coeff0_38*dmats2[38][32] + coeff0_39*dmats2[39][32] + coeff0_40*dmats2[40][32] + coeff0_41*dmats2[41][32] + coeff0_42*dmats2[42][32] + coeff0_43*dmats2[43][32] + coeff0_44*dmats2[44][32] + coeff0_45*dmats2[45][32] + coeff0_46*dmats2[46][32] + coeff0_47*dmats2[47][32] + coeff0_48*dmats2[48][32] + coeff0_49*dmats2[49][32] + coeff0_50*dmats2[50][32] + coeff0_51*dmats2[51][32] + coeff0_52*dmats2[52][32] + coeff0_53*dmats2[53][32] + coeff0_54*dmats2[54][32] + coeff0_55*dmats2[55][32];
          new_coeff0_33 = coeff0_0*dmats2[0][33] + coeff0_1*dmats2[1][33] + coeff0_2*dmats2[2][33] + coeff0_3*dmats2[3][33] + coeff0_4*dmats2[4][33] + coeff0_5*dmats2[5][33] + coeff0_6*dmats2[6][33] + coeff0_7*dmats2[7][33] + coeff0_8*dmats2[8][33] + coeff0_9*dmats2[9][33] + coeff0_10*dmats2[10][33] + coeff0_11*dmats2[11][33] + coeff0_12*dmats2[12][33] + coeff0_13*dmats2[13][33] + coeff0_14*dmats2[14][33] + coeff0_15*dmats2[15][33] + coeff0_16*dmats2[16][33] + coeff0_17*dmats2[17][33] + coeff0_18*dmats2[18][33] + coeff0_19*dmats2[19][33] + coeff0_20*dmats2[20][33] + coeff0_21*dmats2[21][33] + coeff0_22*dmats2[22][33] + coeff0_23*dmats2[23][33] + coeff0_24*dmats2[24][33] + coeff0_25*dmats2[25][33] + coeff0_26*dmats2[26][33] + coeff0_27*dmats2[27][33] + coeff0_28*dmats2[28][33] + coeff0_29*dmats2[29][33] + coeff0_30*dmats2[30][33] + coeff0_31*dmats2[31][33] + coeff0_32*dmats2[32][33] + coeff0_33*dmats2[33][33] + coeff0_34*dmats2[34][33] + coeff0_35*dmats2[35][33] + coeff0_36*dmats2[36][33] + coeff0_37*dmats2[37][33] + coeff0_38*dmats2[38][33] + coeff0_39*dmats2[39][33] + coeff0_40*dmats2[40][33] + coeff0_41*dmats2[41][33] + coeff0_42*dmats2[42][33] + coeff0_43*dmats2[43][33] + coeff0_44*dmats2[44][33] + coeff0_45*dmats2[45][33] + coeff0_46*dmats2[46][33] + coeff0_47*dmats2[47][33] + coeff0_48*dmats2[48][33] + coeff0_49*dmats2[49][33] + coeff0_50*dmats2[50][33] + coeff0_51*dmats2[51][33] + coeff0_52*dmats2[52][33] + coeff0_53*dmats2[53][33] + coeff0_54*dmats2[54][33] + coeff0_55*dmats2[55][33];
          new_coeff0_34 = coeff0_0*dmats2[0][34] + coeff0_1*dmats2[1][34] + coeff0_2*dmats2[2][34] + coeff0_3*dmats2[3][34] + coeff0_4*dmats2[4][34] + coeff0_5*dmats2[5][34] + coeff0_6*dmats2[6][34] + coeff0_7*dmats2[7][34] + coeff0_8*dmats2[8][34] + coeff0_9*dmats2[9][34] + coeff0_10*dmats2[10][34] + coeff0_11*dmats2[11][34] + coeff0_12*dmats2[12][34] + coeff0_13*dmats2[13][34] + coeff0_14*dmats2[14][34] + coeff0_15*dmats2[15][34] + coeff0_16*dmats2[16][34] + coeff0_17*dmats2[17][34] + coeff0_18*dmats2[18][34] + coeff0_19*dmats2[19][34] + coeff0_20*dmats2[20][34] + coeff0_21*dmats2[21][34] + coeff0_22*dmats2[22][34] + coeff0_23*dmats2[23][34] + coeff0_24*dmats2[24][34] + coeff0_25*dmats2[25][34] + coeff0_26*dmats2[26][34] + coeff0_27*dmats2[27][34] + coeff0_28*dmats2[28][34] + coeff0_29*dmats2[29][34] + coeff0_30*dmats2[30][34] + coeff0_31*dmats2[31][34] + coeff0_32*dmats2[32][34] + coeff0_33*dmats2[33][34] + coeff0_34*dmats2[34][34] + coeff0_35*dmats2[35][34] + coeff0_36*dmats2[36][34] + coeff0_37*dmats2[37][34] + coeff0_38*dmats2[38][34] + coeff0_39*dmats2[39][34] + coeff0_40*dmats2[40][34] + coeff0_41*dmats2[41][34] + coeff0_42*dmats2[42][34] + coeff0_43*dmats2[43][34] + coeff0_44*dmats2[44][34] + coeff0_45*dmats2[45][34] + coeff0_46*dmats2[46][34] + coeff0_47*dmats2[47][34] + coeff0_48*dmats2[48][34] + coeff0_49*dmats2[49][34] + coeff0_50*dmats2[50][34] + coeff0_51*dmats2[51][34] + coeff0_52*dmats2[52][34] + coeff0_53*dmats2[53][34] + coeff0_54*dmats2[54][34] + coeff0_55*dmats2[55][34];
          new_coeff0_35 = coeff0_0*dmats2[0][35] + coeff0_1*dmats2[1][35] + coeff0_2*dmats2[2][35] + coeff0_3*dmats2[3][35] + coeff0_4*dmats2[4][35] + coeff0_5*dmats2[5][35] + coeff0_6*dmats2[6][35] + coeff0_7*dmats2[7][35] + coeff0_8*dmats2[8][35] + coeff0_9*dmats2[9][35] + coeff0_10*dmats2[10][35] + coeff0_11*dmats2[11][35] + coeff0_12*dmats2[12][35] + coeff0_13*dmats2[13][35] + coeff0_14*dmats2[14][35] + coeff0_15*dmats2[15][35] + coeff0_16*dmats2[16][35] + coeff0_17*dmats2[17][35] + coeff0_18*dmats2[18][35] + coeff0_19*dmats2[19][35] + coeff0_20*dmats2[20][35] + coeff0_21*dmats2[21][35] + coeff0_22*dmats2[22][35] + coeff0_23*dmats2[23][35] + coeff0_24*dmats2[24][35] + coeff0_25*dmats2[25][35] + coeff0_26*dmats2[26][35] + coeff0_27*dmats2[27][35] + coeff0_28*dmats2[28][35] + coeff0_29*dmats2[29][35] + coeff0_30*dmats2[30][35] + coeff0_31*dmats2[31][35] + coeff0_32*dmats2[32][35] + coeff0_33*dmats2[33][35] + coeff0_34*dmats2[34][35] + coeff0_35*dmats2[35][35] + coeff0_36*dmats2[36][35] + coeff0_37*dmats2[37][35] + coeff0_38*dmats2[38][35] + coeff0_39*dmats2[39][35] + coeff0_40*dmats2[40][35] + coeff0_41*dmats2[41][35] + coeff0_42*dmats2[42][35] + coeff0_43*dmats2[43][35] + coeff0_44*dmats2[44][35] + coeff0_45*dmats2[45][35] + coeff0_46*dmats2[46][35] + coeff0_47*dmats2[47][35] + coeff0_48*dmats2[48][35] + coeff0_49*dmats2[49][35] + coeff0_50*dmats2[50][35] + coeff0_51*dmats2[51][35] + coeff0_52*dmats2[52][35] + coeff0_53*dmats2[53][35] + coeff0_54*dmats2[54][35] + coeff0_55*dmats2[55][35];
          new_coeff0_36 = coeff0_0*dmats2[0][36] + coeff0_1*dmats2[1][36] + coeff0_2*dmats2[2][36] + coeff0_3*dmats2[3][36] + coeff0_4*dmats2[4][36] + coeff0_5*dmats2[5][36] + coeff0_6*dmats2[6][36] + coeff0_7*dmats2[7][36] + coeff0_8*dmats2[8][36] + coeff0_9*dmats2[9][36] + coeff0_10*dmats2[10][36] + coeff0_11*dmats2[11][36] + coeff0_12*dmats2[12][36] + coeff0_13*dmats2[13][36] + coeff0_14*dmats2[14][36] + coeff0_15*dmats2[15][36] + coeff0_16*dmats2[16][36] + coeff0_17*dmats2[17][36] + coeff0_18*dmats2[18][36] + coeff0_19*dmats2[19][36] + coeff0_20*dmats2[20][36] + coeff0_21*dmats2[21][36] + coeff0_22*dmats2[22][36] + coeff0_23*dmats2[23][36] + coeff0_24*dmats2[24][36] + coeff0_25*dmats2[25][36] + coeff0_26*dmats2[26][36] + coeff0_27*dmats2[27][36] + coeff0_28*dmats2[28][36] + coeff0_29*dmats2[29][36] + coeff0_30*dmats2[30][36] + coeff0_31*dmats2[31][36] + coeff0_32*dmats2[32][36] + coeff0_33*dmats2[33][36] + coeff0_34*dmats2[34][36] + coeff0_35*dmats2[35][36] + coeff0_36*dmats2[36][36] + coeff0_37*dmats2[37][36] + coeff0_38*dmats2[38][36] + coeff0_39*dmats2[39][36] + coeff0_40*dmats2[40][36] + coeff0_41*dmats2[41][36] + coeff0_42*dmats2[42][36] + coeff0_43*dmats2[43][36] + coeff0_44*dmats2[44][36] + coeff0_45*dmats2[45][36] + coeff0_46*dmats2[46][36] + coeff0_47*dmats2[47][36] + coeff0_48*dmats2[48][36] + coeff0_49*dmats2[49][36] + coeff0_50*dmats2[50][36] + coeff0_51*dmats2[51][36] + coeff0_52*dmats2[52][36] + coeff0_53*dmats2[53][36] + coeff0_54*dmats2[54][36] + coeff0_55*dmats2[55][36];
          new_coeff0_37 = coeff0_0*dmats2[0][37] + coeff0_1*dmats2[1][37] + coeff0_2*dmats2[2][37] + coeff0_3*dmats2[3][37] + coeff0_4*dmats2[4][37] + coeff0_5*dmats2[5][37] + coeff0_6*dmats2[6][37] + coeff0_7*dmats2[7][37] + coeff0_8*dmats2[8][37] + coeff0_9*dmats2[9][37] + coeff0_10*dmats2[10][37] + coeff0_11*dmats2[11][37] + coeff0_12*dmats2[12][37] + coeff0_13*dmats2[13][37] + coeff0_14*dmats2[14][37] + coeff0_15*dmats2[15][37] + coeff0_16*dmats2[16][37] + coeff0_17*dmats2[17][37] + coeff0_18*dmats2[18][37] + coeff0_19*dmats2[19][37] + coeff0_20*dmats2[20][37] + coeff0_21*dmats2[21][37] + coeff0_22*dmats2[22][37] + coeff0_23*dmats2[23][37] + coeff0_24*dmats2[24][37] + coeff0_25*dmats2[25][37] + coeff0_26*dmats2[26][37] + coeff0_27*dmats2[27][37] + coeff0_28*dmats2[28][37] + coeff0_29*dmats2[29][37] + coeff0_30*dmats2[30][37] + coeff0_31*dmats2[31][37] + coeff0_32*dmats2[32][37] + coeff0_33*dmats2[33][37] + coeff0_34*dmats2[34][37] + coeff0_35*dmats2[35][37] + coeff0_36*dmats2[36][37] + coeff0_37*dmats2[37][37] + coeff0_38*dmats2[38][37] + coeff0_39*dmats2[39][37] + coeff0_40*dmats2[40][37] + coeff0_41*dmats2[41][37] + coeff0_42*dmats2[42][37] + coeff0_43*dmats2[43][37] + coeff0_44*dmats2[44][37] + coeff0_45*dmats2[45][37] + coeff0_46*dmats2[46][37] + coeff0_47*dmats2[47][37] + coeff0_48*dmats2[48][37] + coeff0_49*dmats2[49][37] + coeff0_50*dmats2[50][37] + coeff0_51*dmats2[51][37] + coeff0_52*dmats2[52][37] + coeff0_53*dmats2[53][37] + coeff0_54*dmats2[54][37] + coeff0_55*dmats2[55][37];
          new_coeff0_38 = coeff0_0*dmats2[0][38] + coeff0_1*dmats2[1][38] + coeff0_2*dmats2[2][38] + coeff0_3*dmats2[3][38] + coeff0_4*dmats2[4][38] + coeff0_5*dmats2[5][38] + coeff0_6*dmats2[6][38] + coeff0_7*dmats2[7][38] + coeff0_8*dmats2[8][38] + coeff0_9*dmats2[9][38] + coeff0_10*dmats2[10][38] + coeff0_11*dmats2[11][38] + coeff0_12*dmats2[12][38] + coeff0_13*dmats2[13][38] + coeff0_14*dmats2[14][38] + coeff0_15*dmats2[15][38] + coeff0_16*dmats2[16][38] + coeff0_17*dmats2[17][38] + coeff0_18*dmats2[18][38] + coeff0_19*dmats2[19][38] + coeff0_20*dmats2[20][38] + coeff0_21*dmats2[21][38] + coeff0_22*dmats2[22][38] + coeff0_23*dmats2[23][38] + coeff0_24*dmats2[24][38] + coeff0_25*dmats2[25][38] + coeff0_26*dmats2[26][38] + coeff0_27*dmats2[27][38] + coeff0_28*dmats2[28][38] + coeff0_29*dmats2[29][38] + coeff0_30*dmats2[30][38] + coeff0_31*dmats2[31][38] + coeff0_32*dmats2[32][38] + coeff0_33*dmats2[33][38] + coeff0_34*dmats2[34][38] + coeff0_35*dmats2[35][38] + coeff0_36*dmats2[36][38] + coeff0_37*dmats2[37][38] + coeff0_38*dmats2[38][38] + coeff0_39*dmats2[39][38] + coeff0_40*dmats2[40][38] + coeff0_41*dmats2[41][38] + coeff0_42*dmats2[42][38] + coeff0_43*dmats2[43][38] + coeff0_44*dmats2[44][38] + coeff0_45*dmats2[45][38] + coeff0_46*dmats2[46][38] + coeff0_47*dmats2[47][38] + coeff0_48*dmats2[48][38] + coeff0_49*dmats2[49][38] + coeff0_50*dmats2[50][38] + coeff0_51*dmats2[51][38] + coeff0_52*dmats2[52][38] + coeff0_53*dmats2[53][38] + coeff0_54*dmats2[54][38] + coeff0_55*dmats2[55][38];
          new_coeff0_39 = coeff0_0*dmats2[0][39] + coeff0_1*dmats2[1][39] + coeff0_2*dmats2[2][39] + coeff0_3*dmats2[3][39] + coeff0_4*dmats2[4][39] + coeff0_5*dmats2[5][39] + coeff0_6*dmats2[6][39] + coeff0_7*dmats2[7][39] + coeff0_8*dmats2[8][39] + coeff0_9*dmats2[9][39] + coeff0_10*dmats2[10][39] + coeff0_11*dmats2[11][39] + coeff0_12*dmats2[12][39] + coeff0_13*dmats2[13][39] + coeff0_14*dmats2[14][39] + coeff0_15*dmats2[15][39] + coeff0_16*dmats2[16][39] + coeff0_17*dmats2[17][39] + coeff0_18*dmats2[18][39] + coeff0_19*dmats2[19][39] + coeff0_20*dmats2[20][39] + coeff0_21*dmats2[21][39] + coeff0_22*dmats2[22][39] + coeff0_23*dmats2[23][39] + coeff0_24*dmats2[24][39] + coeff0_25*dmats2[25][39] + coeff0_26*dmats2[26][39] + coeff0_27*dmats2[27][39] + coeff0_28*dmats2[28][39] + coeff0_29*dmats2[29][39] + coeff0_30*dmats2[30][39] + coeff0_31*dmats2[31][39] + coeff0_32*dmats2[32][39] + coeff0_33*dmats2[33][39] + coeff0_34*dmats2[34][39] + coeff0_35*dmats2[35][39] + coeff0_36*dmats2[36][39] + coeff0_37*dmats2[37][39] + coeff0_38*dmats2[38][39] + coeff0_39*dmats2[39][39] + coeff0_40*dmats2[40][39] + coeff0_41*dmats2[41][39] + coeff0_42*dmats2[42][39] + coeff0_43*dmats2[43][39] + coeff0_44*dmats2[44][39] + coeff0_45*dmats2[45][39] + coeff0_46*dmats2[46][39] + coeff0_47*dmats2[47][39] + coeff0_48*dmats2[48][39] + coeff0_49*dmats2[49][39] + coeff0_50*dmats2[50][39] + coeff0_51*dmats2[51][39] + coeff0_52*dmats2[52][39] + coeff0_53*dmats2[53][39] + coeff0_54*dmats2[54][39] + coeff0_55*dmats2[55][39];
          new_coeff0_40 = coeff0_0*dmats2[0][40] + coeff0_1*dmats2[1][40] + coeff0_2*dmats2[2][40] + coeff0_3*dmats2[3][40] + coeff0_4*dmats2[4][40] + coeff0_5*dmats2[5][40] + coeff0_6*dmats2[6][40] + coeff0_7*dmats2[7][40] + coeff0_8*dmats2[8][40] + coeff0_9*dmats2[9][40] + coeff0_10*dmats2[10][40] + coeff0_11*dmats2[11][40] + coeff0_12*dmats2[12][40] + coeff0_13*dmats2[13][40] + coeff0_14*dmats2[14][40] + coeff0_15*dmats2[15][40] + coeff0_16*dmats2[16][40] + coeff0_17*dmats2[17][40] + coeff0_18*dmats2[18][40] + coeff0_19*dmats2[19][40] + coeff0_20*dmats2[20][40] + coeff0_21*dmats2[21][40] + coeff0_22*dmats2[22][40] + coeff0_23*dmats2[23][40] + coeff0_24*dmats2[24][40] + coeff0_25*dmats2[25][40] + coeff0_26*dmats2[26][40] + coeff0_27*dmats2[27][40] + coeff0_28*dmats2[28][40] + coeff0_29*dmats2[29][40] + coeff0_30*dmats2[30][40] + coeff0_31*dmats2[31][40] + coeff0_32*dmats2[32][40] + coeff0_33*dmats2[33][40] + coeff0_34*dmats2[34][40] + coeff0_35*dmats2[35][40] + coeff0_36*dmats2[36][40] + coeff0_37*dmats2[37][40] + coeff0_38*dmats2[38][40] + coeff0_39*dmats2[39][40] + coeff0_40*dmats2[40][40] + coeff0_41*dmats2[41][40] + coeff0_42*dmats2[42][40] + coeff0_43*dmats2[43][40] + coeff0_44*dmats2[44][40] + coeff0_45*dmats2[45][40] + coeff0_46*dmats2[46][40] + coeff0_47*dmats2[47][40] + coeff0_48*dmats2[48][40] + coeff0_49*dmats2[49][40] + coeff0_50*dmats2[50][40] + coeff0_51*dmats2[51][40] + coeff0_52*dmats2[52][40] + coeff0_53*dmats2[53][40] + coeff0_54*dmats2[54][40] + coeff0_55*dmats2[55][40];
          new_coeff0_41 = coeff0_0*dmats2[0][41] + coeff0_1*dmats2[1][41] + coeff0_2*dmats2[2][41] + coeff0_3*dmats2[3][41] + coeff0_4*dmats2[4][41] + coeff0_5*dmats2[5][41] + coeff0_6*dmats2[6][41] + coeff0_7*dmats2[7][41] + coeff0_8*dmats2[8][41] + coeff0_9*dmats2[9][41] + coeff0_10*dmats2[10][41] + coeff0_11*dmats2[11][41] + coeff0_12*dmats2[12][41] + coeff0_13*dmats2[13][41] + coeff0_14*dmats2[14][41] + coeff0_15*dmats2[15][41] + coeff0_16*dmats2[16][41] + coeff0_17*dmats2[17][41] + coeff0_18*dmats2[18][41] + coeff0_19*dmats2[19][41] + coeff0_20*dmats2[20][41] + coeff0_21*dmats2[21][41] + coeff0_22*dmats2[22][41] + coeff0_23*dmats2[23][41] + coeff0_24*dmats2[24][41] + coeff0_25*dmats2[25][41] + coeff0_26*dmats2[26][41] + coeff0_27*dmats2[27][41] + coeff0_28*dmats2[28][41] + coeff0_29*dmats2[29][41] + coeff0_30*dmats2[30][41] + coeff0_31*dmats2[31][41] + coeff0_32*dmats2[32][41] + coeff0_33*dmats2[33][41] + coeff0_34*dmats2[34][41] + coeff0_35*dmats2[35][41] + coeff0_36*dmats2[36][41] + coeff0_37*dmats2[37][41] + coeff0_38*dmats2[38][41] + coeff0_39*dmats2[39][41] + coeff0_40*dmats2[40][41] + coeff0_41*dmats2[41][41] + coeff0_42*dmats2[42][41] + coeff0_43*dmats2[43][41] + coeff0_44*dmats2[44][41] + coeff0_45*dmats2[45][41] + coeff0_46*dmats2[46][41] + coeff0_47*dmats2[47][41] + coeff0_48*dmats2[48][41] + coeff0_49*dmats2[49][41] + coeff0_50*dmats2[50][41] + coeff0_51*dmats2[51][41] + coeff0_52*dmats2[52][41] + coeff0_53*dmats2[53][41] + coeff0_54*dmats2[54][41] + coeff0_55*dmats2[55][41];
          new_coeff0_42 = coeff0_0*dmats2[0][42] + coeff0_1*dmats2[1][42] + coeff0_2*dmats2[2][42] + coeff0_3*dmats2[3][42] + coeff0_4*dmats2[4][42] + coeff0_5*dmats2[5][42] + coeff0_6*dmats2[6][42] + coeff0_7*dmats2[7][42] + coeff0_8*dmats2[8][42] + coeff0_9*dmats2[9][42] + coeff0_10*dmats2[10][42] + coeff0_11*dmats2[11][42] + coeff0_12*dmats2[12][42] + coeff0_13*dmats2[13][42] + coeff0_14*dmats2[14][42] + coeff0_15*dmats2[15][42] + coeff0_16*dmats2[16][42] + coeff0_17*dmats2[17][42] + coeff0_18*dmats2[18][42] + coeff0_19*dmats2[19][42] + coeff0_20*dmats2[20][42] + coeff0_21*dmats2[21][42] + coeff0_22*dmats2[22][42] + coeff0_23*dmats2[23][42] + coeff0_24*dmats2[24][42] + coeff0_25*dmats2[25][42] + coeff0_26*dmats2[26][42] + coeff0_27*dmats2[27][42] + coeff0_28*dmats2[28][42] + coeff0_29*dmats2[29][42] + coeff0_30*dmats2[30][42] + coeff0_31*dmats2[31][42] + coeff0_32*dmats2[32][42] + coeff0_33*dmats2[33][42] + coeff0_34*dmats2[34][42] + coeff0_35*dmats2[35][42] + coeff0_36*dmats2[36][42] + coeff0_37*dmats2[37][42] + coeff0_38*dmats2[38][42] + coeff0_39*dmats2[39][42] + coeff0_40*dmats2[40][42] + coeff0_41*dmats2[41][42] + coeff0_42*dmats2[42][42] + coeff0_43*dmats2[43][42] + coeff0_44*dmats2[44][42] + coeff0_45*dmats2[45][42] + coeff0_46*dmats2[46][42] + coeff0_47*dmats2[47][42] + coeff0_48*dmats2[48][42] + coeff0_49*dmats2[49][42] + coeff0_50*dmats2[50][42] + coeff0_51*dmats2[51][42] + coeff0_52*dmats2[52][42] + coeff0_53*dmats2[53][42] + coeff0_54*dmats2[54][42] + coeff0_55*dmats2[55][42];
          new_coeff0_43 = coeff0_0*dmats2[0][43] + coeff0_1*dmats2[1][43] + coeff0_2*dmats2[2][43] + coeff0_3*dmats2[3][43] + coeff0_4*dmats2[4][43] + coeff0_5*dmats2[5][43] + coeff0_6*dmats2[6][43] + coeff0_7*dmats2[7][43] + coeff0_8*dmats2[8][43] + coeff0_9*dmats2[9][43] + coeff0_10*dmats2[10][43] + coeff0_11*dmats2[11][43] + coeff0_12*dmats2[12][43] + coeff0_13*dmats2[13][43] + coeff0_14*dmats2[14][43] + coeff0_15*dmats2[15][43] + coeff0_16*dmats2[16][43] + coeff0_17*dmats2[17][43] + coeff0_18*dmats2[18][43] + coeff0_19*dmats2[19][43] + coeff0_20*dmats2[20][43] + coeff0_21*dmats2[21][43] + coeff0_22*dmats2[22][43] + coeff0_23*dmats2[23][43] + coeff0_24*dmats2[24][43] + coeff0_25*dmats2[25][43] + coeff0_26*dmats2[26][43] + coeff0_27*dmats2[27][43] + coeff0_28*dmats2[28][43] + coeff0_29*dmats2[29][43] + coeff0_30*dmats2[30][43] + coeff0_31*dmats2[31][43] + coeff0_32*dmats2[32][43] + coeff0_33*dmats2[33][43] + coeff0_34*dmats2[34][43] + coeff0_35*dmats2[35][43] + coeff0_36*dmats2[36][43] + coeff0_37*dmats2[37][43] + coeff0_38*dmats2[38][43] + coeff0_39*dmats2[39][43] + coeff0_40*dmats2[40][43] + coeff0_41*dmats2[41][43] + coeff0_42*dmats2[42][43] + coeff0_43*dmats2[43][43] + coeff0_44*dmats2[44][43] + coeff0_45*dmats2[45][43] + coeff0_46*dmats2[46][43] + coeff0_47*dmats2[47][43] + coeff0_48*dmats2[48][43] + coeff0_49*dmats2[49][43] + coeff0_50*dmats2[50][43] + coeff0_51*dmats2[51][43] + coeff0_52*dmats2[52][43] + coeff0_53*dmats2[53][43] + coeff0_54*dmats2[54][43] + coeff0_55*dmats2[55][43];
          new_coeff0_44 = coeff0_0*dmats2[0][44] + coeff0_1*dmats2[1][44] + coeff0_2*dmats2[2][44] + coeff0_3*dmats2[3][44] + coeff0_4*dmats2[4][44] + coeff0_5*dmats2[5][44] + coeff0_6*dmats2[6][44] + coeff0_7*dmats2[7][44] + coeff0_8*dmats2[8][44] + coeff0_9*dmats2[9][44] + coeff0_10*dmats2[10][44] + coeff0_11*dmats2[11][44] + coeff0_12*dmats2[12][44] + coeff0_13*dmats2[13][44] + coeff0_14*dmats2[14][44] + coeff0_15*dmats2[15][44] + coeff0_16*dmats2[16][44] + coeff0_17*dmats2[17][44] + coeff0_18*dmats2[18][44] + coeff0_19*dmats2[19][44] + coeff0_20*dmats2[20][44] + coeff0_21*dmats2[21][44] + coeff0_22*dmats2[22][44] + coeff0_23*dmats2[23][44] + coeff0_24*dmats2[24][44] + coeff0_25*dmats2[25][44] + coeff0_26*dmats2[26][44] + coeff0_27*dmats2[27][44] + coeff0_28*dmats2[28][44] + coeff0_29*dmats2[29][44] + coeff0_30*dmats2[30][44] + coeff0_31*dmats2[31][44] + coeff0_32*dmats2[32][44] + coeff0_33*dmats2[33][44] + coeff0_34*dmats2[34][44] + coeff0_35*dmats2[35][44] + coeff0_36*dmats2[36][44] + coeff0_37*dmats2[37][44] + coeff0_38*dmats2[38][44] + coeff0_39*dmats2[39][44] + coeff0_40*dmats2[40][44] + coeff0_41*dmats2[41][44] + coeff0_42*dmats2[42][44] + coeff0_43*dmats2[43][44] + coeff0_44*dmats2[44][44] + coeff0_45*dmats2[45][44] + coeff0_46*dmats2[46][44] + coeff0_47*dmats2[47][44] + coeff0_48*dmats2[48][44] + coeff0_49*dmats2[49][44] + coeff0_50*dmats2[50][44] + coeff0_51*dmats2[51][44] + coeff0_52*dmats2[52][44] + coeff0_53*dmats2[53][44] + coeff0_54*dmats2[54][44] + coeff0_55*dmats2[55][44];
          new_coeff0_45 = coeff0_0*dmats2[0][45] + coeff0_1*dmats2[1][45] + coeff0_2*dmats2[2][45] + coeff0_3*dmats2[3][45] + coeff0_4*dmats2[4][45] + coeff0_5*dmats2[5][45] + coeff0_6*dmats2[6][45] + coeff0_7*dmats2[7][45] + coeff0_8*dmats2[8][45] + coeff0_9*dmats2[9][45] + coeff0_10*dmats2[10][45] + coeff0_11*dmats2[11][45] + coeff0_12*dmats2[12][45] + coeff0_13*dmats2[13][45] + coeff0_14*dmats2[14][45] + coeff0_15*dmats2[15][45] + coeff0_16*dmats2[16][45] + coeff0_17*dmats2[17][45] + coeff0_18*dmats2[18][45] + coeff0_19*dmats2[19][45] + coeff0_20*dmats2[20][45] + coeff0_21*dmats2[21][45] + coeff0_22*dmats2[22][45] + coeff0_23*dmats2[23][45] + coeff0_24*dmats2[24][45] + coeff0_25*dmats2[25][45] + coeff0_26*dmats2[26][45] + coeff0_27*dmats2[27][45] + coeff0_28*dmats2[28][45] + coeff0_29*dmats2[29][45] + coeff0_30*dmats2[30][45] + coeff0_31*dmats2[31][45] + coeff0_32*dmats2[32][45] + coeff0_33*dmats2[33][45] + coeff0_34*dmats2[34][45] + coeff0_35*dmats2[35][45] + coeff0_36*dmats2[36][45] + coeff0_37*dmats2[37][45] + coeff0_38*dmats2[38][45] + coeff0_39*dmats2[39][45] + coeff0_40*dmats2[40][45] + coeff0_41*dmats2[41][45] + coeff0_42*dmats2[42][45] + coeff0_43*dmats2[43][45] + coeff0_44*dmats2[44][45] + coeff0_45*dmats2[45][45] + coeff0_46*dmats2[46][45] + coeff0_47*dmats2[47][45] + coeff0_48*dmats2[48][45] + coeff0_49*dmats2[49][45] + coeff0_50*dmats2[50][45] + coeff0_51*dmats2[51][45] + coeff0_52*dmats2[52][45] + coeff0_53*dmats2[53][45] + coeff0_54*dmats2[54][45] + coeff0_55*dmats2[55][45];
          new_coeff0_46 = coeff0_0*dmats2[0][46] + coeff0_1*dmats2[1][46] + coeff0_2*dmats2[2][46] + coeff0_3*dmats2[3][46] + coeff0_4*dmats2[4][46] + coeff0_5*dmats2[5][46] + coeff0_6*dmats2[6][46] + coeff0_7*dmats2[7][46] + coeff0_8*dmats2[8][46] + coeff0_9*dmats2[9][46] + coeff0_10*dmats2[10][46] + coeff0_11*dmats2[11][46] + coeff0_12*dmats2[12][46] + coeff0_13*dmats2[13][46] + coeff0_14*dmats2[14][46] + coeff0_15*dmats2[15][46] + coeff0_16*dmats2[16][46] + coeff0_17*dmats2[17][46] + coeff0_18*dmats2[18][46] + coeff0_19*dmats2[19][46] + coeff0_20*dmats2[20][46] + coeff0_21*dmats2[21][46] + coeff0_22*dmats2[22][46] + coeff0_23*dmats2[23][46] + coeff0_24*dmats2[24][46] + coeff0_25*dmats2[25][46] + coeff0_26*dmats2[26][46] + coeff0_27*dmats2[27][46] + coeff0_28*dmats2[28][46] + coeff0_29*dmats2[29][46] + coeff0_30*dmats2[30][46] + coeff0_31*dmats2[31][46] + coeff0_32*dmats2[32][46] + coeff0_33*dmats2[33][46] + coeff0_34*dmats2[34][46] + coeff0_35*dmats2[35][46] + coeff0_36*dmats2[36][46] + coeff0_37*dmats2[37][46] + coeff0_38*dmats2[38][46] + coeff0_39*dmats2[39][46] + coeff0_40*dmats2[40][46] + coeff0_41*dmats2[41][46] + coeff0_42*dmats2[42][46] + coeff0_43*dmats2[43][46] + coeff0_44*dmats2[44][46] + coeff0_45*dmats2[45][46] + coeff0_46*dmats2[46][46] + coeff0_47*dmats2[47][46] + coeff0_48*dmats2[48][46] + coeff0_49*dmats2[49][46] + coeff0_50*dmats2[50][46] + coeff0_51*dmats2[51][46] + coeff0_52*dmats2[52][46] + coeff0_53*dmats2[53][46] + coeff0_54*dmats2[54][46] + coeff0_55*dmats2[55][46];
          new_coeff0_47 = coeff0_0*dmats2[0][47] + coeff0_1*dmats2[1][47] + coeff0_2*dmats2[2][47] + coeff0_3*dmats2[3][47] + coeff0_4*dmats2[4][47] + coeff0_5*dmats2[5][47] + coeff0_6*dmats2[6][47] + coeff0_7*dmats2[7][47] + coeff0_8*dmats2[8][47] + coeff0_9*dmats2[9][47] + coeff0_10*dmats2[10][47] + coeff0_11*dmats2[11][47] + coeff0_12*dmats2[12][47] + coeff0_13*dmats2[13][47] + coeff0_14*dmats2[14][47] + coeff0_15*dmats2[15][47] + coeff0_16*dmats2[16][47] + coeff0_17*dmats2[17][47] + coeff0_18*dmats2[18][47] + coeff0_19*dmats2[19][47] + coeff0_20*dmats2[20][47] + coeff0_21*dmats2[21][47] + coeff0_22*dmats2[22][47] + coeff0_23*dmats2[23][47] + coeff0_24*dmats2[24][47] + coeff0_25*dmats2[25][47] + coeff0_26*dmats2[26][47] + coeff0_27*dmats2[27][47] + coeff0_28*dmats2[28][47] + coeff0_29*dmats2[29][47] + coeff0_30*dmats2[30][47] + coeff0_31*dmats2[31][47] + coeff0_32*dmats2[32][47] + coeff0_33*dmats2[33][47] + coeff0_34*dmats2[34][47] + coeff0_35*dmats2[35][47] + coeff0_36*dmats2[36][47] + coeff0_37*dmats2[37][47] + coeff0_38*dmats2[38][47] + coeff0_39*dmats2[39][47] + coeff0_40*dmats2[40][47] + coeff0_41*dmats2[41][47] + coeff0_42*dmats2[42][47] + coeff0_43*dmats2[43][47] + coeff0_44*dmats2[44][47] + coeff0_45*dmats2[45][47] + coeff0_46*dmats2[46][47] + coeff0_47*dmats2[47][47] + coeff0_48*dmats2[48][47] + coeff0_49*dmats2[49][47] + coeff0_50*dmats2[50][47] + coeff0_51*dmats2[51][47] + coeff0_52*dmats2[52][47] + coeff0_53*dmats2[53][47] + coeff0_54*dmats2[54][47] + coeff0_55*dmats2[55][47];
          new_coeff0_48 = coeff0_0*dmats2[0][48] + coeff0_1*dmats2[1][48] + coeff0_2*dmats2[2][48] + coeff0_3*dmats2[3][48] + coeff0_4*dmats2[4][48] + coeff0_5*dmats2[5][48] + coeff0_6*dmats2[6][48] + coeff0_7*dmats2[7][48] + coeff0_8*dmats2[8][48] + coeff0_9*dmats2[9][48] + coeff0_10*dmats2[10][48] + coeff0_11*dmats2[11][48] + coeff0_12*dmats2[12][48] + coeff0_13*dmats2[13][48] + coeff0_14*dmats2[14][48] + coeff0_15*dmats2[15][48] + coeff0_16*dmats2[16][48] + coeff0_17*dmats2[17][48] + coeff0_18*dmats2[18][48] + coeff0_19*dmats2[19][48] + coeff0_20*dmats2[20][48] + coeff0_21*dmats2[21][48] + coeff0_22*dmats2[22][48] + coeff0_23*dmats2[23][48] + coeff0_24*dmats2[24][48] + coeff0_25*dmats2[25][48] + coeff0_26*dmats2[26][48] + coeff0_27*dmats2[27][48] + coeff0_28*dmats2[28][48] + coeff0_29*dmats2[29][48] + coeff0_30*dmats2[30][48] + coeff0_31*dmats2[31][48] + coeff0_32*dmats2[32][48] + coeff0_33*dmats2[33][48] + coeff0_34*dmats2[34][48] + coeff0_35*dmats2[35][48] + coeff0_36*dmats2[36][48] + coeff0_37*dmats2[37][48] + coeff0_38*dmats2[38][48] + coeff0_39*dmats2[39][48] + coeff0_40*dmats2[40][48] + coeff0_41*dmats2[41][48] + coeff0_42*dmats2[42][48] + coeff0_43*dmats2[43][48] + coeff0_44*dmats2[44][48] + coeff0_45*dmats2[45][48] + coeff0_46*dmats2[46][48] + coeff0_47*dmats2[47][48] + coeff0_48*dmats2[48][48] + coeff0_49*dmats2[49][48] + coeff0_50*dmats2[50][48] + coeff0_51*dmats2[51][48] + coeff0_52*dmats2[52][48] + coeff0_53*dmats2[53][48] + coeff0_54*dmats2[54][48] + coeff0_55*dmats2[55][48];
          new_coeff0_49 = coeff0_0*dmats2[0][49] + coeff0_1*dmats2[1][49] + coeff0_2*dmats2[2][49] + coeff0_3*dmats2[3][49] + coeff0_4*dmats2[4][49] + coeff0_5*dmats2[5][49] + coeff0_6*dmats2[6][49] + coeff0_7*dmats2[7][49] + coeff0_8*dmats2[8][49] + coeff0_9*dmats2[9][49] + coeff0_10*dmats2[10][49] + coeff0_11*dmats2[11][49] + coeff0_12*dmats2[12][49] + coeff0_13*dmats2[13][49] + coeff0_14*dmats2[14][49] + coeff0_15*dmats2[15][49] + coeff0_16*dmats2[16][49] + coeff0_17*dmats2[17][49] + coeff0_18*dmats2[18][49] + coeff0_19*dmats2[19][49] + coeff0_20*dmats2[20][49] + coeff0_21*dmats2[21][49] + coeff0_22*dmats2[22][49] + coeff0_23*dmats2[23][49] + coeff0_24*dmats2[24][49] + coeff0_25*dmats2[25][49] + coeff0_26*dmats2[26][49] + coeff0_27*dmats2[27][49] + coeff0_28*dmats2[28][49] + coeff0_29*dmats2[29][49] + coeff0_30*dmats2[30][49] + coeff0_31*dmats2[31][49] + coeff0_32*dmats2[32][49] + coeff0_33*dmats2[33][49] + coeff0_34*dmats2[34][49] + coeff0_35*dmats2[35][49] + coeff0_36*dmats2[36][49] + coeff0_37*dmats2[37][49] + coeff0_38*dmats2[38][49] + coeff0_39*dmats2[39][49] + coeff0_40*dmats2[40][49] + coeff0_41*dmats2[41][49] + coeff0_42*dmats2[42][49] + coeff0_43*dmats2[43][49] + coeff0_44*dmats2[44][49] + coeff0_45*dmats2[45][49] + coeff0_46*dmats2[46][49] + coeff0_47*dmats2[47][49] + coeff0_48*dmats2[48][49] + coeff0_49*dmats2[49][49] + coeff0_50*dmats2[50][49] + coeff0_51*dmats2[51][49] + coeff0_52*dmats2[52][49] + coeff0_53*dmats2[53][49] + coeff0_54*dmats2[54][49] + coeff0_55*dmats2[55][49];
          new_coeff0_50 = coeff0_0*dmats2[0][50] + coeff0_1*dmats2[1][50] + coeff0_2*dmats2[2][50] + coeff0_3*dmats2[3][50] + coeff0_4*dmats2[4][50] + coeff0_5*dmats2[5][50] + coeff0_6*dmats2[6][50] + coeff0_7*dmats2[7][50] + coeff0_8*dmats2[8][50] + coeff0_9*dmats2[9][50] + coeff0_10*dmats2[10][50] + coeff0_11*dmats2[11][50] + coeff0_12*dmats2[12][50] + coeff0_13*dmats2[13][50] + coeff0_14*dmats2[14][50] + coeff0_15*dmats2[15][50] + coeff0_16*dmats2[16][50] + coeff0_17*dmats2[17][50] + coeff0_18*dmats2[18][50] + coeff0_19*dmats2[19][50] + coeff0_20*dmats2[20][50] + coeff0_21*dmats2[21][50] + coeff0_22*dmats2[22][50] + coeff0_23*dmats2[23][50] + coeff0_24*dmats2[24][50] + coeff0_25*dmats2[25][50] + coeff0_26*dmats2[26][50] + coeff0_27*dmats2[27][50] + coeff0_28*dmats2[28][50] + coeff0_29*dmats2[29][50] + coeff0_30*dmats2[30][50] + coeff0_31*dmats2[31][50] + coeff0_32*dmats2[32][50] + coeff0_33*dmats2[33][50] + coeff0_34*dmats2[34][50] + coeff0_35*dmats2[35][50] + coeff0_36*dmats2[36][50] + coeff0_37*dmats2[37][50] + coeff0_38*dmats2[38][50] + coeff0_39*dmats2[39][50] + coeff0_40*dmats2[40][50] + coeff0_41*dmats2[41][50] + coeff0_42*dmats2[42][50] + coeff0_43*dmats2[43][50] + coeff0_44*dmats2[44][50] + coeff0_45*dmats2[45][50] + coeff0_46*dmats2[46][50] + coeff0_47*dmats2[47][50] + coeff0_48*dmats2[48][50] + coeff0_49*dmats2[49][50] + coeff0_50*dmats2[50][50] + coeff0_51*dmats2[51][50] + coeff0_52*dmats2[52][50] + coeff0_53*dmats2[53][50] + coeff0_54*dmats2[54][50] + coeff0_55*dmats2[55][50];
          new_coeff0_51 = coeff0_0*dmats2[0][51] + coeff0_1*dmats2[1][51] + coeff0_2*dmats2[2][51] + coeff0_3*dmats2[3][51] + coeff0_4*dmats2[4][51] + coeff0_5*dmats2[5][51] + coeff0_6*dmats2[6][51] + coeff0_7*dmats2[7][51] + coeff0_8*dmats2[8][51] + coeff0_9*dmats2[9][51] + coeff0_10*dmats2[10][51] + coeff0_11*dmats2[11][51] + coeff0_12*dmats2[12][51] + coeff0_13*dmats2[13][51] + coeff0_14*dmats2[14][51] + coeff0_15*dmats2[15][51] + coeff0_16*dmats2[16][51] + coeff0_17*dmats2[17][51] + coeff0_18*dmats2[18][51] + coeff0_19*dmats2[19][51] + coeff0_20*dmats2[20][51] + coeff0_21*dmats2[21][51] + coeff0_22*dmats2[22][51] + coeff0_23*dmats2[23][51] + coeff0_24*dmats2[24][51] + coeff0_25*dmats2[25][51] + coeff0_26*dmats2[26][51] + coeff0_27*dmats2[27][51] + coeff0_28*dmats2[28][51] + coeff0_29*dmats2[29][51] + coeff0_30*dmats2[30][51] + coeff0_31*dmats2[31][51] + coeff0_32*dmats2[32][51] + coeff0_33*dmats2[33][51] + coeff0_34*dmats2[34][51] + coeff0_35*dmats2[35][51] + coeff0_36*dmats2[36][51] + coeff0_37*dmats2[37][51] + coeff0_38*dmats2[38][51] + coeff0_39*dmats2[39][51] + coeff0_40*dmats2[40][51] + coeff0_41*dmats2[41][51] + coeff0_42*dmats2[42][51] + coeff0_43*dmats2[43][51] + coeff0_44*dmats2[44][51] + coeff0_45*dmats2[45][51] + coeff0_46*dmats2[46][51] + coeff0_47*dmats2[47][51] + coeff0_48*dmats2[48][51] + coeff0_49*dmats2[49][51] + coeff0_50*dmats2[50][51] + coeff0_51*dmats2[51][51] + coeff0_52*dmats2[52][51] + coeff0_53*dmats2[53][51] + coeff0_54*dmats2[54][51] + coeff0_55*dmats2[55][51];
          new_coeff0_52 = coeff0_0*dmats2[0][52] + coeff0_1*dmats2[1][52] + coeff0_2*dmats2[2][52] + coeff0_3*dmats2[3][52] + coeff0_4*dmats2[4][52] + coeff0_5*dmats2[5][52] + coeff0_6*dmats2[6][52] + coeff0_7*dmats2[7][52] + coeff0_8*dmats2[8][52] + coeff0_9*dmats2[9][52] + coeff0_10*dmats2[10][52] + coeff0_11*dmats2[11][52] + coeff0_12*dmats2[12][52] + coeff0_13*dmats2[13][52] + coeff0_14*dmats2[14][52] + coeff0_15*dmats2[15][52] + coeff0_16*dmats2[16][52] + coeff0_17*dmats2[17][52] + coeff0_18*dmats2[18][52] + coeff0_19*dmats2[19][52] + coeff0_20*dmats2[20][52] + coeff0_21*dmats2[21][52] + coeff0_22*dmats2[22][52] + coeff0_23*dmats2[23][52] + coeff0_24*dmats2[24][52] + coeff0_25*dmats2[25][52] + coeff0_26*dmats2[26][52] + coeff0_27*dmats2[27][52] + coeff0_28*dmats2[28][52] + coeff0_29*dmats2[29][52] + coeff0_30*dmats2[30][52] + coeff0_31*dmats2[31][52] + coeff0_32*dmats2[32][52] + coeff0_33*dmats2[33][52] + coeff0_34*dmats2[34][52] + coeff0_35*dmats2[35][52] + coeff0_36*dmats2[36][52] + coeff0_37*dmats2[37][52] + coeff0_38*dmats2[38][52] + coeff0_39*dmats2[39][52] + coeff0_40*dmats2[40][52] + coeff0_41*dmats2[41][52] + coeff0_42*dmats2[42][52] + coeff0_43*dmats2[43][52] + coeff0_44*dmats2[44][52] + coeff0_45*dmats2[45][52] + coeff0_46*dmats2[46][52] + coeff0_47*dmats2[47][52] + coeff0_48*dmats2[48][52] + coeff0_49*dmats2[49][52] + coeff0_50*dmats2[50][52] + coeff0_51*dmats2[51][52] + coeff0_52*dmats2[52][52] + coeff0_53*dmats2[53][52] + coeff0_54*dmats2[54][52] + coeff0_55*dmats2[55][52];
          new_coeff0_53 = coeff0_0*dmats2[0][53] + coeff0_1*dmats2[1][53] + coeff0_2*dmats2[2][53] + coeff0_3*dmats2[3][53] + coeff0_4*dmats2[4][53] + coeff0_5*dmats2[5][53] + coeff0_6*dmats2[6][53] + coeff0_7*dmats2[7][53] + coeff0_8*dmats2[8][53] + coeff0_9*dmats2[9][53] + coeff0_10*dmats2[10][53] + coeff0_11*dmats2[11][53] + coeff0_12*dmats2[12][53] + coeff0_13*dmats2[13][53] + coeff0_14*dmats2[14][53] + coeff0_15*dmats2[15][53] + coeff0_16*dmats2[16][53] + coeff0_17*dmats2[17][53] + coeff0_18*dmats2[18][53] + coeff0_19*dmats2[19][53] + coeff0_20*dmats2[20][53] + coeff0_21*dmats2[21][53] + coeff0_22*dmats2[22][53] + coeff0_23*dmats2[23][53] + coeff0_24*dmats2[24][53] + coeff0_25*dmats2[25][53] + coeff0_26*dmats2[26][53] + coeff0_27*dmats2[27][53] + coeff0_28*dmats2[28][53] + coeff0_29*dmats2[29][53] + coeff0_30*dmats2[30][53] + coeff0_31*dmats2[31][53] + coeff0_32*dmats2[32][53] + coeff0_33*dmats2[33][53] + coeff0_34*dmats2[34][53] + coeff0_35*dmats2[35][53] + coeff0_36*dmats2[36][53] + coeff0_37*dmats2[37][53] + coeff0_38*dmats2[38][53] + coeff0_39*dmats2[39][53] + coeff0_40*dmats2[40][53] + coeff0_41*dmats2[41][53] + coeff0_42*dmats2[42][53] + coeff0_43*dmats2[43][53] + coeff0_44*dmats2[44][53] + coeff0_45*dmats2[45][53] + coeff0_46*dmats2[46][53] + coeff0_47*dmats2[47][53] + coeff0_48*dmats2[48][53] + coeff0_49*dmats2[49][53] + coeff0_50*dmats2[50][53] + coeff0_51*dmats2[51][53] + coeff0_52*dmats2[52][53] + coeff0_53*dmats2[53][53] + coeff0_54*dmats2[54][53] + coeff0_55*dmats2[55][53];
          new_coeff0_54 = coeff0_0*dmats2[0][54] + coeff0_1*dmats2[1][54] + coeff0_2*dmats2[2][54] + coeff0_3*dmats2[3][54] + coeff0_4*dmats2[4][54] + coeff0_5*dmats2[5][54] + coeff0_6*dmats2[6][54] + coeff0_7*dmats2[7][54] + coeff0_8*dmats2[8][54] + coeff0_9*dmats2[9][54] + coeff0_10*dmats2[10][54] + coeff0_11*dmats2[11][54] + coeff0_12*dmats2[12][54] + coeff0_13*dmats2[13][54] + coeff0_14*dmats2[14][54] + coeff0_15*dmats2[15][54] + coeff0_16*dmats2[16][54] + coeff0_17*dmats2[17][54] + coeff0_18*dmats2[18][54] + coeff0_19*dmats2[19][54] + coeff0_20*dmats2[20][54] + coeff0_21*dmats2[21][54] + coeff0_22*dmats2[22][54] + coeff0_23*dmats2[23][54] + coeff0_24*dmats2[24][54] + coeff0_25*dmats2[25][54] + coeff0_26*dmats2[26][54] + coeff0_27*dmats2[27][54] + coeff0_28*dmats2[28][54] + coeff0_29*dmats2[29][54] + coeff0_30*dmats2[30][54] + coeff0_31*dmats2[31][54] + coeff0_32*dmats2[32][54] + coeff0_33*dmats2[33][54] + coeff0_34*dmats2[34][54] + coeff0_35*dmats2[35][54] + coeff0_36*dmats2[36][54] + coeff0_37*dmats2[37][54] + coeff0_38*dmats2[38][54] + coeff0_39*dmats2[39][54] + coeff0_40*dmats2[40][54] + coeff0_41*dmats2[41][54] + coeff0_42*dmats2[42][54] + coeff0_43*dmats2[43][54] + coeff0_44*dmats2[44][54] + coeff0_45*dmats2[45][54] + coeff0_46*dmats2[46][54] + coeff0_47*dmats2[47][54] + coeff0_48*dmats2[48][54] + coeff0_49*dmats2[49][54] + coeff0_50*dmats2[50][54] + coeff0_51*dmats2[51][54] + coeff0_52*dmats2[52][54] + coeff0_53*dmats2[53][54] + coeff0_54*dmats2[54][54] + coeff0_55*dmats2[55][54];
          new_coeff0_55 = coeff0_0*dmats2[0][55] + coeff0_1*dmats2[1][55] + coeff0_2*dmats2[2][55] + coeff0_3*dmats2[3][55] + coeff0_4*dmats2[4][55] + coeff0_5*dmats2[5][55] + coeff0_6*dmats2[6][55] + coeff0_7*dmats2[7][55] + coeff0_8*dmats2[8][55] + coeff0_9*dmats2[9][55] + coeff0_10*dmats2[10][55] + coeff0_11*dmats2[11][55] + coeff0_12*dmats2[12][55] + coeff0_13*dmats2[13][55] + coeff0_14*dmats2[14][55] + coeff0_15*dmats2[15][55] + coeff0_16*dmats2[16][55] + coeff0_17*dmats2[17][55] + coeff0_18*dmats2[18][55] + coeff0_19*dmats2[19][55] + coeff0_20*dmats2[20][55] + coeff0_21*dmats2[21][55] + coeff0_22*dmats2[22][55] + coeff0_23*dmats2[23][55] + coeff0_24*dmats2[24][55] + coeff0_25*dmats2[25][55] + coeff0_26*dmats2[26][55] + coeff0_27*dmats2[27][55] + coeff0_28*dmats2[28][55] + coeff0_29*dmats2[29][55] + coeff0_30*dmats2[30][55] + coeff0_31*dmats2[31][55] + coeff0_32*dmats2[32][55] + coeff0_33*dmats2[33][55] + coeff0_34*dmats2[34][55] + coeff0_35*dmats2[35][55] + coeff0_36*dmats2[36][55] + coeff0_37*dmats2[37][55] + coeff0_38*dmats2[38][55] + coeff0_39*dmats2[39][55] + coeff0_40*dmats2[40][55] + coeff0_41*dmats2[41][55] + coeff0_42*dmats2[42][55] + coeff0_43*dmats2[43][55] + coeff0_44*dmats2[44][55] + coeff0_45*dmats2[45][55] + coeff0_46*dmats2[46][55] + coeff0_47*dmats2[47][55] + coeff0_48*dmats2[48][55] + coeff0_49*dmats2[49][55] + coeff0_50*dmats2[50][55] + coeff0_51*dmats2[51][55] + coeff0_52*dmats2[52][55] + coeff0_53*dmats2[53][55] + coeff0_54*dmats2[54][55] + coeff0_55*dmats2[55][55];
        }
    
      }
      // Compute derivatives on reference element as dot product of coefficients and basisvalues
      derivatives[deriv_num] = new_coeff0_0*basisvalue0 + new_coeff0_1*basisvalue1 + new_coeff0_2*basisvalue2 + new_coeff0_3*basisvalue3 + new_coeff0_4*basisvalue4 + new_coeff0_5*basisvalue5 + new_coeff0_6*basisvalue6 + new_coeff0_7*basisvalue7 + new_coeff0_8*basisvalue8 + new_coeff0_9*basisvalue9 + new_coeff0_10*basisvalue10 + new_coeff0_11*basisvalue11 + new_coeff0_12*basisvalue12 + new_coeff0_13*basisvalue13 + new_coeff0_14*basisvalue14 + new_coeff0_15*basisvalue15 + new_coeff0_16*basisvalue16 + new_coeff0_17*basisvalue17 + new_coeff0_18*basisvalue18 + new_coeff0_19*basisvalue19 + new_coeff0_20*basisvalue20 + new_coeff0_21*basisvalue21 + new_coeff0_22*basisvalue22 + new_coeff0_23*basisvalue23 + new_coeff0_24*basisvalue24 + new_coeff0_25*basisvalue25 + new_coeff0_26*basisvalue26 + new_coeff0_27*basisvalue27 + new_coeff0_28*basisvalue28 + new_coeff0_29*basisvalue29 + new_coeff0_30*basisvalue30 + new_coeff0_31*basisvalue31 + new_coeff0_32*basisvalue32 + new_coeff0_33*basisvalue33 + new_coeff0_34*basisvalue34 + new_coeff0_35*basisvalue35 + new_coeff0_36*basisvalue36 + new_coeff0_37*basisvalue37 + new_coeff0_38*basisvalue38 + new_coeff0_39*basisvalue39 + new_coeff0_40*basisvalue40 + new_coeff0_41*basisvalue41 + new_coeff0_42*basisvalue42 + new_coeff0_43*basisvalue43 + new_coeff0_44*basisvalue44 + new_coeff0_45*basisvalue45 + new_coeff0_46*basisvalue46 + new_coeff0_47*basisvalue47 + new_coeff0_48*basisvalue48 + new_coeff0_49*basisvalue49 + new_coeff0_50*basisvalue50 + new_coeff0_51*basisvalue51 + new_coeff0_52*basisvalue52 + new_coeff0_53*basisvalue53 + new_coeff0_54*basisvalue54 + new_coeff0_55*basisvalue55;
    }
    
    // Transform derivatives back to physical element
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        values[row] += transform[row][col]*derivatives[col];
      }
    }
    // Delete pointer to array of derivatives on FIAT element
    delete [] derivatives;
    
    // Delete pointer to array of combinations of derivatives and transform
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      delete [] combinations[row];
      delete [] transform[row];
    }
    
    delete [] combinations;
    delete [] transform;
  }

  /// Evaluate order n derivatives of all basis functions at given point in cell
  virtual void evaluate_basis_derivatives_all(unsigned int n,
                                              double* values,
                                              const double* coordinates,
                                              const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis_derivatives() is not yet implemented.");
  }

  /// Evaluate linear functional for dof i on the function f
  virtual double evaluate_dof(unsigned int i,
                              const ufc::function& f,
                              const ufc::cell& c) const
  {
    // The reference points, direction and weights:
    const static double X[56][1][3] = {{{0, 0, 0}}, {{1, 0, 0}}, {{0, 1, 0}}, {{0, 0, 1}}, {{0, 0.8, 0.2}}, {{0, 0.6, 0.4}}, {{0, 0.4, 0.6}}, {{0, 0.2, 0.8}}, {{0.8, 0, 0.2}}, {{0.6, 0, 0.4}}, {{0.4, 0, 0.6}}, {{0.2, 0, 0.8}}, {{0.8, 0.2, 0}}, {{0.6, 0.4, 0}}, {{0.4, 0.6, 0}}, {{0.2, 0.8, 0}}, {{0, 0, 0.2}}, {{0, 0, 0.4}}, {{0, 0, 0.6}}, {{0, 0, 0.8}}, {{0, 0.2, 0}}, {{0, 0.4, 0}}, {{0, 0.6, 0}}, {{0, 0.8, 0}}, {{0.2, 0, 0}}, {{0.4, 0, 0}}, {{0.6, 0, 0}}, {{0.8, 0, 0}}, {{0.6, 0.2, 0.2}}, {{0.4, 0.4, 0.2}}, {{0.2, 0.6, 0.2}}, {{0.4, 0.2, 0.4}}, {{0.2, 0.4, 0.4}}, {{0.2, 0.2, 0.6}}, {{0, 0.2, 0.2}}, {{0, 0.4, 0.2}}, {{0, 0.6, 0.2}}, {{0, 0.2, 0.4}}, {{0, 0.4, 0.4}}, {{0, 0.2, 0.6}}, {{0.2, 0, 0.2}}, {{0.4, 0, 0.2}}, {{0.6, 0, 0.2}}, {{0.2, 0, 0.4}}, {{0.4, 0, 0.4}}, {{0.2, 0, 0.6}}, {{0.2, 0.2, 0}}, {{0.4, 0.2, 0}}, {{0.6, 0.2, 0}}, {{0.2, 0.4, 0}}, {{0.4, 0.4, 0}}, {{0.2, 0.6, 0}}, {{0.2, 0.2, 0.2}}, {{0.4, 0.2, 0.2}}, {{0.2, 0.4, 0.2}}, {{0.2, 0.2, 0.4}}};
    const static double W[56][1] = {{1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}};
    const static double D[56][1][1] = {{{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}};
    
    const double * const * x = c.coordinates;
    double result = 0.0;
    // Iterate over the points:
    // Evaluate basis functions for affine mapping
    const double w0 = 1.0 - X[i][0][0] - X[i][0][1] - X[i][0][2];
    const double w1 = X[i][0][0];
    const double w2 = X[i][0][1];
    const double w3 = X[i][0][2];
    
    // Compute affine mapping y = F(X)
    double y[3];
    y[0] = w0*x[0][0] + w1*x[1][0] + w2*x[2][0] + w3*x[3][0];
    y[1] = w0*x[0][1] + w1*x[1][1] + w2*x[2][1] + w3*x[3][1];
    y[2] = w0*x[0][2] + w1*x[1][2] + w2*x[2][2] + w3*x[3][2];
    
    // Evaluate function at physical points
    double values[1];
    f.evaluate(values, y, c);
    
    // Map function values using appropriate mapping
    // Affine map: Do nothing
    
    // Note that we do not map the weights (yet).
    
    // Take directional components
    for(int k = 0; k < 1; k++)
      result += values[k]*D[i][0][k];
    // Multiply by weights 
    result *= W[i][0];
    
    return result;
  }

  /// Evaluate linear functionals for all dofs on the function f
  virtual void evaluate_dofs(double* values,
                             const ufc::function& f,
                             const ufc::cell& c) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Interpolate vertex values from dof values
  virtual void interpolate_vertex_values(double* vertex_values,
                                         const double* dof_values,
                                         const ufc::cell& c) const
  {
    // Evaluate at vertices and use affine mapping
    vertex_values[0] = dof_values[0];
    vertex_values[1] = dof_values[1];
    vertex_values[2] = dof_values[2];
    vertex_values[3] = dof_values[3];
  }

  /// Return the number of sub elements (for a mixed element)
  virtual unsigned int num_sub_elements() const
  {
    return 1;
  }

  /// Create a new finite element for sub element i (for a mixed element)
  virtual ufc::finite_element* create_sub_element(unsigned int i) const
  {
    return new poisson3d_5_0_finite_element_0();
  }

};

/// This class defines the interface for a finite element.

class poisson3d_5_0_finite_element_1: public ufc::finite_element
{
public:

  /// Constructor
  poisson3d_5_0_finite_element_1() : ufc::finite_element()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_0_finite_element_1()
  {
    // Do nothing
  }

  /// Return a string identifying the finite element
  virtual const char* signature() const
  {
    return "FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return the cell shape
  virtual ufc::shape cell_shape() const
  {
    return ufc::tetrahedron;
  }

  /// Return the dimension of the finite element function space
  virtual unsigned int space_dimension() const
  {
    return 56;
  }

  /// Return the rank of the value space
  virtual unsigned int value_rank() const
  {
    return 0;
  }

  /// Return the dimension of the value space for axis i
  virtual unsigned int value_dimension(unsigned int i) const
  {
    return 1;
  }

  /// Evaluate basis function i at given point in cell
  virtual void evaluate_basis(unsigned int i,
                              double* values,
                              const double* coordinates,
                              const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Reset values
    *values = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Extract relevant coefficients
    const double coeff0_0 = coefficients0[dof][0];
    const double coeff0_1 = coefficients0[dof][1];
    const double coeff0_2 = coefficients0[dof][2];
    const double coeff0_3 = coefficients0[dof][3];
    const double coeff0_4 = coefficients0[dof][4];
    const double coeff0_5 = coefficients0[dof][5];
    const double coeff0_6 = coefficients0[dof][6];
    const double coeff0_7 = coefficients0[dof][7];
    const double coeff0_8 = coefficients0[dof][8];
    const double coeff0_9 = coefficients0[dof][9];
    const double coeff0_10 = coefficients0[dof][10];
    const double coeff0_11 = coefficients0[dof][11];
    const double coeff0_12 = coefficients0[dof][12];
    const double coeff0_13 = coefficients0[dof][13];
    const double coeff0_14 = coefficients0[dof][14];
    const double coeff0_15 = coefficients0[dof][15];
    const double coeff0_16 = coefficients0[dof][16];
    const double coeff0_17 = coefficients0[dof][17];
    const double coeff0_18 = coefficients0[dof][18];
    const double coeff0_19 = coefficients0[dof][19];
    const double coeff0_20 = coefficients0[dof][20];
    const double coeff0_21 = coefficients0[dof][21];
    const double coeff0_22 = coefficients0[dof][22];
    const double coeff0_23 = coefficients0[dof][23];
    const double coeff0_24 = coefficients0[dof][24];
    const double coeff0_25 = coefficients0[dof][25];
    const double coeff0_26 = coefficients0[dof][26];
    const double coeff0_27 = coefficients0[dof][27];
    const double coeff0_28 = coefficients0[dof][28];
    const double coeff0_29 = coefficients0[dof][29];
    const double coeff0_30 = coefficients0[dof][30];
    const double coeff0_31 = coefficients0[dof][31];
    const double coeff0_32 = coefficients0[dof][32];
    const double coeff0_33 = coefficients0[dof][33];
    const double coeff0_34 = coefficients0[dof][34];
    const double coeff0_35 = coefficients0[dof][35];
    const double coeff0_36 = coefficients0[dof][36];
    const double coeff0_37 = coefficients0[dof][37];
    const double coeff0_38 = coefficients0[dof][38];
    const double coeff0_39 = coefficients0[dof][39];
    const double coeff0_40 = coefficients0[dof][40];
    const double coeff0_41 = coefficients0[dof][41];
    const double coeff0_42 = coefficients0[dof][42];
    const double coeff0_43 = coefficients0[dof][43];
    const double coeff0_44 = coefficients0[dof][44];
    const double coeff0_45 = coefficients0[dof][45];
    const double coeff0_46 = coefficients0[dof][46];
    const double coeff0_47 = coefficients0[dof][47];
    const double coeff0_48 = coefficients0[dof][48];
    const double coeff0_49 = coefficients0[dof][49];
    const double coeff0_50 = coefficients0[dof][50];
    const double coeff0_51 = coefficients0[dof][51];
    const double coeff0_52 = coefficients0[dof][52];
    const double coeff0_53 = coefficients0[dof][53];
    const double coeff0_54 = coefficients0[dof][54];
    const double coeff0_55 = coefficients0[dof][55];
    
    // Compute value(s)
    *values = coeff0_0*basisvalue0 + coeff0_1*basisvalue1 + coeff0_2*basisvalue2 + coeff0_3*basisvalue3 + coeff0_4*basisvalue4 + coeff0_5*basisvalue5 + coeff0_6*basisvalue6 + coeff0_7*basisvalue7 + coeff0_8*basisvalue8 + coeff0_9*basisvalue9 + coeff0_10*basisvalue10 + coeff0_11*basisvalue11 + coeff0_12*basisvalue12 + coeff0_13*basisvalue13 + coeff0_14*basisvalue14 + coeff0_15*basisvalue15 + coeff0_16*basisvalue16 + coeff0_17*basisvalue17 + coeff0_18*basisvalue18 + coeff0_19*basisvalue19 + coeff0_20*basisvalue20 + coeff0_21*basisvalue21 + coeff0_22*basisvalue22 + coeff0_23*basisvalue23 + coeff0_24*basisvalue24 + coeff0_25*basisvalue25 + coeff0_26*basisvalue26 + coeff0_27*basisvalue27 + coeff0_28*basisvalue28 + coeff0_29*basisvalue29 + coeff0_30*basisvalue30 + coeff0_31*basisvalue31 + coeff0_32*basisvalue32 + coeff0_33*basisvalue33 + coeff0_34*basisvalue34 + coeff0_35*basisvalue35 + coeff0_36*basisvalue36 + coeff0_37*basisvalue37 + coeff0_38*basisvalue38 + coeff0_39*basisvalue39 + coeff0_40*basisvalue40 + coeff0_41*basisvalue41 + coeff0_42*basisvalue42 + coeff0_43*basisvalue43 + coeff0_44*basisvalue44 + coeff0_45*basisvalue45 + coeff0_46*basisvalue46 + coeff0_47*basisvalue47 + coeff0_48*basisvalue48 + coeff0_49*basisvalue49 + coeff0_50*basisvalue50 + coeff0_51*basisvalue51 + coeff0_52*basisvalue52 + coeff0_53*basisvalue53 + coeff0_54*basisvalue54 + coeff0_55*basisvalue55;
  }

  /// Evaluate all basis functions at given point in cell
  virtual void evaluate_basis_all(double* values,
                                  const double* coordinates,
                                  const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis() is not yet implemented.");
  }

  /// Evaluate order n derivatives of basis function i at given point in cell
  virtual void evaluate_basis_derivatives(unsigned int i,
                                          unsigned int n,
                                          double* values,
                                          const double* coordinates,
                                          const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Compute number of derivatives
    unsigned int num_derivatives = 1;
    
    for (unsigned int j = 0; j < n; j++)
      num_derivatives *= 3;
    
    
    // Declare pointer to two dimensional array that holds combinations of derivatives and initialise
    unsigned int **combinations = new unsigned int *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      combinations[j] = new unsigned int [n];
      for (unsigned int k = 0; k < n; k++)
        combinations[j][k] = 0;
    }
        
    // Generate combinations of derivatives
    for (unsigned int row = 1; row < num_derivatives; row++)
    {
      for (unsigned int num = 0; num < row; num++)
      {
        for (unsigned int col = n-1; col+1 > 0; col--)
        {
          if (combinations[row][col] + 1 > 2)
            combinations[row][col] = 0;
          else
          {
            combinations[row][col] += 1;
            break;
          }
        }
      }
    }
    
    // Compute inverse of Jacobian
    const double Jinv[3][3] ={{d00 / detJ, d10 / detJ, d20 / detJ}, {d01 / detJ, d11 / detJ, d21 / detJ}, {d02 / detJ, d12 / detJ, d22 / detJ}};
    
    // Declare transformation matrix
    // Declare pointer to two dimensional array and initialise
    double **transform = new double *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      transform[j] = new double [num_derivatives];
      for (unsigned int k = 0; k < num_derivatives; k++)
        transform[j][k] = 1;
    }
    
    // Construct transformation matrix
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        for (unsigned int k = 0; k < n; k++)
          transform[row][col] *= Jinv[combinations[col][k]][combinations[row][k]];
      }
    }
    
    // Reset values
    for (unsigned int j = 0; j < 1*num_derivatives; j++)
      values[j] = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Interesting (new) part
    // Tables of derivatives of the polynomial base (transpose)
    const static double dmats0[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.32455532033676, 0, -1.14376677014985e-14, 1.62513232038197e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.226276025168e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.2249721603218, 0, 0, 0, 1.51109207276003e-14, 0, 0, 1.7779939846807e-14, 0, -1.0584837800154e-14, 0, 0, 0, 0, 0, -1.00872575799093e-14, 0, 0, 1.03757106873844e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.58257569495584, 0, 8.36660026534074, -1.18321595661991, 0, -1.45923311721618e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.02203768115554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.74165738677394, 0, 0, 8.69482604771369, 0, 0, 0, 0, 1.78666554661835e-14, 0, 0, 0, 0, 0, 1.07473131066306e-14, 0, 0, 0, -1.11533477710537e-14, 2.38264269425414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.49909083394701, -1.6247766670982e-14, -3.3466401061363, -2.36643191323984, 15.4919333848297, 0, 0.692820323027544, 0, 0.565685424949235, 0.4, -1.83948951574252e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00288811754535e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.89897948556636, -1.43896667584992e-14, 0, 1.15516000140692e-14, 14.1985914794391, 0, -0.828078671210835, 2.47538399283584e-14, 0, 0, -1.83091262688552e-14, 1.02722007327841e-14, -1.56195834108856e-14, 0, 0, -1.91729044059553e-14, 0, 0, 0, 0, 0, 1.12036901882012e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.41804190462393e-14, 0, -1.19125833850358e-14, 0, 0, -1.13598572445865e-14, 0, -1.07549059979877e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.60000000000001, 0, 8.76356092008264, -1.54919333848296, 0, 0, 9.52470471983252, 0, -1.48131215963608, 0.261861468283188, 0, 0, 0, -2.03129367268393e-14, 0, 0, 2.48374782197935e-14, 0, -2.78808329533534e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.04489815276121e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00610790048597e-14, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.24264068711929, 0, 1.13239065646931e-14, 0, 0, 0, 14.3427433120127, 1.68846056927685e-14, 0, 0, 0, 0, 0, 1.92963956808162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.11769145362398, -1.38374576748428e-14, 3.16227766016837, 4.91934955049958, 0, 0, -1.29538515160783e-14, -1.04815557124913e-14, 10.690449676497, -2.41897262725904, 0, 0, 0, 0, 0, 2.10489624344795e-14, 0, -1.67945221763201e-14, -3.13102977027619e-14, 2.84355872182118e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.79907925474428e-14, 0, -1.53961627596513e-14, 1.10259024133086e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.54558441227157, 0, 0, 7.66811580507233, 0, 0, 0, 0, 2.32369836935692e-14, 10.3691851174526, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.60576914948, 0, 1.09730925298582e-14, 0, -4.20458932936042, 0, -3.43303281162797, 0, 0, 19.6214168703486, 0, 0.611677741841187, 1.15273118941668e-14, 0, 0.529728463363971, 0, 0.432521479156778, 0, 1.6058715222196e-14, 0, -1.16729361337554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.53137212479104, -1.01690618327065e-14, 3.54562104171169, -2.50713268211205, 4.78713553878169, 0, -5.56626745075489, 0, -1.04880884817015, 0.741619848709564, 0, 18.8034951158403, 0, 1.68183573174418, -0.603122387046456, 0, 0.70128378121765, 0, 0.132137494528682, -0.0934353184302471, 0, 0, 0, -1.0082826842246e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07842270669413e-14, 0, 0, 0, 0, 0, -1.43736268462506e-14, 0, 1.40644587163015e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.5951288749407, 0, 0, 0, 10.0285307284481, 0, -0.767649473578742, 0, 0, 0, 0, 16.4130361329658, -1.65111444887587e-14, 0, -1.26347611061158, 0, 0.0967147429123319, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.96647939483827, 0, 8.12403840463594, -1.64130361329659, 0, 0, 11.7728501222091, 0, -2.40312296813958, 0.48550415622761, 0, 0, 0, 10.2761860629321, 0, 0, -1.48323969741912, 0, 0.302765035409732, -0.0611677741841287, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.05298244095218, 0, -1.58564993434419, 4.48489528465109, 4.28174419288837, 0, 0.191485421551277, 0, -3.75233260785876, -4.31161222746203, 0, 0, 0, 0, 18.8807171866294, 0, 0.844371341865034, -1.40094110434133e-14, 1.18187368057056, 1.04463861754666, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.321153829896, 0, 0, 0, 3.92428337406971, 0, 5.49285249860475, 1.63666823149722e-14, 0, 0, 0, 0, -1.21592089550238e-14, 0, 17.3044631365566, -1.98459387250407e-14, -1.73008591662713, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.78485070541082e-14, 0, 0, 0, 0, -1.10973688891617e-14, 0, 2.78631828811134e-14, 0, 0, 0, 0},
    {2.65329983228432, -1.19347092313647e-14, 4.1522061999051, 2.93605316083777, 0, -1.18275179297788e-14, 2.63248931621762, 0, 9.82591326180786, -2.8226127713774, 0, 0, 0, -1.25702218603545e-14, 0, 1.56555930303565e-14, 11.6081867662439, -2.18250550506549e-14, -3.09487177319471, 0.68387650554026, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47816108620456e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.14018107676926e-14, 0, 0, 1.65626348131594e-14, 0, -2.85468388090362e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.01017818278146, 0, 1.31743415178767e-14, 0, 0, 0, 8.91928088068604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.8558564884489, 1.01802247187699e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.2978250586152, 0, 1.49829835452877, 5.50917601898538, 0, 0, 0, 0, 6.64803945320941, 4.13676892548488, 0, 0, 0, 0, 0, 1.7956276449824e-14, 0, 0, 12.5636136423842, -3.55352656109504, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.18752842449636e-14, 0, -1.81638809042383e-14, 1.41922064378353e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87616630392937, 0, 0, 6.22830929985768, 0, 0, 0, 0, 1.27788751430286e-14, 11.0541524195338, 0, 0, 0, 0, -1.24460589269538e-14, 0, 1.31323882635267e-14, 0, 0, 11.6057691494799, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.83186700722507, 0, -4.41087092453692, -3.11895674167863, 16.6749979177077, 0, 2.13065307820924, 0, 1.73967095350099, 1.23013312825382, 0, -4.3665394383501, 0, -0.557935943461974, -3.78153408023783, 0, -0.483186700722511, 0, -0.394520289089677, -0.278967971730981, 23.6981011897578, 0, 0.490653381462665, 0, 0.0626933893908993, 0, 0.438853725736261, 0, 0.05607467216716, 0.380058475033047, 0, 0.0485620906056402, 0, 0.0396507809422115, 0.028037336083582, 0, 0, 0, 0, 0, 0, -1.4054211872897e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.91050664139875, -2.39578864559553e-14, 0, 0, 10.5706241650195, 0, -2.72554057547698, -1.52585599320562e-14, 0, 4.67332857821918, 0, -7.8670586781146, -2.04874497115916e-14, 0, -2.39719223514613, 0, 0.618094504365256, 0, 0, 0, 23.10555488766, 0, 1.62065746295906, 0, -0.469687194424187, 0, 0.790669146636839, 0, 0, 0.240926884676761, 0, -0.0621208350291021, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00653548533975e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.85449644663772, 0, 5.98171817966648, -2.48806675764062, 1.90029237516522, 1.1743756718293e-14, -0.339934634239532, 0, -2.35922146606161, 0.981306762925312, 1.26408545402584e-14, 9.95226703056241, 0, -6.45364422706459, -0.430945803685666, 0, 0.0770899289327487, 1.15125419787792e-14, 0.535021138879238, -0.222539456105688, 0, 0, 21.5273297444417, 0, 2.75066129614998, 0, -1.00024047132728, 0, 0.648615649442923, 0.0433116829031338, 0, -0.00774782937530679, 0, -0.0537716476536673, 0.022366056877342, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.54523626091315, 0, 0, 0, 6.71778024562961, 0, -0.609449400220043, 0, 0, 0, 1.34513153299042e-14, 14.6593983227032, 0, 0, -1.52344936219872, 0, 0.138210132827979, 0, 0, 0, 0, 0, 18.119501277094, 0, 0, 0, -1.47332496632642, 0, 0, 0.153112421864225, 0, -0.0138906409944101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.52336024752225, 0, 7.37120708415866, -1.62882203585592, 0, 0, 12.0171306297064, 0, -2.90724328050878, 0.642416074439622, 0, 0, 0, 13.9858820944259, 0, -1.58432045778813e-14, -2.72522906732402, 0, 0.659300804656272, -0.145686271816947, 0, 0, 0, 0, 10.8043830863937, 0, 0, 0, -1.40563403846548, 0, 0, 0.273895826790425, 0, -0.066262224031037, 0.0146420212340151, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00201541731901e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.3084006188056, 0, -1.26706433592532e-14, 0, -1.52362350055011, 0, 11.1963004093827, -1.80488219855834e-14, 0, 4.26614580154031, 0, 0.132992762321602, 0, -2.81814707567137e-14, -4.72217953828916, 0, -6.6768459701302, 0, 0, 0, 0, 0, 0, 0, 23.1532444221696, 0, 0.721778878560592, 0, 0, 1.11125127955291, 0, 1.19087439227729, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.75883613229288e-14, 0, 0},
    {3.51865775274499, 0, 1.92724822331887, 2.72554057547696, 1.73472166622177, 0, -2.01705689521106, 0, 3.42052627529741, -4.03112887414929, 0, 4.08831086321549, 0, 0.365669640132029, 5.37643791520786, 0, -6.25148194071026, 0, -2.03981013744549, 1.80803322065276, 0, 0, 0, 0, 0, 0, 22.1880978975596, 0, 1.98456380761454, -1.26521523890981, 0, 1.4711357857929, 0, 0.363818136386341, -0.294009452979946, 0, 0, 0, 0, 0, 0, 0, -1.54553205611541e-14, 0, 1.15952481122279e-14, 0, 0, 1.43620668240546e-14, 0, 0, 0, 0, -1.05116925393268e-14, 0, 0, -1.5785116269651e-14},
    {0, 1.41060126129509, 0, 0, 0, 3.63405410063598, 0, 2.50356888118884, 0, 0, 0, 0, 3.56857028479907, 0, 0, 11.263055412878, 0, -1.49298814645068, 1.38190240500657e-14, 0, 0, 0, 0, 0, 0, 0, 0, 19.3673596462205, 0, 0, -2.65048896124153, 0, 0.266287609379577, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.60041438401192e-14, 0, 0, 0, -1.39285916740261e-14, 0, 0, 0, 0, -1.79660973598228e-14, 0, 0},
    {2.30350221379959, 0, 4.4158804331639, 1.78428514239954, 0, 0, 4.2661458015403, 0, 7.83741028656788, -2.63899331455874, 0, 0, 0, 2.23427840700301, 0, 0, 13.2221027072096, 0, -4.67379217909115, 1.18363558466232, 0, 0, 0, 0, 0, 0, 0, 0, 12.1258851598179, 0, 0, -3.11150358274815, 0, 0.833612074594106, -0.192474367616157, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18321633904026e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.80903542948782e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.14718316987778, 1.13474050017499e-14, -0.86189160737134, 6.09449400220041, 1.55158222708543, 0, 0.0693888666488805, 0, -3.0594117081557, 1.80277563773198, 1.20363012761808e-14, -1.0807889766904e-14, 0, 0, 9.03122156537878, 0, 0.403888506800973, -1.0302390341142e-14, -3.67461994579464, -5.49650682721195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21.7841260588564, -1.02507068376833e-14, 0.974215733960552, 0, 1.78974858569576, 1.8079190879493, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.26168012376113, 1.18273446592099e-14, 1.57200977122562e-14, 0, 1.42204860051343, 0, 4.47852016375308, 0, 0, 0, 1.10987276082662e-14, 0, 0, 0, 8.27725128825318, 0, 5.37909280973871, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.9654813226339, 0, -2.61992366301004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.24759447164935e-14, 0, 0},
    {2.06031501455084, -1.74209683534797e-14, 2.25696201807214, 3.98978286964829, 0, 0, 0.953939201416936, 0, 8.01142041980429, 1.18019368870418, 0, 0, 0, 0, 0, 1.94785199387925e-14, 5.55254896421454, -2.57142210914795e-14, 9.62241374388478, -3.59830837050572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13.3932520322736, 0, -4.68666192508058, 1.18356086726904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06752353778446e-14, 0, 0, -2.32785032194072e-14, 1.53466649110978e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.09264703862701, 0, -1.95067300612033e-14, 0, 0, 0, 5.38682254607084, 0, 0, 0, 0, 0, 0, -1.87552786673862e-14, 0, 0, 13.4377817958112, 0, -1.51672730138571e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18.907670401189, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.38196745713692e-14, 0, 0},
    {1.78428514239955, 0, 0.814411017927951, 5.06770487035908, 0, 0, 0, 0, 4.01510046524765, 6.58672305740272, 0, 0, 0, -1.66919444397739e-14, 0, 0, 0, 0, 10.0159311874144, 2.83293314500741, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14.0929454377398, -4.55552790213387, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.0397792145408e-14, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.45686271816937, 0, 0, 5.07816454066238, 0, 0, 0, 0, 0, 10.0142755247554, 0, 0, 1.12786864624392e-14, 0, 0, 2.17930072871246e-14, 0, 0, 0, 13.8784813613723, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.5535587278944, 0, 0, 0, 0, 0, 0, 0, 1.19526598856153e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats1[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.47722557505166, 0, 0, 1.40751126032068e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06911007824451e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.76376261582596, 0, 0, 0, 0, 1.14716615426708e-14, 0, -1.04150722074414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.09700660014256e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747793, 7.24568837309471, 4.18330013267037, -0.591607978309947, 0, 0, 0, 0, 1.56424483988496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-2.64575131106459, 0, 9.66091783079295, 0.683130051063975, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00911719995905e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 0, 0, 4.34741302385685, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.19132134712707e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.24037034920393, 0, 0, 7.52994023880671, 0, 0, 0, 0, 1.5531385856235e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00830684779644e-14, 2.81476231211997e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847576, -1.67332005306815, -1.18321595661991, 7.74596669241484, -1.2, 0.346410161513776, -0.979795897113268, 0.282842712474625, 0.200000000000004, -1.25790505365476e-14, 0, 0, 1.05528898544744e-14, 0, 0, 0, -1.12515066521072e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 9.16515138991169, 7.09929573971953, -2.04939015319193, -0.414039335605418, -0.478091443733742, 0.169030850945706, -1.25706005145317e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07716088515501e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.8, -5.69209978830307, 4.3817804600413, -0.774596669241499, 0, 10.998181667894, 4.76235235991625, 0.962140470884724, -0.740656079818034, 0.13093073414159, 0, -1.12401392033415e-14, 0, -3.21594604552363e-14, -1.31211420896762e-14, 0, 0, 0, -1.70767152060798e-14, -1.55264798414045e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2325574011616e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.03479319100648e-14, 0, 0, 0, 0, 0, 0},
    {5.19615242270665, 0, -3.16227766016841, -2.2360679774998, 0, 0, 13.7477270848675, 0, 0.534522483824853, 0.37796447300922, 0, 0, 0, -3.83748191193675e-14, 0, 0, 2.1315292421099e-14, 0, -1.62182060497289e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.68659168002595e-14, 0, 0, 0, 0, 1.40965823998977e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974982, 2.12132034355964, -0.40824829046386, 3.17542648054296, 0, 0, 0, 7.17137165600636, -1.38013111868469, -1.56144011671765, 0, 0, 0, 0, 1.60086230480545e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 2.73861278752582, 1.58113883008418, 2.4596747752498, 0, 0, 0, 9.25820099772551, 5.34522483824851, -1.20948631362952, 0, 0, 0, 0, 1.34977494398807e-14, 1.99156888319442e-14, 0, 0, -2.15636170105579e-14, 2.42856949828063e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16523470700075e-14, 0, 0, -1.09194628747146e-14, 1.11395268009851e-14},
    {-1.80000000000001, -1.20044841895264e-14, 3.6514837167011, -2.84018778721876, 0, -1.08976206329851e-14, -1.29819986860444e-14, 0, 12.3442679969674, 1.39659449751036, 0, 0, 0, 0, -1.50769312330474e-14, 1.13191919416064e-14, 1.11250942527182e-14, -1.93488728499311e-14, -2.44419195896427e-14, 1.02799713186386e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.16729566976785e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.23874183066048e-14, 0, -1.16953047556544e-14, 0},
    {1.27279220613579, 0, 0, 3.83405790253616, 0, 0, 0, 0, 1.22025515571026e-14, 5.18459255872629, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.20454076850486, 0, 0, 6.6407830863536, 0, 0, 0, 0, 2.01466364901978e-14, 8.97997772825746, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573302, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341419, -1.71651640581399, 0.594618725379066, 0.420458932936045, 9.8107084351743, -1.18450885369836, 0.305838870920594, -0.105945692672787, -1.02581475831037, 0.264864231681993, -0.09175166127617, 0.21626073957839, -0.0749149177264317, -0.0529728463363858, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403131, -2.78313372537745, -0.908295106229251, -0.524404424085076, 0.370809924354782, 11.1242977306435, 9.40174755792014, -2.42752078113806, 0.840917865872085, -0.301561193523232, -0.794200206656966, 0.350641890608823, 0.114434427054266, 0.0660687472643449, -0.0467176592151217, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747036, 3.74574588632197, -1.05945692672796, -8.09173593712688, 5.01426536422408, 1.80936716113936, -0.383824736789376, -1.10800657553489, 0.313391585263996, 0, 12.7134831207354, 8.2065180664829, -2.84282124887607, 1.01946290306866, -0.631738055305799, -0.227958835180076, 0.0483573714561715, 0.139595707137601, -0.0394836284566235, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 7.03562363973514, 4.06201920231798, -0.820651806648283, 0, -6.79705818718658, 5.88642506110458, -2.08116553882673, -1.2015614840698, 0.242752078113809, 0, 0, 14.8323969741913, 5.13809303146605, 0, 0.856348838577665, -0.741619848709558, 0.262202212042531, 0.151382517704873, -0.0305838870920523, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-3.42539535431071, 0, 9.38083151964686, 1.89521416591735, 0, 0, -3.39852909359328, 0, -2.77488738510233, -0.560611910581382, 0, 0, 0, 17.7988763690296, 0, 0, 0.4281744192888, 0, 0.34960294939005, 0.0706304617818509, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.19229891779162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172086, 2.24244764232556, 2.14087209644419, -0.331662479035536, 0.0957427107756383, 6.49923072370878, -1.87616630392937, -2.15580611373101, 0, 0, 0, 0, 9.4403585933147, -1.46249406456535, 0.422185670932515, -2.04706526287666, 0.590936840285285, 0.522319308773338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.05431025609327e-14, 0, 0},
    {1.71269767715535, 1.16057691494799, 1.34011878852097, 1.89521416591737, 2.53311402559511, 1.96214168703485, -0.56642151559888, 2.74642624930238, 3.17129986868838, -1.82198870938951, 0, 0, 0, 0, 11.1699829238239, 8.6522315682783, -2.49768411251823, -0.865042958313582, -0.998865569685885, 0.441440386136645, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.03475770530409e-14, 1.29209414685306e-14, 0, 0, 0, 0, 0, 0, 1.60120018608036e-14, 0, 0, -1.26160718303102e-14, 0},
    {1.32664991614215, -2.69693703815181, 2.07610309995255, 1.46802658041886, 0, 3.03973683071412, 1.3162446581088, -6.38211787508102, 4.91295663090393, -1.4113063856887, 0, 0, 0, -1.51913273054672e-14, -2.55599087474972e-14, 13.4039795085888, 5.80409338312195, 2.01017818278148, -1.54743588659735, 0.341938252770119, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2030832256185e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.39126707790871e-14, 1.05862461256535e-14, 0, 0, 0, 0, -1.27456553064636e-14, 0, 1.42541964027269e-14, 0, 0, -1.47910175216627e-14, 0},
    {3.82970843102536, 0, -1.49829835452879, 4.23782770691178, 0, 0, 3.79967103839267, 0, -3.54562104171168, -4.07409060843207, 0, 0, 0, 0, 0, 0, 16.7549743857359, 0, 1.11676565710082, 0.987090711415275, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.21705165839016e-14, 0, 0, 0, 0, 0, -1.21257170970779e-14},
    {1.48323969741913, 1.00508909139073, -0.193429485824663, 3.55615782880927, 0, 0, 0, 4.45964044034302, -0.858258202906985, 2.67027285925187, 0, 0, 0, 0, 0, 0, 0, 8.42792824422443, -1.62195554683794, -2.29379153190447, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.14891252930761, 1.29756443747035, 0.749149177264386, 2.75458800949269, 0, 0, 0, 5.75737105184054, 3.3240197266047, 2.06838446274244, 0, 0, 0, 0, 0, 1.63535268777982e-14, 0, 10.8804085776374, 6.28180682119208, -1.77676328054753, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.10314190327717e-14, 0, 0, 0},
    {-1.32664991614216, -1.36618976334274e-14, 1.73008591662712, -3.18072425757423, 0, 0, 0, 0, 7.67649473578737, -2.38836465270395, 0, 0, 0, 0, 0, 1.75825778552664e-14, -1.61250752397677e-14, -2.1076052013037e-14, 14.5072114368499, 2.05162951662072, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.938083151964686, 0, 0, 3.11415464992885, 0, 0, 0, 0, 0, 5.52707620976691, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62480768092719, 0, 0, 5.39387407630363, 0, 0, 0, 0, 1.11162283755055e-14, 9.57317681262151, 0, 0, 0, 0, -1.0778909817559e-14, 0, 1.14540099911627e-14, 0, 0, 10.0508909139073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993662, 0.86983547675049, 0.615066564126915, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.278967971730982, -1.89076704011892, 0.627677936394719, -0.241593350361255, 0.512496888990065, -0.197260144544833, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954525, -1.03851746182648, 0.219426862868131, -0.0728431359084663, 0.0280373360835797, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711053, 0.0140186680417948, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725405, 3.45525332069938, 0.997445717412069, -1.41060126129511, 3.23209352764251, 5.28531208250978, -2.8908723349783, -1.3627702877385, -0.393397896234731, 0.556348640264194, 2.3366642891096, 9.0278480722887, -3.93352933905729, 1.64018416088946, -0.732969916135167, -1.19859611757306, 0.655588223176202, 0.309047252182634, 0.0892142571199805, -0.12616801237611, 13.0996183150502, 11.55277744383, -2.44096975264614, 0.810328731479527, -0.311895674167858, -0.234843597212094, -0.907332870306511, 0.39533457331842, -0.16484471056831, 0.0736662483163195, 0.120463442338379, -0.0658890955530703, -0.0310604175145504, -0.00896637020658568, 0.0126803623514093, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066012, 2.99085908983323, -1.24403337882031, 0.950146187582609, 5.74064456311311, -0.169967317119758, -0.721110255092799, -1.17961073303081, 0.490653381462658, -10.3037210107158, 4.9761335152812, 5.78174466995658, -3.2268221135323, -0.215472901842833, -1.3018558182182, 0.0385449644663712, 0.163532434528623, 0.267510569439619, -0.111269728052842, 0, 14.555131461167, 10.7636648722209, -3.5732138395088, 1.37533064807499, 1.03556292536503, -0.500120235663637, -0.581087203147972, 0.324307824721462, 0.0216558414515678, 0.13084143273245, -0.0038739146876535, -0.0164356280722662, -0.0268858238268361, 0.011183028438671, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585591, 0.772618130456579, 3.86595114186566, -1.05140010313427, 9.1544290607646, 3.35889012281481, 3.878512233171, -0.304724700110019, -1.52475169285616, 0.414677792940096, 0, -9.46260092820841, 7.32969916135161, 0.564240504518017, -2.07602937339135, -0.761724681099362, -0.879563899362184, 0.0691050664139924, 0.345781182036189, -0.0940400840863445, 0, 0, 16.3745228938128, 9.05975063854702, -3.48709964663734, 0, 0.951027176355638, -0.736662483163211, -0.0567083043941542, 0.208648802584722, 0.0765562109321131, 0.0883994979795834, -0.006945320497205, -0.0347523163751387, 0.00945138406569424, 0, 0, 0, 0, 0, -1.0442355414814e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, -6.78263087840204, 3.68560354207932, -0.814411017927972, 0, 10.0216907612581, 6.00856531485321, 2.67510569439611, -1.45362164025439, 0.321208037219812, 0, 0, -7.5700807425667, 6.99294104721295, 0, -2.27270584034422, -1.36261453366201, -0.60665694841583, 0.329650402328123, -0.0728431359084861, 0, 0, 0, 18.7137404500718, 5.40219154319687, 0, 0, 0.760821741084505, -0.702817019232738, 0, 0.228415531250637, 0.136947913395213, 0.0609713174047677, -0.0331311120155155, 0.00732101061700594, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.13362172336404e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.09901951359279, 0, -4.65474668125631, -3.2914029430219, 0, 1.1660466779942e-14, 13.490737563232, 0, 1.83585684909537, 1.29814682728311, 0, 0, 0, -3.53270434653113, 0, -2.35369542990423e-14, -3.05941170815564, 0, -0.416333199893202, -0.294392028877585, 0, 0, 0, 0, 21.8326971917504, 0, 0, 0, 0.355050145839434, 0, 0, 0.307482445914322, 0, 0.0418430609640539, 0.0295875121532883, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.51979983923137e-14, 1.31936453578951e-14, 0, 0, 0, 1.03690494372784e-14, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.1542003094028, -1.09264703862703, 1.54523626091313, 2.95048422176041, -0.76181175027506, 0.263899331455881, 5.59815020469135, -1.93925611658552, -2.28543525082516, 2.13307290077015, -0.257539376818861, 0.0664963811608048, -0.0230350221379904, 9.14446135479764, -2.36108976914457, 0.817905488277896, -3.3384229850651, 1.1564636454577, 1.02505848514081, 0, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280294, -0.125015768949701, -2.15192884958005, 0.555625639776455, -0.192474367616153, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07577610922145e-14, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659431, 1.36277028773846, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871973, 1.7102631376487, -2.01556443707465, 2.41867732448956, 2.04415543160775, -0.527798662911745, 0.182834820066009, 2.68821895760391, 7.07977053255618, -3.12574097035514, -1.76652739792483, -1.01990506872274, 0.904016610326372, 0, 0, 0, 0, 0, 13.1266557397187, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454906, -1.66605356688628, 0.735567892896448, 0.315075748468082, 0.181909068193171, -0.147004726489972, 0, 0, 0, 0, 0, 0, 0, -1.19843614648072e-14, 0, 1.70149229231864e-14, 0, 0, 1.13549801043889e-14, 0, 0, 0, 0, 0, -1.36131053899298e-14, 0, -1.03720200830826e-14},
    {1.48690428533295, 0.705300630647538, 2.0360275448199, 1.15175110689976, -2.93221479395416, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967313, 0, 2.76420265655951, 1.78428514239953, -0.618094504365259, -9.08783875864328, 5.631527706439, 2.03210252328835, -0.746494073225345, -2.15494277062552, 0.764033484562584, 0, 0, 0, 0, 0, 0, 15.0018922739643, 9.68367982311023, -3.3545250915713, 2.13860408462396, -1.32524448062077, -0.478206411017798, 0.133143804689786, 0.384353057392894, -0.124241670058205, 0, 0, 0, 0, 0, 0, 0, -1.06952639252695e-14, 0, 1.24523903365769e-14, 0, 0, 1.13816587687308e-14, -1.06362575304491e-14, 0, 1.13288756971e-14, 0, -1.21696875531858e-14, -1.03472165536955e-14, 0, -1.2600380808192e-14},
    {1.15175110689979, 3.82426463519456, 2.20794021658195, 0.892142571199782, 0, -2.46306042692148, 2.13307290077015, 6.78739640804928, 3.91870514328393, -1.31949665727936, 0, 0, 3.22490309931941, 1.11713920350152, 1.32014938580353e-14, -7.63378455726037, 6.61105135360481, -4.04762275910198, -2.33689608954557, 0.591817792331178, 0, 0, 0, 0, 0, 0, 0, 17.5022076529583, 6.06294257990892, 0, 1.79642743108413, -1.55575179137408, 0.721929233499942, 0.416806037297049, -0.096237183808073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.27043515283634e-14, 0, 0},
    {-2.65985524643219, 1.31595766643121e-14, 5.09901951359278, -2.06031501455086, 0, 1.2454667647061e-14, -1.23153021346074, 0, 9.04986187739902, 3.04724700110024, 0, 0, 0, 3.8698837191833, 1.50559796220762e-14, -1.82444885045587e-14, -3.81689227863021, 2.48972418334491e-14, -5.39683034546926, -1.36674464685442, 0, 0, 0, 0, 1.11023026702718e-14, 0, 0, 0, 21.00264918355, 0, 0, 0.898213715542071, 0, 0.962572311333264, 0.222250255910579, 0, 0, 0, 0, 0, 0, 0, 0, 1.30048635444922e-14, 0, -2.8168247578276e-14, 0, 0, 0, 0, 0, -1.22574722556207e-14, 0, 0, 0, 0},
    {1.57359158493889, 1.49284005458437, -0.430945803685673, 3.04724700110021, 0.775791113542717, -0.120185042515475, 0.0346944333244397, 5.29905651979671, -1.52970585407785, 0.901387818865986, 0, 0, 0, 0, 4.51561078268939, -0.699555414372413, 0.201944253400488, 6.36462844462229, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980277, -3.09993548319961, 0.894874292847881, 0.903959543974646, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880569, 0.728431359084677, 2.57539376818856, 0.917928424547677, 0.71102430025671, -0.205255035576791, 2.23926008187654, 2.58567482211399, 0.761811750275056, 0, 0, 0, 0, 5.34294273196306, 4.13862564412661, -1.19471831485579, 2.68954640486934, 3.1056206816986, -2.32269806558124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.8876627769294, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.76398525469263, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, -1.46593983227033, 1.12848100903608, 1.99489143482414, 0, 1.10151410945722, 0.476969600708474, -5.20357020296093, 4.00571020990214, 0.590096844352093, 0, 0, 0, 0, -1.06679106813357e-14, 6.4115312783557, 2.77627448210726, -6.24994106094659, 4.81120687194238, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.4651953323153, 6.69662601613678, 3.0440762145518, -2.34333096254029, 0.591780433634522, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.29095028749876e-14, 0},
    {2.97380857066591, 0, -0.814411017927952, 5.75875553449896, 0, 0, 1.37689263682153, 0, -2.89087233497831, 1.70346285967311, 0, 0, 0, 0, 0, 0, 8.01441409794461, 0, -3.47218947830365, -5.19371076584693, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.3314941653941, 0, 1.69115345252877, 1.70832296330021, 0, 0, 0, 0, 0, 0, 0, 0, 1.01698699146052e-14, 0, 0, 0, 0, 0, 1.04634390793553e-14, 0, 0, -1.24951195166655e-14, 0, 0, 0},
    {1.15175110689979, 0.546323519313506, -0.105140010313426, 3.27118942773248, 0, 0, 0, 2.69341127303542, -0.518347241175112, 4.25171145123352, 0, 0, 0, 0, -1.50547813101981e-14, 0, 0, 6.71889089790563, -1.29305115618718, 1.82865048192211, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635795, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199775, 0.705300630647549, 0.407205508963978, 2.53385243517953, 0, 0, 0, 3.47717900165117, 2.00755023262382, 3.29336152870136, 0, 0, 0, 0, 0, 0, 0, 8.6740508508577, 5.0079655937072, 1.41646657250369, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.2048487632307, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.09128807146668e-14, 0, 0, 0, 0, 0, 0, 0},
    {-1.03015750727542, 0, 0.940400840863396, -2.92584077107542, 0, 0, 0, 0, 4.6362386688682, -3.80284633026898, 0, 0, 0, 0, 1.68691976659293e-14, 0, -1.57365387853084e-14, 0, 11.5654011344769, -1.63559471386627, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.2731316843076, 2.63013526059784, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.15424097657397e-14, 0, 0, -1.09417683247237e-14},
    {0.728431359084685, 0, 0, 2.53908227033119, 0, 0, 0, 0, 0, 5.00713776237767, 0, 0, 0, 0, 0, 1.10587002885661e-14, 0, 0, 0, 6.93924068068616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6.2767793639472, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376112, 0, 0, 4.39781949681095, 0, 0, 0, 0, 0, 8.67261700493487, 0, 0, 0, 0, 0, 1.88729435175678e-14, 0, 0, 0, 12.0191174248973, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8717007662564, 0, 0, 0, 0, 0, 0, 0, 1.03515041106796e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats2[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.82574185835055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.16397779494323, 0, 0, 1.29984998459287e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00622635224035e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.763762615825961, 0, 0, 0, 0, 0, 0, -1.12787476580434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.00211722600663e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747792, 1.44913767461894, 4.18330013267037, -0.591607978309952, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00245830515541e-14, 0, 0, 0, 0, -1.10514927319296e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.3228756555323, 0, 3.86436713231717, -0.341565025531983, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 7.09929573971953, 0, 4.34741302385685, 0, 1.16116958235673e-14, 0, 0, 1.97703621279534e-14, 0, 0, 0, 0, 0, 1.19025197250128e-14, 0, 0, 0, 0, 1.15385132004597e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.08012344973465, 0, 7.09929573971953, 2.50998007960224, 0, 0, 0, 0, 1.2984107062089e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.21524148795069e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18401735111452e-14, 0},
    {-3.81881307912987, 0, 1.20295604068146e-14, 8.87411967464943, 0, 1.13142405616155e-14, 0, 0, 0, 0, 0, 0, 0, 1.25032789779226e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847577, -1.67332005306815, -1.18321595661992, 7.74596669241485, -1.2, 0.346410161513777, -0.979795897113271, 0.282842712474625, 0.200000000000004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 1.30930734141596, 7.09929573971954, -2.04939015319192, -0.41403933560542, -0.47809144373374, 0.169030850945707, 0, 0, 0, -1.01115137587522e-14, 0, 0, -1.19390261962029e-14, 0, -1.01768611746272e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.80000000000001, 0.632455532033679, 4.38178046004131, -0.77459666924148, 0, 3.14233761939829, 4.76235235991626, -0.106904496764969, -0.740656079818034, 0.130930734141593, 0, 0, 0, -1.8947471087206e-14, 0, 0, 1.24782077916574e-14, 0, -1.57210017045496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03923048454133, 0, 3.16227766016837, -0.447213595499959, 0, 0, 5.89188303637179, 0, -0.534522483824846, 0.0755928946018422, 0, 0, 0, -1.32102604647237e-14, 0, 0, 1.28087199916397e-14, 0, -1.09806075799093e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974981, 2.12132034355963, -0.408248290463856, 3.17542648054296, 9.07114735222146, 0, 0, 7.17137165600636, -1.3801311186847, -1.56144011671765, 0, 0, 0, 1.05914511754833e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 0.547722557505163, 1.58113883008417, 2.45967477524979, 0, 9.07114735222145, 0, 1.85164019954509, 5.34522483824851, -1.20948631362952, 0, 0, 0, -1.11256081632663e-14, 0, 0, 0, 0, -2.1484687092401e-14, 1.51441359452775e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.03593488692865e-14, 0, -1.10855626475394e-14, 0},
    {0.900000000000005, 0, 1.46059348668043, 1.4200938936094, 0, 0, 9.07114735222145, 0, 4.93770719878695, -0.698297248755175, 0, 0, 0, 0, 0, 0, 2.13673764691668e-14, 0, -1.74964245430402e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07342779687771e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.27279220613579, -6.2609903369994, 0, 3.83405790253616, 0, -1.49065575463019e-14, 0, 10.5830052442584, 0, 5.18459255872628, 0, 0, 0, 0, 0, 1.30274753827373e-14, 0, 1.32206973351868e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.734846922834947, -1.04202290943615e-14, -6.26099033699941, 2.21359436211788, 0, 0, 0, 0, 10.5830052442584, 2.99332590941916, 0, 0, 0, 0, 0, 0, 0, 0, -1.10071029919877e-14, 1.58024635044107e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.71576766497729, 0, 0, -4.69574275274958, 0, -1.13946705425176e-14, 0, 0, 1.07947992678322e-14, 12.69960629311, 0, 0, 0, -2.12576157138471e-14, -1.14768107589579e-14, 0, 0, 0, 0, -1.45786160921091e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.11099168517849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16464450008484e-14, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573303, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341418, -1.71651640581399, 0.594618725379066, 0.420458932936047, 9.81070843517429, -1.18450885369836, 0.305838870920593, -0.105945692672788, -1.02581475831037, 0.264864231681991, -0.0917516612761725, 0.216260739578389, -0.0749149177264338, -0.0529728463363881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403132, -2.78313372537745, -0.908295106229256, -0.524404424085065, 0.370809924354784, 1.23603308118261, 9.40174755792014, -2.42752078113806, 0.840917865872082, -0.301561193523232, -0.794200206656965, 0.350641890608817, 0.114434427054266, 0.0660687472643408, -0.0467176592151232, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.09687112732375e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747035, 3.74574588632197, -1.05945692672795, 0.404586796856342, 5.01426536422407, 1.80936716113936, -0.38382473678937, -1.10800657553489, 0.313391585264001, 0, 2.82521847127454, 8.2065180664829, -2.84282124887607, -0.0509731451534336, -0.631738055305794, -0.227958835180071, 0.0483573714561653, 0.139595707137598, -0.0394836284566152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 0.335029697130247, 4.06201920231797, -0.820651806648293, 0, 1.69926454679664, 5.88642506110457, -0.0991031208965088, -1.20156148406979, 0.242752078113803, 0, 0, 4.94413232473044, 5.13809303146604, 0, -0.214087209644424, -0.741619848709556, 0.0124858196210727, 0.151382517704866, -0.030583887092065, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.856348838577677, 0, 2.68023757704196, -0.473803541479351, 0, 0, 5.09779364038993, 0, -0.792824967172094, 0.140152977645347, 0, 0, 0, 7.9106117195687, 0, 0, -0.642261628933262, 0, 0.0998865569685846, -0.0176576154454718, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172091, 2.24244764232556, 2.14087209644418, -0.331662479035544, 0.0957427107756388, 6.49923072370878, -1.87616630392938, -2.15580611373101, 11.0554159678513, 0, 0, 0, 9.44035859331469, -1.46249406456535, 0.42218567093252, -2.04706526287666, 0.590936840285289, 0.522319308773339, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.71269767715534, 1.160576914948, 1.34011878852098, 1.89521416591738, 0.361873432227874, 1.96214168703486, -0.566421515598884, 2.74642624930237, 3.17129986868839, -1.82198870938951, 0, 11.0554159678513, 0, 0, 1.59571184626056, 8.6522315682783, -2.49768411251823, -0.865042958313566, -0.99886556968588, 0.441440386136656, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.67261791825198e-14, 0, 0, 0, 0, 0, 0, 1.30794708089814e-14, 0, 0, -1.0374605283645e-14, 0},
    {1.32664991614216, 0.29965967090575, 2.07610309995255, 1.46802658041888, 0, 0.868496237346876, 1.31624465810881, 0.709124208342335, 4.91295663090393, -1.4113063856887, 0, 0, 11.0554159678513, 0, 0, 3.82970843102537, 5.80409338312195, -0.223353131420173, -1.54743588659735, 0.341938252770127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.50077495359425e-14, 0},
    {0.765941686205065, 0, 1.49829835452878, 0.84756554138235, 0, 0, 1.62843044502543, 0, 3.54562104171167, -0.81481812168641, 0, 0, -1.13658139175294e-14, 11.0554159678513, 0, 0, 7.18070330817253, 0, -1.11676565710083, 0.197418142283055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 1.00508909139074, -0.193429485824671, 3.55615782880925, -8.46157280212813, 0, 0, 4.45964044034302, -0.85825820290699, 2.67027285925187, 0, 0, 0, -1.0471287355653e-14, 12.4373429638327, 0, 0, 8.42792824422442, -1.62195554683794, -2.29379153190449, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.1489125293076, 0.259512887494065, 0.749149177264405, 2.75458800949269, 0, -8.46157280212812, 0, 1.15147421036811, 3.3240197266047, 2.06838446274243, 0, 1.28739579884012e-14, 0, 1.43483072465507e-14, 0, 12.4373429638328, 0, 2.17608171552748, 6.28180682119208, -1.77676328054752, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.1069077748037e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.66332495807107, 0, 0.692034366650861, 1.5903621287871, 0, 0, -8.46157280212812, 0, 3.07059789431495, 1.19418232635199, 0, 0, 0, 1.58467639420295e-14, 0, 1.59120238800483e-14, 12.4373429638327, -1.09120262064712e-14, 5.80288457473997, -1.02581475831036, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.17878507096849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.93808315196469, 7.62808987244124, 0, 3.11415464992885, 0, 0, 0, -7.5213980463361, 0, 5.52707620976692, -1.06609684736951e-14, 0, 0, 0, -1.38639078823126e-14, 0, 1.48563198377856e-14, 14.2141062443803, 1.67911998216622e-14, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.541602560309069, 0, 7.62808987244124, 1.79795802543454, 0, 0, 0, 0, -7.5213980463361, 3.19105893754051, 0, 0, 0, 0, 0, 0, 0, 0, 14.2141062443803, 3.35029697130244, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-5.3615918034355, 0, 0, 8.89943818451481, 0, 0, 0, 0, 0, -5.26497863243528, 0, 0, 0, 1.27752977123219e-14, 0, 0, 0, -1.16097894474412e-14, 1.10230978840132e-14, 16.583123951777, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993663, 0.86983547675049, 0.615066564126914, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.27896797173098, -1.89076704011892, 0.627677936394719, -0.241593350361254, 0.512496888990065, -0.197260144544832, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954516, -1.03851746182648, 0.219426862868131, -0.0728431359084662, 0.0280373360835794, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711051, 0.0140186680417946, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725404, 3.45525332069938, 0.997445717412055, -1.41060126129511, 3.23209352764251, 5.28531208250977, -2.8908723349783, -1.3627702877385, -0.393397896234727, 0.556348640264192, 2.33666428910959, 9.02784807228868, -3.93352933905729, 1.64018416088945, -0.732969916135173, -1.19859611757306, 0.655588223176204, 0.309047252182629, 0.0892142571199751, -0.126168012376112, 1.19087439227729, 11.55277744383, -2.44096975264613, 0.810328731479525, -0.311895674167859, -0.234843597212091, -0.907332870306511, 0.395334573318418, -0.164844710568308, 0.0736662483163234, 0.120463442338379, -0.0658890955530668, -0.0310604175145528, -0.00896637020658492, 0.012680362351411, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.04376434543615e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066013, 2.99085908983323, -1.24403337882031, 0.950146187582614, 5.74064456311311, -0.169967317119763, -0.721110255092803, -1.1796107330308, 0.490653381462655, 0.294392028877601, 4.97613351528119, 5.78174466995657, -3.2268221135323, -0.215472901842835, -1.3018558182182, 0.0385449644663701, 0.16353243452863, 0.267510569439621, -0.111269728052844, 0, 2.64638753839399, 10.7636648722209, -3.5732138395088, 1.37533064807499, -0.0295875121532872, -0.500120235663636, -0.581087203147972, 0.324307824721462, 0.0216558414515659, 0.130841432732449, -0.00387391468765372, -0.0164356280722662, -0.0268858238268349, 0.0111830284386701, 0, 0, 0, 0, -1.28026114151189e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585592, 0.772618130456574, 3.86595114186566, -1.05140010313427, 0.160604018609906, 3.35889012281481, 3.878512233171, -0.30472470011002, -1.52475169285616, 0.414677792940093, 0, 1.13551211138501, 7.32969916135161, 0.564240504518021, -0.0364215679542351, -0.761724681099363, -0.879563899362178, 0.0691050664139924, 0.345781182036181, -0.094040084086348, 0, 0, 4.46577897103986, 9.05975063854702, -3.48709964663735, 0, -0.114123261162678, -0.736662483163213, -0.0567083043941508, 0.00366050530850509, 0.076556210932112, 0.0883994979795821, -0.00694532049720509, -0.0347523163751398, 0.00945138406569354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, 0.199489143482414, 3.68560354207933, -0.814411017927961, 0, 1.0278657191034, 6.00856531485322, -0.0786795792469394, -1.45362164025439, 0.321208037219813, 0, 0, 3.02803229702669, 6.99294104721296, 0, -0.23309803490711, -1.36261453366201, 0.0178428514239989, 0.329650402328134, -0.072843135908474, 0, 0, 0, 6.80499652729884, 5.40219154319687, 0, 0, -0.304328696433804, -0.70281701923274, 0, 0.0234272339744255, 0.136947913395213, -0.00179327404131462, -0.0331311120155176, 0.00732101061700848, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.728431359084683, 0, 2.32737334062817, -0.470200420431708, 0, 0, 4.49691252107735, 0, -0.917928424547684, 0.185449546754732, 0, 0, 0, 7.06540869306229, 0, -1.02749514743743e-14, -1.01980390271856, 0, 0.208166599946621, -0.0420560041253766, 0, 0, 0, 0, 9.92395326897747, 0, 0, 0, -0.710100291678883, 0, 0, 0.102494148638111, 0, -0.0209215304820291, 0.00422678745046967, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.15420030940281, -1.09264703862702, 1.54523626091312, 2.95048422176041, -0.761811750275057, 0.263899331455879, 5.59815020469135, -1.93925611658552, -2.28543525082517, 2.13307290077016, -0.257539376818857, 0.0664963811608075, -0.0230350221379865, 9.14446135479764, -2.36108976914457, 0.817905488277892, -3.3384229850651, 1.1564636454577, 1.02505848514081, 13.0453753561106, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280297, -0.125015768949703, -2.15192884958005, 0.555625639776455, -0.192474367616155, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659433, 1.36277028773847, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871972, 1.7102631376487, -2.01556443707464, 0.268741924943282, 2.04415543160775, -0.527798662911754, 0.182834820066007, 2.68821895760393, 7.07977053255618, -3.12574097035514, -1.76652739792482, -1.01990506872274, 0.904016610326381, 0, 13.0453753561106, 0, 0, 0, 1.4585173044132, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454905, -1.66605356688628, 0.735567892896452, 0.315075748468088, 0.181909068193171, -0.14700472648997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.76253856517652e-14, 0, 0, 0, 0, 0, 0, 0, -1.02644438987504e-14, 0, 0, 0},
    {1.48690428533294, 0.705300630647549, 2.0360275448199, 1.15175110689978, 0.146610739697706, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967312, 1.19461378362765e-14, 0.614267257013224, 1.78428514239954, -0.61809450436525, 0.454391937932155, 5.631527706439, 2.03210252328835, -0.746494073225347, -2.1549427706255, 0.764033484562606, 0, 0, 13.0453753561106, 0, 0, 0, 3.33375383865873, 9.68367982311023, -3.3545250915713, -0.1069302042312, -1.32524448062077, -0.47820641101779, 0.133143804689788, 0.384353057392899, -0.124241670058195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.33133676896015e-14, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.182107839771165, 2.20794021658195, 0.892142571199765, 0, 0.615765106730381, 2.13307290077015, 0.323209352764259, 3.91870514328393, -1.31949665727937, 0, 0, 1.07496769977315, 1.11713920350151, 0, 1.90844613931509, 6.61105135360481, -0.192743940909622, -2.33689608954558, 0.591817792331162, 0, 0, 0, 13.0453753561106, 0, 0, 0, 5.83406921765277, 6.06294257990893, 0, -0.449106857771032, -1.55575179137408, 0.0343775825476156, 0.416806037297052, -0.0962371838080755, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.664963811608044, 0, 1.45686271816936, 0.515078753637704, 0, 0, 1.84729532019112, 0, 2.58567482211401, -0.761811750275049, 0, 0, 0, 1.71994831963702, 1.05069828708852e-14, -1.56804141189904e-14, 5.72533841794525, 1.28292660358282e-14, -1.54195152727692, 0.341686161713602, 0, 0, 0, 0, 13.0453753561106, 0, 0, 0, 9.33451074824443, 0, 0, -1.34732057331309, 0, 0.275020660380932, -0.0555625639776445, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.3208801604271e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.57359158493888, 1.49284005458436, -0.430945803685674, 3.04724700110019, 0.775791113542713, -0.120185042515468, 0.0346944333244412, 5.29905651979672, -1.52970585407786, 0.901387818865991, -10.576283741361, 0, 0, 0, 4.51561078268937, -0.699555414372417, 0.20194425340049, 6.36462844462228, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980274, -3.09993548319962, 0.894874292847881, 0.903959543974651, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880566, 0.72843135908468, 2.57539376818856, 0.131132632078236, 0.71102430025671, -0.205255035576782, 2.23926008187654, 2.585674822114, 0.761811750275049, 0, -10.576283741361, 0, 0, 0.763277533137571, 4.1386256441266, -1.19471831485579, 2.68954640486935, 3.1056206816986, -2.32269806558126, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 1.84109468241848, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.763985254692621, 0, 0, 0, 0, 0, 0, 0, 0, -1.35629152642122e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, 0.162882203585585, 1.12848100903607, 1.99489143482414, 0, 0.31471831698778, 0.476969600708467, 0.578174466995659, 4.00571020990214, 0.590096844352089, 0, 0, -10.576283741361, 0, -1.14841985676491e-14, 1.83186607953021, 2.77627448210727, 0.694437895660718, 4.8112068719424, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 4.41862723780437, 6.69662601613678, -0.338230690505757, -2.34333096254029, 0.591780433634517, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.594761714133188, 0, 0.814411017927947, 1.1517511068998, 0, 1.39874122938874e-14, 0.590096844352078, 0, 2.89087233497829, 0.340692571934624, 0, 0, 1.04169365895487e-14, -10.576283741361, 0, 0, 3.43474889911913, 0, 3.47218947830366, -1.03874215316938, 0, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 8.28492607088319, 0, -1.69115345252878, 0.341664592660038, 0, 0, 0, 0, 0, 0, 0, 0, 1.04348006604658e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.546323519313508, -0.105140010313428, 3.27118942773248, 9.65295620481433, 0, 0, 2.69341127303542, -0.51834724117513, 4.25171145123353, 0, 0, 0, 0, -9.91526600752599, 0, 0, 6.71889089790562, -1.29305115618718, 1.82865048192213, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635794, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199779, 0.141060126129514, 0.407205508963965, 2.53385243517954, 0, 9.65295620481433, 0, 0.695435800330239, 2.00755023262382, 3.29336152870136, 0, 0, 0, -1.35671976966506e-14, 0, -9.91526600752598, 0, 1.73481017017155, 5.00796559370719, 1.4164665725037, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 2.44096975264614, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.515078753637729, 0, 0.376160336345341, 1.46292038553772, 0, 0, 9.65295620481433, 0, 1.85449546754728, 1.90142316513449, 0, 0, 0, -2.50850100800641e-14, 0, -1.15008035787034e-14, -9.91526600752594, 0, 4.62616045379078, 0.817797356933146, 0, 0, 0, 0, -1.24919104274206e-14, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 6.50925267372303, -1.31506763029891, 0, 0, 0, 0, 0, -1.31906496265821e-14, 0, 0, 1.19318131197878e-14, -1.10848897873181e-14, 1.67436700563434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.72843135908468, -7.94708263760856, 0, 2.53908227033116, 0, 0, 0, 10.2207771580387, 0, 5.00713776237768, 0, 0, 1.91058434396028e-14, 0, -1.58541378910724e-14, 1.90136980421293e-14, -1.88766397254795e-14, -8.49879943502228, -1.97928218732183e-14, 6.93924068068615, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 0, 6.27677936394721, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47602702235557e-14, 0, 0},
    {0.420560041253711, 0, -7.94708263760856, 1.46593983227032, 0, 0, 0, 0, 10.2207771580387, 2.89087233497828, 0, 0, 0, -1.08180349039434e-14, 1.10015960051229e-14, 0, 1.60406067004907e-14, 0, -8.49879943502225, 4.00637247496576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 3.62390025541881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00860104949949e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.542378855465, 1.44235171923932e-14, 0, -6.91050664139876, 0, 0, 0, 0, -1.41976691442264e-14, 12.2649325896464, 0, 0, 1.30312779804118e-14, 0, 0, 2.24879933982623e-14, 0, 1.64486782168017e-14, -1.79783245387702e-14, -5.66586629001484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20.4998755596024, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16147208367439e-14, 0, 0, 0, 0, 0, 0, 1.28659042607863e-14, 0, 0, 0, 0}};
    
    // Compute reference derivatives
    // Declare pointer to array of derivatives on FIAT element
    double *derivatives = new double [num_derivatives];
    
    // Declare coefficients
    double coeff0_0 = 0;
    double coeff0_1 = 0;
    double coeff0_2 = 0;
    double coeff0_3 = 0;
    double coeff0_4 = 0;
    double coeff0_5 = 0;
    double coeff0_6 = 0;
    double coeff0_7 = 0;
    double coeff0_8 = 0;
    double coeff0_9 = 0;
    double coeff0_10 = 0;
    double coeff0_11 = 0;
    double coeff0_12 = 0;
    double coeff0_13 = 0;
    double coeff0_14 = 0;
    double coeff0_15 = 0;
    double coeff0_16 = 0;
    double coeff0_17 = 0;
    double coeff0_18 = 0;
    double coeff0_19 = 0;
    double coeff0_20 = 0;
    double coeff0_21 = 0;
    double coeff0_22 = 0;
    double coeff0_23 = 0;
    double coeff0_24 = 0;
    double coeff0_25 = 0;
    double coeff0_26 = 0;
    double coeff0_27 = 0;
    double coeff0_28 = 0;
    double coeff0_29 = 0;
    double coeff0_30 = 0;
    double coeff0_31 = 0;
    double coeff0_32 = 0;
    double coeff0_33 = 0;
    double coeff0_34 = 0;
    double coeff0_35 = 0;
    double coeff0_36 = 0;
    double coeff0_37 = 0;
    double coeff0_38 = 0;
    double coeff0_39 = 0;
    double coeff0_40 = 0;
    double coeff0_41 = 0;
    double coeff0_42 = 0;
    double coeff0_43 = 0;
    double coeff0_44 = 0;
    double coeff0_45 = 0;
    double coeff0_46 = 0;
    double coeff0_47 = 0;
    double coeff0_48 = 0;
    double coeff0_49 = 0;
    double coeff0_50 = 0;
    double coeff0_51 = 0;
    double coeff0_52 = 0;
    double coeff0_53 = 0;
    double coeff0_54 = 0;
    double coeff0_55 = 0;
    
    // Declare new coefficients
    double new_coeff0_0 = 0;
    double new_coeff0_1 = 0;
    double new_coeff0_2 = 0;
    double new_coeff0_3 = 0;
    double new_coeff0_4 = 0;
    double new_coeff0_5 = 0;
    double new_coeff0_6 = 0;
    double new_coeff0_7 = 0;
    double new_coeff0_8 = 0;
    double new_coeff0_9 = 0;
    double new_coeff0_10 = 0;
    double new_coeff0_11 = 0;
    double new_coeff0_12 = 0;
    double new_coeff0_13 = 0;
    double new_coeff0_14 = 0;
    double new_coeff0_15 = 0;
    double new_coeff0_16 = 0;
    double new_coeff0_17 = 0;
    double new_coeff0_18 = 0;
    double new_coeff0_19 = 0;
    double new_coeff0_20 = 0;
    double new_coeff0_21 = 0;
    double new_coeff0_22 = 0;
    double new_coeff0_23 = 0;
    double new_coeff0_24 = 0;
    double new_coeff0_25 = 0;
    double new_coeff0_26 = 0;
    double new_coeff0_27 = 0;
    double new_coeff0_28 = 0;
    double new_coeff0_29 = 0;
    double new_coeff0_30 = 0;
    double new_coeff0_31 = 0;
    double new_coeff0_32 = 0;
    double new_coeff0_33 = 0;
    double new_coeff0_34 = 0;
    double new_coeff0_35 = 0;
    double new_coeff0_36 = 0;
    double new_coeff0_37 = 0;
    double new_coeff0_38 = 0;
    double new_coeff0_39 = 0;
    double new_coeff0_40 = 0;
    double new_coeff0_41 = 0;
    double new_coeff0_42 = 0;
    double new_coeff0_43 = 0;
    double new_coeff0_44 = 0;
    double new_coeff0_45 = 0;
    double new_coeff0_46 = 0;
    double new_coeff0_47 = 0;
    double new_coeff0_48 = 0;
    double new_coeff0_49 = 0;
    double new_coeff0_50 = 0;
    double new_coeff0_51 = 0;
    double new_coeff0_52 = 0;
    double new_coeff0_53 = 0;
    double new_coeff0_54 = 0;
    double new_coeff0_55 = 0;
    
    // Loop possible derivatives
    for (unsigned int deriv_num = 0; deriv_num < num_derivatives; deriv_num++)
    {
      // Get values from coefficients array
      new_coeff0_0 = coefficients0[dof][0];
      new_coeff0_1 = coefficients0[dof][1];
      new_coeff0_2 = coefficients0[dof][2];
      new_coeff0_3 = coefficients0[dof][3];
      new_coeff0_4 = coefficients0[dof][4];
      new_coeff0_5 = coefficients0[dof][5];
      new_coeff0_6 = coefficients0[dof][6];
      new_coeff0_7 = coefficients0[dof][7];
      new_coeff0_8 = coefficients0[dof][8];
      new_coeff0_9 = coefficients0[dof][9];
      new_coeff0_10 = coefficients0[dof][10];
      new_coeff0_11 = coefficients0[dof][11];
      new_coeff0_12 = coefficients0[dof][12];
      new_coeff0_13 = coefficients0[dof][13];
      new_coeff0_14 = coefficients0[dof][14];
      new_coeff0_15 = coefficients0[dof][15];
      new_coeff0_16 = coefficients0[dof][16];
      new_coeff0_17 = coefficients0[dof][17];
      new_coeff0_18 = coefficients0[dof][18];
      new_coeff0_19 = coefficients0[dof][19];
      new_coeff0_20 = coefficients0[dof][20];
      new_coeff0_21 = coefficients0[dof][21];
      new_coeff0_22 = coefficients0[dof][22];
      new_coeff0_23 = coefficients0[dof][23];
      new_coeff0_24 = coefficients0[dof][24];
      new_coeff0_25 = coefficients0[dof][25];
      new_coeff0_26 = coefficients0[dof][26];
      new_coeff0_27 = coefficients0[dof][27];
      new_coeff0_28 = coefficients0[dof][28];
      new_coeff0_29 = coefficients0[dof][29];
      new_coeff0_30 = coefficients0[dof][30];
      new_coeff0_31 = coefficients0[dof][31];
      new_coeff0_32 = coefficients0[dof][32];
      new_coeff0_33 = coefficients0[dof][33];
      new_coeff0_34 = coefficients0[dof][34];
      new_coeff0_35 = coefficients0[dof][35];
      new_coeff0_36 = coefficients0[dof][36];
      new_coeff0_37 = coefficients0[dof][37];
      new_coeff0_38 = coefficients0[dof][38];
      new_coeff0_39 = coefficients0[dof][39];
      new_coeff0_40 = coefficients0[dof][40];
      new_coeff0_41 = coefficients0[dof][41];
      new_coeff0_42 = coefficients0[dof][42];
      new_coeff0_43 = coefficients0[dof][43];
      new_coeff0_44 = coefficients0[dof][44];
      new_coeff0_45 = coefficients0[dof][45];
      new_coeff0_46 = coefficients0[dof][46];
      new_coeff0_47 = coefficients0[dof][47];
      new_coeff0_48 = coefficients0[dof][48];
      new_coeff0_49 = coefficients0[dof][49];
      new_coeff0_50 = coefficients0[dof][50];
      new_coeff0_51 = coefficients0[dof][51];
      new_coeff0_52 = coefficients0[dof][52];
      new_coeff0_53 = coefficients0[dof][53];
      new_coeff0_54 = coefficients0[dof][54];
      new_coeff0_55 = coefficients0[dof][55];
    
      // Loop derivative order
      for (unsigned int j = 0; j < n; j++)
      {
        // Update old coefficients
        coeff0_0 = new_coeff0_0;
        coeff0_1 = new_coeff0_1;
        coeff0_2 = new_coeff0_2;
        coeff0_3 = new_coeff0_3;
        coeff0_4 = new_coeff0_4;
        coeff0_5 = new_coeff0_5;
        coeff0_6 = new_coeff0_6;
        coeff0_7 = new_coeff0_7;
        coeff0_8 = new_coeff0_8;
        coeff0_9 = new_coeff0_9;
        coeff0_10 = new_coeff0_10;
        coeff0_11 = new_coeff0_11;
        coeff0_12 = new_coeff0_12;
        coeff0_13 = new_coeff0_13;
        coeff0_14 = new_coeff0_14;
        coeff0_15 = new_coeff0_15;
        coeff0_16 = new_coeff0_16;
        coeff0_17 = new_coeff0_17;
        coeff0_18 = new_coeff0_18;
        coeff0_19 = new_coeff0_19;
        coeff0_20 = new_coeff0_20;
        coeff0_21 = new_coeff0_21;
        coeff0_22 = new_coeff0_22;
        coeff0_23 = new_coeff0_23;
        coeff0_24 = new_coeff0_24;
        coeff0_25 = new_coeff0_25;
        coeff0_26 = new_coeff0_26;
        coeff0_27 = new_coeff0_27;
        coeff0_28 = new_coeff0_28;
        coeff0_29 = new_coeff0_29;
        coeff0_30 = new_coeff0_30;
        coeff0_31 = new_coeff0_31;
        coeff0_32 = new_coeff0_32;
        coeff0_33 = new_coeff0_33;
        coeff0_34 = new_coeff0_34;
        coeff0_35 = new_coeff0_35;
        coeff0_36 = new_coeff0_36;
        coeff0_37 = new_coeff0_37;
        coeff0_38 = new_coeff0_38;
        coeff0_39 = new_coeff0_39;
        coeff0_40 = new_coeff0_40;
        coeff0_41 = new_coeff0_41;
        coeff0_42 = new_coeff0_42;
        coeff0_43 = new_coeff0_43;
        coeff0_44 = new_coeff0_44;
        coeff0_45 = new_coeff0_45;
        coeff0_46 = new_coeff0_46;
        coeff0_47 = new_coeff0_47;
        coeff0_48 = new_coeff0_48;
        coeff0_49 = new_coeff0_49;
        coeff0_50 = new_coeff0_50;
        coeff0_51 = new_coeff0_51;
        coeff0_52 = new_coeff0_52;
        coeff0_53 = new_coeff0_53;
        coeff0_54 = new_coeff0_54;
        coeff0_55 = new_coeff0_55;
    
        if(combinations[deriv_num][j] == 0)
        {
          new_coeff0_0 = coeff0_0*dmats0[0][0] + coeff0_1*dmats0[1][0] + coeff0_2*dmats0[2][0] + coeff0_3*dmats0[3][0] + coeff0_4*dmats0[4][0] + coeff0_5*dmats0[5][0] + coeff0_6*dmats0[6][0] + coeff0_7*dmats0[7][0] + coeff0_8*dmats0[8][0] + coeff0_9*dmats0[9][0] + coeff0_10*dmats0[10][0] + coeff0_11*dmats0[11][0] + coeff0_12*dmats0[12][0] + coeff0_13*dmats0[13][0] + coeff0_14*dmats0[14][0] + coeff0_15*dmats0[15][0] + coeff0_16*dmats0[16][0] + coeff0_17*dmats0[17][0] + coeff0_18*dmats0[18][0] + coeff0_19*dmats0[19][0] + coeff0_20*dmats0[20][0] + coeff0_21*dmats0[21][0] + coeff0_22*dmats0[22][0] + coeff0_23*dmats0[23][0] + coeff0_24*dmats0[24][0] + coeff0_25*dmats0[25][0] + coeff0_26*dmats0[26][0] + coeff0_27*dmats0[27][0] + coeff0_28*dmats0[28][0] + coeff0_29*dmats0[29][0] + coeff0_30*dmats0[30][0] + coeff0_31*dmats0[31][0] + coeff0_32*dmats0[32][0] + coeff0_33*dmats0[33][0] + coeff0_34*dmats0[34][0] + coeff0_35*dmats0[35][0] + coeff0_36*dmats0[36][0] + coeff0_37*dmats0[37][0] + coeff0_38*dmats0[38][0] + coeff0_39*dmats0[39][0] + coeff0_40*dmats0[40][0] + coeff0_41*dmats0[41][0] + coeff0_42*dmats0[42][0] + coeff0_43*dmats0[43][0] + coeff0_44*dmats0[44][0] + coeff0_45*dmats0[45][0] + coeff0_46*dmats0[46][0] + coeff0_47*dmats0[47][0] + coeff0_48*dmats0[48][0] + coeff0_49*dmats0[49][0] + coeff0_50*dmats0[50][0] + coeff0_51*dmats0[51][0] + coeff0_52*dmats0[52][0] + coeff0_53*dmats0[53][0] + coeff0_54*dmats0[54][0] + coeff0_55*dmats0[55][0];
          new_coeff0_1 = coeff0_0*dmats0[0][1] + coeff0_1*dmats0[1][1] + coeff0_2*dmats0[2][1] + coeff0_3*dmats0[3][1] + coeff0_4*dmats0[4][1] + coeff0_5*dmats0[5][1] + coeff0_6*dmats0[6][1] + coeff0_7*dmats0[7][1] + coeff0_8*dmats0[8][1] + coeff0_9*dmats0[9][1] + coeff0_10*dmats0[10][1] + coeff0_11*dmats0[11][1] + coeff0_12*dmats0[12][1] + coeff0_13*dmats0[13][1] + coeff0_14*dmats0[14][1] + coeff0_15*dmats0[15][1] + coeff0_16*dmats0[16][1] + coeff0_17*dmats0[17][1] + coeff0_18*dmats0[18][1] + coeff0_19*dmats0[19][1] + coeff0_20*dmats0[20][1] + coeff0_21*dmats0[21][1] + coeff0_22*dmats0[22][1] + coeff0_23*dmats0[23][1] + coeff0_24*dmats0[24][1] + coeff0_25*dmats0[25][1] + coeff0_26*dmats0[26][1] + coeff0_27*dmats0[27][1] + coeff0_28*dmats0[28][1] + coeff0_29*dmats0[29][1] + coeff0_30*dmats0[30][1] + coeff0_31*dmats0[31][1] + coeff0_32*dmats0[32][1] + coeff0_33*dmats0[33][1] + coeff0_34*dmats0[34][1] + coeff0_35*dmats0[35][1] + coeff0_36*dmats0[36][1] + coeff0_37*dmats0[37][1] + coeff0_38*dmats0[38][1] + coeff0_39*dmats0[39][1] + coeff0_40*dmats0[40][1] + coeff0_41*dmats0[41][1] + coeff0_42*dmats0[42][1] + coeff0_43*dmats0[43][1] + coeff0_44*dmats0[44][1] + coeff0_45*dmats0[45][1] + coeff0_46*dmats0[46][1] + coeff0_47*dmats0[47][1] + coeff0_48*dmats0[48][1] + coeff0_49*dmats0[49][1] + coeff0_50*dmats0[50][1] + coeff0_51*dmats0[51][1] + coeff0_52*dmats0[52][1] + coeff0_53*dmats0[53][1] + coeff0_54*dmats0[54][1] + coeff0_55*dmats0[55][1];
          new_coeff0_2 = coeff0_0*dmats0[0][2] + coeff0_1*dmats0[1][2] + coeff0_2*dmats0[2][2] + coeff0_3*dmats0[3][2] + coeff0_4*dmats0[4][2] + coeff0_5*dmats0[5][2] + coeff0_6*dmats0[6][2] + coeff0_7*dmats0[7][2] + coeff0_8*dmats0[8][2] + coeff0_9*dmats0[9][2] + coeff0_10*dmats0[10][2] + coeff0_11*dmats0[11][2] + coeff0_12*dmats0[12][2] + coeff0_13*dmats0[13][2] + coeff0_14*dmats0[14][2] + coeff0_15*dmats0[15][2] + coeff0_16*dmats0[16][2] + coeff0_17*dmats0[17][2] + coeff0_18*dmats0[18][2] + coeff0_19*dmats0[19][2] + coeff0_20*dmats0[20][2] + coeff0_21*dmats0[21][2] + coeff0_22*dmats0[22][2] + coeff0_23*dmats0[23][2] + coeff0_24*dmats0[24][2] + coeff0_25*dmats0[25][2] + coeff0_26*dmats0[26][2] + coeff0_27*dmats0[27][2] + coeff0_28*dmats0[28][2] + coeff0_29*dmats0[29][2] + coeff0_30*dmats0[30][2] + coeff0_31*dmats0[31][2] + coeff0_32*dmats0[32][2] + coeff0_33*dmats0[33][2] + coeff0_34*dmats0[34][2] + coeff0_35*dmats0[35][2] + coeff0_36*dmats0[36][2] + coeff0_37*dmats0[37][2] + coeff0_38*dmats0[38][2] + coeff0_39*dmats0[39][2] + coeff0_40*dmats0[40][2] + coeff0_41*dmats0[41][2] + coeff0_42*dmats0[42][2] + coeff0_43*dmats0[43][2] + coeff0_44*dmats0[44][2] + coeff0_45*dmats0[45][2] + coeff0_46*dmats0[46][2] + coeff0_47*dmats0[47][2] + coeff0_48*dmats0[48][2] + coeff0_49*dmats0[49][2] + coeff0_50*dmats0[50][2] + coeff0_51*dmats0[51][2] + coeff0_52*dmats0[52][2] + coeff0_53*dmats0[53][2] + coeff0_54*dmats0[54][2] + coeff0_55*dmats0[55][2];
          new_coeff0_3 = coeff0_0*dmats0[0][3] + coeff0_1*dmats0[1][3] + coeff0_2*dmats0[2][3] + coeff0_3*dmats0[3][3] + coeff0_4*dmats0[4][3] + coeff0_5*dmats0[5][3] + coeff0_6*dmats0[6][3] + coeff0_7*dmats0[7][3] + coeff0_8*dmats0[8][3] + coeff0_9*dmats0[9][3] + coeff0_10*dmats0[10][3] + coeff0_11*dmats0[11][3] + coeff0_12*dmats0[12][3] + coeff0_13*dmats0[13][3] + coeff0_14*dmats0[14][3] + coeff0_15*dmats0[15][3] + coeff0_16*dmats0[16][3] + coeff0_17*dmats0[17][3] + coeff0_18*dmats0[18][3] + coeff0_19*dmats0[19][3] + coeff0_20*dmats0[20][3] + coeff0_21*dmats0[21][3] + coeff0_22*dmats0[22][3] + coeff0_23*dmats0[23][3] + coeff0_24*dmats0[24][3] + coeff0_25*dmats0[25][3] + coeff0_26*dmats0[26][3] + coeff0_27*dmats0[27][3] + coeff0_28*dmats0[28][3] + coeff0_29*dmats0[29][3] + coeff0_30*dmats0[30][3] + coeff0_31*dmats0[31][3] + coeff0_32*dmats0[32][3] + coeff0_33*dmats0[33][3] + coeff0_34*dmats0[34][3] + coeff0_35*dmats0[35][3] + coeff0_36*dmats0[36][3] + coeff0_37*dmats0[37][3] + coeff0_38*dmats0[38][3] + coeff0_39*dmats0[39][3] + coeff0_40*dmats0[40][3] + coeff0_41*dmats0[41][3] + coeff0_42*dmats0[42][3] + coeff0_43*dmats0[43][3] + coeff0_44*dmats0[44][3] + coeff0_45*dmats0[45][3] + coeff0_46*dmats0[46][3] + coeff0_47*dmats0[47][3] + coeff0_48*dmats0[48][3] + coeff0_49*dmats0[49][3] + coeff0_50*dmats0[50][3] + coeff0_51*dmats0[51][3] + coeff0_52*dmats0[52][3] + coeff0_53*dmats0[53][3] + coeff0_54*dmats0[54][3] + coeff0_55*dmats0[55][3];
          new_coeff0_4 = coeff0_0*dmats0[0][4] + coeff0_1*dmats0[1][4] + coeff0_2*dmats0[2][4] + coeff0_3*dmats0[3][4] + coeff0_4*dmats0[4][4] + coeff0_5*dmats0[5][4] + coeff0_6*dmats0[6][4] + coeff0_7*dmats0[7][4] + coeff0_8*dmats0[8][4] + coeff0_9*dmats0[9][4] + coeff0_10*dmats0[10][4] + coeff0_11*dmats0[11][4] + coeff0_12*dmats0[12][4] + coeff0_13*dmats0[13][4] + coeff0_14*dmats0[14][4] + coeff0_15*dmats0[15][4] + coeff0_16*dmats0[16][4] + coeff0_17*dmats0[17][4] + coeff0_18*dmats0[18][4] + coeff0_19*dmats0[19][4] + coeff0_20*dmats0[20][4] + coeff0_21*dmats0[21][4] + coeff0_22*dmats0[22][4] + coeff0_23*dmats0[23][4] + coeff0_24*dmats0[24][4] + coeff0_25*dmats0[25][4] + coeff0_26*dmats0[26][4] + coeff0_27*dmats0[27][4] + coeff0_28*dmats0[28][4] + coeff0_29*dmats0[29][4] + coeff0_30*dmats0[30][4] + coeff0_31*dmats0[31][4] + coeff0_32*dmats0[32][4] + coeff0_33*dmats0[33][4] + coeff0_34*dmats0[34][4] + coeff0_35*dmats0[35][4] + coeff0_36*dmats0[36][4] + coeff0_37*dmats0[37][4] + coeff0_38*dmats0[38][4] + coeff0_39*dmats0[39][4] + coeff0_40*dmats0[40][4] + coeff0_41*dmats0[41][4] + coeff0_42*dmats0[42][4] + coeff0_43*dmats0[43][4] + coeff0_44*dmats0[44][4] + coeff0_45*dmats0[45][4] + coeff0_46*dmats0[46][4] + coeff0_47*dmats0[47][4] + coeff0_48*dmats0[48][4] + coeff0_49*dmats0[49][4] + coeff0_50*dmats0[50][4] + coeff0_51*dmats0[51][4] + coeff0_52*dmats0[52][4] + coeff0_53*dmats0[53][4] + coeff0_54*dmats0[54][4] + coeff0_55*dmats0[55][4];
          new_coeff0_5 = coeff0_0*dmats0[0][5] + coeff0_1*dmats0[1][5] + coeff0_2*dmats0[2][5] + coeff0_3*dmats0[3][5] + coeff0_4*dmats0[4][5] + coeff0_5*dmats0[5][5] + coeff0_6*dmats0[6][5] + coeff0_7*dmats0[7][5] + coeff0_8*dmats0[8][5] + coeff0_9*dmats0[9][5] + coeff0_10*dmats0[10][5] + coeff0_11*dmats0[11][5] + coeff0_12*dmats0[12][5] + coeff0_13*dmats0[13][5] + coeff0_14*dmats0[14][5] + coeff0_15*dmats0[15][5] + coeff0_16*dmats0[16][5] + coeff0_17*dmats0[17][5] + coeff0_18*dmats0[18][5] + coeff0_19*dmats0[19][5] + coeff0_20*dmats0[20][5] + coeff0_21*dmats0[21][5] + coeff0_22*dmats0[22][5] + coeff0_23*dmats0[23][5] + coeff0_24*dmats0[24][5] + coeff0_25*dmats0[25][5] + coeff0_26*dmats0[26][5] + coeff0_27*dmats0[27][5] + coeff0_28*dmats0[28][5] + coeff0_29*dmats0[29][5] + coeff0_30*dmats0[30][5] + coeff0_31*dmats0[31][5] + coeff0_32*dmats0[32][5] + coeff0_33*dmats0[33][5] + coeff0_34*dmats0[34][5] + coeff0_35*dmats0[35][5] + coeff0_36*dmats0[36][5] + coeff0_37*dmats0[37][5] + coeff0_38*dmats0[38][5] + coeff0_39*dmats0[39][5] + coeff0_40*dmats0[40][5] + coeff0_41*dmats0[41][5] + coeff0_42*dmats0[42][5] + coeff0_43*dmats0[43][5] + coeff0_44*dmats0[44][5] + coeff0_45*dmats0[45][5] + coeff0_46*dmats0[46][5] + coeff0_47*dmats0[47][5] + coeff0_48*dmats0[48][5] + coeff0_49*dmats0[49][5] + coeff0_50*dmats0[50][5] + coeff0_51*dmats0[51][5] + coeff0_52*dmats0[52][5] + coeff0_53*dmats0[53][5] + coeff0_54*dmats0[54][5] + coeff0_55*dmats0[55][5];
          new_coeff0_6 = coeff0_0*dmats0[0][6] + coeff0_1*dmats0[1][6] + coeff0_2*dmats0[2][6] + coeff0_3*dmats0[3][6] + coeff0_4*dmats0[4][6] + coeff0_5*dmats0[5][6] + coeff0_6*dmats0[6][6] + coeff0_7*dmats0[7][6] + coeff0_8*dmats0[8][6] + coeff0_9*dmats0[9][6] + coeff0_10*dmats0[10][6] + coeff0_11*dmats0[11][6] + coeff0_12*dmats0[12][6] + coeff0_13*dmats0[13][6] + coeff0_14*dmats0[14][6] + coeff0_15*dmats0[15][6] + coeff0_16*dmats0[16][6] + coeff0_17*dmats0[17][6] + coeff0_18*dmats0[18][6] + coeff0_19*dmats0[19][6] + coeff0_20*dmats0[20][6] + coeff0_21*dmats0[21][6] + coeff0_22*dmats0[22][6] + coeff0_23*dmats0[23][6] + coeff0_24*dmats0[24][6] + coeff0_25*dmats0[25][6] + coeff0_26*dmats0[26][6] + coeff0_27*dmats0[27][6] + coeff0_28*dmats0[28][6] + coeff0_29*dmats0[29][6] + coeff0_30*dmats0[30][6] + coeff0_31*dmats0[31][6] + coeff0_32*dmats0[32][6] + coeff0_33*dmats0[33][6] + coeff0_34*dmats0[34][6] + coeff0_35*dmats0[35][6] + coeff0_36*dmats0[36][6] + coeff0_37*dmats0[37][6] + coeff0_38*dmats0[38][6] + coeff0_39*dmats0[39][6] + coeff0_40*dmats0[40][6] + coeff0_41*dmats0[41][6] + coeff0_42*dmats0[42][6] + coeff0_43*dmats0[43][6] + coeff0_44*dmats0[44][6] + coeff0_45*dmats0[45][6] + coeff0_46*dmats0[46][6] + coeff0_47*dmats0[47][6] + coeff0_48*dmats0[48][6] + coeff0_49*dmats0[49][6] + coeff0_50*dmats0[50][6] + coeff0_51*dmats0[51][6] + coeff0_52*dmats0[52][6] + coeff0_53*dmats0[53][6] + coeff0_54*dmats0[54][6] + coeff0_55*dmats0[55][6];
          new_coeff0_7 = coeff0_0*dmats0[0][7] + coeff0_1*dmats0[1][7] + coeff0_2*dmats0[2][7] + coeff0_3*dmats0[3][7] + coeff0_4*dmats0[4][7] + coeff0_5*dmats0[5][7] + coeff0_6*dmats0[6][7] + coeff0_7*dmats0[7][7] + coeff0_8*dmats0[8][7] + coeff0_9*dmats0[9][7] + coeff0_10*dmats0[10][7] + coeff0_11*dmats0[11][7] + coeff0_12*dmats0[12][7] + coeff0_13*dmats0[13][7] + coeff0_14*dmats0[14][7] + coeff0_15*dmats0[15][7] + coeff0_16*dmats0[16][7] + coeff0_17*dmats0[17][7] + coeff0_18*dmats0[18][7] + coeff0_19*dmats0[19][7] + coeff0_20*dmats0[20][7] + coeff0_21*dmats0[21][7] + coeff0_22*dmats0[22][7] + coeff0_23*dmats0[23][7] + coeff0_24*dmats0[24][7] + coeff0_25*dmats0[25][7] + coeff0_26*dmats0[26][7] + coeff0_27*dmats0[27][7] + coeff0_28*dmats0[28][7] + coeff0_29*dmats0[29][7] + coeff0_30*dmats0[30][7] + coeff0_31*dmats0[31][7] + coeff0_32*dmats0[32][7] + coeff0_33*dmats0[33][7] + coeff0_34*dmats0[34][7] + coeff0_35*dmats0[35][7] + coeff0_36*dmats0[36][7] + coeff0_37*dmats0[37][7] + coeff0_38*dmats0[38][7] + coeff0_39*dmats0[39][7] + coeff0_40*dmats0[40][7] + coeff0_41*dmats0[41][7] + coeff0_42*dmats0[42][7] + coeff0_43*dmats0[43][7] + coeff0_44*dmats0[44][7] + coeff0_45*dmats0[45][7] + coeff0_46*dmats0[46][7] + coeff0_47*dmats0[47][7] + coeff0_48*dmats0[48][7] + coeff0_49*dmats0[49][7] + coeff0_50*dmats0[50][7] + coeff0_51*dmats0[51][7] + coeff0_52*dmats0[52][7] + coeff0_53*dmats0[53][7] + coeff0_54*dmats0[54][7] + coeff0_55*dmats0[55][7];
          new_coeff0_8 = coeff0_0*dmats0[0][8] + coeff0_1*dmats0[1][8] + coeff0_2*dmats0[2][8] + coeff0_3*dmats0[3][8] + coeff0_4*dmats0[4][8] + coeff0_5*dmats0[5][8] + coeff0_6*dmats0[6][8] + coeff0_7*dmats0[7][8] + coeff0_8*dmats0[8][8] + coeff0_9*dmats0[9][8] + coeff0_10*dmats0[10][8] + coeff0_11*dmats0[11][8] + coeff0_12*dmats0[12][8] + coeff0_13*dmats0[13][8] + coeff0_14*dmats0[14][8] + coeff0_15*dmats0[15][8] + coeff0_16*dmats0[16][8] + coeff0_17*dmats0[17][8] + coeff0_18*dmats0[18][8] + coeff0_19*dmats0[19][8] + coeff0_20*dmats0[20][8] + coeff0_21*dmats0[21][8] + coeff0_22*dmats0[22][8] + coeff0_23*dmats0[23][8] + coeff0_24*dmats0[24][8] + coeff0_25*dmats0[25][8] + coeff0_26*dmats0[26][8] + coeff0_27*dmats0[27][8] + coeff0_28*dmats0[28][8] + coeff0_29*dmats0[29][8] + coeff0_30*dmats0[30][8] + coeff0_31*dmats0[31][8] + coeff0_32*dmats0[32][8] + coeff0_33*dmats0[33][8] + coeff0_34*dmats0[34][8] + coeff0_35*dmats0[35][8] + coeff0_36*dmats0[36][8] + coeff0_37*dmats0[37][8] + coeff0_38*dmats0[38][8] + coeff0_39*dmats0[39][8] + coeff0_40*dmats0[40][8] + coeff0_41*dmats0[41][8] + coeff0_42*dmats0[42][8] + coeff0_43*dmats0[43][8] + coeff0_44*dmats0[44][8] + coeff0_45*dmats0[45][8] + coeff0_46*dmats0[46][8] + coeff0_47*dmats0[47][8] + coeff0_48*dmats0[48][8] + coeff0_49*dmats0[49][8] + coeff0_50*dmats0[50][8] + coeff0_51*dmats0[51][8] + coeff0_52*dmats0[52][8] + coeff0_53*dmats0[53][8] + coeff0_54*dmats0[54][8] + coeff0_55*dmats0[55][8];
          new_coeff0_9 = coeff0_0*dmats0[0][9] + coeff0_1*dmats0[1][9] + coeff0_2*dmats0[2][9] + coeff0_3*dmats0[3][9] + coeff0_4*dmats0[4][9] + coeff0_5*dmats0[5][9] + coeff0_6*dmats0[6][9] + coeff0_7*dmats0[7][9] + coeff0_8*dmats0[8][9] + coeff0_9*dmats0[9][9] + coeff0_10*dmats0[10][9] + coeff0_11*dmats0[11][9] + coeff0_12*dmats0[12][9] + coeff0_13*dmats0[13][9] + coeff0_14*dmats0[14][9] + coeff0_15*dmats0[15][9] + coeff0_16*dmats0[16][9] + coeff0_17*dmats0[17][9] + coeff0_18*dmats0[18][9] + coeff0_19*dmats0[19][9] + coeff0_20*dmats0[20][9] + coeff0_21*dmats0[21][9] + coeff0_22*dmats0[22][9] + coeff0_23*dmats0[23][9] + coeff0_24*dmats0[24][9] + coeff0_25*dmats0[25][9] + coeff0_26*dmats0[26][9] + coeff0_27*dmats0[27][9] + coeff0_28*dmats0[28][9] + coeff0_29*dmats0[29][9] + coeff0_30*dmats0[30][9] + coeff0_31*dmats0[31][9] + coeff0_32*dmats0[32][9] + coeff0_33*dmats0[33][9] + coeff0_34*dmats0[34][9] + coeff0_35*dmats0[35][9] + coeff0_36*dmats0[36][9] + coeff0_37*dmats0[37][9] + coeff0_38*dmats0[38][9] + coeff0_39*dmats0[39][9] + coeff0_40*dmats0[40][9] + coeff0_41*dmats0[41][9] + coeff0_42*dmats0[42][9] + coeff0_43*dmats0[43][9] + coeff0_44*dmats0[44][9] + coeff0_45*dmats0[45][9] + coeff0_46*dmats0[46][9] + coeff0_47*dmats0[47][9] + coeff0_48*dmats0[48][9] + coeff0_49*dmats0[49][9] + coeff0_50*dmats0[50][9] + coeff0_51*dmats0[51][9] + coeff0_52*dmats0[52][9] + coeff0_53*dmats0[53][9] + coeff0_54*dmats0[54][9] + coeff0_55*dmats0[55][9];
          new_coeff0_10 = coeff0_0*dmats0[0][10] + coeff0_1*dmats0[1][10] + coeff0_2*dmats0[2][10] + coeff0_3*dmats0[3][10] + coeff0_4*dmats0[4][10] + coeff0_5*dmats0[5][10] + coeff0_6*dmats0[6][10] + coeff0_7*dmats0[7][10] + coeff0_8*dmats0[8][10] + coeff0_9*dmats0[9][10] + coeff0_10*dmats0[10][10] + coeff0_11*dmats0[11][10] + coeff0_12*dmats0[12][10] + coeff0_13*dmats0[13][10] + coeff0_14*dmats0[14][10] + coeff0_15*dmats0[15][10] + coeff0_16*dmats0[16][10] + coeff0_17*dmats0[17][10] + coeff0_18*dmats0[18][10] + coeff0_19*dmats0[19][10] + coeff0_20*dmats0[20][10] + coeff0_21*dmats0[21][10] + coeff0_22*dmats0[22][10] + coeff0_23*dmats0[23][10] + coeff0_24*dmats0[24][10] + coeff0_25*dmats0[25][10] + coeff0_26*dmats0[26][10] + coeff0_27*dmats0[27][10] + coeff0_28*dmats0[28][10] + coeff0_29*dmats0[29][10] + coeff0_30*dmats0[30][10] + coeff0_31*dmats0[31][10] + coeff0_32*dmats0[32][10] + coeff0_33*dmats0[33][10] + coeff0_34*dmats0[34][10] + coeff0_35*dmats0[35][10] + coeff0_36*dmats0[36][10] + coeff0_37*dmats0[37][10] + coeff0_38*dmats0[38][10] + coeff0_39*dmats0[39][10] + coeff0_40*dmats0[40][10] + coeff0_41*dmats0[41][10] + coeff0_42*dmats0[42][10] + coeff0_43*dmats0[43][10] + coeff0_44*dmats0[44][10] + coeff0_45*dmats0[45][10] + coeff0_46*dmats0[46][10] + coeff0_47*dmats0[47][10] + coeff0_48*dmats0[48][10] + coeff0_49*dmats0[49][10] + coeff0_50*dmats0[50][10] + coeff0_51*dmats0[51][10] + coeff0_52*dmats0[52][10] + coeff0_53*dmats0[53][10] + coeff0_54*dmats0[54][10] + coeff0_55*dmats0[55][10];
          new_coeff0_11 = coeff0_0*dmats0[0][11] + coeff0_1*dmats0[1][11] + coeff0_2*dmats0[2][11] + coeff0_3*dmats0[3][11] + coeff0_4*dmats0[4][11] + coeff0_5*dmats0[5][11] + coeff0_6*dmats0[6][11] + coeff0_7*dmats0[7][11] + coeff0_8*dmats0[8][11] + coeff0_9*dmats0[9][11] + coeff0_10*dmats0[10][11] + coeff0_11*dmats0[11][11] + coeff0_12*dmats0[12][11] + coeff0_13*dmats0[13][11] + coeff0_14*dmats0[14][11] + coeff0_15*dmats0[15][11] + coeff0_16*dmats0[16][11] + coeff0_17*dmats0[17][11] + coeff0_18*dmats0[18][11] + coeff0_19*dmats0[19][11] + coeff0_20*dmats0[20][11] + coeff0_21*dmats0[21][11] + coeff0_22*dmats0[22][11] + coeff0_23*dmats0[23][11] + coeff0_24*dmats0[24][11] + coeff0_25*dmats0[25][11] + coeff0_26*dmats0[26][11] + coeff0_27*dmats0[27][11] + coeff0_28*dmats0[28][11] + coeff0_29*dmats0[29][11] + coeff0_30*dmats0[30][11] + coeff0_31*dmats0[31][11] + coeff0_32*dmats0[32][11] + coeff0_33*dmats0[33][11] + coeff0_34*dmats0[34][11] + coeff0_35*dmats0[35][11] + coeff0_36*dmats0[36][11] + coeff0_37*dmats0[37][11] + coeff0_38*dmats0[38][11] + coeff0_39*dmats0[39][11] + coeff0_40*dmats0[40][11] + coeff0_41*dmats0[41][11] + coeff0_42*dmats0[42][11] + coeff0_43*dmats0[43][11] + coeff0_44*dmats0[44][11] + coeff0_45*dmats0[45][11] + coeff0_46*dmats0[46][11] + coeff0_47*dmats0[47][11] + coeff0_48*dmats0[48][11] + coeff0_49*dmats0[49][11] + coeff0_50*dmats0[50][11] + coeff0_51*dmats0[51][11] + coeff0_52*dmats0[52][11] + coeff0_53*dmats0[53][11] + coeff0_54*dmats0[54][11] + coeff0_55*dmats0[55][11];
          new_coeff0_12 = coeff0_0*dmats0[0][12] + coeff0_1*dmats0[1][12] + coeff0_2*dmats0[2][12] + coeff0_3*dmats0[3][12] + coeff0_4*dmats0[4][12] + coeff0_5*dmats0[5][12] + coeff0_6*dmats0[6][12] + coeff0_7*dmats0[7][12] + coeff0_8*dmats0[8][12] + coeff0_9*dmats0[9][12] + coeff0_10*dmats0[10][12] + coeff0_11*dmats0[11][12] + coeff0_12*dmats0[12][12] + coeff0_13*dmats0[13][12] + coeff0_14*dmats0[14][12] + coeff0_15*dmats0[15][12] + coeff0_16*dmats0[16][12] + coeff0_17*dmats0[17][12] + coeff0_18*dmats0[18][12] + coeff0_19*dmats0[19][12] + coeff0_20*dmats0[20][12] + coeff0_21*dmats0[21][12] + coeff0_22*dmats0[22][12] + coeff0_23*dmats0[23][12] + coeff0_24*dmats0[24][12] + coeff0_25*dmats0[25][12] + coeff0_26*dmats0[26][12] + coeff0_27*dmats0[27][12] + coeff0_28*dmats0[28][12] + coeff0_29*dmats0[29][12] + coeff0_30*dmats0[30][12] + coeff0_31*dmats0[31][12] + coeff0_32*dmats0[32][12] + coeff0_33*dmats0[33][12] + coeff0_34*dmats0[34][12] + coeff0_35*dmats0[35][12] + coeff0_36*dmats0[36][12] + coeff0_37*dmats0[37][12] + coeff0_38*dmats0[38][12] + coeff0_39*dmats0[39][12] + coeff0_40*dmats0[40][12] + coeff0_41*dmats0[41][12] + coeff0_42*dmats0[42][12] + coeff0_43*dmats0[43][12] + coeff0_44*dmats0[44][12] + coeff0_45*dmats0[45][12] + coeff0_46*dmats0[46][12] + coeff0_47*dmats0[47][12] + coeff0_48*dmats0[48][12] + coeff0_49*dmats0[49][12] + coeff0_50*dmats0[50][12] + coeff0_51*dmats0[51][12] + coeff0_52*dmats0[52][12] + coeff0_53*dmats0[53][12] + coeff0_54*dmats0[54][12] + coeff0_55*dmats0[55][12];
          new_coeff0_13 = coeff0_0*dmats0[0][13] + coeff0_1*dmats0[1][13] + coeff0_2*dmats0[2][13] + coeff0_3*dmats0[3][13] + coeff0_4*dmats0[4][13] + coeff0_5*dmats0[5][13] + coeff0_6*dmats0[6][13] + coeff0_7*dmats0[7][13] + coeff0_8*dmats0[8][13] + coeff0_9*dmats0[9][13] + coeff0_10*dmats0[10][13] + coeff0_11*dmats0[11][13] + coeff0_12*dmats0[12][13] + coeff0_13*dmats0[13][13] + coeff0_14*dmats0[14][13] + coeff0_15*dmats0[15][13] + coeff0_16*dmats0[16][13] + coeff0_17*dmats0[17][13] + coeff0_18*dmats0[18][13] + coeff0_19*dmats0[19][13] + coeff0_20*dmats0[20][13] + coeff0_21*dmats0[21][13] + coeff0_22*dmats0[22][13] + coeff0_23*dmats0[23][13] + coeff0_24*dmats0[24][13] + coeff0_25*dmats0[25][13] + coeff0_26*dmats0[26][13] + coeff0_27*dmats0[27][13] + coeff0_28*dmats0[28][13] + coeff0_29*dmats0[29][13] + coeff0_30*dmats0[30][13] + coeff0_31*dmats0[31][13] + coeff0_32*dmats0[32][13] + coeff0_33*dmats0[33][13] + coeff0_34*dmats0[34][13] + coeff0_35*dmats0[35][13] + coeff0_36*dmats0[36][13] + coeff0_37*dmats0[37][13] + coeff0_38*dmats0[38][13] + coeff0_39*dmats0[39][13] + coeff0_40*dmats0[40][13] + coeff0_41*dmats0[41][13] + coeff0_42*dmats0[42][13] + coeff0_43*dmats0[43][13] + coeff0_44*dmats0[44][13] + coeff0_45*dmats0[45][13] + coeff0_46*dmats0[46][13] + coeff0_47*dmats0[47][13] + coeff0_48*dmats0[48][13] + coeff0_49*dmats0[49][13] + coeff0_50*dmats0[50][13] + coeff0_51*dmats0[51][13] + coeff0_52*dmats0[52][13] + coeff0_53*dmats0[53][13] + coeff0_54*dmats0[54][13] + coeff0_55*dmats0[55][13];
          new_coeff0_14 = coeff0_0*dmats0[0][14] + coeff0_1*dmats0[1][14] + coeff0_2*dmats0[2][14] + coeff0_3*dmats0[3][14] + coeff0_4*dmats0[4][14] + coeff0_5*dmats0[5][14] + coeff0_6*dmats0[6][14] + coeff0_7*dmats0[7][14] + coeff0_8*dmats0[8][14] + coeff0_9*dmats0[9][14] + coeff0_10*dmats0[10][14] + coeff0_11*dmats0[11][14] + coeff0_12*dmats0[12][14] + coeff0_13*dmats0[13][14] + coeff0_14*dmats0[14][14] + coeff0_15*dmats0[15][14] + coeff0_16*dmats0[16][14] + coeff0_17*dmats0[17][14] + coeff0_18*dmats0[18][14] + coeff0_19*dmats0[19][14] + coeff0_20*dmats0[20][14] + coeff0_21*dmats0[21][14] + coeff0_22*dmats0[22][14] + coeff0_23*dmats0[23][14] + coeff0_24*dmats0[24][14] + coeff0_25*dmats0[25][14] + coeff0_26*dmats0[26][14] + coeff0_27*dmats0[27][14] + coeff0_28*dmats0[28][14] + coeff0_29*dmats0[29][14] + coeff0_30*dmats0[30][14] + coeff0_31*dmats0[31][14] + coeff0_32*dmats0[32][14] + coeff0_33*dmats0[33][14] + coeff0_34*dmats0[34][14] + coeff0_35*dmats0[35][14] + coeff0_36*dmats0[36][14] + coeff0_37*dmats0[37][14] + coeff0_38*dmats0[38][14] + coeff0_39*dmats0[39][14] + coeff0_40*dmats0[40][14] + coeff0_41*dmats0[41][14] + coeff0_42*dmats0[42][14] + coeff0_43*dmats0[43][14] + coeff0_44*dmats0[44][14] + coeff0_45*dmats0[45][14] + coeff0_46*dmats0[46][14] + coeff0_47*dmats0[47][14] + coeff0_48*dmats0[48][14] + coeff0_49*dmats0[49][14] + coeff0_50*dmats0[50][14] + coeff0_51*dmats0[51][14] + coeff0_52*dmats0[52][14] + coeff0_53*dmats0[53][14] + coeff0_54*dmats0[54][14] + coeff0_55*dmats0[55][14];
          new_coeff0_15 = coeff0_0*dmats0[0][15] + coeff0_1*dmats0[1][15] + coeff0_2*dmats0[2][15] + coeff0_3*dmats0[3][15] + coeff0_4*dmats0[4][15] + coeff0_5*dmats0[5][15] + coeff0_6*dmats0[6][15] + coeff0_7*dmats0[7][15] + coeff0_8*dmats0[8][15] + coeff0_9*dmats0[9][15] + coeff0_10*dmats0[10][15] + coeff0_11*dmats0[11][15] + coeff0_12*dmats0[12][15] + coeff0_13*dmats0[13][15] + coeff0_14*dmats0[14][15] + coeff0_15*dmats0[15][15] + coeff0_16*dmats0[16][15] + coeff0_17*dmats0[17][15] + coeff0_18*dmats0[18][15] + coeff0_19*dmats0[19][15] + coeff0_20*dmats0[20][15] + coeff0_21*dmats0[21][15] + coeff0_22*dmats0[22][15] + coeff0_23*dmats0[23][15] + coeff0_24*dmats0[24][15] + coeff0_25*dmats0[25][15] + coeff0_26*dmats0[26][15] + coeff0_27*dmats0[27][15] + coeff0_28*dmats0[28][15] + coeff0_29*dmats0[29][15] + coeff0_30*dmats0[30][15] + coeff0_31*dmats0[31][15] + coeff0_32*dmats0[32][15] + coeff0_33*dmats0[33][15] + coeff0_34*dmats0[34][15] + coeff0_35*dmats0[35][15] + coeff0_36*dmats0[36][15] + coeff0_37*dmats0[37][15] + coeff0_38*dmats0[38][15] + coeff0_39*dmats0[39][15] + coeff0_40*dmats0[40][15] + coeff0_41*dmats0[41][15] + coeff0_42*dmats0[42][15] + coeff0_43*dmats0[43][15] + coeff0_44*dmats0[44][15] + coeff0_45*dmats0[45][15] + coeff0_46*dmats0[46][15] + coeff0_47*dmats0[47][15] + coeff0_48*dmats0[48][15] + coeff0_49*dmats0[49][15] + coeff0_50*dmats0[50][15] + coeff0_51*dmats0[51][15] + coeff0_52*dmats0[52][15] + coeff0_53*dmats0[53][15] + coeff0_54*dmats0[54][15] + coeff0_55*dmats0[55][15];
          new_coeff0_16 = coeff0_0*dmats0[0][16] + coeff0_1*dmats0[1][16] + coeff0_2*dmats0[2][16] + coeff0_3*dmats0[3][16] + coeff0_4*dmats0[4][16] + coeff0_5*dmats0[5][16] + coeff0_6*dmats0[6][16] + coeff0_7*dmats0[7][16] + coeff0_8*dmats0[8][16] + coeff0_9*dmats0[9][16] + coeff0_10*dmats0[10][16] + coeff0_11*dmats0[11][16] + coeff0_12*dmats0[12][16] + coeff0_13*dmats0[13][16] + coeff0_14*dmats0[14][16] + coeff0_15*dmats0[15][16] + coeff0_16*dmats0[16][16] + coeff0_17*dmats0[17][16] + coeff0_18*dmats0[18][16] + coeff0_19*dmats0[19][16] + coeff0_20*dmats0[20][16] + coeff0_21*dmats0[21][16] + coeff0_22*dmats0[22][16] + coeff0_23*dmats0[23][16] + coeff0_24*dmats0[24][16] + coeff0_25*dmats0[25][16] + coeff0_26*dmats0[26][16] + coeff0_27*dmats0[27][16] + coeff0_28*dmats0[28][16] + coeff0_29*dmats0[29][16] + coeff0_30*dmats0[30][16] + coeff0_31*dmats0[31][16] + coeff0_32*dmats0[32][16] + coeff0_33*dmats0[33][16] + coeff0_34*dmats0[34][16] + coeff0_35*dmats0[35][16] + coeff0_36*dmats0[36][16] + coeff0_37*dmats0[37][16] + coeff0_38*dmats0[38][16] + coeff0_39*dmats0[39][16] + coeff0_40*dmats0[40][16] + coeff0_41*dmats0[41][16] + coeff0_42*dmats0[42][16] + coeff0_43*dmats0[43][16] + coeff0_44*dmats0[44][16] + coeff0_45*dmats0[45][16] + coeff0_46*dmats0[46][16] + coeff0_47*dmats0[47][16] + coeff0_48*dmats0[48][16] + coeff0_49*dmats0[49][16] + coeff0_50*dmats0[50][16] + coeff0_51*dmats0[51][16] + coeff0_52*dmats0[52][16] + coeff0_53*dmats0[53][16] + coeff0_54*dmats0[54][16] + coeff0_55*dmats0[55][16];
          new_coeff0_17 = coeff0_0*dmats0[0][17] + coeff0_1*dmats0[1][17] + coeff0_2*dmats0[2][17] + coeff0_3*dmats0[3][17] + coeff0_4*dmats0[4][17] + coeff0_5*dmats0[5][17] + coeff0_6*dmats0[6][17] + coeff0_7*dmats0[7][17] + coeff0_8*dmats0[8][17] + coeff0_9*dmats0[9][17] + coeff0_10*dmats0[10][17] + coeff0_11*dmats0[11][17] + coeff0_12*dmats0[12][17] + coeff0_13*dmats0[13][17] + coeff0_14*dmats0[14][17] + coeff0_15*dmats0[15][17] + coeff0_16*dmats0[16][17] + coeff0_17*dmats0[17][17] + coeff0_18*dmats0[18][17] + coeff0_19*dmats0[19][17] + coeff0_20*dmats0[20][17] + coeff0_21*dmats0[21][17] + coeff0_22*dmats0[22][17] + coeff0_23*dmats0[23][17] + coeff0_24*dmats0[24][17] + coeff0_25*dmats0[25][17] + coeff0_26*dmats0[26][17] + coeff0_27*dmats0[27][17] + coeff0_28*dmats0[28][17] + coeff0_29*dmats0[29][17] + coeff0_30*dmats0[30][17] + coeff0_31*dmats0[31][17] + coeff0_32*dmats0[32][17] + coeff0_33*dmats0[33][17] + coeff0_34*dmats0[34][17] + coeff0_35*dmats0[35][17] + coeff0_36*dmats0[36][17] + coeff0_37*dmats0[37][17] + coeff0_38*dmats0[38][17] + coeff0_39*dmats0[39][17] + coeff0_40*dmats0[40][17] + coeff0_41*dmats0[41][17] + coeff0_42*dmats0[42][17] + coeff0_43*dmats0[43][17] + coeff0_44*dmats0[44][17] + coeff0_45*dmats0[45][17] + coeff0_46*dmats0[46][17] + coeff0_47*dmats0[47][17] + coeff0_48*dmats0[48][17] + coeff0_49*dmats0[49][17] + coeff0_50*dmats0[50][17] + coeff0_51*dmats0[51][17] + coeff0_52*dmats0[52][17] + coeff0_53*dmats0[53][17] + coeff0_54*dmats0[54][17] + coeff0_55*dmats0[55][17];
          new_coeff0_18 = coeff0_0*dmats0[0][18] + coeff0_1*dmats0[1][18] + coeff0_2*dmats0[2][18] + coeff0_3*dmats0[3][18] + coeff0_4*dmats0[4][18] + coeff0_5*dmats0[5][18] + coeff0_6*dmats0[6][18] + coeff0_7*dmats0[7][18] + coeff0_8*dmats0[8][18] + coeff0_9*dmats0[9][18] + coeff0_10*dmats0[10][18] + coeff0_11*dmats0[11][18] + coeff0_12*dmats0[12][18] + coeff0_13*dmats0[13][18] + coeff0_14*dmats0[14][18] + coeff0_15*dmats0[15][18] + coeff0_16*dmats0[16][18] + coeff0_17*dmats0[17][18] + coeff0_18*dmats0[18][18] + coeff0_19*dmats0[19][18] + coeff0_20*dmats0[20][18] + coeff0_21*dmats0[21][18] + coeff0_22*dmats0[22][18] + coeff0_23*dmats0[23][18] + coeff0_24*dmats0[24][18] + coeff0_25*dmats0[25][18] + coeff0_26*dmats0[26][18] + coeff0_27*dmats0[27][18] + coeff0_28*dmats0[28][18] + coeff0_29*dmats0[29][18] + coeff0_30*dmats0[30][18] + coeff0_31*dmats0[31][18] + coeff0_32*dmats0[32][18] + coeff0_33*dmats0[33][18] + coeff0_34*dmats0[34][18] + coeff0_35*dmats0[35][18] + coeff0_36*dmats0[36][18] + coeff0_37*dmats0[37][18] + coeff0_38*dmats0[38][18] + coeff0_39*dmats0[39][18] + coeff0_40*dmats0[40][18] + coeff0_41*dmats0[41][18] + coeff0_42*dmats0[42][18] + coeff0_43*dmats0[43][18] + coeff0_44*dmats0[44][18] + coeff0_45*dmats0[45][18] + coeff0_46*dmats0[46][18] + coeff0_47*dmats0[47][18] + coeff0_48*dmats0[48][18] + coeff0_49*dmats0[49][18] + coeff0_50*dmats0[50][18] + coeff0_51*dmats0[51][18] + coeff0_52*dmats0[52][18] + coeff0_53*dmats0[53][18] + coeff0_54*dmats0[54][18] + coeff0_55*dmats0[55][18];
          new_coeff0_19 = coeff0_0*dmats0[0][19] + coeff0_1*dmats0[1][19] + coeff0_2*dmats0[2][19] + coeff0_3*dmats0[3][19] + coeff0_4*dmats0[4][19] + coeff0_5*dmats0[5][19] + coeff0_6*dmats0[6][19] + coeff0_7*dmats0[7][19] + coeff0_8*dmats0[8][19] + coeff0_9*dmats0[9][19] + coeff0_10*dmats0[10][19] + coeff0_11*dmats0[11][19] + coeff0_12*dmats0[12][19] + coeff0_13*dmats0[13][19] + coeff0_14*dmats0[14][19] + coeff0_15*dmats0[15][19] + coeff0_16*dmats0[16][19] + coeff0_17*dmats0[17][19] + coeff0_18*dmats0[18][19] + coeff0_19*dmats0[19][19] + coeff0_20*dmats0[20][19] + coeff0_21*dmats0[21][19] + coeff0_22*dmats0[22][19] + coeff0_23*dmats0[23][19] + coeff0_24*dmats0[24][19] + coeff0_25*dmats0[25][19] + coeff0_26*dmats0[26][19] + coeff0_27*dmats0[27][19] + coeff0_28*dmats0[28][19] + coeff0_29*dmats0[29][19] + coeff0_30*dmats0[30][19] + coeff0_31*dmats0[31][19] + coeff0_32*dmats0[32][19] + coeff0_33*dmats0[33][19] + coeff0_34*dmats0[34][19] + coeff0_35*dmats0[35][19] + coeff0_36*dmats0[36][19] + coeff0_37*dmats0[37][19] + coeff0_38*dmats0[38][19] + coeff0_39*dmats0[39][19] + coeff0_40*dmats0[40][19] + coeff0_41*dmats0[41][19] + coeff0_42*dmats0[42][19] + coeff0_43*dmats0[43][19] + coeff0_44*dmats0[44][19] + coeff0_45*dmats0[45][19] + coeff0_46*dmats0[46][19] + coeff0_47*dmats0[47][19] + coeff0_48*dmats0[48][19] + coeff0_49*dmats0[49][19] + coeff0_50*dmats0[50][19] + coeff0_51*dmats0[51][19] + coeff0_52*dmats0[52][19] + coeff0_53*dmats0[53][19] + coeff0_54*dmats0[54][19] + coeff0_55*dmats0[55][19];
          new_coeff0_20 = coeff0_0*dmats0[0][20] + coeff0_1*dmats0[1][20] + coeff0_2*dmats0[2][20] + coeff0_3*dmats0[3][20] + coeff0_4*dmats0[4][20] + coeff0_5*dmats0[5][20] + coeff0_6*dmats0[6][20] + coeff0_7*dmats0[7][20] + coeff0_8*dmats0[8][20] + coeff0_9*dmats0[9][20] + coeff0_10*dmats0[10][20] + coeff0_11*dmats0[11][20] + coeff0_12*dmats0[12][20] + coeff0_13*dmats0[13][20] + coeff0_14*dmats0[14][20] + coeff0_15*dmats0[15][20] + coeff0_16*dmats0[16][20] + coeff0_17*dmats0[17][20] + coeff0_18*dmats0[18][20] + coeff0_19*dmats0[19][20] + coeff0_20*dmats0[20][20] + coeff0_21*dmats0[21][20] + coeff0_22*dmats0[22][20] + coeff0_23*dmats0[23][20] + coeff0_24*dmats0[24][20] + coeff0_25*dmats0[25][20] + coeff0_26*dmats0[26][20] + coeff0_27*dmats0[27][20] + coeff0_28*dmats0[28][20] + coeff0_29*dmats0[29][20] + coeff0_30*dmats0[30][20] + coeff0_31*dmats0[31][20] + coeff0_32*dmats0[32][20] + coeff0_33*dmats0[33][20] + coeff0_34*dmats0[34][20] + coeff0_35*dmats0[35][20] + coeff0_36*dmats0[36][20] + coeff0_37*dmats0[37][20] + coeff0_38*dmats0[38][20] + coeff0_39*dmats0[39][20] + coeff0_40*dmats0[40][20] + coeff0_41*dmats0[41][20] + coeff0_42*dmats0[42][20] + coeff0_43*dmats0[43][20] + coeff0_44*dmats0[44][20] + coeff0_45*dmats0[45][20] + coeff0_46*dmats0[46][20] + coeff0_47*dmats0[47][20] + coeff0_48*dmats0[48][20] + coeff0_49*dmats0[49][20] + coeff0_50*dmats0[50][20] + coeff0_51*dmats0[51][20] + coeff0_52*dmats0[52][20] + coeff0_53*dmats0[53][20] + coeff0_54*dmats0[54][20] + coeff0_55*dmats0[55][20];
          new_coeff0_21 = coeff0_0*dmats0[0][21] + coeff0_1*dmats0[1][21] + coeff0_2*dmats0[2][21] + coeff0_3*dmats0[3][21] + coeff0_4*dmats0[4][21] + coeff0_5*dmats0[5][21] + coeff0_6*dmats0[6][21] + coeff0_7*dmats0[7][21] + coeff0_8*dmats0[8][21] + coeff0_9*dmats0[9][21] + coeff0_10*dmats0[10][21] + coeff0_11*dmats0[11][21] + coeff0_12*dmats0[12][21] + coeff0_13*dmats0[13][21] + coeff0_14*dmats0[14][21] + coeff0_15*dmats0[15][21] + coeff0_16*dmats0[16][21] + coeff0_17*dmats0[17][21] + coeff0_18*dmats0[18][21] + coeff0_19*dmats0[19][21] + coeff0_20*dmats0[20][21] + coeff0_21*dmats0[21][21] + coeff0_22*dmats0[22][21] + coeff0_23*dmats0[23][21] + coeff0_24*dmats0[24][21] + coeff0_25*dmats0[25][21] + coeff0_26*dmats0[26][21] + coeff0_27*dmats0[27][21] + coeff0_28*dmats0[28][21] + coeff0_29*dmats0[29][21] + coeff0_30*dmats0[30][21] + coeff0_31*dmats0[31][21] + coeff0_32*dmats0[32][21] + coeff0_33*dmats0[33][21] + coeff0_34*dmats0[34][21] + coeff0_35*dmats0[35][21] + coeff0_36*dmats0[36][21] + coeff0_37*dmats0[37][21] + coeff0_38*dmats0[38][21] + coeff0_39*dmats0[39][21] + coeff0_40*dmats0[40][21] + coeff0_41*dmats0[41][21] + coeff0_42*dmats0[42][21] + coeff0_43*dmats0[43][21] + coeff0_44*dmats0[44][21] + coeff0_45*dmats0[45][21] + coeff0_46*dmats0[46][21] + coeff0_47*dmats0[47][21] + coeff0_48*dmats0[48][21] + coeff0_49*dmats0[49][21] + coeff0_50*dmats0[50][21] + coeff0_51*dmats0[51][21] + coeff0_52*dmats0[52][21] + coeff0_53*dmats0[53][21] + coeff0_54*dmats0[54][21] + coeff0_55*dmats0[55][21];
          new_coeff0_22 = coeff0_0*dmats0[0][22] + coeff0_1*dmats0[1][22] + coeff0_2*dmats0[2][22] + coeff0_3*dmats0[3][22] + coeff0_4*dmats0[4][22] + coeff0_5*dmats0[5][22] + coeff0_6*dmats0[6][22] + coeff0_7*dmats0[7][22] + coeff0_8*dmats0[8][22] + coeff0_9*dmats0[9][22] + coeff0_10*dmats0[10][22] + coeff0_11*dmats0[11][22] + coeff0_12*dmats0[12][22] + coeff0_13*dmats0[13][22] + coeff0_14*dmats0[14][22] + coeff0_15*dmats0[15][22] + coeff0_16*dmats0[16][22] + coeff0_17*dmats0[17][22] + coeff0_18*dmats0[18][22] + coeff0_19*dmats0[19][22] + coeff0_20*dmats0[20][22] + coeff0_21*dmats0[21][22] + coeff0_22*dmats0[22][22] + coeff0_23*dmats0[23][22] + coeff0_24*dmats0[24][22] + coeff0_25*dmats0[25][22] + coeff0_26*dmats0[26][22] + coeff0_27*dmats0[27][22] + coeff0_28*dmats0[28][22] + coeff0_29*dmats0[29][22] + coeff0_30*dmats0[30][22] + coeff0_31*dmats0[31][22] + coeff0_32*dmats0[32][22] + coeff0_33*dmats0[33][22] + coeff0_34*dmats0[34][22] + coeff0_35*dmats0[35][22] + coeff0_36*dmats0[36][22] + coeff0_37*dmats0[37][22] + coeff0_38*dmats0[38][22] + coeff0_39*dmats0[39][22] + coeff0_40*dmats0[40][22] + coeff0_41*dmats0[41][22] + coeff0_42*dmats0[42][22] + coeff0_43*dmats0[43][22] + coeff0_44*dmats0[44][22] + coeff0_45*dmats0[45][22] + coeff0_46*dmats0[46][22] + coeff0_47*dmats0[47][22] + coeff0_48*dmats0[48][22] + coeff0_49*dmats0[49][22] + coeff0_50*dmats0[50][22] + coeff0_51*dmats0[51][22] + coeff0_52*dmats0[52][22] + coeff0_53*dmats0[53][22] + coeff0_54*dmats0[54][22] + coeff0_55*dmats0[55][22];
          new_coeff0_23 = coeff0_0*dmats0[0][23] + coeff0_1*dmats0[1][23] + coeff0_2*dmats0[2][23] + coeff0_3*dmats0[3][23] + coeff0_4*dmats0[4][23] + coeff0_5*dmats0[5][23] + coeff0_6*dmats0[6][23] + coeff0_7*dmats0[7][23] + coeff0_8*dmats0[8][23] + coeff0_9*dmats0[9][23] + coeff0_10*dmats0[10][23] + coeff0_11*dmats0[11][23] + coeff0_12*dmats0[12][23] + coeff0_13*dmats0[13][23] + coeff0_14*dmats0[14][23] + coeff0_15*dmats0[15][23] + coeff0_16*dmats0[16][23] + coeff0_17*dmats0[17][23] + coeff0_18*dmats0[18][23] + coeff0_19*dmats0[19][23] + coeff0_20*dmats0[20][23] + coeff0_21*dmats0[21][23] + coeff0_22*dmats0[22][23] + coeff0_23*dmats0[23][23] + coeff0_24*dmats0[24][23] + coeff0_25*dmats0[25][23] + coeff0_26*dmats0[26][23] + coeff0_27*dmats0[27][23] + coeff0_28*dmats0[28][23] + coeff0_29*dmats0[29][23] + coeff0_30*dmats0[30][23] + coeff0_31*dmats0[31][23] + coeff0_32*dmats0[32][23] + coeff0_33*dmats0[33][23] + coeff0_34*dmats0[34][23] + coeff0_35*dmats0[35][23] + coeff0_36*dmats0[36][23] + coeff0_37*dmats0[37][23] + coeff0_38*dmats0[38][23] + coeff0_39*dmats0[39][23] + coeff0_40*dmats0[40][23] + coeff0_41*dmats0[41][23] + coeff0_42*dmats0[42][23] + coeff0_43*dmats0[43][23] + coeff0_44*dmats0[44][23] + coeff0_45*dmats0[45][23] + coeff0_46*dmats0[46][23] + coeff0_47*dmats0[47][23] + coeff0_48*dmats0[48][23] + coeff0_49*dmats0[49][23] + coeff0_50*dmats0[50][23] + coeff0_51*dmats0[51][23] + coeff0_52*dmats0[52][23] + coeff0_53*dmats0[53][23] + coeff0_54*dmats0[54][23] + coeff0_55*dmats0[55][23];
          new_coeff0_24 = coeff0_0*dmats0[0][24] + coeff0_1*dmats0[1][24] + coeff0_2*dmats0[2][24] + coeff0_3*dmats0[3][24] + coeff0_4*dmats0[4][24] + coeff0_5*dmats0[5][24] + coeff0_6*dmats0[6][24] + coeff0_7*dmats0[7][24] + coeff0_8*dmats0[8][24] + coeff0_9*dmats0[9][24] + coeff0_10*dmats0[10][24] + coeff0_11*dmats0[11][24] + coeff0_12*dmats0[12][24] + coeff0_13*dmats0[13][24] + coeff0_14*dmats0[14][24] + coeff0_15*dmats0[15][24] + coeff0_16*dmats0[16][24] + coeff0_17*dmats0[17][24] + coeff0_18*dmats0[18][24] + coeff0_19*dmats0[19][24] + coeff0_20*dmats0[20][24] + coeff0_21*dmats0[21][24] + coeff0_22*dmats0[22][24] + coeff0_23*dmats0[23][24] + coeff0_24*dmats0[24][24] + coeff0_25*dmats0[25][24] + coeff0_26*dmats0[26][24] + coeff0_27*dmats0[27][24] + coeff0_28*dmats0[28][24] + coeff0_29*dmats0[29][24] + coeff0_30*dmats0[30][24] + coeff0_31*dmats0[31][24] + coeff0_32*dmats0[32][24] + coeff0_33*dmats0[33][24] + coeff0_34*dmats0[34][24] + coeff0_35*dmats0[35][24] + coeff0_36*dmats0[36][24] + coeff0_37*dmats0[37][24] + coeff0_38*dmats0[38][24] + coeff0_39*dmats0[39][24] + coeff0_40*dmats0[40][24] + coeff0_41*dmats0[41][24] + coeff0_42*dmats0[42][24] + coeff0_43*dmats0[43][24] + coeff0_44*dmats0[44][24] + coeff0_45*dmats0[45][24] + coeff0_46*dmats0[46][24] + coeff0_47*dmats0[47][24] + coeff0_48*dmats0[48][24] + coeff0_49*dmats0[49][24] + coeff0_50*dmats0[50][24] + coeff0_51*dmats0[51][24] + coeff0_52*dmats0[52][24] + coeff0_53*dmats0[53][24] + coeff0_54*dmats0[54][24] + coeff0_55*dmats0[55][24];
          new_coeff0_25 = coeff0_0*dmats0[0][25] + coeff0_1*dmats0[1][25] + coeff0_2*dmats0[2][25] + coeff0_3*dmats0[3][25] + coeff0_4*dmats0[4][25] + coeff0_5*dmats0[5][25] + coeff0_6*dmats0[6][25] + coeff0_7*dmats0[7][25] + coeff0_8*dmats0[8][25] + coeff0_9*dmats0[9][25] + coeff0_10*dmats0[10][25] + coeff0_11*dmats0[11][25] + coeff0_12*dmats0[12][25] + coeff0_13*dmats0[13][25] + coeff0_14*dmats0[14][25] + coeff0_15*dmats0[15][25] + coeff0_16*dmats0[16][25] + coeff0_17*dmats0[17][25] + coeff0_18*dmats0[18][25] + coeff0_19*dmats0[19][25] + coeff0_20*dmats0[20][25] + coeff0_21*dmats0[21][25] + coeff0_22*dmats0[22][25] + coeff0_23*dmats0[23][25] + coeff0_24*dmats0[24][25] + coeff0_25*dmats0[25][25] + coeff0_26*dmats0[26][25] + coeff0_27*dmats0[27][25] + coeff0_28*dmats0[28][25] + coeff0_29*dmats0[29][25] + coeff0_30*dmats0[30][25] + coeff0_31*dmats0[31][25] + coeff0_32*dmats0[32][25] + coeff0_33*dmats0[33][25] + coeff0_34*dmats0[34][25] + coeff0_35*dmats0[35][25] + coeff0_36*dmats0[36][25] + coeff0_37*dmats0[37][25] + coeff0_38*dmats0[38][25] + coeff0_39*dmats0[39][25] + coeff0_40*dmats0[40][25] + coeff0_41*dmats0[41][25] + coeff0_42*dmats0[42][25] + coeff0_43*dmats0[43][25] + coeff0_44*dmats0[44][25] + coeff0_45*dmats0[45][25] + coeff0_46*dmats0[46][25] + coeff0_47*dmats0[47][25] + coeff0_48*dmats0[48][25] + coeff0_49*dmats0[49][25] + coeff0_50*dmats0[50][25] + coeff0_51*dmats0[51][25] + coeff0_52*dmats0[52][25] + coeff0_53*dmats0[53][25] + coeff0_54*dmats0[54][25] + coeff0_55*dmats0[55][25];
          new_coeff0_26 = coeff0_0*dmats0[0][26] + coeff0_1*dmats0[1][26] + coeff0_2*dmats0[2][26] + coeff0_3*dmats0[3][26] + coeff0_4*dmats0[4][26] + coeff0_5*dmats0[5][26] + coeff0_6*dmats0[6][26] + coeff0_7*dmats0[7][26] + coeff0_8*dmats0[8][26] + coeff0_9*dmats0[9][26] + coeff0_10*dmats0[10][26] + coeff0_11*dmats0[11][26] + coeff0_12*dmats0[12][26] + coeff0_13*dmats0[13][26] + coeff0_14*dmats0[14][26] + coeff0_15*dmats0[15][26] + coeff0_16*dmats0[16][26] + coeff0_17*dmats0[17][26] + coeff0_18*dmats0[18][26] + coeff0_19*dmats0[19][26] + coeff0_20*dmats0[20][26] + coeff0_21*dmats0[21][26] + coeff0_22*dmats0[22][26] + coeff0_23*dmats0[23][26] + coeff0_24*dmats0[24][26] + coeff0_25*dmats0[25][26] + coeff0_26*dmats0[26][26] + coeff0_27*dmats0[27][26] + coeff0_28*dmats0[28][26] + coeff0_29*dmats0[29][26] + coeff0_30*dmats0[30][26] + coeff0_31*dmats0[31][26] + coeff0_32*dmats0[32][26] + coeff0_33*dmats0[33][26] + coeff0_34*dmats0[34][26] + coeff0_35*dmats0[35][26] + coeff0_36*dmats0[36][26] + coeff0_37*dmats0[37][26] + coeff0_38*dmats0[38][26] + coeff0_39*dmats0[39][26] + coeff0_40*dmats0[40][26] + coeff0_41*dmats0[41][26] + coeff0_42*dmats0[42][26] + coeff0_43*dmats0[43][26] + coeff0_44*dmats0[44][26] + coeff0_45*dmats0[45][26] + coeff0_46*dmats0[46][26] + coeff0_47*dmats0[47][26] + coeff0_48*dmats0[48][26] + coeff0_49*dmats0[49][26] + coeff0_50*dmats0[50][26] + coeff0_51*dmats0[51][26] + coeff0_52*dmats0[52][26] + coeff0_53*dmats0[53][26] + coeff0_54*dmats0[54][26] + coeff0_55*dmats0[55][26];
          new_coeff0_27 = coeff0_0*dmats0[0][27] + coeff0_1*dmats0[1][27] + coeff0_2*dmats0[2][27] + coeff0_3*dmats0[3][27] + coeff0_4*dmats0[4][27] + coeff0_5*dmats0[5][27] + coeff0_6*dmats0[6][27] + coeff0_7*dmats0[7][27] + coeff0_8*dmats0[8][27] + coeff0_9*dmats0[9][27] + coeff0_10*dmats0[10][27] + coeff0_11*dmats0[11][27] + coeff0_12*dmats0[12][27] + coeff0_13*dmats0[13][27] + coeff0_14*dmats0[14][27] + coeff0_15*dmats0[15][27] + coeff0_16*dmats0[16][27] + coeff0_17*dmats0[17][27] + coeff0_18*dmats0[18][27] + coeff0_19*dmats0[19][27] + coeff0_20*dmats0[20][27] + coeff0_21*dmats0[21][27] + coeff0_22*dmats0[22][27] + coeff0_23*dmats0[23][27] + coeff0_24*dmats0[24][27] + coeff0_25*dmats0[25][27] + coeff0_26*dmats0[26][27] + coeff0_27*dmats0[27][27] + coeff0_28*dmats0[28][27] + coeff0_29*dmats0[29][27] + coeff0_30*dmats0[30][27] + coeff0_31*dmats0[31][27] + coeff0_32*dmats0[32][27] + coeff0_33*dmats0[33][27] + coeff0_34*dmats0[34][27] + coeff0_35*dmats0[35][27] + coeff0_36*dmats0[36][27] + coeff0_37*dmats0[37][27] + coeff0_38*dmats0[38][27] + coeff0_39*dmats0[39][27] + coeff0_40*dmats0[40][27] + coeff0_41*dmats0[41][27] + coeff0_42*dmats0[42][27] + coeff0_43*dmats0[43][27] + coeff0_44*dmats0[44][27] + coeff0_45*dmats0[45][27] + coeff0_46*dmats0[46][27] + coeff0_47*dmats0[47][27] + coeff0_48*dmats0[48][27] + coeff0_49*dmats0[49][27] + coeff0_50*dmats0[50][27] + coeff0_51*dmats0[51][27] + coeff0_52*dmats0[52][27] + coeff0_53*dmats0[53][27] + coeff0_54*dmats0[54][27] + coeff0_55*dmats0[55][27];
          new_coeff0_28 = coeff0_0*dmats0[0][28] + coeff0_1*dmats0[1][28] + coeff0_2*dmats0[2][28] + coeff0_3*dmats0[3][28] + coeff0_4*dmats0[4][28] + coeff0_5*dmats0[5][28] + coeff0_6*dmats0[6][28] + coeff0_7*dmats0[7][28] + coeff0_8*dmats0[8][28] + coeff0_9*dmats0[9][28] + coeff0_10*dmats0[10][28] + coeff0_11*dmats0[11][28] + coeff0_12*dmats0[12][28] + coeff0_13*dmats0[13][28] + coeff0_14*dmats0[14][28] + coeff0_15*dmats0[15][28] + coeff0_16*dmats0[16][28] + coeff0_17*dmats0[17][28] + coeff0_18*dmats0[18][28] + coeff0_19*dmats0[19][28] + coeff0_20*dmats0[20][28] + coeff0_21*dmats0[21][28] + coeff0_22*dmats0[22][28] + coeff0_23*dmats0[23][28] + coeff0_24*dmats0[24][28] + coeff0_25*dmats0[25][28] + coeff0_26*dmats0[26][28] + coeff0_27*dmats0[27][28] + coeff0_28*dmats0[28][28] + coeff0_29*dmats0[29][28] + coeff0_30*dmats0[30][28] + coeff0_31*dmats0[31][28] + coeff0_32*dmats0[32][28] + coeff0_33*dmats0[33][28] + coeff0_34*dmats0[34][28] + coeff0_35*dmats0[35][28] + coeff0_36*dmats0[36][28] + coeff0_37*dmats0[37][28] + coeff0_38*dmats0[38][28] + coeff0_39*dmats0[39][28] + coeff0_40*dmats0[40][28] + coeff0_41*dmats0[41][28] + coeff0_42*dmats0[42][28] + coeff0_43*dmats0[43][28] + coeff0_44*dmats0[44][28] + coeff0_45*dmats0[45][28] + coeff0_46*dmats0[46][28] + coeff0_47*dmats0[47][28] + coeff0_48*dmats0[48][28] + coeff0_49*dmats0[49][28] + coeff0_50*dmats0[50][28] + coeff0_51*dmats0[51][28] + coeff0_52*dmats0[52][28] + coeff0_53*dmats0[53][28] + coeff0_54*dmats0[54][28] + coeff0_55*dmats0[55][28];
          new_coeff0_29 = coeff0_0*dmats0[0][29] + coeff0_1*dmats0[1][29] + coeff0_2*dmats0[2][29] + coeff0_3*dmats0[3][29] + coeff0_4*dmats0[4][29] + coeff0_5*dmats0[5][29] + coeff0_6*dmats0[6][29] + coeff0_7*dmats0[7][29] + coeff0_8*dmats0[8][29] + coeff0_9*dmats0[9][29] + coeff0_10*dmats0[10][29] + coeff0_11*dmats0[11][29] + coeff0_12*dmats0[12][29] + coeff0_13*dmats0[13][29] + coeff0_14*dmats0[14][29] + coeff0_15*dmats0[15][29] + coeff0_16*dmats0[16][29] + coeff0_17*dmats0[17][29] + coeff0_18*dmats0[18][29] + coeff0_19*dmats0[19][29] + coeff0_20*dmats0[20][29] + coeff0_21*dmats0[21][29] + coeff0_22*dmats0[22][29] + coeff0_23*dmats0[23][29] + coeff0_24*dmats0[24][29] + coeff0_25*dmats0[25][29] + coeff0_26*dmats0[26][29] + coeff0_27*dmats0[27][29] + coeff0_28*dmats0[28][29] + coeff0_29*dmats0[29][29] + coeff0_30*dmats0[30][29] + coeff0_31*dmats0[31][29] + coeff0_32*dmats0[32][29] + coeff0_33*dmats0[33][29] + coeff0_34*dmats0[34][29] + coeff0_35*dmats0[35][29] + coeff0_36*dmats0[36][29] + coeff0_37*dmats0[37][29] + coeff0_38*dmats0[38][29] + coeff0_39*dmats0[39][29] + coeff0_40*dmats0[40][29] + coeff0_41*dmats0[41][29] + coeff0_42*dmats0[42][29] + coeff0_43*dmats0[43][29] + coeff0_44*dmats0[44][29] + coeff0_45*dmats0[45][29] + coeff0_46*dmats0[46][29] + coeff0_47*dmats0[47][29] + coeff0_48*dmats0[48][29] + coeff0_49*dmats0[49][29] + coeff0_50*dmats0[50][29] + coeff0_51*dmats0[51][29] + coeff0_52*dmats0[52][29] + coeff0_53*dmats0[53][29] + coeff0_54*dmats0[54][29] + coeff0_55*dmats0[55][29];
          new_coeff0_30 = coeff0_0*dmats0[0][30] + coeff0_1*dmats0[1][30] + coeff0_2*dmats0[2][30] + coeff0_3*dmats0[3][30] + coeff0_4*dmats0[4][30] + coeff0_5*dmats0[5][30] + coeff0_6*dmats0[6][30] + coeff0_7*dmats0[7][30] + coeff0_8*dmats0[8][30] + coeff0_9*dmats0[9][30] + coeff0_10*dmats0[10][30] + coeff0_11*dmats0[11][30] + coeff0_12*dmats0[12][30] + coeff0_13*dmats0[13][30] + coeff0_14*dmats0[14][30] + coeff0_15*dmats0[15][30] + coeff0_16*dmats0[16][30] + coeff0_17*dmats0[17][30] + coeff0_18*dmats0[18][30] + coeff0_19*dmats0[19][30] + coeff0_20*dmats0[20][30] + coeff0_21*dmats0[21][30] + coeff0_22*dmats0[22][30] + coeff0_23*dmats0[23][30] + coeff0_24*dmats0[24][30] + coeff0_25*dmats0[25][30] + coeff0_26*dmats0[26][30] + coeff0_27*dmats0[27][30] + coeff0_28*dmats0[28][30] + coeff0_29*dmats0[29][30] + coeff0_30*dmats0[30][30] + coeff0_31*dmats0[31][30] + coeff0_32*dmats0[32][30] + coeff0_33*dmats0[33][30] + coeff0_34*dmats0[34][30] + coeff0_35*dmats0[35][30] + coeff0_36*dmats0[36][30] + coeff0_37*dmats0[37][30] + coeff0_38*dmats0[38][30] + coeff0_39*dmats0[39][30] + coeff0_40*dmats0[40][30] + coeff0_41*dmats0[41][30] + coeff0_42*dmats0[42][30] + coeff0_43*dmats0[43][30] + coeff0_44*dmats0[44][30] + coeff0_45*dmats0[45][30] + coeff0_46*dmats0[46][30] + coeff0_47*dmats0[47][30] + coeff0_48*dmats0[48][30] + coeff0_49*dmats0[49][30] + coeff0_50*dmats0[50][30] + coeff0_51*dmats0[51][30] + coeff0_52*dmats0[52][30] + coeff0_53*dmats0[53][30] + coeff0_54*dmats0[54][30] + coeff0_55*dmats0[55][30];
          new_coeff0_31 = coeff0_0*dmats0[0][31] + coeff0_1*dmats0[1][31] + coeff0_2*dmats0[2][31] + coeff0_3*dmats0[3][31] + coeff0_4*dmats0[4][31] + coeff0_5*dmats0[5][31] + coeff0_6*dmats0[6][31] + coeff0_7*dmats0[7][31] + coeff0_8*dmats0[8][31] + coeff0_9*dmats0[9][31] + coeff0_10*dmats0[10][31] + coeff0_11*dmats0[11][31] + coeff0_12*dmats0[12][31] + coeff0_13*dmats0[13][31] + coeff0_14*dmats0[14][31] + coeff0_15*dmats0[15][31] + coeff0_16*dmats0[16][31] + coeff0_17*dmats0[17][31] + coeff0_18*dmats0[18][31] + coeff0_19*dmats0[19][31] + coeff0_20*dmats0[20][31] + coeff0_21*dmats0[21][31] + coeff0_22*dmats0[22][31] + coeff0_23*dmats0[23][31] + coeff0_24*dmats0[24][31] + coeff0_25*dmats0[25][31] + coeff0_26*dmats0[26][31] + coeff0_27*dmats0[27][31] + coeff0_28*dmats0[28][31] + coeff0_29*dmats0[29][31] + coeff0_30*dmats0[30][31] + coeff0_31*dmats0[31][31] + coeff0_32*dmats0[32][31] + coeff0_33*dmats0[33][31] + coeff0_34*dmats0[34][31] + coeff0_35*dmats0[35][31] + coeff0_36*dmats0[36][31] + coeff0_37*dmats0[37][31] + coeff0_38*dmats0[38][31] + coeff0_39*dmats0[39][31] + coeff0_40*dmats0[40][31] + coeff0_41*dmats0[41][31] + coeff0_42*dmats0[42][31] + coeff0_43*dmats0[43][31] + coeff0_44*dmats0[44][31] + coeff0_45*dmats0[45][31] + coeff0_46*dmats0[46][31] + coeff0_47*dmats0[47][31] + coeff0_48*dmats0[48][31] + coeff0_49*dmats0[49][31] + coeff0_50*dmats0[50][31] + coeff0_51*dmats0[51][31] + coeff0_52*dmats0[52][31] + coeff0_53*dmats0[53][31] + coeff0_54*dmats0[54][31] + coeff0_55*dmats0[55][31];
          new_coeff0_32 = coeff0_0*dmats0[0][32] + coeff0_1*dmats0[1][32] + coeff0_2*dmats0[2][32] + coeff0_3*dmats0[3][32] + coeff0_4*dmats0[4][32] + coeff0_5*dmats0[5][32] + coeff0_6*dmats0[6][32] + coeff0_7*dmats0[7][32] + coeff0_8*dmats0[8][32] + coeff0_9*dmats0[9][32] + coeff0_10*dmats0[10][32] + coeff0_11*dmats0[11][32] + coeff0_12*dmats0[12][32] + coeff0_13*dmats0[13][32] + coeff0_14*dmats0[14][32] + coeff0_15*dmats0[15][32] + coeff0_16*dmats0[16][32] + coeff0_17*dmats0[17][32] + coeff0_18*dmats0[18][32] + coeff0_19*dmats0[19][32] + coeff0_20*dmats0[20][32] + coeff0_21*dmats0[21][32] + coeff0_22*dmats0[22][32] + coeff0_23*dmats0[23][32] + coeff0_24*dmats0[24][32] + coeff0_25*dmats0[25][32] + coeff0_26*dmats0[26][32] + coeff0_27*dmats0[27][32] + coeff0_28*dmats0[28][32] + coeff0_29*dmats0[29][32] + coeff0_30*dmats0[30][32] + coeff0_31*dmats0[31][32] + coeff0_32*dmats0[32][32] + coeff0_33*dmats0[33][32] + coeff0_34*dmats0[34][32] + coeff0_35*dmats0[35][32] + coeff0_36*dmats0[36][32] + coeff0_37*dmats0[37][32] + coeff0_38*dmats0[38][32] + coeff0_39*dmats0[39][32] + coeff0_40*dmats0[40][32] + coeff0_41*dmats0[41][32] + coeff0_42*dmats0[42][32] + coeff0_43*dmats0[43][32] + coeff0_44*dmats0[44][32] + coeff0_45*dmats0[45][32] + coeff0_46*dmats0[46][32] + coeff0_47*dmats0[47][32] + coeff0_48*dmats0[48][32] + coeff0_49*dmats0[49][32] + coeff0_50*dmats0[50][32] + coeff0_51*dmats0[51][32] + coeff0_52*dmats0[52][32] + coeff0_53*dmats0[53][32] + coeff0_54*dmats0[54][32] + coeff0_55*dmats0[55][32];
          new_coeff0_33 = coeff0_0*dmats0[0][33] + coeff0_1*dmats0[1][33] + coeff0_2*dmats0[2][33] + coeff0_3*dmats0[3][33] + coeff0_4*dmats0[4][33] + coeff0_5*dmats0[5][33] + coeff0_6*dmats0[6][33] + coeff0_7*dmats0[7][33] + coeff0_8*dmats0[8][33] + coeff0_9*dmats0[9][33] + coeff0_10*dmats0[10][33] + coeff0_11*dmats0[11][33] + coeff0_12*dmats0[12][33] + coeff0_13*dmats0[13][33] + coeff0_14*dmats0[14][33] + coeff0_15*dmats0[15][33] + coeff0_16*dmats0[16][33] + coeff0_17*dmats0[17][33] + coeff0_18*dmats0[18][33] + coeff0_19*dmats0[19][33] + coeff0_20*dmats0[20][33] + coeff0_21*dmats0[21][33] + coeff0_22*dmats0[22][33] + coeff0_23*dmats0[23][33] + coeff0_24*dmats0[24][33] + coeff0_25*dmats0[25][33] + coeff0_26*dmats0[26][33] + coeff0_27*dmats0[27][33] + coeff0_28*dmats0[28][33] + coeff0_29*dmats0[29][33] + coeff0_30*dmats0[30][33] + coeff0_31*dmats0[31][33] + coeff0_32*dmats0[32][33] + coeff0_33*dmats0[33][33] + coeff0_34*dmats0[34][33] + coeff0_35*dmats0[35][33] + coeff0_36*dmats0[36][33] + coeff0_37*dmats0[37][33] + coeff0_38*dmats0[38][33] + coeff0_39*dmats0[39][33] + coeff0_40*dmats0[40][33] + coeff0_41*dmats0[41][33] + coeff0_42*dmats0[42][33] + coeff0_43*dmats0[43][33] + coeff0_44*dmats0[44][33] + coeff0_45*dmats0[45][33] + coeff0_46*dmats0[46][33] + coeff0_47*dmats0[47][33] + coeff0_48*dmats0[48][33] + coeff0_49*dmats0[49][33] + coeff0_50*dmats0[50][33] + coeff0_51*dmats0[51][33] + coeff0_52*dmats0[52][33] + coeff0_53*dmats0[53][33] + coeff0_54*dmats0[54][33] + coeff0_55*dmats0[55][33];
          new_coeff0_34 = coeff0_0*dmats0[0][34] + coeff0_1*dmats0[1][34] + coeff0_2*dmats0[2][34] + coeff0_3*dmats0[3][34] + coeff0_4*dmats0[4][34] + coeff0_5*dmats0[5][34] + coeff0_6*dmats0[6][34] + coeff0_7*dmats0[7][34] + coeff0_8*dmats0[8][34] + coeff0_9*dmats0[9][34] + coeff0_10*dmats0[10][34] + coeff0_11*dmats0[11][34] + coeff0_12*dmats0[12][34] + coeff0_13*dmats0[13][34] + coeff0_14*dmats0[14][34] + coeff0_15*dmats0[15][34] + coeff0_16*dmats0[16][34] + coeff0_17*dmats0[17][34] + coeff0_18*dmats0[18][34] + coeff0_19*dmats0[19][34] + coeff0_20*dmats0[20][34] + coeff0_21*dmats0[21][34] + coeff0_22*dmats0[22][34] + coeff0_23*dmats0[23][34] + coeff0_24*dmats0[24][34] + coeff0_25*dmats0[25][34] + coeff0_26*dmats0[26][34] + coeff0_27*dmats0[27][34] + coeff0_28*dmats0[28][34] + coeff0_29*dmats0[29][34] + coeff0_30*dmats0[30][34] + coeff0_31*dmats0[31][34] + coeff0_32*dmats0[32][34] + coeff0_33*dmats0[33][34] + coeff0_34*dmats0[34][34] + coeff0_35*dmats0[35][34] + coeff0_36*dmats0[36][34] + coeff0_37*dmats0[37][34] + coeff0_38*dmats0[38][34] + coeff0_39*dmats0[39][34] + coeff0_40*dmats0[40][34] + coeff0_41*dmats0[41][34] + coeff0_42*dmats0[42][34] + coeff0_43*dmats0[43][34] + coeff0_44*dmats0[44][34] + coeff0_45*dmats0[45][34] + coeff0_46*dmats0[46][34] + coeff0_47*dmats0[47][34] + coeff0_48*dmats0[48][34] + coeff0_49*dmats0[49][34] + coeff0_50*dmats0[50][34] + coeff0_51*dmats0[51][34] + coeff0_52*dmats0[52][34] + coeff0_53*dmats0[53][34] + coeff0_54*dmats0[54][34] + coeff0_55*dmats0[55][34];
          new_coeff0_35 = coeff0_0*dmats0[0][35] + coeff0_1*dmats0[1][35] + coeff0_2*dmats0[2][35] + coeff0_3*dmats0[3][35] + coeff0_4*dmats0[4][35] + coeff0_5*dmats0[5][35] + coeff0_6*dmats0[6][35] + coeff0_7*dmats0[7][35] + coeff0_8*dmats0[8][35] + coeff0_9*dmats0[9][35] + coeff0_10*dmats0[10][35] + coeff0_11*dmats0[11][35] + coeff0_12*dmats0[12][35] + coeff0_13*dmats0[13][35] + coeff0_14*dmats0[14][35] + coeff0_15*dmats0[15][35] + coeff0_16*dmats0[16][35] + coeff0_17*dmats0[17][35] + coeff0_18*dmats0[18][35] + coeff0_19*dmats0[19][35] + coeff0_20*dmats0[20][35] + coeff0_21*dmats0[21][35] + coeff0_22*dmats0[22][35] + coeff0_23*dmats0[23][35] + coeff0_24*dmats0[24][35] + coeff0_25*dmats0[25][35] + coeff0_26*dmats0[26][35] + coeff0_27*dmats0[27][35] + coeff0_28*dmats0[28][35] + coeff0_29*dmats0[29][35] + coeff0_30*dmats0[30][35] + coeff0_31*dmats0[31][35] + coeff0_32*dmats0[32][35] + coeff0_33*dmats0[33][35] + coeff0_34*dmats0[34][35] + coeff0_35*dmats0[35][35] + coeff0_36*dmats0[36][35] + coeff0_37*dmats0[37][35] + coeff0_38*dmats0[38][35] + coeff0_39*dmats0[39][35] + coeff0_40*dmats0[40][35] + coeff0_41*dmats0[41][35] + coeff0_42*dmats0[42][35] + coeff0_43*dmats0[43][35] + coeff0_44*dmats0[44][35] + coeff0_45*dmats0[45][35] + coeff0_46*dmats0[46][35] + coeff0_47*dmats0[47][35] + coeff0_48*dmats0[48][35] + coeff0_49*dmats0[49][35] + coeff0_50*dmats0[50][35] + coeff0_51*dmats0[51][35] + coeff0_52*dmats0[52][35] + coeff0_53*dmats0[53][35] + coeff0_54*dmats0[54][35] + coeff0_55*dmats0[55][35];
          new_coeff0_36 = coeff0_0*dmats0[0][36] + coeff0_1*dmats0[1][36] + coeff0_2*dmats0[2][36] + coeff0_3*dmats0[3][36] + coeff0_4*dmats0[4][36] + coeff0_5*dmats0[5][36] + coeff0_6*dmats0[6][36] + coeff0_7*dmats0[7][36] + coeff0_8*dmats0[8][36] + coeff0_9*dmats0[9][36] + coeff0_10*dmats0[10][36] + coeff0_11*dmats0[11][36] + coeff0_12*dmats0[12][36] + coeff0_13*dmats0[13][36] + coeff0_14*dmats0[14][36] + coeff0_15*dmats0[15][36] + coeff0_16*dmats0[16][36] + coeff0_17*dmats0[17][36] + coeff0_18*dmats0[18][36] + coeff0_19*dmats0[19][36] + coeff0_20*dmats0[20][36] + coeff0_21*dmats0[21][36] + coeff0_22*dmats0[22][36] + coeff0_23*dmats0[23][36] + coeff0_24*dmats0[24][36] + coeff0_25*dmats0[25][36] + coeff0_26*dmats0[26][36] + coeff0_27*dmats0[27][36] + coeff0_28*dmats0[28][36] + coeff0_29*dmats0[29][36] + coeff0_30*dmats0[30][36] + coeff0_31*dmats0[31][36] + coeff0_32*dmats0[32][36] + coeff0_33*dmats0[33][36] + coeff0_34*dmats0[34][36] + coeff0_35*dmats0[35][36] + coeff0_36*dmats0[36][36] + coeff0_37*dmats0[37][36] + coeff0_38*dmats0[38][36] + coeff0_39*dmats0[39][36] + coeff0_40*dmats0[40][36] + coeff0_41*dmats0[41][36] + coeff0_42*dmats0[42][36] + coeff0_43*dmats0[43][36] + coeff0_44*dmats0[44][36] + coeff0_45*dmats0[45][36] + coeff0_46*dmats0[46][36] + coeff0_47*dmats0[47][36] + coeff0_48*dmats0[48][36] + coeff0_49*dmats0[49][36] + coeff0_50*dmats0[50][36] + coeff0_51*dmats0[51][36] + coeff0_52*dmats0[52][36] + coeff0_53*dmats0[53][36] + coeff0_54*dmats0[54][36] + coeff0_55*dmats0[55][36];
          new_coeff0_37 = coeff0_0*dmats0[0][37] + coeff0_1*dmats0[1][37] + coeff0_2*dmats0[2][37] + coeff0_3*dmats0[3][37] + coeff0_4*dmats0[4][37] + coeff0_5*dmats0[5][37] + coeff0_6*dmats0[6][37] + coeff0_7*dmats0[7][37] + coeff0_8*dmats0[8][37] + coeff0_9*dmats0[9][37] + coeff0_10*dmats0[10][37] + coeff0_11*dmats0[11][37] + coeff0_12*dmats0[12][37] + coeff0_13*dmats0[13][37] + coeff0_14*dmats0[14][37] + coeff0_15*dmats0[15][37] + coeff0_16*dmats0[16][37] + coeff0_17*dmats0[17][37] + coeff0_18*dmats0[18][37] + coeff0_19*dmats0[19][37] + coeff0_20*dmats0[20][37] + coeff0_21*dmats0[21][37] + coeff0_22*dmats0[22][37] + coeff0_23*dmats0[23][37] + coeff0_24*dmats0[24][37] + coeff0_25*dmats0[25][37] + coeff0_26*dmats0[26][37] + coeff0_27*dmats0[27][37] + coeff0_28*dmats0[28][37] + coeff0_29*dmats0[29][37] + coeff0_30*dmats0[30][37] + coeff0_31*dmats0[31][37] + coeff0_32*dmats0[32][37] + coeff0_33*dmats0[33][37] + coeff0_34*dmats0[34][37] + coeff0_35*dmats0[35][37] + coeff0_36*dmats0[36][37] + coeff0_37*dmats0[37][37] + coeff0_38*dmats0[38][37] + coeff0_39*dmats0[39][37] + coeff0_40*dmats0[40][37] + coeff0_41*dmats0[41][37] + coeff0_42*dmats0[42][37] + coeff0_43*dmats0[43][37] + coeff0_44*dmats0[44][37] + coeff0_45*dmats0[45][37] + coeff0_46*dmats0[46][37] + coeff0_47*dmats0[47][37] + coeff0_48*dmats0[48][37] + coeff0_49*dmats0[49][37] + coeff0_50*dmats0[50][37] + coeff0_51*dmats0[51][37] + coeff0_52*dmats0[52][37] + coeff0_53*dmats0[53][37] + coeff0_54*dmats0[54][37] + coeff0_55*dmats0[55][37];
          new_coeff0_38 = coeff0_0*dmats0[0][38] + coeff0_1*dmats0[1][38] + coeff0_2*dmats0[2][38] + coeff0_3*dmats0[3][38] + coeff0_4*dmats0[4][38] + coeff0_5*dmats0[5][38] + coeff0_6*dmats0[6][38] + coeff0_7*dmats0[7][38] + coeff0_8*dmats0[8][38] + coeff0_9*dmats0[9][38] + coeff0_10*dmats0[10][38] + coeff0_11*dmats0[11][38] + coeff0_12*dmats0[12][38] + coeff0_13*dmats0[13][38] + coeff0_14*dmats0[14][38] + coeff0_15*dmats0[15][38] + coeff0_16*dmats0[16][38] + coeff0_17*dmats0[17][38] + coeff0_18*dmats0[18][38] + coeff0_19*dmats0[19][38] + coeff0_20*dmats0[20][38] + coeff0_21*dmats0[21][38] + coeff0_22*dmats0[22][38] + coeff0_23*dmats0[23][38] + coeff0_24*dmats0[24][38] + coeff0_25*dmats0[25][38] + coeff0_26*dmats0[26][38] + coeff0_27*dmats0[27][38] + coeff0_28*dmats0[28][38] + coeff0_29*dmats0[29][38] + coeff0_30*dmats0[30][38] + coeff0_31*dmats0[31][38] + coeff0_32*dmats0[32][38] + coeff0_33*dmats0[33][38] + coeff0_34*dmats0[34][38] + coeff0_35*dmats0[35][38] + coeff0_36*dmats0[36][38] + coeff0_37*dmats0[37][38] + coeff0_38*dmats0[38][38] + coeff0_39*dmats0[39][38] + coeff0_40*dmats0[40][38] + coeff0_41*dmats0[41][38] + coeff0_42*dmats0[42][38] + coeff0_43*dmats0[43][38] + coeff0_44*dmats0[44][38] + coeff0_45*dmats0[45][38] + coeff0_46*dmats0[46][38] + coeff0_47*dmats0[47][38] + coeff0_48*dmats0[48][38] + coeff0_49*dmats0[49][38] + coeff0_50*dmats0[50][38] + coeff0_51*dmats0[51][38] + coeff0_52*dmats0[52][38] + coeff0_53*dmats0[53][38] + coeff0_54*dmats0[54][38] + coeff0_55*dmats0[55][38];
          new_coeff0_39 = coeff0_0*dmats0[0][39] + coeff0_1*dmats0[1][39] + coeff0_2*dmats0[2][39] + coeff0_3*dmats0[3][39] + coeff0_4*dmats0[4][39] + coeff0_5*dmats0[5][39] + coeff0_6*dmats0[6][39] + coeff0_7*dmats0[7][39] + coeff0_8*dmats0[8][39] + coeff0_9*dmats0[9][39] + coeff0_10*dmats0[10][39] + coeff0_11*dmats0[11][39] + coeff0_12*dmats0[12][39] + coeff0_13*dmats0[13][39] + coeff0_14*dmats0[14][39] + coeff0_15*dmats0[15][39] + coeff0_16*dmats0[16][39] + coeff0_17*dmats0[17][39] + coeff0_18*dmats0[18][39] + coeff0_19*dmats0[19][39] + coeff0_20*dmats0[20][39] + coeff0_21*dmats0[21][39] + coeff0_22*dmats0[22][39] + coeff0_23*dmats0[23][39] + coeff0_24*dmats0[24][39] + coeff0_25*dmats0[25][39] + coeff0_26*dmats0[26][39] + coeff0_27*dmats0[27][39] + coeff0_28*dmats0[28][39] + coeff0_29*dmats0[29][39] + coeff0_30*dmats0[30][39] + coeff0_31*dmats0[31][39] + coeff0_32*dmats0[32][39] + coeff0_33*dmats0[33][39] + coeff0_34*dmats0[34][39] + coeff0_35*dmats0[35][39] + coeff0_36*dmats0[36][39] + coeff0_37*dmats0[37][39] + coeff0_38*dmats0[38][39] + coeff0_39*dmats0[39][39] + coeff0_40*dmats0[40][39] + coeff0_41*dmats0[41][39] + coeff0_42*dmats0[42][39] + coeff0_43*dmats0[43][39] + coeff0_44*dmats0[44][39] + coeff0_45*dmats0[45][39] + coeff0_46*dmats0[46][39] + coeff0_47*dmats0[47][39] + coeff0_48*dmats0[48][39] + coeff0_49*dmats0[49][39] + coeff0_50*dmats0[50][39] + coeff0_51*dmats0[51][39] + coeff0_52*dmats0[52][39] + coeff0_53*dmats0[53][39] + coeff0_54*dmats0[54][39] + coeff0_55*dmats0[55][39];
          new_coeff0_40 = coeff0_0*dmats0[0][40] + coeff0_1*dmats0[1][40] + coeff0_2*dmats0[2][40] + coeff0_3*dmats0[3][40] + coeff0_4*dmats0[4][40] + coeff0_5*dmats0[5][40] + coeff0_6*dmats0[6][40] + coeff0_7*dmats0[7][40] + coeff0_8*dmats0[8][40] + coeff0_9*dmats0[9][40] + coeff0_10*dmats0[10][40] + coeff0_11*dmats0[11][40] + coeff0_12*dmats0[12][40] + coeff0_13*dmats0[13][40] + coeff0_14*dmats0[14][40] + coeff0_15*dmats0[15][40] + coeff0_16*dmats0[16][40] + coeff0_17*dmats0[17][40] + coeff0_18*dmats0[18][40] + coeff0_19*dmats0[19][40] + coeff0_20*dmats0[20][40] + coeff0_21*dmats0[21][40] + coeff0_22*dmats0[22][40] + coeff0_23*dmats0[23][40] + coeff0_24*dmats0[24][40] + coeff0_25*dmats0[25][40] + coeff0_26*dmats0[26][40] + coeff0_27*dmats0[27][40] + coeff0_28*dmats0[28][40] + coeff0_29*dmats0[29][40] + coeff0_30*dmats0[30][40] + coeff0_31*dmats0[31][40] + coeff0_32*dmats0[32][40] + coeff0_33*dmats0[33][40] + coeff0_34*dmats0[34][40] + coeff0_35*dmats0[35][40] + coeff0_36*dmats0[36][40] + coeff0_37*dmats0[37][40] + coeff0_38*dmats0[38][40] + coeff0_39*dmats0[39][40] + coeff0_40*dmats0[40][40] + coeff0_41*dmats0[41][40] + coeff0_42*dmats0[42][40] + coeff0_43*dmats0[43][40] + coeff0_44*dmats0[44][40] + coeff0_45*dmats0[45][40] + coeff0_46*dmats0[46][40] + coeff0_47*dmats0[47][40] + coeff0_48*dmats0[48][40] + coeff0_49*dmats0[49][40] + coeff0_50*dmats0[50][40] + coeff0_51*dmats0[51][40] + coeff0_52*dmats0[52][40] + coeff0_53*dmats0[53][40] + coeff0_54*dmats0[54][40] + coeff0_55*dmats0[55][40];
          new_coeff0_41 = coeff0_0*dmats0[0][41] + coeff0_1*dmats0[1][41] + coeff0_2*dmats0[2][41] + coeff0_3*dmats0[3][41] + coeff0_4*dmats0[4][41] + coeff0_5*dmats0[5][41] + coeff0_6*dmats0[6][41] + coeff0_7*dmats0[7][41] + coeff0_8*dmats0[8][41] + coeff0_9*dmats0[9][41] + coeff0_10*dmats0[10][41] + coeff0_11*dmats0[11][41] + coeff0_12*dmats0[12][41] + coeff0_13*dmats0[13][41] + coeff0_14*dmats0[14][41] + coeff0_15*dmats0[15][41] + coeff0_16*dmats0[16][41] + coeff0_17*dmats0[17][41] + coeff0_18*dmats0[18][41] + coeff0_19*dmats0[19][41] + coeff0_20*dmats0[20][41] + coeff0_21*dmats0[21][41] + coeff0_22*dmats0[22][41] + coeff0_23*dmats0[23][41] + coeff0_24*dmats0[24][41] + coeff0_25*dmats0[25][41] + coeff0_26*dmats0[26][41] + coeff0_27*dmats0[27][41] + coeff0_28*dmats0[28][41] + coeff0_29*dmats0[29][41] + coeff0_30*dmats0[30][41] + coeff0_31*dmats0[31][41] + coeff0_32*dmats0[32][41] + coeff0_33*dmats0[33][41] + coeff0_34*dmats0[34][41] + coeff0_35*dmats0[35][41] + coeff0_36*dmats0[36][41] + coeff0_37*dmats0[37][41] + coeff0_38*dmats0[38][41] + coeff0_39*dmats0[39][41] + coeff0_40*dmats0[40][41] + coeff0_41*dmats0[41][41] + coeff0_42*dmats0[42][41] + coeff0_43*dmats0[43][41] + coeff0_44*dmats0[44][41] + coeff0_45*dmats0[45][41] + coeff0_46*dmats0[46][41] + coeff0_47*dmats0[47][41] + coeff0_48*dmats0[48][41] + coeff0_49*dmats0[49][41] + coeff0_50*dmats0[50][41] + coeff0_51*dmats0[51][41] + coeff0_52*dmats0[52][41] + coeff0_53*dmats0[53][41] + coeff0_54*dmats0[54][41] + coeff0_55*dmats0[55][41];
          new_coeff0_42 = coeff0_0*dmats0[0][42] + coeff0_1*dmats0[1][42] + coeff0_2*dmats0[2][42] + coeff0_3*dmats0[3][42] + coeff0_4*dmats0[4][42] + coeff0_5*dmats0[5][42] + coeff0_6*dmats0[6][42] + coeff0_7*dmats0[7][42] + coeff0_8*dmats0[8][42] + coeff0_9*dmats0[9][42] + coeff0_10*dmats0[10][42] + coeff0_11*dmats0[11][42] + coeff0_12*dmats0[12][42] + coeff0_13*dmats0[13][42] + coeff0_14*dmats0[14][42] + coeff0_15*dmats0[15][42] + coeff0_16*dmats0[16][42] + coeff0_17*dmats0[17][42] + coeff0_18*dmats0[18][42] + coeff0_19*dmats0[19][42] + coeff0_20*dmats0[20][42] + coeff0_21*dmats0[21][42] + coeff0_22*dmats0[22][42] + coeff0_23*dmats0[23][42] + coeff0_24*dmats0[24][42] + coeff0_25*dmats0[25][42] + coeff0_26*dmats0[26][42] + coeff0_27*dmats0[27][42] + coeff0_28*dmats0[28][42] + coeff0_29*dmats0[29][42] + coeff0_30*dmats0[30][42] + coeff0_31*dmats0[31][42] + coeff0_32*dmats0[32][42] + coeff0_33*dmats0[33][42] + coeff0_34*dmats0[34][42] + coeff0_35*dmats0[35][42] + coeff0_36*dmats0[36][42] + coeff0_37*dmats0[37][42] + coeff0_38*dmats0[38][42] + coeff0_39*dmats0[39][42] + coeff0_40*dmats0[40][42] + coeff0_41*dmats0[41][42] + coeff0_42*dmats0[42][42] + coeff0_43*dmats0[43][42] + coeff0_44*dmats0[44][42] + coeff0_45*dmats0[45][42] + coeff0_46*dmats0[46][42] + coeff0_47*dmats0[47][42] + coeff0_48*dmats0[48][42] + coeff0_49*dmats0[49][42] + coeff0_50*dmats0[50][42] + coeff0_51*dmats0[51][42] + coeff0_52*dmats0[52][42] + coeff0_53*dmats0[53][42] + coeff0_54*dmats0[54][42] + coeff0_55*dmats0[55][42];
          new_coeff0_43 = coeff0_0*dmats0[0][43] + coeff0_1*dmats0[1][43] + coeff0_2*dmats0[2][43] + coeff0_3*dmats0[3][43] + coeff0_4*dmats0[4][43] + coeff0_5*dmats0[5][43] + coeff0_6*dmats0[6][43] + coeff0_7*dmats0[7][43] + coeff0_8*dmats0[8][43] + coeff0_9*dmats0[9][43] + coeff0_10*dmats0[10][43] + coeff0_11*dmats0[11][43] + coeff0_12*dmats0[12][43] + coeff0_13*dmats0[13][43] + coeff0_14*dmats0[14][43] + coeff0_15*dmats0[15][43] + coeff0_16*dmats0[16][43] + coeff0_17*dmats0[17][43] + coeff0_18*dmats0[18][43] + coeff0_19*dmats0[19][43] + coeff0_20*dmats0[20][43] + coeff0_21*dmats0[21][43] + coeff0_22*dmats0[22][43] + coeff0_23*dmats0[23][43] + coeff0_24*dmats0[24][43] + coeff0_25*dmats0[25][43] + coeff0_26*dmats0[26][43] + coeff0_27*dmats0[27][43] + coeff0_28*dmats0[28][43] + coeff0_29*dmats0[29][43] + coeff0_30*dmats0[30][43] + coeff0_31*dmats0[31][43] + coeff0_32*dmats0[32][43] + coeff0_33*dmats0[33][43] + coeff0_34*dmats0[34][43] + coeff0_35*dmats0[35][43] + coeff0_36*dmats0[36][43] + coeff0_37*dmats0[37][43] + coeff0_38*dmats0[38][43] + coeff0_39*dmats0[39][43] + coeff0_40*dmats0[40][43] + coeff0_41*dmats0[41][43] + coeff0_42*dmats0[42][43] + coeff0_43*dmats0[43][43] + coeff0_44*dmats0[44][43] + coeff0_45*dmats0[45][43] + coeff0_46*dmats0[46][43] + coeff0_47*dmats0[47][43] + coeff0_48*dmats0[48][43] + coeff0_49*dmats0[49][43] + coeff0_50*dmats0[50][43] + coeff0_51*dmats0[51][43] + coeff0_52*dmats0[52][43] + coeff0_53*dmats0[53][43] + coeff0_54*dmats0[54][43] + coeff0_55*dmats0[55][43];
          new_coeff0_44 = coeff0_0*dmats0[0][44] + coeff0_1*dmats0[1][44] + coeff0_2*dmats0[2][44] + coeff0_3*dmats0[3][44] + coeff0_4*dmats0[4][44] + coeff0_5*dmats0[5][44] + coeff0_6*dmats0[6][44] + coeff0_7*dmats0[7][44] + coeff0_8*dmats0[8][44] + coeff0_9*dmats0[9][44] + coeff0_10*dmats0[10][44] + coeff0_11*dmats0[11][44] + coeff0_12*dmats0[12][44] + coeff0_13*dmats0[13][44] + coeff0_14*dmats0[14][44] + coeff0_15*dmats0[15][44] + coeff0_16*dmats0[16][44] + coeff0_17*dmats0[17][44] + coeff0_18*dmats0[18][44] + coeff0_19*dmats0[19][44] + coeff0_20*dmats0[20][44] + coeff0_21*dmats0[21][44] + coeff0_22*dmats0[22][44] + coeff0_23*dmats0[23][44] + coeff0_24*dmats0[24][44] + coeff0_25*dmats0[25][44] + coeff0_26*dmats0[26][44] + coeff0_27*dmats0[27][44] + coeff0_28*dmats0[28][44] + coeff0_29*dmats0[29][44] + coeff0_30*dmats0[30][44] + coeff0_31*dmats0[31][44] + coeff0_32*dmats0[32][44] + coeff0_33*dmats0[33][44] + coeff0_34*dmats0[34][44] + coeff0_35*dmats0[35][44] + coeff0_36*dmats0[36][44] + coeff0_37*dmats0[37][44] + coeff0_38*dmats0[38][44] + coeff0_39*dmats0[39][44] + coeff0_40*dmats0[40][44] + coeff0_41*dmats0[41][44] + coeff0_42*dmats0[42][44] + coeff0_43*dmats0[43][44] + coeff0_44*dmats0[44][44] + coeff0_45*dmats0[45][44] + coeff0_46*dmats0[46][44] + coeff0_47*dmats0[47][44] + coeff0_48*dmats0[48][44] + coeff0_49*dmats0[49][44] + coeff0_50*dmats0[50][44] + coeff0_51*dmats0[51][44] + coeff0_52*dmats0[52][44] + coeff0_53*dmats0[53][44] + coeff0_54*dmats0[54][44] + coeff0_55*dmats0[55][44];
          new_coeff0_45 = coeff0_0*dmats0[0][45] + coeff0_1*dmats0[1][45] + coeff0_2*dmats0[2][45] + coeff0_3*dmats0[3][45] + coeff0_4*dmats0[4][45] + coeff0_5*dmats0[5][45] + coeff0_6*dmats0[6][45] + coeff0_7*dmats0[7][45] + coeff0_8*dmats0[8][45] + coeff0_9*dmats0[9][45] + coeff0_10*dmats0[10][45] + coeff0_11*dmats0[11][45] + coeff0_12*dmats0[12][45] + coeff0_13*dmats0[13][45] + coeff0_14*dmats0[14][45] + coeff0_15*dmats0[15][45] + coeff0_16*dmats0[16][45] + coeff0_17*dmats0[17][45] + coeff0_18*dmats0[18][45] + coeff0_19*dmats0[19][45] + coeff0_20*dmats0[20][45] + coeff0_21*dmats0[21][45] + coeff0_22*dmats0[22][45] + coeff0_23*dmats0[23][45] + coeff0_24*dmats0[24][45] + coeff0_25*dmats0[25][45] + coeff0_26*dmats0[26][45] + coeff0_27*dmats0[27][45] + coeff0_28*dmats0[28][45] + coeff0_29*dmats0[29][45] + coeff0_30*dmats0[30][45] + coeff0_31*dmats0[31][45] + coeff0_32*dmats0[32][45] + coeff0_33*dmats0[33][45] + coeff0_34*dmats0[34][45] + coeff0_35*dmats0[35][45] + coeff0_36*dmats0[36][45] + coeff0_37*dmats0[37][45] + coeff0_38*dmats0[38][45] + coeff0_39*dmats0[39][45] + coeff0_40*dmats0[40][45] + coeff0_41*dmats0[41][45] + coeff0_42*dmats0[42][45] + coeff0_43*dmats0[43][45] + coeff0_44*dmats0[44][45] + coeff0_45*dmats0[45][45] + coeff0_46*dmats0[46][45] + coeff0_47*dmats0[47][45] + coeff0_48*dmats0[48][45] + coeff0_49*dmats0[49][45] + coeff0_50*dmats0[50][45] + coeff0_51*dmats0[51][45] + coeff0_52*dmats0[52][45] + coeff0_53*dmats0[53][45] + coeff0_54*dmats0[54][45] + coeff0_55*dmats0[55][45];
          new_coeff0_46 = coeff0_0*dmats0[0][46] + coeff0_1*dmats0[1][46] + coeff0_2*dmats0[2][46] + coeff0_3*dmats0[3][46] + coeff0_4*dmats0[4][46] + coeff0_5*dmats0[5][46] + coeff0_6*dmats0[6][46] + coeff0_7*dmats0[7][46] + coeff0_8*dmats0[8][46] + coeff0_9*dmats0[9][46] + coeff0_10*dmats0[10][46] + coeff0_11*dmats0[11][46] + coeff0_12*dmats0[12][46] + coeff0_13*dmats0[13][46] + coeff0_14*dmats0[14][46] + coeff0_15*dmats0[15][46] + coeff0_16*dmats0[16][46] + coeff0_17*dmats0[17][46] + coeff0_18*dmats0[18][46] + coeff0_19*dmats0[19][46] + coeff0_20*dmats0[20][46] + coeff0_21*dmats0[21][46] + coeff0_22*dmats0[22][46] + coeff0_23*dmats0[23][46] + coeff0_24*dmats0[24][46] + coeff0_25*dmats0[25][46] + coeff0_26*dmats0[26][46] + coeff0_27*dmats0[27][46] + coeff0_28*dmats0[28][46] + coeff0_29*dmats0[29][46] + coeff0_30*dmats0[30][46] + coeff0_31*dmats0[31][46] + coeff0_32*dmats0[32][46] + coeff0_33*dmats0[33][46] + coeff0_34*dmats0[34][46] + coeff0_35*dmats0[35][46] + coeff0_36*dmats0[36][46] + coeff0_37*dmats0[37][46] + coeff0_38*dmats0[38][46] + coeff0_39*dmats0[39][46] + coeff0_40*dmats0[40][46] + coeff0_41*dmats0[41][46] + coeff0_42*dmats0[42][46] + coeff0_43*dmats0[43][46] + coeff0_44*dmats0[44][46] + coeff0_45*dmats0[45][46] + coeff0_46*dmats0[46][46] + coeff0_47*dmats0[47][46] + coeff0_48*dmats0[48][46] + coeff0_49*dmats0[49][46] + coeff0_50*dmats0[50][46] + coeff0_51*dmats0[51][46] + coeff0_52*dmats0[52][46] + coeff0_53*dmats0[53][46] + coeff0_54*dmats0[54][46] + coeff0_55*dmats0[55][46];
          new_coeff0_47 = coeff0_0*dmats0[0][47] + coeff0_1*dmats0[1][47] + coeff0_2*dmats0[2][47] + coeff0_3*dmats0[3][47] + coeff0_4*dmats0[4][47] + coeff0_5*dmats0[5][47] + coeff0_6*dmats0[6][47] + coeff0_7*dmats0[7][47] + coeff0_8*dmats0[8][47] + coeff0_9*dmats0[9][47] + coeff0_10*dmats0[10][47] + coeff0_11*dmats0[11][47] + coeff0_12*dmats0[12][47] + coeff0_13*dmats0[13][47] + coeff0_14*dmats0[14][47] + coeff0_15*dmats0[15][47] + coeff0_16*dmats0[16][47] + coeff0_17*dmats0[17][47] + coeff0_18*dmats0[18][47] + coeff0_19*dmats0[19][47] + coeff0_20*dmats0[20][47] + coeff0_21*dmats0[21][47] + coeff0_22*dmats0[22][47] + coeff0_23*dmats0[23][47] + coeff0_24*dmats0[24][47] + coeff0_25*dmats0[25][47] + coeff0_26*dmats0[26][47] + coeff0_27*dmats0[27][47] + coeff0_28*dmats0[28][47] + coeff0_29*dmats0[29][47] + coeff0_30*dmats0[30][47] + coeff0_31*dmats0[31][47] + coeff0_32*dmats0[32][47] + coeff0_33*dmats0[33][47] + coeff0_34*dmats0[34][47] + coeff0_35*dmats0[35][47] + coeff0_36*dmats0[36][47] + coeff0_37*dmats0[37][47] + coeff0_38*dmats0[38][47] + coeff0_39*dmats0[39][47] + coeff0_40*dmats0[40][47] + coeff0_41*dmats0[41][47] + coeff0_42*dmats0[42][47] + coeff0_43*dmats0[43][47] + coeff0_44*dmats0[44][47] + coeff0_45*dmats0[45][47] + coeff0_46*dmats0[46][47] + coeff0_47*dmats0[47][47] + coeff0_48*dmats0[48][47] + coeff0_49*dmats0[49][47] + coeff0_50*dmats0[50][47] + coeff0_51*dmats0[51][47] + coeff0_52*dmats0[52][47] + coeff0_53*dmats0[53][47] + coeff0_54*dmats0[54][47] + coeff0_55*dmats0[55][47];
          new_coeff0_48 = coeff0_0*dmats0[0][48] + coeff0_1*dmats0[1][48] + coeff0_2*dmats0[2][48] + coeff0_3*dmats0[3][48] + coeff0_4*dmats0[4][48] + coeff0_5*dmats0[5][48] + coeff0_6*dmats0[6][48] + coeff0_7*dmats0[7][48] + coeff0_8*dmats0[8][48] + coeff0_9*dmats0[9][48] + coeff0_10*dmats0[10][48] + coeff0_11*dmats0[11][48] + coeff0_12*dmats0[12][48] + coeff0_13*dmats0[13][48] + coeff0_14*dmats0[14][48] + coeff0_15*dmats0[15][48] + coeff0_16*dmats0[16][48] + coeff0_17*dmats0[17][48] + coeff0_18*dmats0[18][48] + coeff0_19*dmats0[19][48] + coeff0_20*dmats0[20][48] + coeff0_21*dmats0[21][48] + coeff0_22*dmats0[22][48] + coeff0_23*dmats0[23][48] + coeff0_24*dmats0[24][48] + coeff0_25*dmats0[25][48] + coeff0_26*dmats0[26][48] + coeff0_27*dmats0[27][48] + coeff0_28*dmats0[28][48] + coeff0_29*dmats0[29][48] + coeff0_30*dmats0[30][48] + coeff0_31*dmats0[31][48] + coeff0_32*dmats0[32][48] + coeff0_33*dmats0[33][48] + coeff0_34*dmats0[34][48] + coeff0_35*dmats0[35][48] + coeff0_36*dmats0[36][48] + coeff0_37*dmats0[37][48] + coeff0_38*dmats0[38][48] + coeff0_39*dmats0[39][48] + coeff0_40*dmats0[40][48] + coeff0_41*dmats0[41][48] + coeff0_42*dmats0[42][48] + coeff0_43*dmats0[43][48] + coeff0_44*dmats0[44][48] + coeff0_45*dmats0[45][48] + coeff0_46*dmats0[46][48] + coeff0_47*dmats0[47][48] + coeff0_48*dmats0[48][48] + coeff0_49*dmats0[49][48] + coeff0_50*dmats0[50][48] + coeff0_51*dmats0[51][48] + coeff0_52*dmats0[52][48] + coeff0_53*dmats0[53][48] + coeff0_54*dmats0[54][48] + coeff0_55*dmats0[55][48];
          new_coeff0_49 = coeff0_0*dmats0[0][49] + coeff0_1*dmats0[1][49] + coeff0_2*dmats0[2][49] + coeff0_3*dmats0[3][49] + coeff0_4*dmats0[4][49] + coeff0_5*dmats0[5][49] + coeff0_6*dmats0[6][49] + coeff0_7*dmats0[7][49] + coeff0_8*dmats0[8][49] + coeff0_9*dmats0[9][49] + coeff0_10*dmats0[10][49] + coeff0_11*dmats0[11][49] + coeff0_12*dmats0[12][49] + coeff0_13*dmats0[13][49] + coeff0_14*dmats0[14][49] + coeff0_15*dmats0[15][49] + coeff0_16*dmats0[16][49] + coeff0_17*dmats0[17][49] + coeff0_18*dmats0[18][49] + coeff0_19*dmats0[19][49] + coeff0_20*dmats0[20][49] + coeff0_21*dmats0[21][49] + coeff0_22*dmats0[22][49] + coeff0_23*dmats0[23][49] + coeff0_24*dmats0[24][49] + coeff0_25*dmats0[25][49] + coeff0_26*dmats0[26][49] + coeff0_27*dmats0[27][49] + coeff0_28*dmats0[28][49] + coeff0_29*dmats0[29][49] + coeff0_30*dmats0[30][49] + coeff0_31*dmats0[31][49] + coeff0_32*dmats0[32][49] + coeff0_33*dmats0[33][49] + coeff0_34*dmats0[34][49] + coeff0_35*dmats0[35][49] + coeff0_36*dmats0[36][49] + coeff0_37*dmats0[37][49] + coeff0_38*dmats0[38][49] + coeff0_39*dmats0[39][49] + coeff0_40*dmats0[40][49] + coeff0_41*dmats0[41][49] + coeff0_42*dmats0[42][49] + coeff0_43*dmats0[43][49] + coeff0_44*dmats0[44][49] + coeff0_45*dmats0[45][49] + coeff0_46*dmats0[46][49] + coeff0_47*dmats0[47][49] + coeff0_48*dmats0[48][49] + coeff0_49*dmats0[49][49] + coeff0_50*dmats0[50][49] + coeff0_51*dmats0[51][49] + coeff0_52*dmats0[52][49] + coeff0_53*dmats0[53][49] + coeff0_54*dmats0[54][49] + coeff0_55*dmats0[55][49];
          new_coeff0_50 = coeff0_0*dmats0[0][50] + coeff0_1*dmats0[1][50] + coeff0_2*dmats0[2][50] + coeff0_3*dmats0[3][50] + coeff0_4*dmats0[4][50] + coeff0_5*dmats0[5][50] + coeff0_6*dmats0[6][50] + coeff0_7*dmats0[7][50] + coeff0_8*dmats0[8][50] + coeff0_9*dmats0[9][50] + coeff0_10*dmats0[10][50] + coeff0_11*dmats0[11][50] + coeff0_12*dmats0[12][50] + coeff0_13*dmats0[13][50] + coeff0_14*dmats0[14][50] + coeff0_15*dmats0[15][50] + coeff0_16*dmats0[16][50] + coeff0_17*dmats0[17][50] + coeff0_18*dmats0[18][50] + coeff0_19*dmats0[19][50] + coeff0_20*dmats0[20][50] + coeff0_21*dmats0[21][50] + coeff0_22*dmats0[22][50] + coeff0_23*dmats0[23][50] + coeff0_24*dmats0[24][50] + coeff0_25*dmats0[25][50] + coeff0_26*dmats0[26][50] + coeff0_27*dmats0[27][50] + coeff0_28*dmats0[28][50] + coeff0_29*dmats0[29][50] + coeff0_30*dmats0[30][50] + coeff0_31*dmats0[31][50] + coeff0_32*dmats0[32][50] + coeff0_33*dmats0[33][50] + coeff0_34*dmats0[34][50] + coeff0_35*dmats0[35][50] + coeff0_36*dmats0[36][50] + coeff0_37*dmats0[37][50] + coeff0_38*dmats0[38][50] + coeff0_39*dmats0[39][50] + coeff0_40*dmats0[40][50] + coeff0_41*dmats0[41][50] + coeff0_42*dmats0[42][50] + coeff0_43*dmats0[43][50] + coeff0_44*dmats0[44][50] + coeff0_45*dmats0[45][50] + coeff0_46*dmats0[46][50] + coeff0_47*dmats0[47][50] + coeff0_48*dmats0[48][50] + coeff0_49*dmats0[49][50] + coeff0_50*dmats0[50][50] + coeff0_51*dmats0[51][50] + coeff0_52*dmats0[52][50] + coeff0_53*dmats0[53][50] + coeff0_54*dmats0[54][50] + coeff0_55*dmats0[55][50];
          new_coeff0_51 = coeff0_0*dmats0[0][51] + coeff0_1*dmats0[1][51] + coeff0_2*dmats0[2][51] + coeff0_3*dmats0[3][51] + coeff0_4*dmats0[4][51] + coeff0_5*dmats0[5][51] + coeff0_6*dmats0[6][51] + coeff0_7*dmats0[7][51] + coeff0_8*dmats0[8][51] + coeff0_9*dmats0[9][51] + coeff0_10*dmats0[10][51] + coeff0_11*dmats0[11][51] + coeff0_12*dmats0[12][51] + coeff0_13*dmats0[13][51] + coeff0_14*dmats0[14][51] + coeff0_15*dmats0[15][51] + coeff0_16*dmats0[16][51] + coeff0_17*dmats0[17][51] + coeff0_18*dmats0[18][51] + coeff0_19*dmats0[19][51] + coeff0_20*dmats0[20][51] + coeff0_21*dmats0[21][51] + coeff0_22*dmats0[22][51] + coeff0_23*dmats0[23][51] + coeff0_24*dmats0[24][51] + coeff0_25*dmats0[25][51] + coeff0_26*dmats0[26][51] + coeff0_27*dmats0[27][51] + coeff0_28*dmats0[28][51] + coeff0_29*dmats0[29][51] + coeff0_30*dmats0[30][51] + coeff0_31*dmats0[31][51] + coeff0_32*dmats0[32][51] + coeff0_33*dmats0[33][51] + coeff0_34*dmats0[34][51] + coeff0_35*dmats0[35][51] + coeff0_36*dmats0[36][51] + coeff0_37*dmats0[37][51] + coeff0_38*dmats0[38][51] + coeff0_39*dmats0[39][51] + coeff0_40*dmats0[40][51] + coeff0_41*dmats0[41][51] + coeff0_42*dmats0[42][51] + coeff0_43*dmats0[43][51] + coeff0_44*dmats0[44][51] + coeff0_45*dmats0[45][51] + coeff0_46*dmats0[46][51] + coeff0_47*dmats0[47][51] + coeff0_48*dmats0[48][51] + coeff0_49*dmats0[49][51] + coeff0_50*dmats0[50][51] + coeff0_51*dmats0[51][51] + coeff0_52*dmats0[52][51] + coeff0_53*dmats0[53][51] + coeff0_54*dmats0[54][51] + coeff0_55*dmats0[55][51];
          new_coeff0_52 = coeff0_0*dmats0[0][52] + coeff0_1*dmats0[1][52] + coeff0_2*dmats0[2][52] + coeff0_3*dmats0[3][52] + coeff0_4*dmats0[4][52] + coeff0_5*dmats0[5][52] + coeff0_6*dmats0[6][52] + coeff0_7*dmats0[7][52] + coeff0_8*dmats0[8][52] + coeff0_9*dmats0[9][52] + coeff0_10*dmats0[10][52] + coeff0_11*dmats0[11][52] + coeff0_12*dmats0[12][52] + coeff0_13*dmats0[13][52] + coeff0_14*dmats0[14][52] + coeff0_15*dmats0[15][52] + coeff0_16*dmats0[16][52] + coeff0_17*dmats0[17][52] + coeff0_18*dmats0[18][52] + coeff0_19*dmats0[19][52] + coeff0_20*dmats0[20][52] + coeff0_21*dmats0[21][52] + coeff0_22*dmats0[22][52] + coeff0_23*dmats0[23][52] + coeff0_24*dmats0[24][52] + coeff0_25*dmats0[25][52] + coeff0_26*dmats0[26][52] + coeff0_27*dmats0[27][52] + coeff0_28*dmats0[28][52] + coeff0_29*dmats0[29][52] + coeff0_30*dmats0[30][52] + coeff0_31*dmats0[31][52] + coeff0_32*dmats0[32][52] + coeff0_33*dmats0[33][52] + coeff0_34*dmats0[34][52] + coeff0_35*dmats0[35][52] + coeff0_36*dmats0[36][52] + coeff0_37*dmats0[37][52] + coeff0_38*dmats0[38][52] + coeff0_39*dmats0[39][52] + coeff0_40*dmats0[40][52] + coeff0_41*dmats0[41][52] + coeff0_42*dmats0[42][52] + coeff0_43*dmats0[43][52] + coeff0_44*dmats0[44][52] + coeff0_45*dmats0[45][52] + coeff0_46*dmats0[46][52] + coeff0_47*dmats0[47][52] + coeff0_48*dmats0[48][52] + coeff0_49*dmats0[49][52] + coeff0_50*dmats0[50][52] + coeff0_51*dmats0[51][52] + coeff0_52*dmats0[52][52] + coeff0_53*dmats0[53][52] + coeff0_54*dmats0[54][52] + coeff0_55*dmats0[55][52];
          new_coeff0_53 = coeff0_0*dmats0[0][53] + coeff0_1*dmats0[1][53] + coeff0_2*dmats0[2][53] + coeff0_3*dmats0[3][53] + coeff0_4*dmats0[4][53] + coeff0_5*dmats0[5][53] + coeff0_6*dmats0[6][53] + coeff0_7*dmats0[7][53] + coeff0_8*dmats0[8][53] + coeff0_9*dmats0[9][53] + coeff0_10*dmats0[10][53] + coeff0_11*dmats0[11][53] + coeff0_12*dmats0[12][53] + coeff0_13*dmats0[13][53] + coeff0_14*dmats0[14][53] + coeff0_15*dmats0[15][53] + coeff0_16*dmats0[16][53] + coeff0_17*dmats0[17][53] + coeff0_18*dmats0[18][53] + coeff0_19*dmats0[19][53] + coeff0_20*dmats0[20][53] + coeff0_21*dmats0[21][53] + coeff0_22*dmats0[22][53] + coeff0_23*dmats0[23][53] + coeff0_24*dmats0[24][53] + coeff0_25*dmats0[25][53] + coeff0_26*dmats0[26][53] + coeff0_27*dmats0[27][53] + coeff0_28*dmats0[28][53] + coeff0_29*dmats0[29][53] + coeff0_30*dmats0[30][53] + coeff0_31*dmats0[31][53] + coeff0_32*dmats0[32][53] + coeff0_33*dmats0[33][53] + coeff0_34*dmats0[34][53] + coeff0_35*dmats0[35][53] + coeff0_36*dmats0[36][53] + coeff0_37*dmats0[37][53] + coeff0_38*dmats0[38][53] + coeff0_39*dmats0[39][53] + coeff0_40*dmats0[40][53] + coeff0_41*dmats0[41][53] + coeff0_42*dmats0[42][53] + coeff0_43*dmats0[43][53] + coeff0_44*dmats0[44][53] + coeff0_45*dmats0[45][53] + coeff0_46*dmats0[46][53] + coeff0_47*dmats0[47][53] + coeff0_48*dmats0[48][53] + coeff0_49*dmats0[49][53] + coeff0_50*dmats0[50][53] + coeff0_51*dmats0[51][53] + coeff0_52*dmats0[52][53] + coeff0_53*dmats0[53][53] + coeff0_54*dmats0[54][53] + coeff0_55*dmats0[55][53];
          new_coeff0_54 = coeff0_0*dmats0[0][54] + coeff0_1*dmats0[1][54] + coeff0_2*dmats0[2][54] + coeff0_3*dmats0[3][54] + coeff0_4*dmats0[4][54] + coeff0_5*dmats0[5][54] + coeff0_6*dmats0[6][54] + coeff0_7*dmats0[7][54] + coeff0_8*dmats0[8][54] + coeff0_9*dmats0[9][54] + coeff0_10*dmats0[10][54] + coeff0_11*dmats0[11][54] + coeff0_12*dmats0[12][54] + coeff0_13*dmats0[13][54] + coeff0_14*dmats0[14][54] + coeff0_15*dmats0[15][54] + coeff0_16*dmats0[16][54] + coeff0_17*dmats0[17][54] + coeff0_18*dmats0[18][54] + coeff0_19*dmats0[19][54] + coeff0_20*dmats0[20][54] + coeff0_21*dmats0[21][54] + coeff0_22*dmats0[22][54] + coeff0_23*dmats0[23][54] + coeff0_24*dmats0[24][54] + coeff0_25*dmats0[25][54] + coeff0_26*dmats0[26][54] + coeff0_27*dmats0[27][54] + coeff0_28*dmats0[28][54] + coeff0_29*dmats0[29][54] + coeff0_30*dmats0[30][54] + coeff0_31*dmats0[31][54] + coeff0_32*dmats0[32][54] + coeff0_33*dmats0[33][54] + coeff0_34*dmats0[34][54] + coeff0_35*dmats0[35][54] + coeff0_36*dmats0[36][54] + coeff0_37*dmats0[37][54] + coeff0_38*dmats0[38][54] + coeff0_39*dmats0[39][54] + coeff0_40*dmats0[40][54] + coeff0_41*dmats0[41][54] + coeff0_42*dmats0[42][54] + coeff0_43*dmats0[43][54] + coeff0_44*dmats0[44][54] + coeff0_45*dmats0[45][54] + coeff0_46*dmats0[46][54] + coeff0_47*dmats0[47][54] + coeff0_48*dmats0[48][54] + coeff0_49*dmats0[49][54] + coeff0_50*dmats0[50][54] + coeff0_51*dmats0[51][54] + coeff0_52*dmats0[52][54] + coeff0_53*dmats0[53][54] + coeff0_54*dmats0[54][54] + coeff0_55*dmats0[55][54];
          new_coeff0_55 = coeff0_0*dmats0[0][55] + coeff0_1*dmats0[1][55] + coeff0_2*dmats0[2][55] + coeff0_3*dmats0[3][55] + coeff0_4*dmats0[4][55] + coeff0_5*dmats0[5][55] + coeff0_6*dmats0[6][55] + coeff0_7*dmats0[7][55] + coeff0_8*dmats0[8][55] + coeff0_9*dmats0[9][55] + coeff0_10*dmats0[10][55] + coeff0_11*dmats0[11][55] + coeff0_12*dmats0[12][55] + coeff0_13*dmats0[13][55] + coeff0_14*dmats0[14][55] + coeff0_15*dmats0[15][55] + coeff0_16*dmats0[16][55] + coeff0_17*dmats0[17][55] + coeff0_18*dmats0[18][55] + coeff0_19*dmats0[19][55] + coeff0_20*dmats0[20][55] + coeff0_21*dmats0[21][55] + coeff0_22*dmats0[22][55] + coeff0_23*dmats0[23][55] + coeff0_24*dmats0[24][55] + coeff0_25*dmats0[25][55] + coeff0_26*dmats0[26][55] + coeff0_27*dmats0[27][55] + coeff0_28*dmats0[28][55] + coeff0_29*dmats0[29][55] + coeff0_30*dmats0[30][55] + coeff0_31*dmats0[31][55] + coeff0_32*dmats0[32][55] + coeff0_33*dmats0[33][55] + coeff0_34*dmats0[34][55] + coeff0_35*dmats0[35][55] + coeff0_36*dmats0[36][55] + coeff0_37*dmats0[37][55] + coeff0_38*dmats0[38][55] + coeff0_39*dmats0[39][55] + coeff0_40*dmats0[40][55] + coeff0_41*dmats0[41][55] + coeff0_42*dmats0[42][55] + coeff0_43*dmats0[43][55] + coeff0_44*dmats0[44][55] + coeff0_45*dmats0[45][55] + coeff0_46*dmats0[46][55] + coeff0_47*dmats0[47][55] + coeff0_48*dmats0[48][55] + coeff0_49*dmats0[49][55] + coeff0_50*dmats0[50][55] + coeff0_51*dmats0[51][55] + coeff0_52*dmats0[52][55] + coeff0_53*dmats0[53][55] + coeff0_54*dmats0[54][55] + coeff0_55*dmats0[55][55];
        }
        if(combinations[deriv_num][j] == 1)
        {
          new_coeff0_0 = coeff0_0*dmats1[0][0] + coeff0_1*dmats1[1][0] + coeff0_2*dmats1[2][0] + coeff0_3*dmats1[3][0] + coeff0_4*dmats1[4][0] + coeff0_5*dmats1[5][0] + coeff0_6*dmats1[6][0] + coeff0_7*dmats1[7][0] + coeff0_8*dmats1[8][0] + coeff0_9*dmats1[9][0] + coeff0_10*dmats1[10][0] + coeff0_11*dmats1[11][0] + coeff0_12*dmats1[12][0] + coeff0_13*dmats1[13][0] + coeff0_14*dmats1[14][0] + coeff0_15*dmats1[15][0] + coeff0_16*dmats1[16][0] + coeff0_17*dmats1[17][0] + coeff0_18*dmats1[18][0] + coeff0_19*dmats1[19][0] + coeff0_20*dmats1[20][0] + coeff0_21*dmats1[21][0] + coeff0_22*dmats1[22][0] + coeff0_23*dmats1[23][0] + coeff0_24*dmats1[24][0] + coeff0_25*dmats1[25][0] + coeff0_26*dmats1[26][0] + coeff0_27*dmats1[27][0] + coeff0_28*dmats1[28][0] + coeff0_29*dmats1[29][0] + coeff0_30*dmats1[30][0] + coeff0_31*dmats1[31][0] + coeff0_32*dmats1[32][0] + coeff0_33*dmats1[33][0] + coeff0_34*dmats1[34][0] + coeff0_35*dmats1[35][0] + coeff0_36*dmats1[36][0] + coeff0_37*dmats1[37][0] + coeff0_38*dmats1[38][0] + coeff0_39*dmats1[39][0] + coeff0_40*dmats1[40][0] + coeff0_41*dmats1[41][0] + coeff0_42*dmats1[42][0] + coeff0_43*dmats1[43][0] + coeff0_44*dmats1[44][0] + coeff0_45*dmats1[45][0] + coeff0_46*dmats1[46][0] + coeff0_47*dmats1[47][0] + coeff0_48*dmats1[48][0] + coeff0_49*dmats1[49][0] + coeff0_50*dmats1[50][0] + coeff0_51*dmats1[51][0] + coeff0_52*dmats1[52][0] + coeff0_53*dmats1[53][0] + coeff0_54*dmats1[54][0] + coeff0_55*dmats1[55][0];
          new_coeff0_1 = coeff0_0*dmats1[0][1] + coeff0_1*dmats1[1][1] + coeff0_2*dmats1[2][1] + coeff0_3*dmats1[3][1] + coeff0_4*dmats1[4][1] + coeff0_5*dmats1[5][1] + coeff0_6*dmats1[6][1] + coeff0_7*dmats1[7][1] + coeff0_8*dmats1[8][1] + coeff0_9*dmats1[9][1] + coeff0_10*dmats1[10][1] + coeff0_11*dmats1[11][1] + coeff0_12*dmats1[12][1] + coeff0_13*dmats1[13][1] + coeff0_14*dmats1[14][1] + coeff0_15*dmats1[15][1] + coeff0_16*dmats1[16][1] + coeff0_17*dmats1[17][1] + coeff0_18*dmats1[18][1] + coeff0_19*dmats1[19][1] + coeff0_20*dmats1[20][1] + coeff0_21*dmats1[21][1] + coeff0_22*dmats1[22][1] + coeff0_23*dmats1[23][1] + coeff0_24*dmats1[24][1] + coeff0_25*dmats1[25][1] + coeff0_26*dmats1[26][1] + coeff0_27*dmats1[27][1] + coeff0_28*dmats1[28][1] + coeff0_29*dmats1[29][1] + coeff0_30*dmats1[30][1] + coeff0_31*dmats1[31][1] + coeff0_32*dmats1[32][1] + coeff0_33*dmats1[33][1] + coeff0_34*dmats1[34][1] + coeff0_35*dmats1[35][1] + coeff0_36*dmats1[36][1] + coeff0_37*dmats1[37][1] + coeff0_38*dmats1[38][1] + coeff0_39*dmats1[39][1] + coeff0_40*dmats1[40][1] + coeff0_41*dmats1[41][1] + coeff0_42*dmats1[42][1] + coeff0_43*dmats1[43][1] + coeff0_44*dmats1[44][1] + coeff0_45*dmats1[45][1] + coeff0_46*dmats1[46][1] + coeff0_47*dmats1[47][1] + coeff0_48*dmats1[48][1] + coeff0_49*dmats1[49][1] + coeff0_50*dmats1[50][1] + coeff0_51*dmats1[51][1] + coeff0_52*dmats1[52][1] + coeff0_53*dmats1[53][1] + coeff0_54*dmats1[54][1] + coeff0_55*dmats1[55][1];
          new_coeff0_2 = coeff0_0*dmats1[0][2] + coeff0_1*dmats1[1][2] + coeff0_2*dmats1[2][2] + coeff0_3*dmats1[3][2] + coeff0_4*dmats1[4][2] + coeff0_5*dmats1[5][2] + coeff0_6*dmats1[6][2] + coeff0_7*dmats1[7][2] + coeff0_8*dmats1[8][2] + coeff0_9*dmats1[9][2] + coeff0_10*dmats1[10][2] + coeff0_11*dmats1[11][2] + coeff0_12*dmats1[12][2] + coeff0_13*dmats1[13][2] + coeff0_14*dmats1[14][2] + coeff0_15*dmats1[15][2] + coeff0_16*dmats1[16][2] + coeff0_17*dmats1[17][2] + coeff0_18*dmats1[18][2] + coeff0_19*dmats1[19][2] + coeff0_20*dmats1[20][2] + coeff0_21*dmats1[21][2] + coeff0_22*dmats1[22][2] + coeff0_23*dmats1[23][2] + coeff0_24*dmats1[24][2] + coeff0_25*dmats1[25][2] + coeff0_26*dmats1[26][2] + coeff0_27*dmats1[27][2] + coeff0_28*dmats1[28][2] + coeff0_29*dmats1[29][2] + coeff0_30*dmats1[30][2] + coeff0_31*dmats1[31][2] + coeff0_32*dmats1[32][2] + coeff0_33*dmats1[33][2] + coeff0_34*dmats1[34][2] + coeff0_35*dmats1[35][2] + coeff0_36*dmats1[36][2] + coeff0_37*dmats1[37][2] + coeff0_38*dmats1[38][2] + coeff0_39*dmats1[39][2] + coeff0_40*dmats1[40][2] + coeff0_41*dmats1[41][2] + coeff0_42*dmats1[42][2] + coeff0_43*dmats1[43][2] + coeff0_44*dmats1[44][2] + coeff0_45*dmats1[45][2] + coeff0_46*dmats1[46][2] + coeff0_47*dmats1[47][2] + coeff0_48*dmats1[48][2] + coeff0_49*dmats1[49][2] + coeff0_50*dmats1[50][2] + coeff0_51*dmats1[51][2] + coeff0_52*dmats1[52][2] + coeff0_53*dmats1[53][2] + coeff0_54*dmats1[54][2] + coeff0_55*dmats1[55][2];
          new_coeff0_3 = coeff0_0*dmats1[0][3] + coeff0_1*dmats1[1][3] + coeff0_2*dmats1[2][3] + coeff0_3*dmats1[3][3] + coeff0_4*dmats1[4][3] + coeff0_5*dmats1[5][3] + coeff0_6*dmats1[6][3] + coeff0_7*dmats1[7][3] + coeff0_8*dmats1[8][3] + coeff0_9*dmats1[9][3] + coeff0_10*dmats1[10][3] + coeff0_11*dmats1[11][3] + coeff0_12*dmats1[12][3] + coeff0_13*dmats1[13][3] + coeff0_14*dmats1[14][3] + coeff0_15*dmats1[15][3] + coeff0_16*dmats1[16][3] + coeff0_17*dmats1[17][3] + coeff0_18*dmats1[18][3] + coeff0_19*dmats1[19][3] + coeff0_20*dmats1[20][3] + coeff0_21*dmats1[21][3] + coeff0_22*dmats1[22][3] + coeff0_23*dmats1[23][3] + coeff0_24*dmats1[24][3] + coeff0_25*dmats1[25][3] + coeff0_26*dmats1[26][3] + coeff0_27*dmats1[27][3] + coeff0_28*dmats1[28][3] + coeff0_29*dmats1[29][3] + coeff0_30*dmats1[30][3] + coeff0_31*dmats1[31][3] + coeff0_32*dmats1[32][3] + coeff0_33*dmats1[33][3] + coeff0_34*dmats1[34][3] + coeff0_35*dmats1[35][3] + coeff0_36*dmats1[36][3] + coeff0_37*dmats1[37][3] + coeff0_38*dmats1[38][3] + coeff0_39*dmats1[39][3] + coeff0_40*dmats1[40][3] + coeff0_41*dmats1[41][3] + coeff0_42*dmats1[42][3] + coeff0_43*dmats1[43][3] + coeff0_44*dmats1[44][3] + coeff0_45*dmats1[45][3] + coeff0_46*dmats1[46][3] + coeff0_47*dmats1[47][3] + coeff0_48*dmats1[48][3] + coeff0_49*dmats1[49][3] + coeff0_50*dmats1[50][3] + coeff0_51*dmats1[51][3] + coeff0_52*dmats1[52][3] + coeff0_53*dmats1[53][3] + coeff0_54*dmats1[54][3] + coeff0_55*dmats1[55][3];
          new_coeff0_4 = coeff0_0*dmats1[0][4] + coeff0_1*dmats1[1][4] + coeff0_2*dmats1[2][4] + coeff0_3*dmats1[3][4] + coeff0_4*dmats1[4][4] + coeff0_5*dmats1[5][4] + coeff0_6*dmats1[6][4] + coeff0_7*dmats1[7][4] + coeff0_8*dmats1[8][4] + coeff0_9*dmats1[9][4] + coeff0_10*dmats1[10][4] + coeff0_11*dmats1[11][4] + coeff0_12*dmats1[12][4] + coeff0_13*dmats1[13][4] + coeff0_14*dmats1[14][4] + coeff0_15*dmats1[15][4] + coeff0_16*dmats1[16][4] + coeff0_17*dmats1[17][4] + coeff0_18*dmats1[18][4] + coeff0_19*dmats1[19][4] + coeff0_20*dmats1[20][4] + coeff0_21*dmats1[21][4] + coeff0_22*dmats1[22][4] + coeff0_23*dmats1[23][4] + coeff0_24*dmats1[24][4] + coeff0_25*dmats1[25][4] + coeff0_26*dmats1[26][4] + coeff0_27*dmats1[27][4] + coeff0_28*dmats1[28][4] + coeff0_29*dmats1[29][4] + coeff0_30*dmats1[30][4] + coeff0_31*dmats1[31][4] + coeff0_32*dmats1[32][4] + coeff0_33*dmats1[33][4] + coeff0_34*dmats1[34][4] + coeff0_35*dmats1[35][4] + coeff0_36*dmats1[36][4] + coeff0_37*dmats1[37][4] + coeff0_38*dmats1[38][4] + coeff0_39*dmats1[39][4] + coeff0_40*dmats1[40][4] + coeff0_41*dmats1[41][4] + coeff0_42*dmats1[42][4] + coeff0_43*dmats1[43][4] + coeff0_44*dmats1[44][4] + coeff0_45*dmats1[45][4] + coeff0_46*dmats1[46][4] + coeff0_47*dmats1[47][4] + coeff0_48*dmats1[48][4] + coeff0_49*dmats1[49][4] + coeff0_50*dmats1[50][4] + coeff0_51*dmats1[51][4] + coeff0_52*dmats1[52][4] + coeff0_53*dmats1[53][4] + coeff0_54*dmats1[54][4] + coeff0_55*dmats1[55][4];
          new_coeff0_5 = coeff0_0*dmats1[0][5] + coeff0_1*dmats1[1][5] + coeff0_2*dmats1[2][5] + coeff0_3*dmats1[3][5] + coeff0_4*dmats1[4][5] + coeff0_5*dmats1[5][5] + coeff0_6*dmats1[6][5] + coeff0_7*dmats1[7][5] + coeff0_8*dmats1[8][5] + coeff0_9*dmats1[9][5] + coeff0_10*dmats1[10][5] + coeff0_11*dmats1[11][5] + coeff0_12*dmats1[12][5] + coeff0_13*dmats1[13][5] + coeff0_14*dmats1[14][5] + coeff0_15*dmats1[15][5] + coeff0_16*dmats1[16][5] + coeff0_17*dmats1[17][5] + coeff0_18*dmats1[18][5] + coeff0_19*dmats1[19][5] + coeff0_20*dmats1[20][5] + coeff0_21*dmats1[21][5] + coeff0_22*dmats1[22][5] + coeff0_23*dmats1[23][5] + coeff0_24*dmats1[24][5] + coeff0_25*dmats1[25][5] + coeff0_26*dmats1[26][5] + coeff0_27*dmats1[27][5] + coeff0_28*dmats1[28][5] + coeff0_29*dmats1[29][5] + coeff0_30*dmats1[30][5] + coeff0_31*dmats1[31][5] + coeff0_32*dmats1[32][5] + coeff0_33*dmats1[33][5] + coeff0_34*dmats1[34][5] + coeff0_35*dmats1[35][5] + coeff0_36*dmats1[36][5] + coeff0_37*dmats1[37][5] + coeff0_38*dmats1[38][5] + coeff0_39*dmats1[39][5] + coeff0_40*dmats1[40][5] + coeff0_41*dmats1[41][5] + coeff0_42*dmats1[42][5] + coeff0_43*dmats1[43][5] + coeff0_44*dmats1[44][5] + coeff0_45*dmats1[45][5] + coeff0_46*dmats1[46][5] + coeff0_47*dmats1[47][5] + coeff0_48*dmats1[48][5] + coeff0_49*dmats1[49][5] + coeff0_50*dmats1[50][5] + coeff0_51*dmats1[51][5] + coeff0_52*dmats1[52][5] + coeff0_53*dmats1[53][5] + coeff0_54*dmats1[54][5] + coeff0_55*dmats1[55][5];
          new_coeff0_6 = coeff0_0*dmats1[0][6] + coeff0_1*dmats1[1][6] + coeff0_2*dmats1[2][6] + coeff0_3*dmats1[3][6] + coeff0_4*dmats1[4][6] + coeff0_5*dmats1[5][6] + coeff0_6*dmats1[6][6] + coeff0_7*dmats1[7][6] + coeff0_8*dmats1[8][6] + coeff0_9*dmats1[9][6] + coeff0_10*dmats1[10][6] + coeff0_11*dmats1[11][6] + coeff0_12*dmats1[12][6] + coeff0_13*dmats1[13][6] + coeff0_14*dmats1[14][6] + coeff0_15*dmats1[15][6] + coeff0_16*dmats1[16][6] + coeff0_17*dmats1[17][6] + coeff0_18*dmats1[18][6] + coeff0_19*dmats1[19][6] + coeff0_20*dmats1[20][6] + coeff0_21*dmats1[21][6] + coeff0_22*dmats1[22][6] + coeff0_23*dmats1[23][6] + coeff0_24*dmats1[24][6] + coeff0_25*dmats1[25][6] + coeff0_26*dmats1[26][6] + coeff0_27*dmats1[27][6] + coeff0_28*dmats1[28][6] + coeff0_29*dmats1[29][6] + coeff0_30*dmats1[30][6] + coeff0_31*dmats1[31][6] + coeff0_32*dmats1[32][6] + coeff0_33*dmats1[33][6] + coeff0_34*dmats1[34][6] + coeff0_35*dmats1[35][6] + coeff0_36*dmats1[36][6] + coeff0_37*dmats1[37][6] + coeff0_38*dmats1[38][6] + coeff0_39*dmats1[39][6] + coeff0_40*dmats1[40][6] + coeff0_41*dmats1[41][6] + coeff0_42*dmats1[42][6] + coeff0_43*dmats1[43][6] + coeff0_44*dmats1[44][6] + coeff0_45*dmats1[45][6] + coeff0_46*dmats1[46][6] + coeff0_47*dmats1[47][6] + coeff0_48*dmats1[48][6] + coeff0_49*dmats1[49][6] + coeff0_50*dmats1[50][6] + coeff0_51*dmats1[51][6] + coeff0_52*dmats1[52][6] + coeff0_53*dmats1[53][6] + coeff0_54*dmats1[54][6] + coeff0_55*dmats1[55][6];
          new_coeff0_7 = coeff0_0*dmats1[0][7] + coeff0_1*dmats1[1][7] + coeff0_2*dmats1[2][7] + coeff0_3*dmats1[3][7] + coeff0_4*dmats1[4][7] + coeff0_5*dmats1[5][7] + coeff0_6*dmats1[6][7] + coeff0_7*dmats1[7][7] + coeff0_8*dmats1[8][7] + coeff0_9*dmats1[9][7] + coeff0_10*dmats1[10][7] + coeff0_11*dmats1[11][7] + coeff0_12*dmats1[12][7] + coeff0_13*dmats1[13][7] + coeff0_14*dmats1[14][7] + coeff0_15*dmats1[15][7] + coeff0_16*dmats1[16][7] + coeff0_17*dmats1[17][7] + coeff0_18*dmats1[18][7] + coeff0_19*dmats1[19][7] + coeff0_20*dmats1[20][7] + coeff0_21*dmats1[21][7] + coeff0_22*dmats1[22][7] + coeff0_23*dmats1[23][7] + coeff0_24*dmats1[24][7] + coeff0_25*dmats1[25][7] + coeff0_26*dmats1[26][7] + coeff0_27*dmats1[27][7] + coeff0_28*dmats1[28][7] + coeff0_29*dmats1[29][7] + coeff0_30*dmats1[30][7] + coeff0_31*dmats1[31][7] + coeff0_32*dmats1[32][7] + coeff0_33*dmats1[33][7] + coeff0_34*dmats1[34][7] + coeff0_35*dmats1[35][7] + coeff0_36*dmats1[36][7] + coeff0_37*dmats1[37][7] + coeff0_38*dmats1[38][7] + coeff0_39*dmats1[39][7] + coeff0_40*dmats1[40][7] + coeff0_41*dmats1[41][7] + coeff0_42*dmats1[42][7] + coeff0_43*dmats1[43][7] + coeff0_44*dmats1[44][7] + coeff0_45*dmats1[45][7] + coeff0_46*dmats1[46][7] + coeff0_47*dmats1[47][7] + coeff0_48*dmats1[48][7] + coeff0_49*dmats1[49][7] + coeff0_50*dmats1[50][7] + coeff0_51*dmats1[51][7] + coeff0_52*dmats1[52][7] + coeff0_53*dmats1[53][7] + coeff0_54*dmats1[54][7] + coeff0_55*dmats1[55][7];
          new_coeff0_8 = coeff0_0*dmats1[0][8] + coeff0_1*dmats1[1][8] + coeff0_2*dmats1[2][8] + coeff0_3*dmats1[3][8] + coeff0_4*dmats1[4][8] + coeff0_5*dmats1[5][8] + coeff0_6*dmats1[6][8] + coeff0_7*dmats1[7][8] + coeff0_8*dmats1[8][8] + coeff0_9*dmats1[9][8] + coeff0_10*dmats1[10][8] + coeff0_11*dmats1[11][8] + coeff0_12*dmats1[12][8] + coeff0_13*dmats1[13][8] + coeff0_14*dmats1[14][8] + coeff0_15*dmats1[15][8] + coeff0_16*dmats1[16][8] + coeff0_17*dmats1[17][8] + coeff0_18*dmats1[18][8] + coeff0_19*dmats1[19][8] + coeff0_20*dmats1[20][8] + coeff0_21*dmats1[21][8] + coeff0_22*dmats1[22][8] + coeff0_23*dmats1[23][8] + coeff0_24*dmats1[24][8] + coeff0_25*dmats1[25][8] + coeff0_26*dmats1[26][8] + coeff0_27*dmats1[27][8] + coeff0_28*dmats1[28][8] + coeff0_29*dmats1[29][8] + coeff0_30*dmats1[30][8] + coeff0_31*dmats1[31][8] + coeff0_32*dmats1[32][8] + coeff0_33*dmats1[33][8] + coeff0_34*dmats1[34][8] + coeff0_35*dmats1[35][8] + coeff0_36*dmats1[36][8] + coeff0_37*dmats1[37][8] + coeff0_38*dmats1[38][8] + coeff0_39*dmats1[39][8] + coeff0_40*dmats1[40][8] + coeff0_41*dmats1[41][8] + coeff0_42*dmats1[42][8] + coeff0_43*dmats1[43][8] + coeff0_44*dmats1[44][8] + coeff0_45*dmats1[45][8] + coeff0_46*dmats1[46][8] + coeff0_47*dmats1[47][8] + coeff0_48*dmats1[48][8] + coeff0_49*dmats1[49][8] + coeff0_50*dmats1[50][8] + coeff0_51*dmats1[51][8] + coeff0_52*dmats1[52][8] + coeff0_53*dmats1[53][8] + coeff0_54*dmats1[54][8] + coeff0_55*dmats1[55][8];
          new_coeff0_9 = coeff0_0*dmats1[0][9] + coeff0_1*dmats1[1][9] + coeff0_2*dmats1[2][9] + coeff0_3*dmats1[3][9] + coeff0_4*dmats1[4][9] + coeff0_5*dmats1[5][9] + coeff0_6*dmats1[6][9] + coeff0_7*dmats1[7][9] + coeff0_8*dmats1[8][9] + coeff0_9*dmats1[9][9] + coeff0_10*dmats1[10][9] + coeff0_11*dmats1[11][9] + coeff0_12*dmats1[12][9] + coeff0_13*dmats1[13][9] + coeff0_14*dmats1[14][9] + coeff0_15*dmats1[15][9] + coeff0_16*dmats1[16][9] + coeff0_17*dmats1[17][9] + coeff0_18*dmats1[18][9] + coeff0_19*dmats1[19][9] + coeff0_20*dmats1[20][9] + coeff0_21*dmats1[21][9] + coeff0_22*dmats1[22][9] + coeff0_23*dmats1[23][9] + coeff0_24*dmats1[24][9] + coeff0_25*dmats1[25][9] + coeff0_26*dmats1[26][9] + coeff0_27*dmats1[27][9] + coeff0_28*dmats1[28][9] + coeff0_29*dmats1[29][9] + coeff0_30*dmats1[30][9] + coeff0_31*dmats1[31][9] + coeff0_32*dmats1[32][9] + coeff0_33*dmats1[33][9] + coeff0_34*dmats1[34][9] + coeff0_35*dmats1[35][9] + coeff0_36*dmats1[36][9] + coeff0_37*dmats1[37][9] + coeff0_38*dmats1[38][9] + coeff0_39*dmats1[39][9] + coeff0_40*dmats1[40][9] + coeff0_41*dmats1[41][9] + coeff0_42*dmats1[42][9] + coeff0_43*dmats1[43][9] + coeff0_44*dmats1[44][9] + coeff0_45*dmats1[45][9] + coeff0_46*dmats1[46][9] + coeff0_47*dmats1[47][9] + coeff0_48*dmats1[48][9] + coeff0_49*dmats1[49][9] + coeff0_50*dmats1[50][9] + coeff0_51*dmats1[51][9] + coeff0_52*dmats1[52][9] + coeff0_53*dmats1[53][9] + coeff0_54*dmats1[54][9] + coeff0_55*dmats1[55][9];
          new_coeff0_10 = coeff0_0*dmats1[0][10] + coeff0_1*dmats1[1][10] + coeff0_2*dmats1[2][10] + coeff0_3*dmats1[3][10] + coeff0_4*dmats1[4][10] + coeff0_5*dmats1[5][10] + coeff0_6*dmats1[6][10] + coeff0_7*dmats1[7][10] + coeff0_8*dmats1[8][10] + coeff0_9*dmats1[9][10] + coeff0_10*dmats1[10][10] + coeff0_11*dmats1[11][10] + coeff0_12*dmats1[12][10] + coeff0_13*dmats1[13][10] + coeff0_14*dmats1[14][10] + coeff0_15*dmats1[15][10] + coeff0_16*dmats1[16][10] + coeff0_17*dmats1[17][10] + coeff0_18*dmats1[18][10] + coeff0_19*dmats1[19][10] + coeff0_20*dmats1[20][10] + coeff0_21*dmats1[21][10] + coeff0_22*dmats1[22][10] + coeff0_23*dmats1[23][10] + coeff0_24*dmats1[24][10] + coeff0_25*dmats1[25][10] + coeff0_26*dmats1[26][10] + coeff0_27*dmats1[27][10] + coeff0_28*dmats1[28][10] + coeff0_29*dmats1[29][10] + coeff0_30*dmats1[30][10] + coeff0_31*dmats1[31][10] + coeff0_32*dmats1[32][10] + coeff0_33*dmats1[33][10] + coeff0_34*dmats1[34][10] + coeff0_35*dmats1[35][10] + coeff0_36*dmats1[36][10] + coeff0_37*dmats1[37][10] + coeff0_38*dmats1[38][10] + coeff0_39*dmats1[39][10] + coeff0_40*dmats1[40][10] + coeff0_41*dmats1[41][10] + coeff0_42*dmats1[42][10] + coeff0_43*dmats1[43][10] + coeff0_44*dmats1[44][10] + coeff0_45*dmats1[45][10] + coeff0_46*dmats1[46][10] + coeff0_47*dmats1[47][10] + coeff0_48*dmats1[48][10] + coeff0_49*dmats1[49][10] + coeff0_50*dmats1[50][10] + coeff0_51*dmats1[51][10] + coeff0_52*dmats1[52][10] + coeff0_53*dmats1[53][10] + coeff0_54*dmats1[54][10] + coeff0_55*dmats1[55][10];
          new_coeff0_11 = coeff0_0*dmats1[0][11] + coeff0_1*dmats1[1][11] + coeff0_2*dmats1[2][11] + coeff0_3*dmats1[3][11] + coeff0_4*dmats1[4][11] + coeff0_5*dmats1[5][11] + coeff0_6*dmats1[6][11] + coeff0_7*dmats1[7][11] + coeff0_8*dmats1[8][11] + coeff0_9*dmats1[9][11] + coeff0_10*dmats1[10][11] + coeff0_11*dmats1[11][11] + coeff0_12*dmats1[12][11] + coeff0_13*dmats1[13][11] + coeff0_14*dmats1[14][11] + coeff0_15*dmats1[15][11] + coeff0_16*dmats1[16][11] + coeff0_17*dmats1[17][11] + coeff0_18*dmats1[18][11] + coeff0_19*dmats1[19][11] + coeff0_20*dmats1[20][11] + coeff0_21*dmats1[21][11] + coeff0_22*dmats1[22][11] + coeff0_23*dmats1[23][11] + coeff0_24*dmats1[24][11] + coeff0_25*dmats1[25][11] + coeff0_26*dmats1[26][11] + coeff0_27*dmats1[27][11] + coeff0_28*dmats1[28][11] + coeff0_29*dmats1[29][11] + coeff0_30*dmats1[30][11] + coeff0_31*dmats1[31][11] + coeff0_32*dmats1[32][11] + coeff0_33*dmats1[33][11] + coeff0_34*dmats1[34][11] + coeff0_35*dmats1[35][11] + coeff0_36*dmats1[36][11] + coeff0_37*dmats1[37][11] + coeff0_38*dmats1[38][11] + coeff0_39*dmats1[39][11] + coeff0_40*dmats1[40][11] + coeff0_41*dmats1[41][11] + coeff0_42*dmats1[42][11] + coeff0_43*dmats1[43][11] + coeff0_44*dmats1[44][11] + coeff0_45*dmats1[45][11] + coeff0_46*dmats1[46][11] + coeff0_47*dmats1[47][11] + coeff0_48*dmats1[48][11] + coeff0_49*dmats1[49][11] + coeff0_50*dmats1[50][11] + coeff0_51*dmats1[51][11] + coeff0_52*dmats1[52][11] + coeff0_53*dmats1[53][11] + coeff0_54*dmats1[54][11] + coeff0_55*dmats1[55][11];
          new_coeff0_12 = coeff0_0*dmats1[0][12] + coeff0_1*dmats1[1][12] + coeff0_2*dmats1[2][12] + coeff0_3*dmats1[3][12] + coeff0_4*dmats1[4][12] + coeff0_5*dmats1[5][12] + coeff0_6*dmats1[6][12] + coeff0_7*dmats1[7][12] + coeff0_8*dmats1[8][12] + coeff0_9*dmats1[9][12] + coeff0_10*dmats1[10][12] + coeff0_11*dmats1[11][12] + coeff0_12*dmats1[12][12] + coeff0_13*dmats1[13][12] + coeff0_14*dmats1[14][12] + coeff0_15*dmats1[15][12] + coeff0_16*dmats1[16][12] + coeff0_17*dmats1[17][12] + coeff0_18*dmats1[18][12] + coeff0_19*dmats1[19][12] + coeff0_20*dmats1[20][12] + coeff0_21*dmats1[21][12] + coeff0_22*dmats1[22][12] + coeff0_23*dmats1[23][12] + coeff0_24*dmats1[24][12] + coeff0_25*dmats1[25][12] + coeff0_26*dmats1[26][12] + coeff0_27*dmats1[27][12] + coeff0_28*dmats1[28][12] + coeff0_29*dmats1[29][12] + coeff0_30*dmats1[30][12] + coeff0_31*dmats1[31][12] + coeff0_32*dmats1[32][12] + coeff0_33*dmats1[33][12] + coeff0_34*dmats1[34][12] + coeff0_35*dmats1[35][12] + coeff0_36*dmats1[36][12] + coeff0_37*dmats1[37][12] + coeff0_38*dmats1[38][12] + coeff0_39*dmats1[39][12] + coeff0_40*dmats1[40][12] + coeff0_41*dmats1[41][12] + coeff0_42*dmats1[42][12] + coeff0_43*dmats1[43][12] + coeff0_44*dmats1[44][12] + coeff0_45*dmats1[45][12] + coeff0_46*dmats1[46][12] + coeff0_47*dmats1[47][12] + coeff0_48*dmats1[48][12] + coeff0_49*dmats1[49][12] + coeff0_50*dmats1[50][12] + coeff0_51*dmats1[51][12] + coeff0_52*dmats1[52][12] + coeff0_53*dmats1[53][12] + coeff0_54*dmats1[54][12] + coeff0_55*dmats1[55][12];
          new_coeff0_13 = coeff0_0*dmats1[0][13] + coeff0_1*dmats1[1][13] + coeff0_2*dmats1[2][13] + coeff0_3*dmats1[3][13] + coeff0_4*dmats1[4][13] + coeff0_5*dmats1[5][13] + coeff0_6*dmats1[6][13] + coeff0_7*dmats1[7][13] + coeff0_8*dmats1[8][13] + coeff0_9*dmats1[9][13] + coeff0_10*dmats1[10][13] + coeff0_11*dmats1[11][13] + coeff0_12*dmats1[12][13] + coeff0_13*dmats1[13][13] + coeff0_14*dmats1[14][13] + coeff0_15*dmats1[15][13] + coeff0_16*dmats1[16][13] + coeff0_17*dmats1[17][13] + coeff0_18*dmats1[18][13] + coeff0_19*dmats1[19][13] + coeff0_20*dmats1[20][13] + coeff0_21*dmats1[21][13] + coeff0_22*dmats1[22][13] + coeff0_23*dmats1[23][13] + coeff0_24*dmats1[24][13] + coeff0_25*dmats1[25][13] + coeff0_26*dmats1[26][13] + coeff0_27*dmats1[27][13] + coeff0_28*dmats1[28][13] + coeff0_29*dmats1[29][13] + coeff0_30*dmats1[30][13] + coeff0_31*dmats1[31][13] + coeff0_32*dmats1[32][13] + coeff0_33*dmats1[33][13] + coeff0_34*dmats1[34][13] + coeff0_35*dmats1[35][13] + coeff0_36*dmats1[36][13] + coeff0_37*dmats1[37][13] + coeff0_38*dmats1[38][13] + coeff0_39*dmats1[39][13] + coeff0_40*dmats1[40][13] + coeff0_41*dmats1[41][13] + coeff0_42*dmats1[42][13] + coeff0_43*dmats1[43][13] + coeff0_44*dmats1[44][13] + coeff0_45*dmats1[45][13] + coeff0_46*dmats1[46][13] + coeff0_47*dmats1[47][13] + coeff0_48*dmats1[48][13] + coeff0_49*dmats1[49][13] + coeff0_50*dmats1[50][13] + coeff0_51*dmats1[51][13] + coeff0_52*dmats1[52][13] + coeff0_53*dmats1[53][13] + coeff0_54*dmats1[54][13] + coeff0_55*dmats1[55][13];
          new_coeff0_14 = coeff0_0*dmats1[0][14] + coeff0_1*dmats1[1][14] + coeff0_2*dmats1[2][14] + coeff0_3*dmats1[3][14] + coeff0_4*dmats1[4][14] + coeff0_5*dmats1[5][14] + coeff0_6*dmats1[6][14] + coeff0_7*dmats1[7][14] + coeff0_8*dmats1[8][14] + coeff0_9*dmats1[9][14] + coeff0_10*dmats1[10][14] + coeff0_11*dmats1[11][14] + coeff0_12*dmats1[12][14] + coeff0_13*dmats1[13][14] + coeff0_14*dmats1[14][14] + coeff0_15*dmats1[15][14] + coeff0_16*dmats1[16][14] + coeff0_17*dmats1[17][14] + coeff0_18*dmats1[18][14] + coeff0_19*dmats1[19][14] + coeff0_20*dmats1[20][14] + coeff0_21*dmats1[21][14] + coeff0_22*dmats1[22][14] + coeff0_23*dmats1[23][14] + coeff0_24*dmats1[24][14] + coeff0_25*dmats1[25][14] + coeff0_26*dmats1[26][14] + coeff0_27*dmats1[27][14] + coeff0_28*dmats1[28][14] + coeff0_29*dmats1[29][14] + coeff0_30*dmats1[30][14] + coeff0_31*dmats1[31][14] + coeff0_32*dmats1[32][14] + coeff0_33*dmats1[33][14] + coeff0_34*dmats1[34][14] + coeff0_35*dmats1[35][14] + coeff0_36*dmats1[36][14] + coeff0_37*dmats1[37][14] + coeff0_38*dmats1[38][14] + coeff0_39*dmats1[39][14] + coeff0_40*dmats1[40][14] + coeff0_41*dmats1[41][14] + coeff0_42*dmats1[42][14] + coeff0_43*dmats1[43][14] + coeff0_44*dmats1[44][14] + coeff0_45*dmats1[45][14] + coeff0_46*dmats1[46][14] + coeff0_47*dmats1[47][14] + coeff0_48*dmats1[48][14] + coeff0_49*dmats1[49][14] + coeff0_50*dmats1[50][14] + coeff0_51*dmats1[51][14] + coeff0_52*dmats1[52][14] + coeff0_53*dmats1[53][14] + coeff0_54*dmats1[54][14] + coeff0_55*dmats1[55][14];
          new_coeff0_15 = coeff0_0*dmats1[0][15] + coeff0_1*dmats1[1][15] + coeff0_2*dmats1[2][15] + coeff0_3*dmats1[3][15] + coeff0_4*dmats1[4][15] + coeff0_5*dmats1[5][15] + coeff0_6*dmats1[6][15] + coeff0_7*dmats1[7][15] + coeff0_8*dmats1[8][15] + coeff0_9*dmats1[9][15] + coeff0_10*dmats1[10][15] + coeff0_11*dmats1[11][15] + coeff0_12*dmats1[12][15] + coeff0_13*dmats1[13][15] + coeff0_14*dmats1[14][15] + coeff0_15*dmats1[15][15] + coeff0_16*dmats1[16][15] + coeff0_17*dmats1[17][15] + coeff0_18*dmats1[18][15] + coeff0_19*dmats1[19][15] + coeff0_20*dmats1[20][15] + coeff0_21*dmats1[21][15] + coeff0_22*dmats1[22][15] + coeff0_23*dmats1[23][15] + coeff0_24*dmats1[24][15] + coeff0_25*dmats1[25][15] + coeff0_26*dmats1[26][15] + coeff0_27*dmats1[27][15] + coeff0_28*dmats1[28][15] + coeff0_29*dmats1[29][15] + coeff0_30*dmats1[30][15] + coeff0_31*dmats1[31][15] + coeff0_32*dmats1[32][15] + coeff0_33*dmats1[33][15] + coeff0_34*dmats1[34][15] + coeff0_35*dmats1[35][15] + coeff0_36*dmats1[36][15] + coeff0_37*dmats1[37][15] + coeff0_38*dmats1[38][15] + coeff0_39*dmats1[39][15] + coeff0_40*dmats1[40][15] + coeff0_41*dmats1[41][15] + coeff0_42*dmats1[42][15] + coeff0_43*dmats1[43][15] + coeff0_44*dmats1[44][15] + coeff0_45*dmats1[45][15] + coeff0_46*dmats1[46][15] + coeff0_47*dmats1[47][15] + coeff0_48*dmats1[48][15] + coeff0_49*dmats1[49][15] + coeff0_50*dmats1[50][15] + coeff0_51*dmats1[51][15] + coeff0_52*dmats1[52][15] + coeff0_53*dmats1[53][15] + coeff0_54*dmats1[54][15] + coeff0_55*dmats1[55][15];
          new_coeff0_16 = coeff0_0*dmats1[0][16] + coeff0_1*dmats1[1][16] + coeff0_2*dmats1[2][16] + coeff0_3*dmats1[3][16] + coeff0_4*dmats1[4][16] + coeff0_5*dmats1[5][16] + coeff0_6*dmats1[6][16] + coeff0_7*dmats1[7][16] + coeff0_8*dmats1[8][16] + coeff0_9*dmats1[9][16] + coeff0_10*dmats1[10][16] + coeff0_11*dmats1[11][16] + coeff0_12*dmats1[12][16] + coeff0_13*dmats1[13][16] + coeff0_14*dmats1[14][16] + coeff0_15*dmats1[15][16] + coeff0_16*dmats1[16][16] + coeff0_17*dmats1[17][16] + coeff0_18*dmats1[18][16] + coeff0_19*dmats1[19][16] + coeff0_20*dmats1[20][16] + coeff0_21*dmats1[21][16] + coeff0_22*dmats1[22][16] + coeff0_23*dmats1[23][16] + coeff0_24*dmats1[24][16] + coeff0_25*dmats1[25][16] + coeff0_26*dmats1[26][16] + coeff0_27*dmats1[27][16] + coeff0_28*dmats1[28][16] + coeff0_29*dmats1[29][16] + coeff0_30*dmats1[30][16] + coeff0_31*dmats1[31][16] + coeff0_32*dmats1[32][16] + coeff0_33*dmats1[33][16] + coeff0_34*dmats1[34][16] + coeff0_35*dmats1[35][16] + coeff0_36*dmats1[36][16] + coeff0_37*dmats1[37][16] + coeff0_38*dmats1[38][16] + coeff0_39*dmats1[39][16] + coeff0_40*dmats1[40][16] + coeff0_41*dmats1[41][16] + coeff0_42*dmats1[42][16] + coeff0_43*dmats1[43][16] + coeff0_44*dmats1[44][16] + coeff0_45*dmats1[45][16] + coeff0_46*dmats1[46][16] + coeff0_47*dmats1[47][16] + coeff0_48*dmats1[48][16] + coeff0_49*dmats1[49][16] + coeff0_50*dmats1[50][16] + coeff0_51*dmats1[51][16] + coeff0_52*dmats1[52][16] + coeff0_53*dmats1[53][16] + coeff0_54*dmats1[54][16] + coeff0_55*dmats1[55][16];
          new_coeff0_17 = coeff0_0*dmats1[0][17] + coeff0_1*dmats1[1][17] + coeff0_2*dmats1[2][17] + coeff0_3*dmats1[3][17] + coeff0_4*dmats1[4][17] + coeff0_5*dmats1[5][17] + coeff0_6*dmats1[6][17] + coeff0_7*dmats1[7][17] + coeff0_8*dmats1[8][17] + coeff0_9*dmats1[9][17] + coeff0_10*dmats1[10][17] + coeff0_11*dmats1[11][17] + coeff0_12*dmats1[12][17] + coeff0_13*dmats1[13][17] + coeff0_14*dmats1[14][17] + coeff0_15*dmats1[15][17] + coeff0_16*dmats1[16][17] + coeff0_17*dmats1[17][17] + coeff0_18*dmats1[18][17] + coeff0_19*dmats1[19][17] + coeff0_20*dmats1[20][17] + coeff0_21*dmats1[21][17] + coeff0_22*dmats1[22][17] + coeff0_23*dmats1[23][17] + coeff0_24*dmats1[24][17] + coeff0_25*dmats1[25][17] + coeff0_26*dmats1[26][17] + coeff0_27*dmats1[27][17] + coeff0_28*dmats1[28][17] + coeff0_29*dmats1[29][17] + coeff0_30*dmats1[30][17] + coeff0_31*dmats1[31][17] + coeff0_32*dmats1[32][17] + coeff0_33*dmats1[33][17] + coeff0_34*dmats1[34][17] + coeff0_35*dmats1[35][17] + coeff0_36*dmats1[36][17] + coeff0_37*dmats1[37][17] + coeff0_38*dmats1[38][17] + coeff0_39*dmats1[39][17] + coeff0_40*dmats1[40][17] + coeff0_41*dmats1[41][17] + coeff0_42*dmats1[42][17] + coeff0_43*dmats1[43][17] + coeff0_44*dmats1[44][17] + coeff0_45*dmats1[45][17] + coeff0_46*dmats1[46][17] + coeff0_47*dmats1[47][17] + coeff0_48*dmats1[48][17] + coeff0_49*dmats1[49][17] + coeff0_50*dmats1[50][17] + coeff0_51*dmats1[51][17] + coeff0_52*dmats1[52][17] + coeff0_53*dmats1[53][17] + coeff0_54*dmats1[54][17] + coeff0_55*dmats1[55][17];
          new_coeff0_18 = coeff0_0*dmats1[0][18] + coeff0_1*dmats1[1][18] + coeff0_2*dmats1[2][18] + coeff0_3*dmats1[3][18] + coeff0_4*dmats1[4][18] + coeff0_5*dmats1[5][18] + coeff0_6*dmats1[6][18] + coeff0_7*dmats1[7][18] + coeff0_8*dmats1[8][18] + coeff0_9*dmats1[9][18] + coeff0_10*dmats1[10][18] + coeff0_11*dmats1[11][18] + coeff0_12*dmats1[12][18] + coeff0_13*dmats1[13][18] + coeff0_14*dmats1[14][18] + coeff0_15*dmats1[15][18] + coeff0_16*dmats1[16][18] + coeff0_17*dmats1[17][18] + coeff0_18*dmats1[18][18] + coeff0_19*dmats1[19][18] + coeff0_20*dmats1[20][18] + coeff0_21*dmats1[21][18] + coeff0_22*dmats1[22][18] + coeff0_23*dmats1[23][18] + coeff0_24*dmats1[24][18] + coeff0_25*dmats1[25][18] + coeff0_26*dmats1[26][18] + coeff0_27*dmats1[27][18] + coeff0_28*dmats1[28][18] + coeff0_29*dmats1[29][18] + coeff0_30*dmats1[30][18] + coeff0_31*dmats1[31][18] + coeff0_32*dmats1[32][18] + coeff0_33*dmats1[33][18] + coeff0_34*dmats1[34][18] + coeff0_35*dmats1[35][18] + coeff0_36*dmats1[36][18] + coeff0_37*dmats1[37][18] + coeff0_38*dmats1[38][18] + coeff0_39*dmats1[39][18] + coeff0_40*dmats1[40][18] + coeff0_41*dmats1[41][18] + coeff0_42*dmats1[42][18] + coeff0_43*dmats1[43][18] + coeff0_44*dmats1[44][18] + coeff0_45*dmats1[45][18] + coeff0_46*dmats1[46][18] + coeff0_47*dmats1[47][18] + coeff0_48*dmats1[48][18] + coeff0_49*dmats1[49][18] + coeff0_50*dmats1[50][18] + coeff0_51*dmats1[51][18] + coeff0_52*dmats1[52][18] + coeff0_53*dmats1[53][18] + coeff0_54*dmats1[54][18] + coeff0_55*dmats1[55][18];
          new_coeff0_19 = coeff0_0*dmats1[0][19] + coeff0_1*dmats1[1][19] + coeff0_2*dmats1[2][19] + coeff0_3*dmats1[3][19] + coeff0_4*dmats1[4][19] + coeff0_5*dmats1[5][19] + coeff0_6*dmats1[6][19] + coeff0_7*dmats1[7][19] + coeff0_8*dmats1[8][19] + coeff0_9*dmats1[9][19] + coeff0_10*dmats1[10][19] + coeff0_11*dmats1[11][19] + coeff0_12*dmats1[12][19] + coeff0_13*dmats1[13][19] + coeff0_14*dmats1[14][19] + coeff0_15*dmats1[15][19] + coeff0_16*dmats1[16][19] + coeff0_17*dmats1[17][19] + coeff0_18*dmats1[18][19] + coeff0_19*dmats1[19][19] + coeff0_20*dmats1[20][19] + coeff0_21*dmats1[21][19] + coeff0_22*dmats1[22][19] + coeff0_23*dmats1[23][19] + coeff0_24*dmats1[24][19] + coeff0_25*dmats1[25][19] + coeff0_26*dmats1[26][19] + coeff0_27*dmats1[27][19] + coeff0_28*dmats1[28][19] + coeff0_29*dmats1[29][19] + coeff0_30*dmats1[30][19] + coeff0_31*dmats1[31][19] + coeff0_32*dmats1[32][19] + coeff0_33*dmats1[33][19] + coeff0_34*dmats1[34][19] + coeff0_35*dmats1[35][19] + coeff0_36*dmats1[36][19] + coeff0_37*dmats1[37][19] + coeff0_38*dmats1[38][19] + coeff0_39*dmats1[39][19] + coeff0_40*dmats1[40][19] + coeff0_41*dmats1[41][19] + coeff0_42*dmats1[42][19] + coeff0_43*dmats1[43][19] + coeff0_44*dmats1[44][19] + coeff0_45*dmats1[45][19] + coeff0_46*dmats1[46][19] + coeff0_47*dmats1[47][19] + coeff0_48*dmats1[48][19] + coeff0_49*dmats1[49][19] + coeff0_50*dmats1[50][19] + coeff0_51*dmats1[51][19] + coeff0_52*dmats1[52][19] + coeff0_53*dmats1[53][19] + coeff0_54*dmats1[54][19] + coeff0_55*dmats1[55][19];
          new_coeff0_20 = coeff0_0*dmats1[0][20] + coeff0_1*dmats1[1][20] + coeff0_2*dmats1[2][20] + coeff0_3*dmats1[3][20] + coeff0_4*dmats1[4][20] + coeff0_5*dmats1[5][20] + coeff0_6*dmats1[6][20] + coeff0_7*dmats1[7][20] + coeff0_8*dmats1[8][20] + coeff0_9*dmats1[9][20] + coeff0_10*dmats1[10][20] + coeff0_11*dmats1[11][20] + coeff0_12*dmats1[12][20] + coeff0_13*dmats1[13][20] + coeff0_14*dmats1[14][20] + coeff0_15*dmats1[15][20] + coeff0_16*dmats1[16][20] + coeff0_17*dmats1[17][20] + coeff0_18*dmats1[18][20] + coeff0_19*dmats1[19][20] + coeff0_20*dmats1[20][20] + coeff0_21*dmats1[21][20] + coeff0_22*dmats1[22][20] + coeff0_23*dmats1[23][20] + coeff0_24*dmats1[24][20] + coeff0_25*dmats1[25][20] + coeff0_26*dmats1[26][20] + coeff0_27*dmats1[27][20] + coeff0_28*dmats1[28][20] + coeff0_29*dmats1[29][20] + coeff0_30*dmats1[30][20] + coeff0_31*dmats1[31][20] + coeff0_32*dmats1[32][20] + coeff0_33*dmats1[33][20] + coeff0_34*dmats1[34][20] + coeff0_35*dmats1[35][20] + coeff0_36*dmats1[36][20] + coeff0_37*dmats1[37][20] + coeff0_38*dmats1[38][20] + coeff0_39*dmats1[39][20] + coeff0_40*dmats1[40][20] + coeff0_41*dmats1[41][20] + coeff0_42*dmats1[42][20] + coeff0_43*dmats1[43][20] + coeff0_44*dmats1[44][20] + coeff0_45*dmats1[45][20] + coeff0_46*dmats1[46][20] + coeff0_47*dmats1[47][20] + coeff0_48*dmats1[48][20] + coeff0_49*dmats1[49][20] + coeff0_50*dmats1[50][20] + coeff0_51*dmats1[51][20] + coeff0_52*dmats1[52][20] + coeff0_53*dmats1[53][20] + coeff0_54*dmats1[54][20] + coeff0_55*dmats1[55][20];
          new_coeff0_21 = coeff0_0*dmats1[0][21] + coeff0_1*dmats1[1][21] + coeff0_2*dmats1[2][21] + coeff0_3*dmats1[3][21] + coeff0_4*dmats1[4][21] + coeff0_5*dmats1[5][21] + coeff0_6*dmats1[6][21] + coeff0_7*dmats1[7][21] + coeff0_8*dmats1[8][21] + coeff0_9*dmats1[9][21] + coeff0_10*dmats1[10][21] + coeff0_11*dmats1[11][21] + coeff0_12*dmats1[12][21] + coeff0_13*dmats1[13][21] + coeff0_14*dmats1[14][21] + coeff0_15*dmats1[15][21] + coeff0_16*dmats1[16][21] + coeff0_17*dmats1[17][21] + coeff0_18*dmats1[18][21] + coeff0_19*dmats1[19][21] + coeff0_20*dmats1[20][21] + coeff0_21*dmats1[21][21] + coeff0_22*dmats1[22][21] + coeff0_23*dmats1[23][21] + coeff0_24*dmats1[24][21] + coeff0_25*dmats1[25][21] + coeff0_26*dmats1[26][21] + coeff0_27*dmats1[27][21] + coeff0_28*dmats1[28][21] + coeff0_29*dmats1[29][21] + coeff0_30*dmats1[30][21] + coeff0_31*dmats1[31][21] + coeff0_32*dmats1[32][21] + coeff0_33*dmats1[33][21] + coeff0_34*dmats1[34][21] + coeff0_35*dmats1[35][21] + coeff0_36*dmats1[36][21] + coeff0_37*dmats1[37][21] + coeff0_38*dmats1[38][21] + coeff0_39*dmats1[39][21] + coeff0_40*dmats1[40][21] + coeff0_41*dmats1[41][21] + coeff0_42*dmats1[42][21] + coeff0_43*dmats1[43][21] + coeff0_44*dmats1[44][21] + coeff0_45*dmats1[45][21] + coeff0_46*dmats1[46][21] + coeff0_47*dmats1[47][21] + coeff0_48*dmats1[48][21] + coeff0_49*dmats1[49][21] + coeff0_50*dmats1[50][21] + coeff0_51*dmats1[51][21] + coeff0_52*dmats1[52][21] + coeff0_53*dmats1[53][21] + coeff0_54*dmats1[54][21] + coeff0_55*dmats1[55][21];
          new_coeff0_22 = coeff0_0*dmats1[0][22] + coeff0_1*dmats1[1][22] + coeff0_2*dmats1[2][22] + coeff0_3*dmats1[3][22] + coeff0_4*dmats1[4][22] + coeff0_5*dmats1[5][22] + coeff0_6*dmats1[6][22] + coeff0_7*dmats1[7][22] + coeff0_8*dmats1[8][22] + coeff0_9*dmats1[9][22] + coeff0_10*dmats1[10][22] + coeff0_11*dmats1[11][22] + coeff0_12*dmats1[12][22] + coeff0_13*dmats1[13][22] + coeff0_14*dmats1[14][22] + coeff0_15*dmats1[15][22] + coeff0_16*dmats1[16][22] + coeff0_17*dmats1[17][22] + coeff0_18*dmats1[18][22] + coeff0_19*dmats1[19][22] + coeff0_20*dmats1[20][22] + coeff0_21*dmats1[21][22] + coeff0_22*dmats1[22][22] + coeff0_23*dmats1[23][22] + coeff0_24*dmats1[24][22] + coeff0_25*dmats1[25][22] + coeff0_26*dmats1[26][22] + coeff0_27*dmats1[27][22] + coeff0_28*dmats1[28][22] + coeff0_29*dmats1[29][22] + coeff0_30*dmats1[30][22] + coeff0_31*dmats1[31][22] + coeff0_32*dmats1[32][22] + coeff0_33*dmats1[33][22] + coeff0_34*dmats1[34][22] + coeff0_35*dmats1[35][22] + coeff0_36*dmats1[36][22] + coeff0_37*dmats1[37][22] + coeff0_38*dmats1[38][22] + coeff0_39*dmats1[39][22] + coeff0_40*dmats1[40][22] + coeff0_41*dmats1[41][22] + coeff0_42*dmats1[42][22] + coeff0_43*dmats1[43][22] + coeff0_44*dmats1[44][22] + coeff0_45*dmats1[45][22] + coeff0_46*dmats1[46][22] + coeff0_47*dmats1[47][22] + coeff0_48*dmats1[48][22] + coeff0_49*dmats1[49][22] + coeff0_50*dmats1[50][22] + coeff0_51*dmats1[51][22] + coeff0_52*dmats1[52][22] + coeff0_53*dmats1[53][22] + coeff0_54*dmats1[54][22] + coeff0_55*dmats1[55][22];
          new_coeff0_23 = coeff0_0*dmats1[0][23] + coeff0_1*dmats1[1][23] + coeff0_2*dmats1[2][23] + coeff0_3*dmats1[3][23] + coeff0_4*dmats1[4][23] + coeff0_5*dmats1[5][23] + coeff0_6*dmats1[6][23] + coeff0_7*dmats1[7][23] + coeff0_8*dmats1[8][23] + coeff0_9*dmats1[9][23] + coeff0_10*dmats1[10][23] + coeff0_11*dmats1[11][23] + coeff0_12*dmats1[12][23] + coeff0_13*dmats1[13][23] + coeff0_14*dmats1[14][23] + coeff0_15*dmats1[15][23] + coeff0_16*dmats1[16][23] + coeff0_17*dmats1[17][23] + coeff0_18*dmats1[18][23] + coeff0_19*dmats1[19][23] + coeff0_20*dmats1[20][23] + coeff0_21*dmats1[21][23] + coeff0_22*dmats1[22][23] + coeff0_23*dmats1[23][23] + coeff0_24*dmats1[24][23] + coeff0_25*dmats1[25][23] + coeff0_26*dmats1[26][23] + coeff0_27*dmats1[27][23] + coeff0_28*dmats1[28][23] + coeff0_29*dmats1[29][23] + coeff0_30*dmats1[30][23] + coeff0_31*dmats1[31][23] + coeff0_32*dmats1[32][23] + coeff0_33*dmats1[33][23] + coeff0_34*dmats1[34][23] + coeff0_35*dmats1[35][23] + coeff0_36*dmats1[36][23] + coeff0_37*dmats1[37][23] + coeff0_38*dmats1[38][23] + coeff0_39*dmats1[39][23] + coeff0_40*dmats1[40][23] + coeff0_41*dmats1[41][23] + coeff0_42*dmats1[42][23] + coeff0_43*dmats1[43][23] + coeff0_44*dmats1[44][23] + coeff0_45*dmats1[45][23] + coeff0_46*dmats1[46][23] + coeff0_47*dmats1[47][23] + coeff0_48*dmats1[48][23] + coeff0_49*dmats1[49][23] + coeff0_50*dmats1[50][23] + coeff0_51*dmats1[51][23] + coeff0_52*dmats1[52][23] + coeff0_53*dmats1[53][23] + coeff0_54*dmats1[54][23] + coeff0_55*dmats1[55][23];
          new_coeff0_24 = coeff0_0*dmats1[0][24] + coeff0_1*dmats1[1][24] + coeff0_2*dmats1[2][24] + coeff0_3*dmats1[3][24] + coeff0_4*dmats1[4][24] + coeff0_5*dmats1[5][24] + coeff0_6*dmats1[6][24] + coeff0_7*dmats1[7][24] + coeff0_8*dmats1[8][24] + coeff0_9*dmats1[9][24] + coeff0_10*dmats1[10][24] + coeff0_11*dmats1[11][24] + coeff0_12*dmats1[12][24] + coeff0_13*dmats1[13][24] + coeff0_14*dmats1[14][24] + coeff0_15*dmats1[15][24] + coeff0_16*dmats1[16][24] + coeff0_17*dmats1[17][24] + coeff0_18*dmats1[18][24] + coeff0_19*dmats1[19][24] + coeff0_20*dmats1[20][24] + coeff0_21*dmats1[21][24] + coeff0_22*dmats1[22][24] + coeff0_23*dmats1[23][24] + coeff0_24*dmats1[24][24] + coeff0_25*dmats1[25][24] + coeff0_26*dmats1[26][24] + coeff0_27*dmats1[27][24] + coeff0_28*dmats1[28][24] + coeff0_29*dmats1[29][24] + coeff0_30*dmats1[30][24] + coeff0_31*dmats1[31][24] + coeff0_32*dmats1[32][24] + coeff0_33*dmats1[33][24] + coeff0_34*dmats1[34][24] + coeff0_35*dmats1[35][24] + coeff0_36*dmats1[36][24] + coeff0_37*dmats1[37][24] + coeff0_38*dmats1[38][24] + coeff0_39*dmats1[39][24] + coeff0_40*dmats1[40][24] + coeff0_41*dmats1[41][24] + coeff0_42*dmats1[42][24] + coeff0_43*dmats1[43][24] + coeff0_44*dmats1[44][24] + coeff0_45*dmats1[45][24] + coeff0_46*dmats1[46][24] + coeff0_47*dmats1[47][24] + coeff0_48*dmats1[48][24] + coeff0_49*dmats1[49][24] + coeff0_50*dmats1[50][24] + coeff0_51*dmats1[51][24] + coeff0_52*dmats1[52][24] + coeff0_53*dmats1[53][24] + coeff0_54*dmats1[54][24] + coeff0_55*dmats1[55][24];
          new_coeff0_25 = coeff0_0*dmats1[0][25] + coeff0_1*dmats1[1][25] + coeff0_2*dmats1[2][25] + coeff0_3*dmats1[3][25] + coeff0_4*dmats1[4][25] + coeff0_5*dmats1[5][25] + coeff0_6*dmats1[6][25] + coeff0_7*dmats1[7][25] + coeff0_8*dmats1[8][25] + coeff0_9*dmats1[9][25] + coeff0_10*dmats1[10][25] + coeff0_11*dmats1[11][25] + coeff0_12*dmats1[12][25] + coeff0_13*dmats1[13][25] + coeff0_14*dmats1[14][25] + coeff0_15*dmats1[15][25] + coeff0_16*dmats1[16][25] + coeff0_17*dmats1[17][25] + coeff0_18*dmats1[18][25] + coeff0_19*dmats1[19][25] + coeff0_20*dmats1[20][25] + coeff0_21*dmats1[21][25] + coeff0_22*dmats1[22][25] + coeff0_23*dmats1[23][25] + coeff0_24*dmats1[24][25] + coeff0_25*dmats1[25][25] + coeff0_26*dmats1[26][25] + coeff0_27*dmats1[27][25] + coeff0_28*dmats1[28][25] + coeff0_29*dmats1[29][25] + coeff0_30*dmats1[30][25] + coeff0_31*dmats1[31][25] + coeff0_32*dmats1[32][25] + coeff0_33*dmats1[33][25] + coeff0_34*dmats1[34][25] + coeff0_35*dmats1[35][25] + coeff0_36*dmats1[36][25] + coeff0_37*dmats1[37][25] + coeff0_38*dmats1[38][25] + coeff0_39*dmats1[39][25] + coeff0_40*dmats1[40][25] + coeff0_41*dmats1[41][25] + coeff0_42*dmats1[42][25] + coeff0_43*dmats1[43][25] + coeff0_44*dmats1[44][25] + coeff0_45*dmats1[45][25] + coeff0_46*dmats1[46][25] + coeff0_47*dmats1[47][25] + coeff0_48*dmats1[48][25] + coeff0_49*dmats1[49][25] + coeff0_50*dmats1[50][25] + coeff0_51*dmats1[51][25] + coeff0_52*dmats1[52][25] + coeff0_53*dmats1[53][25] + coeff0_54*dmats1[54][25] + coeff0_55*dmats1[55][25];
          new_coeff0_26 = coeff0_0*dmats1[0][26] + coeff0_1*dmats1[1][26] + coeff0_2*dmats1[2][26] + coeff0_3*dmats1[3][26] + coeff0_4*dmats1[4][26] + coeff0_5*dmats1[5][26] + coeff0_6*dmats1[6][26] + coeff0_7*dmats1[7][26] + coeff0_8*dmats1[8][26] + coeff0_9*dmats1[9][26] + coeff0_10*dmats1[10][26] + coeff0_11*dmats1[11][26] + coeff0_12*dmats1[12][26] + coeff0_13*dmats1[13][26] + coeff0_14*dmats1[14][26] + coeff0_15*dmats1[15][26] + coeff0_16*dmats1[16][26] + coeff0_17*dmats1[17][26] + coeff0_18*dmats1[18][26] + coeff0_19*dmats1[19][26] + coeff0_20*dmats1[20][26] + coeff0_21*dmats1[21][26] + coeff0_22*dmats1[22][26] + coeff0_23*dmats1[23][26] + coeff0_24*dmats1[24][26] + coeff0_25*dmats1[25][26] + coeff0_26*dmats1[26][26] + coeff0_27*dmats1[27][26] + coeff0_28*dmats1[28][26] + coeff0_29*dmats1[29][26] + coeff0_30*dmats1[30][26] + coeff0_31*dmats1[31][26] + coeff0_32*dmats1[32][26] + coeff0_33*dmats1[33][26] + coeff0_34*dmats1[34][26] + coeff0_35*dmats1[35][26] + coeff0_36*dmats1[36][26] + coeff0_37*dmats1[37][26] + coeff0_38*dmats1[38][26] + coeff0_39*dmats1[39][26] + coeff0_40*dmats1[40][26] + coeff0_41*dmats1[41][26] + coeff0_42*dmats1[42][26] + coeff0_43*dmats1[43][26] + coeff0_44*dmats1[44][26] + coeff0_45*dmats1[45][26] + coeff0_46*dmats1[46][26] + coeff0_47*dmats1[47][26] + coeff0_48*dmats1[48][26] + coeff0_49*dmats1[49][26] + coeff0_50*dmats1[50][26] + coeff0_51*dmats1[51][26] + coeff0_52*dmats1[52][26] + coeff0_53*dmats1[53][26] + coeff0_54*dmats1[54][26] + coeff0_55*dmats1[55][26];
          new_coeff0_27 = coeff0_0*dmats1[0][27] + coeff0_1*dmats1[1][27] + coeff0_2*dmats1[2][27] + coeff0_3*dmats1[3][27] + coeff0_4*dmats1[4][27] + coeff0_5*dmats1[5][27] + coeff0_6*dmats1[6][27] + coeff0_7*dmats1[7][27] + coeff0_8*dmats1[8][27] + coeff0_9*dmats1[9][27] + coeff0_10*dmats1[10][27] + coeff0_11*dmats1[11][27] + coeff0_12*dmats1[12][27] + coeff0_13*dmats1[13][27] + coeff0_14*dmats1[14][27] + coeff0_15*dmats1[15][27] + coeff0_16*dmats1[16][27] + coeff0_17*dmats1[17][27] + coeff0_18*dmats1[18][27] + coeff0_19*dmats1[19][27] + coeff0_20*dmats1[20][27] + coeff0_21*dmats1[21][27] + coeff0_22*dmats1[22][27] + coeff0_23*dmats1[23][27] + coeff0_24*dmats1[24][27] + coeff0_25*dmats1[25][27] + coeff0_26*dmats1[26][27] + coeff0_27*dmats1[27][27] + coeff0_28*dmats1[28][27] + coeff0_29*dmats1[29][27] + coeff0_30*dmats1[30][27] + coeff0_31*dmats1[31][27] + coeff0_32*dmats1[32][27] + coeff0_33*dmats1[33][27] + coeff0_34*dmats1[34][27] + coeff0_35*dmats1[35][27] + coeff0_36*dmats1[36][27] + coeff0_37*dmats1[37][27] + coeff0_38*dmats1[38][27] + coeff0_39*dmats1[39][27] + coeff0_40*dmats1[40][27] + coeff0_41*dmats1[41][27] + coeff0_42*dmats1[42][27] + coeff0_43*dmats1[43][27] + coeff0_44*dmats1[44][27] + coeff0_45*dmats1[45][27] + coeff0_46*dmats1[46][27] + coeff0_47*dmats1[47][27] + coeff0_48*dmats1[48][27] + coeff0_49*dmats1[49][27] + coeff0_50*dmats1[50][27] + coeff0_51*dmats1[51][27] + coeff0_52*dmats1[52][27] + coeff0_53*dmats1[53][27] + coeff0_54*dmats1[54][27] + coeff0_55*dmats1[55][27];
          new_coeff0_28 = coeff0_0*dmats1[0][28] + coeff0_1*dmats1[1][28] + coeff0_2*dmats1[2][28] + coeff0_3*dmats1[3][28] + coeff0_4*dmats1[4][28] + coeff0_5*dmats1[5][28] + coeff0_6*dmats1[6][28] + coeff0_7*dmats1[7][28] + coeff0_8*dmats1[8][28] + coeff0_9*dmats1[9][28] + coeff0_10*dmats1[10][28] + coeff0_11*dmats1[11][28] + coeff0_12*dmats1[12][28] + coeff0_13*dmats1[13][28] + coeff0_14*dmats1[14][28] + coeff0_15*dmats1[15][28] + coeff0_16*dmats1[16][28] + coeff0_17*dmats1[17][28] + coeff0_18*dmats1[18][28] + coeff0_19*dmats1[19][28] + coeff0_20*dmats1[20][28] + coeff0_21*dmats1[21][28] + coeff0_22*dmats1[22][28] + coeff0_23*dmats1[23][28] + coeff0_24*dmats1[24][28] + coeff0_25*dmats1[25][28] + coeff0_26*dmats1[26][28] + coeff0_27*dmats1[27][28] + coeff0_28*dmats1[28][28] + coeff0_29*dmats1[29][28] + coeff0_30*dmats1[30][28] + coeff0_31*dmats1[31][28] + coeff0_32*dmats1[32][28] + coeff0_33*dmats1[33][28] + coeff0_34*dmats1[34][28] + coeff0_35*dmats1[35][28] + coeff0_36*dmats1[36][28] + coeff0_37*dmats1[37][28] + coeff0_38*dmats1[38][28] + coeff0_39*dmats1[39][28] + coeff0_40*dmats1[40][28] + coeff0_41*dmats1[41][28] + coeff0_42*dmats1[42][28] + coeff0_43*dmats1[43][28] + coeff0_44*dmats1[44][28] + coeff0_45*dmats1[45][28] + coeff0_46*dmats1[46][28] + coeff0_47*dmats1[47][28] + coeff0_48*dmats1[48][28] + coeff0_49*dmats1[49][28] + coeff0_50*dmats1[50][28] + coeff0_51*dmats1[51][28] + coeff0_52*dmats1[52][28] + coeff0_53*dmats1[53][28] + coeff0_54*dmats1[54][28] + coeff0_55*dmats1[55][28];
          new_coeff0_29 = coeff0_0*dmats1[0][29] + coeff0_1*dmats1[1][29] + coeff0_2*dmats1[2][29] + coeff0_3*dmats1[3][29] + coeff0_4*dmats1[4][29] + coeff0_5*dmats1[5][29] + coeff0_6*dmats1[6][29] + coeff0_7*dmats1[7][29] + coeff0_8*dmats1[8][29] + coeff0_9*dmats1[9][29] + coeff0_10*dmats1[10][29] + coeff0_11*dmats1[11][29] + coeff0_12*dmats1[12][29] + coeff0_13*dmats1[13][29] + coeff0_14*dmats1[14][29] + coeff0_15*dmats1[15][29] + coeff0_16*dmats1[16][29] + coeff0_17*dmats1[17][29] + coeff0_18*dmats1[18][29] + coeff0_19*dmats1[19][29] + coeff0_20*dmats1[20][29] + coeff0_21*dmats1[21][29] + coeff0_22*dmats1[22][29] + coeff0_23*dmats1[23][29] + coeff0_24*dmats1[24][29] + coeff0_25*dmats1[25][29] + coeff0_26*dmats1[26][29] + coeff0_27*dmats1[27][29] + coeff0_28*dmats1[28][29] + coeff0_29*dmats1[29][29] + coeff0_30*dmats1[30][29] + coeff0_31*dmats1[31][29] + coeff0_32*dmats1[32][29] + coeff0_33*dmats1[33][29] + coeff0_34*dmats1[34][29] + coeff0_35*dmats1[35][29] + coeff0_36*dmats1[36][29] + coeff0_37*dmats1[37][29] + coeff0_38*dmats1[38][29] + coeff0_39*dmats1[39][29] + coeff0_40*dmats1[40][29] + coeff0_41*dmats1[41][29] + coeff0_42*dmats1[42][29] + coeff0_43*dmats1[43][29] + coeff0_44*dmats1[44][29] + coeff0_45*dmats1[45][29] + coeff0_46*dmats1[46][29] + coeff0_47*dmats1[47][29] + coeff0_48*dmats1[48][29] + coeff0_49*dmats1[49][29] + coeff0_50*dmats1[50][29] + coeff0_51*dmats1[51][29] + coeff0_52*dmats1[52][29] + coeff0_53*dmats1[53][29] + coeff0_54*dmats1[54][29] + coeff0_55*dmats1[55][29];
          new_coeff0_30 = coeff0_0*dmats1[0][30] + coeff0_1*dmats1[1][30] + coeff0_2*dmats1[2][30] + coeff0_3*dmats1[3][30] + coeff0_4*dmats1[4][30] + coeff0_5*dmats1[5][30] + coeff0_6*dmats1[6][30] + coeff0_7*dmats1[7][30] + coeff0_8*dmats1[8][30] + coeff0_9*dmats1[9][30] + coeff0_10*dmats1[10][30] + coeff0_11*dmats1[11][30] + coeff0_12*dmats1[12][30] + coeff0_13*dmats1[13][30] + coeff0_14*dmats1[14][30] + coeff0_15*dmats1[15][30] + coeff0_16*dmats1[16][30] + coeff0_17*dmats1[17][30] + coeff0_18*dmats1[18][30] + coeff0_19*dmats1[19][30] + coeff0_20*dmats1[20][30] + coeff0_21*dmats1[21][30] + coeff0_22*dmats1[22][30] + coeff0_23*dmats1[23][30] + coeff0_24*dmats1[24][30] + coeff0_25*dmats1[25][30] + coeff0_26*dmats1[26][30] + coeff0_27*dmats1[27][30] + coeff0_28*dmats1[28][30] + coeff0_29*dmats1[29][30] + coeff0_30*dmats1[30][30] + coeff0_31*dmats1[31][30] + coeff0_32*dmats1[32][30] + coeff0_33*dmats1[33][30] + coeff0_34*dmats1[34][30] + coeff0_35*dmats1[35][30] + coeff0_36*dmats1[36][30] + coeff0_37*dmats1[37][30] + coeff0_38*dmats1[38][30] + coeff0_39*dmats1[39][30] + coeff0_40*dmats1[40][30] + coeff0_41*dmats1[41][30] + coeff0_42*dmats1[42][30] + coeff0_43*dmats1[43][30] + coeff0_44*dmats1[44][30] + coeff0_45*dmats1[45][30] + coeff0_46*dmats1[46][30] + coeff0_47*dmats1[47][30] + coeff0_48*dmats1[48][30] + coeff0_49*dmats1[49][30] + coeff0_50*dmats1[50][30] + coeff0_51*dmats1[51][30] + coeff0_52*dmats1[52][30] + coeff0_53*dmats1[53][30] + coeff0_54*dmats1[54][30] + coeff0_55*dmats1[55][30];
          new_coeff0_31 = coeff0_0*dmats1[0][31] + coeff0_1*dmats1[1][31] + coeff0_2*dmats1[2][31] + coeff0_3*dmats1[3][31] + coeff0_4*dmats1[4][31] + coeff0_5*dmats1[5][31] + coeff0_6*dmats1[6][31] + coeff0_7*dmats1[7][31] + coeff0_8*dmats1[8][31] + coeff0_9*dmats1[9][31] + coeff0_10*dmats1[10][31] + coeff0_11*dmats1[11][31] + coeff0_12*dmats1[12][31] + coeff0_13*dmats1[13][31] + coeff0_14*dmats1[14][31] + coeff0_15*dmats1[15][31] + coeff0_16*dmats1[16][31] + coeff0_17*dmats1[17][31] + coeff0_18*dmats1[18][31] + coeff0_19*dmats1[19][31] + coeff0_20*dmats1[20][31] + coeff0_21*dmats1[21][31] + coeff0_22*dmats1[22][31] + coeff0_23*dmats1[23][31] + coeff0_24*dmats1[24][31] + coeff0_25*dmats1[25][31] + coeff0_26*dmats1[26][31] + coeff0_27*dmats1[27][31] + coeff0_28*dmats1[28][31] + coeff0_29*dmats1[29][31] + coeff0_30*dmats1[30][31] + coeff0_31*dmats1[31][31] + coeff0_32*dmats1[32][31] + coeff0_33*dmats1[33][31] + coeff0_34*dmats1[34][31] + coeff0_35*dmats1[35][31] + coeff0_36*dmats1[36][31] + coeff0_37*dmats1[37][31] + coeff0_38*dmats1[38][31] + coeff0_39*dmats1[39][31] + coeff0_40*dmats1[40][31] + coeff0_41*dmats1[41][31] + coeff0_42*dmats1[42][31] + coeff0_43*dmats1[43][31] + coeff0_44*dmats1[44][31] + coeff0_45*dmats1[45][31] + coeff0_46*dmats1[46][31] + coeff0_47*dmats1[47][31] + coeff0_48*dmats1[48][31] + coeff0_49*dmats1[49][31] + coeff0_50*dmats1[50][31] + coeff0_51*dmats1[51][31] + coeff0_52*dmats1[52][31] + coeff0_53*dmats1[53][31] + coeff0_54*dmats1[54][31] + coeff0_55*dmats1[55][31];
          new_coeff0_32 = coeff0_0*dmats1[0][32] + coeff0_1*dmats1[1][32] + coeff0_2*dmats1[2][32] + coeff0_3*dmats1[3][32] + coeff0_4*dmats1[4][32] + coeff0_5*dmats1[5][32] + coeff0_6*dmats1[6][32] + coeff0_7*dmats1[7][32] + coeff0_8*dmats1[8][32] + coeff0_9*dmats1[9][32] + coeff0_10*dmats1[10][32] + coeff0_11*dmats1[11][32] + coeff0_12*dmats1[12][32] + coeff0_13*dmats1[13][32] + coeff0_14*dmats1[14][32] + coeff0_15*dmats1[15][32] + coeff0_16*dmats1[16][32] + coeff0_17*dmats1[17][32] + coeff0_18*dmats1[18][32] + coeff0_19*dmats1[19][32] + coeff0_20*dmats1[20][32] + coeff0_21*dmats1[21][32] + coeff0_22*dmats1[22][32] + coeff0_23*dmats1[23][32] + coeff0_24*dmats1[24][32] + coeff0_25*dmats1[25][32] + coeff0_26*dmats1[26][32] + coeff0_27*dmats1[27][32] + coeff0_28*dmats1[28][32] + coeff0_29*dmats1[29][32] + coeff0_30*dmats1[30][32] + coeff0_31*dmats1[31][32] + coeff0_32*dmats1[32][32] + coeff0_33*dmats1[33][32] + coeff0_34*dmats1[34][32] + coeff0_35*dmats1[35][32] + coeff0_36*dmats1[36][32] + coeff0_37*dmats1[37][32] + coeff0_38*dmats1[38][32] + coeff0_39*dmats1[39][32] + coeff0_40*dmats1[40][32] + coeff0_41*dmats1[41][32] + coeff0_42*dmats1[42][32] + coeff0_43*dmats1[43][32] + coeff0_44*dmats1[44][32] + coeff0_45*dmats1[45][32] + coeff0_46*dmats1[46][32] + coeff0_47*dmats1[47][32] + coeff0_48*dmats1[48][32] + coeff0_49*dmats1[49][32] + coeff0_50*dmats1[50][32] + coeff0_51*dmats1[51][32] + coeff0_52*dmats1[52][32] + coeff0_53*dmats1[53][32] + coeff0_54*dmats1[54][32] + coeff0_55*dmats1[55][32];
          new_coeff0_33 = coeff0_0*dmats1[0][33] + coeff0_1*dmats1[1][33] + coeff0_2*dmats1[2][33] + coeff0_3*dmats1[3][33] + coeff0_4*dmats1[4][33] + coeff0_5*dmats1[5][33] + coeff0_6*dmats1[6][33] + coeff0_7*dmats1[7][33] + coeff0_8*dmats1[8][33] + coeff0_9*dmats1[9][33] + coeff0_10*dmats1[10][33] + coeff0_11*dmats1[11][33] + coeff0_12*dmats1[12][33] + coeff0_13*dmats1[13][33] + coeff0_14*dmats1[14][33] + coeff0_15*dmats1[15][33] + coeff0_16*dmats1[16][33] + coeff0_17*dmats1[17][33] + coeff0_18*dmats1[18][33] + coeff0_19*dmats1[19][33] + coeff0_20*dmats1[20][33] + coeff0_21*dmats1[21][33] + coeff0_22*dmats1[22][33] + coeff0_23*dmats1[23][33] + coeff0_24*dmats1[24][33] + coeff0_25*dmats1[25][33] + coeff0_26*dmats1[26][33] + coeff0_27*dmats1[27][33] + coeff0_28*dmats1[28][33] + coeff0_29*dmats1[29][33] + coeff0_30*dmats1[30][33] + coeff0_31*dmats1[31][33] + coeff0_32*dmats1[32][33] + coeff0_33*dmats1[33][33] + coeff0_34*dmats1[34][33] + coeff0_35*dmats1[35][33] + coeff0_36*dmats1[36][33] + coeff0_37*dmats1[37][33] + coeff0_38*dmats1[38][33] + coeff0_39*dmats1[39][33] + coeff0_40*dmats1[40][33] + coeff0_41*dmats1[41][33] + coeff0_42*dmats1[42][33] + coeff0_43*dmats1[43][33] + coeff0_44*dmats1[44][33] + coeff0_45*dmats1[45][33] + coeff0_46*dmats1[46][33] + coeff0_47*dmats1[47][33] + coeff0_48*dmats1[48][33] + coeff0_49*dmats1[49][33] + coeff0_50*dmats1[50][33] + coeff0_51*dmats1[51][33] + coeff0_52*dmats1[52][33] + coeff0_53*dmats1[53][33] + coeff0_54*dmats1[54][33] + coeff0_55*dmats1[55][33];
          new_coeff0_34 = coeff0_0*dmats1[0][34] + coeff0_1*dmats1[1][34] + coeff0_2*dmats1[2][34] + coeff0_3*dmats1[3][34] + coeff0_4*dmats1[4][34] + coeff0_5*dmats1[5][34] + coeff0_6*dmats1[6][34] + coeff0_7*dmats1[7][34] + coeff0_8*dmats1[8][34] + coeff0_9*dmats1[9][34] + coeff0_10*dmats1[10][34] + coeff0_11*dmats1[11][34] + coeff0_12*dmats1[12][34] + coeff0_13*dmats1[13][34] + coeff0_14*dmats1[14][34] + coeff0_15*dmats1[15][34] + coeff0_16*dmats1[16][34] + coeff0_17*dmats1[17][34] + coeff0_18*dmats1[18][34] + coeff0_19*dmats1[19][34] + coeff0_20*dmats1[20][34] + coeff0_21*dmats1[21][34] + coeff0_22*dmats1[22][34] + coeff0_23*dmats1[23][34] + coeff0_24*dmats1[24][34] + coeff0_25*dmats1[25][34] + coeff0_26*dmats1[26][34] + coeff0_27*dmats1[27][34] + coeff0_28*dmats1[28][34] + coeff0_29*dmats1[29][34] + coeff0_30*dmats1[30][34] + coeff0_31*dmats1[31][34] + coeff0_32*dmats1[32][34] + coeff0_33*dmats1[33][34] + coeff0_34*dmats1[34][34] + coeff0_35*dmats1[35][34] + coeff0_36*dmats1[36][34] + coeff0_37*dmats1[37][34] + coeff0_38*dmats1[38][34] + coeff0_39*dmats1[39][34] + coeff0_40*dmats1[40][34] + coeff0_41*dmats1[41][34] + coeff0_42*dmats1[42][34] + coeff0_43*dmats1[43][34] + coeff0_44*dmats1[44][34] + coeff0_45*dmats1[45][34] + coeff0_46*dmats1[46][34] + coeff0_47*dmats1[47][34] + coeff0_48*dmats1[48][34] + coeff0_49*dmats1[49][34] + coeff0_50*dmats1[50][34] + coeff0_51*dmats1[51][34] + coeff0_52*dmats1[52][34] + coeff0_53*dmats1[53][34] + coeff0_54*dmats1[54][34] + coeff0_55*dmats1[55][34];
          new_coeff0_35 = coeff0_0*dmats1[0][35] + coeff0_1*dmats1[1][35] + coeff0_2*dmats1[2][35] + coeff0_3*dmats1[3][35] + coeff0_4*dmats1[4][35] + coeff0_5*dmats1[5][35] + coeff0_6*dmats1[6][35] + coeff0_7*dmats1[7][35] + coeff0_8*dmats1[8][35] + coeff0_9*dmats1[9][35] + coeff0_10*dmats1[10][35] + coeff0_11*dmats1[11][35] + coeff0_12*dmats1[12][35] + coeff0_13*dmats1[13][35] + coeff0_14*dmats1[14][35] + coeff0_15*dmats1[15][35] + coeff0_16*dmats1[16][35] + coeff0_17*dmats1[17][35] + coeff0_18*dmats1[18][35] + coeff0_19*dmats1[19][35] + coeff0_20*dmats1[20][35] + coeff0_21*dmats1[21][35] + coeff0_22*dmats1[22][35] + coeff0_23*dmats1[23][35] + coeff0_24*dmats1[24][35] + coeff0_25*dmats1[25][35] + coeff0_26*dmats1[26][35] + coeff0_27*dmats1[27][35] + coeff0_28*dmats1[28][35] + coeff0_29*dmats1[29][35] + coeff0_30*dmats1[30][35] + coeff0_31*dmats1[31][35] + coeff0_32*dmats1[32][35] + coeff0_33*dmats1[33][35] + coeff0_34*dmats1[34][35] + coeff0_35*dmats1[35][35] + coeff0_36*dmats1[36][35] + coeff0_37*dmats1[37][35] + coeff0_38*dmats1[38][35] + coeff0_39*dmats1[39][35] + coeff0_40*dmats1[40][35] + coeff0_41*dmats1[41][35] + coeff0_42*dmats1[42][35] + coeff0_43*dmats1[43][35] + coeff0_44*dmats1[44][35] + coeff0_45*dmats1[45][35] + coeff0_46*dmats1[46][35] + coeff0_47*dmats1[47][35] + coeff0_48*dmats1[48][35] + coeff0_49*dmats1[49][35] + coeff0_50*dmats1[50][35] + coeff0_51*dmats1[51][35] + coeff0_52*dmats1[52][35] + coeff0_53*dmats1[53][35] + coeff0_54*dmats1[54][35] + coeff0_55*dmats1[55][35];
          new_coeff0_36 = coeff0_0*dmats1[0][36] + coeff0_1*dmats1[1][36] + coeff0_2*dmats1[2][36] + coeff0_3*dmats1[3][36] + coeff0_4*dmats1[4][36] + coeff0_5*dmats1[5][36] + coeff0_6*dmats1[6][36] + coeff0_7*dmats1[7][36] + coeff0_8*dmats1[8][36] + coeff0_9*dmats1[9][36] + coeff0_10*dmats1[10][36] + coeff0_11*dmats1[11][36] + coeff0_12*dmats1[12][36] + coeff0_13*dmats1[13][36] + coeff0_14*dmats1[14][36] + coeff0_15*dmats1[15][36] + coeff0_16*dmats1[16][36] + coeff0_17*dmats1[17][36] + coeff0_18*dmats1[18][36] + coeff0_19*dmats1[19][36] + coeff0_20*dmats1[20][36] + coeff0_21*dmats1[21][36] + coeff0_22*dmats1[22][36] + coeff0_23*dmats1[23][36] + coeff0_24*dmats1[24][36] + coeff0_25*dmats1[25][36] + coeff0_26*dmats1[26][36] + coeff0_27*dmats1[27][36] + coeff0_28*dmats1[28][36] + coeff0_29*dmats1[29][36] + coeff0_30*dmats1[30][36] + coeff0_31*dmats1[31][36] + coeff0_32*dmats1[32][36] + coeff0_33*dmats1[33][36] + coeff0_34*dmats1[34][36] + coeff0_35*dmats1[35][36] + coeff0_36*dmats1[36][36] + coeff0_37*dmats1[37][36] + coeff0_38*dmats1[38][36] + coeff0_39*dmats1[39][36] + coeff0_40*dmats1[40][36] + coeff0_41*dmats1[41][36] + coeff0_42*dmats1[42][36] + coeff0_43*dmats1[43][36] + coeff0_44*dmats1[44][36] + coeff0_45*dmats1[45][36] + coeff0_46*dmats1[46][36] + coeff0_47*dmats1[47][36] + coeff0_48*dmats1[48][36] + coeff0_49*dmats1[49][36] + coeff0_50*dmats1[50][36] + coeff0_51*dmats1[51][36] + coeff0_52*dmats1[52][36] + coeff0_53*dmats1[53][36] + coeff0_54*dmats1[54][36] + coeff0_55*dmats1[55][36];
          new_coeff0_37 = coeff0_0*dmats1[0][37] + coeff0_1*dmats1[1][37] + coeff0_2*dmats1[2][37] + coeff0_3*dmats1[3][37] + coeff0_4*dmats1[4][37] + coeff0_5*dmats1[5][37] + coeff0_6*dmats1[6][37] + coeff0_7*dmats1[7][37] + coeff0_8*dmats1[8][37] + coeff0_9*dmats1[9][37] + coeff0_10*dmats1[10][37] + coeff0_11*dmats1[11][37] + coeff0_12*dmats1[12][37] + coeff0_13*dmats1[13][37] + coeff0_14*dmats1[14][37] + coeff0_15*dmats1[15][37] + coeff0_16*dmats1[16][37] + coeff0_17*dmats1[17][37] + coeff0_18*dmats1[18][37] + coeff0_19*dmats1[19][37] + coeff0_20*dmats1[20][37] + coeff0_21*dmats1[21][37] + coeff0_22*dmats1[22][37] + coeff0_23*dmats1[23][37] + coeff0_24*dmats1[24][37] + coeff0_25*dmats1[25][37] + coeff0_26*dmats1[26][37] + coeff0_27*dmats1[27][37] + coeff0_28*dmats1[28][37] + coeff0_29*dmats1[29][37] + coeff0_30*dmats1[30][37] + coeff0_31*dmats1[31][37] + coeff0_32*dmats1[32][37] + coeff0_33*dmats1[33][37] + coeff0_34*dmats1[34][37] + coeff0_35*dmats1[35][37] + coeff0_36*dmats1[36][37] + coeff0_37*dmats1[37][37] + coeff0_38*dmats1[38][37] + coeff0_39*dmats1[39][37] + coeff0_40*dmats1[40][37] + coeff0_41*dmats1[41][37] + coeff0_42*dmats1[42][37] + coeff0_43*dmats1[43][37] + coeff0_44*dmats1[44][37] + coeff0_45*dmats1[45][37] + coeff0_46*dmats1[46][37] + coeff0_47*dmats1[47][37] + coeff0_48*dmats1[48][37] + coeff0_49*dmats1[49][37] + coeff0_50*dmats1[50][37] + coeff0_51*dmats1[51][37] + coeff0_52*dmats1[52][37] + coeff0_53*dmats1[53][37] + coeff0_54*dmats1[54][37] + coeff0_55*dmats1[55][37];
          new_coeff0_38 = coeff0_0*dmats1[0][38] + coeff0_1*dmats1[1][38] + coeff0_2*dmats1[2][38] + coeff0_3*dmats1[3][38] + coeff0_4*dmats1[4][38] + coeff0_5*dmats1[5][38] + coeff0_6*dmats1[6][38] + coeff0_7*dmats1[7][38] + coeff0_8*dmats1[8][38] + coeff0_9*dmats1[9][38] + coeff0_10*dmats1[10][38] + coeff0_11*dmats1[11][38] + coeff0_12*dmats1[12][38] + coeff0_13*dmats1[13][38] + coeff0_14*dmats1[14][38] + coeff0_15*dmats1[15][38] + coeff0_16*dmats1[16][38] + coeff0_17*dmats1[17][38] + coeff0_18*dmats1[18][38] + coeff0_19*dmats1[19][38] + coeff0_20*dmats1[20][38] + coeff0_21*dmats1[21][38] + coeff0_22*dmats1[22][38] + coeff0_23*dmats1[23][38] + coeff0_24*dmats1[24][38] + coeff0_25*dmats1[25][38] + coeff0_26*dmats1[26][38] + coeff0_27*dmats1[27][38] + coeff0_28*dmats1[28][38] + coeff0_29*dmats1[29][38] + coeff0_30*dmats1[30][38] + coeff0_31*dmats1[31][38] + coeff0_32*dmats1[32][38] + coeff0_33*dmats1[33][38] + coeff0_34*dmats1[34][38] + coeff0_35*dmats1[35][38] + coeff0_36*dmats1[36][38] + coeff0_37*dmats1[37][38] + coeff0_38*dmats1[38][38] + coeff0_39*dmats1[39][38] + coeff0_40*dmats1[40][38] + coeff0_41*dmats1[41][38] + coeff0_42*dmats1[42][38] + coeff0_43*dmats1[43][38] + coeff0_44*dmats1[44][38] + coeff0_45*dmats1[45][38] + coeff0_46*dmats1[46][38] + coeff0_47*dmats1[47][38] + coeff0_48*dmats1[48][38] + coeff0_49*dmats1[49][38] + coeff0_50*dmats1[50][38] + coeff0_51*dmats1[51][38] + coeff0_52*dmats1[52][38] + coeff0_53*dmats1[53][38] + coeff0_54*dmats1[54][38] + coeff0_55*dmats1[55][38];
          new_coeff0_39 = coeff0_0*dmats1[0][39] + coeff0_1*dmats1[1][39] + coeff0_2*dmats1[2][39] + coeff0_3*dmats1[3][39] + coeff0_4*dmats1[4][39] + coeff0_5*dmats1[5][39] + coeff0_6*dmats1[6][39] + coeff0_7*dmats1[7][39] + coeff0_8*dmats1[8][39] + coeff0_9*dmats1[9][39] + coeff0_10*dmats1[10][39] + coeff0_11*dmats1[11][39] + coeff0_12*dmats1[12][39] + coeff0_13*dmats1[13][39] + coeff0_14*dmats1[14][39] + coeff0_15*dmats1[15][39] + coeff0_16*dmats1[16][39] + coeff0_17*dmats1[17][39] + coeff0_18*dmats1[18][39] + coeff0_19*dmats1[19][39] + coeff0_20*dmats1[20][39] + coeff0_21*dmats1[21][39] + coeff0_22*dmats1[22][39] + coeff0_23*dmats1[23][39] + coeff0_24*dmats1[24][39] + coeff0_25*dmats1[25][39] + coeff0_26*dmats1[26][39] + coeff0_27*dmats1[27][39] + coeff0_28*dmats1[28][39] + coeff0_29*dmats1[29][39] + coeff0_30*dmats1[30][39] + coeff0_31*dmats1[31][39] + coeff0_32*dmats1[32][39] + coeff0_33*dmats1[33][39] + coeff0_34*dmats1[34][39] + coeff0_35*dmats1[35][39] + coeff0_36*dmats1[36][39] + coeff0_37*dmats1[37][39] + coeff0_38*dmats1[38][39] + coeff0_39*dmats1[39][39] + coeff0_40*dmats1[40][39] + coeff0_41*dmats1[41][39] + coeff0_42*dmats1[42][39] + coeff0_43*dmats1[43][39] + coeff0_44*dmats1[44][39] + coeff0_45*dmats1[45][39] + coeff0_46*dmats1[46][39] + coeff0_47*dmats1[47][39] + coeff0_48*dmats1[48][39] + coeff0_49*dmats1[49][39] + coeff0_50*dmats1[50][39] + coeff0_51*dmats1[51][39] + coeff0_52*dmats1[52][39] + coeff0_53*dmats1[53][39] + coeff0_54*dmats1[54][39] + coeff0_55*dmats1[55][39];
          new_coeff0_40 = coeff0_0*dmats1[0][40] + coeff0_1*dmats1[1][40] + coeff0_2*dmats1[2][40] + coeff0_3*dmats1[3][40] + coeff0_4*dmats1[4][40] + coeff0_5*dmats1[5][40] + coeff0_6*dmats1[6][40] + coeff0_7*dmats1[7][40] + coeff0_8*dmats1[8][40] + coeff0_9*dmats1[9][40] + coeff0_10*dmats1[10][40] + coeff0_11*dmats1[11][40] + coeff0_12*dmats1[12][40] + coeff0_13*dmats1[13][40] + coeff0_14*dmats1[14][40] + coeff0_15*dmats1[15][40] + coeff0_16*dmats1[16][40] + coeff0_17*dmats1[17][40] + coeff0_18*dmats1[18][40] + coeff0_19*dmats1[19][40] + coeff0_20*dmats1[20][40] + coeff0_21*dmats1[21][40] + coeff0_22*dmats1[22][40] + coeff0_23*dmats1[23][40] + coeff0_24*dmats1[24][40] + coeff0_25*dmats1[25][40] + coeff0_26*dmats1[26][40] + coeff0_27*dmats1[27][40] + coeff0_28*dmats1[28][40] + coeff0_29*dmats1[29][40] + coeff0_30*dmats1[30][40] + coeff0_31*dmats1[31][40] + coeff0_32*dmats1[32][40] + coeff0_33*dmats1[33][40] + coeff0_34*dmats1[34][40] + coeff0_35*dmats1[35][40] + coeff0_36*dmats1[36][40] + coeff0_37*dmats1[37][40] + coeff0_38*dmats1[38][40] + coeff0_39*dmats1[39][40] + coeff0_40*dmats1[40][40] + coeff0_41*dmats1[41][40] + coeff0_42*dmats1[42][40] + coeff0_43*dmats1[43][40] + coeff0_44*dmats1[44][40] + coeff0_45*dmats1[45][40] + coeff0_46*dmats1[46][40] + coeff0_47*dmats1[47][40] + coeff0_48*dmats1[48][40] + coeff0_49*dmats1[49][40] + coeff0_50*dmats1[50][40] + coeff0_51*dmats1[51][40] + coeff0_52*dmats1[52][40] + coeff0_53*dmats1[53][40] + coeff0_54*dmats1[54][40] + coeff0_55*dmats1[55][40];
          new_coeff0_41 = coeff0_0*dmats1[0][41] + coeff0_1*dmats1[1][41] + coeff0_2*dmats1[2][41] + coeff0_3*dmats1[3][41] + coeff0_4*dmats1[4][41] + coeff0_5*dmats1[5][41] + coeff0_6*dmats1[6][41] + coeff0_7*dmats1[7][41] + coeff0_8*dmats1[8][41] + coeff0_9*dmats1[9][41] + coeff0_10*dmats1[10][41] + coeff0_11*dmats1[11][41] + coeff0_12*dmats1[12][41] + coeff0_13*dmats1[13][41] + coeff0_14*dmats1[14][41] + coeff0_15*dmats1[15][41] + coeff0_16*dmats1[16][41] + coeff0_17*dmats1[17][41] + coeff0_18*dmats1[18][41] + coeff0_19*dmats1[19][41] + coeff0_20*dmats1[20][41] + coeff0_21*dmats1[21][41] + coeff0_22*dmats1[22][41] + coeff0_23*dmats1[23][41] + coeff0_24*dmats1[24][41] + coeff0_25*dmats1[25][41] + coeff0_26*dmats1[26][41] + coeff0_27*dmats1[27][41] + coeff0_28*dmats1[28][41] + coeff0_29*dmats1[29][41] + coeff0_30*dmats1[30][41] + coeff0_31*dmats1[31][41] + coeff0_32*dmats1[32][41] + coeff0_33*dmats1[33][41] + coeff0_34*dmats1[34][41] + coeff0_35*dmats1[35][41] + coeff0_36*dmats1[36][41] + coeff0_37*dmats1[37][41] + coeff0_38*dmats1[38][41] + coeff0_39*dmats1[39][41] + coeff0_40*dmats1[40][41] + coeff0_41*dmats1[41][41] + coeff0_42*dmats1[42][41] + coeff0_43*dmats1[43][41] + coeff0_44*dmats1[44][41] + coeff0_45*dmats1[45][41] + coeff0_46*dmats1[46][41] + coeff0_47*dmats1[47][41] + coeff0_48*dmats1[48][41] + coeff0_49*dmats1[49][41] + coeff0_50*dmats1[50][41] + coeff0_51*dmats1[51][41] + coeff0_52*dmats1[52][41] + coeff0_53*dmats1[53][41] + coeff0_54*dmats1[54][41] + coeff0_55*dmats1[55][41];
          new_coeff0_42 = coeff0_0*dmats1[0][42] + coeff0_1*dmats1[1][42] + coeff0_2*dmats1[2][42] + coeff0_3*dmats1[3][42] + coeff0_4*dmats1[4][42] + coeff0_5*dmats1[5][42] + coeff0_6*dmats1[6][42] + coeff0_7*dmats1[7][42] + coeff0_8*dmats1[8][42] + coeff0_9*dmats1[9][42] + coeff0_10*dmats1[10][42] + coeff0_11*dmats1[11][42] + coeff0_12*dmats1[12][42] + coeff0_13*dmats1[13][42] + coeff0_14*dmats1[14][42] + coeff0_15*dmats1[15][42] + coeff0_16*dmats1[16][42] + coeff0_17*dmats1[17][42] + coeff0_18*dmats1[18][42] + coeff0_19*dmats1[19][42] + coeff0_20*dmats1[20][42] + coeff0_21*dmats1[21][42] + coeff0_22*dmats1[22][42] + coeff0_23*dmats1[23][42] + coeff0_24*dmats1[24][42] + coeff0_25*dmats1[25][42] + coeff0_26*dmats1[26][42] + coeff0_27*dmats1[27][42] + coeff0_28*dmats1[28][42] + coeff0_29*dmats1[29][42] + coeff0_30*dmats1[30][42] + coeff0_31*dmats1[31][42] + coeff0_32*dmats1[32][42] + coeff0_33*dmats1[33][42] + coeff0_34*dmats1[34][42] + coeff0_35*dmats1[35][42] + coeff0_36*dmats1[36][42] + coeff0_37*dmats1[37][42] + coeff0_38*dmats1[38][42] + coeff0_39*dmats1[39][42] + coeff0_40*dmats1[40][42] + coeff0_41*dmats1[41][42] + coeff0_42*dmats1[42][42] + coeff0_43*dmats1[43][42] + coeff0_44*dmats1[44][42] + coeff0_45*dmats1[45][42] + coeff0_46*dmats1[46][42] + coeff0_47*dmats1[47][42] + coeff0_48*dmats1[48][42] + coeff0_49*dmats1[49][42] + coeff0_50*dmats1[50][42] + coeff0_51*dmats1[51][42] + coeff0_52*dmats1[52][42] + coeff0_53*dmats1[53][42] + coeff0_54*dmats1[54][42] + coeff0_55*dmats1[55][42];
          new_coeff0_43 = coeff0_0*dmats1[0][43] + coeff0_1*dmats1[1][43] + coeff0_2*dmats1[2][43] + coeff0_3*dmats1[3][43] + coeff0_4*dmats1[4][43] + coeff0_5*dmats1[5][43] + coeff0_6*dmats1[6][43] + coeff0_7*dmats1[7][43] + coeff0_8*dmats1[8][43] + coeff0_9*dmats1[9][43] + coeff0_10*dmats1[10][43] + coeff0_11*dmats1[11][43] + coeff0_12*dmats1[12][43] + coeff0_13*dmats1[13][43] + coeff0_14*dmats1[14][43] + coeff0_15*dmats1[15][43] + coeff0_16*dmats1[16][43] + coeff0_17*dmats1[17][43] + coeff0_18*dmats1[18][43] + coeff0_19*dmats1[19][43] + coeff0_20*dmats1[20][43] + coeff0_21*dmats1[21][43] + coeff0_22*dmats1[22][43] + coeff0_23*dmats1[23][43] + coeff0_24*dmats1[24][43] + coeff0_25*dmats1[25][43] + coeff0_26*dmats1[26][43] + coeff0_27*dmats1[27][43] + coeff0_28*dmats1[28][43] + coeff0_29*dmats1[29][43] + coeff0_30*dmats1[30][43] + coeff0_31*dmats1[31][43] + coeff0_32*dmats1[32][43] + coeff0_33*dmats1[33][43] + coeff0_34*dmats1[34][43] + coeff0_35*dmats1[35][43] + coeff0_36*dmats1[36][43] + coeff0_37*dmats1[37][43] + coeff0_38*dmats1[38][43] + coeff0_39*dmats1[39][43] + coeff0_40*dmats1[40][43] + coeff0_41*dmats1[41][43] + coeff0_42*dmats1[42][43] + coeff0_43*dmats1[43][43] + coeff0_44*dmats1[44][43] + coeff0_45*dmats1[45][43] + coeff0_46*dmats1[46][43] + coeff0_47*dmats1[47][43] + coeff0_48*dmats1[48][43] + coeff0_49*dmats1[49][43] + coeff0_50*dmats1[50][43] + coeff0_51*dmats1[51][43] + coeff0_52*dmats1[52][43] + coeff0_53*dmats1[53][43] + coeff0_54*dmats1[54][43] + coeff0_55*dmats1[55][43];
          new_coeff0_44 = coeff0_0*dmats1[0][44] + coeff0_1*dmats1[1][44] + coeff0_2*dmats1[2][44] + coeff0_3*dmats1[3][44] + coeff0_4*dmats1[4][44] + coeff0_5*dmats1[5][44] + coeff0_6*dmats1[6][44] + coeff0_7*dmats1[7][44] + coeff0_8*dmats1[8][44] + coeff0_9*dmats1[9][44] + coeff0_10*dmats1[10][44] + coeff0_11*dmats1[11][44] + coeff0_12*dmats1[12][44] + coeff0_13*dmats1[13][44] + coeff0_14*dmats1[14][44] + coeff0_15*dmats1[15][44] + coeff0_16*dmats1[16][44] + coeff0_17*dmats1[17][44] + coeff0_18*dmats1[18][44] + coeff0_19*dmats1[19][44] + coeff0_20*dmats1[20][44] + coeff0_21*dmats1[21][44] + coeff0_22*dmats1[22][44] + coeff0_23*dmats1[23][44] + coeff0_24*dmats1[24][44] + coeff0_25*dmats1[25][44] + coeff0_26*dmats1[26][44] + coeff0_27*dmats1[27][44] + coeff0_28*dmats1[28][44] + coeff0_29*dmats1[29][44] + coeff0_30*dmats1[30][44] + coeff0_31*dmats1[31][44] + coeff0_32*dmats1[32][44] + coeff0_33*dmats1[33][44] + coeff0_34*dmats1[34][44] + coeff0_35*dmats1[35][44] + coeff0_36*dmats1[36][44] + coeff0_37*dmats1[37][44] + coeff0_38*dmats1[38][44] + coeff0_39*dmats1[39][44] + coeff0_40*dmats1[40][44] + coeff0_41*dmats1[41][44] + coeff0_42*dmats1[42][44] + coeff0_43*dmats1[43][44] + coeff0_44*dmats1[44][44] + coeff0_45*dmats1[45][44] + coeff0_46*dmats1[46][44] + coeff0_47*dmats1[47][44] + coeff0_48*dmats1[48][44] + coeff0_49*dmats1[49][44] + coeff0_50*dmats1[50][44] + coeff0_51*dmats1[51][44] + coeff0_52*dmats1[52][44] + coeff0_53*dmats1[53][44] + coeff0_54*dmats1[54][44] + coeff0_55*dmats1[55][44];
          new_coeff0_45 = coeff0_0*dmats1[0][45] + coeff0_1*dmats1[1][45] + coeff0_2*dmats1[2][45] + coeff0_3*dmats1[3][45] + coeff0_4*dmats1[4][45] + coeff0_5*dmats1[5][45] + coeff0_6*dmats1[6][45] + coeff0_7*dmats1[7][45] + coeff0_8*dmats1[8][45] + coeff0_9*dmats1[9][45] + coeff0_10*dmats1[10][45] + coeff0_11*dmats1[11][45] + coeff0_12*dmats1[12][45] + coeff0_13*dmats1[13][45] + coeff0_14*dmats1[14][45] + coeff0_15*dmats1[15][45] + coeff0_16*dmats1[16][45] + coeff0_17*dmats1[17][45] + coeff0_18*dmats1[18][45] + coeff0_19*dmats1[19][45] + coeff0_20*dmats1[20][45] + coeff0_21*dmats1[21][45] + coeff0_22*dmats1[22][45] + coeff0_23*dmats1[23][45] + coeff0_24*dmats1[24][45] + coeff0_25*dmats1[25][45] + coeff0_26*dmats1[26][45] + coeff0_27*dmats1[27][45] + coeff0_28*dmats1[28][45] + coeff0_29*dmats1[29][45] + coeff0_30*dmats1[30][45] + coeff0_31*dmats1[31][45] + coeff0_32*dmats1[32][45] + coeff0_33*dmats1[33][45] + coeff0_34*dmats1[34][45] + coeff0_35*dmats1[35][45] + coeff0_36*dmats1[36][45] + coeff0_37*dmats1[37][45] + coeff0_38*dmats1[38][45] + coeff0_39*dmats1[39][45] + coeff0_40*dmats1[40][45] + coeff0_41*dmats1[41][45] + coeff0_42*dmats1[42][45] + coeff0_43*dmats1[43][45] + coeff0_44*dmats1[44][45] + coeff0_45*dmats1[45][45] + coeff0_46*dmats1[46][45] + coeff0_47*dmats1[47][45] + coeff0_48*dmats1[48][45] + coeff0_49*dmats1[49][45] + coeff0_50*dmats1[50][45] + coeff0_51*dmats1[51][45] + coeff0_52*dmats1[52][45] + coeff0_53*dmats1[53][45] + coeff0_54*dmats1[54][45] + coeff0_55*dmats1[55][45];
          new_coeff0_46 = coeff0_0*dmats1[0][46] + coeff0_1*dmats1[1][46] + coeff0_2*dmats1[2][46] + coeff0_3*dmats1[3][46] + coeff0_4*dmats1[4][46] + coeff0_5*dmats1[5][46] + coeff0_6*dmats1[6][46] + coeff0_7*dmats1[7][46] + coeff0_8*dmats1[8][46] + coeff0_9*dmats1[9][46] + coeff0_10*dmats1[10][46] + coeff0_11*dmats1[11][46] + coeff0_12*dmats1[12][46] + coeff0_13*dmats1[13][46] + coeff0_14*dmats1[14][46] + coeff0_15*dmats1[15][46] + coeff0_16*dmats1[16][46] + coeff0_17*dmats1[17][46] + coeff0_18*dmats1[18][46] + coeff0_19*dmats1[19][46] + coeff0_20*dmats1[20][46] + coeff0_21*dmats1[21][46] + coeff0_22*dmats1[22][46] + coeff0_23*dmats1[23][46] + coeff0_24*dmats1[24][46] + coeff0_25*dmats1[25][46] + coeff0_26*dmats1[26][46] + coeff0_27*dmats1[27][46] + coeff0_28*dmats1[28][46] + coeff0_29*dmats1[29][46] + coeff0_30*dmats1[30][46] + coeff0_31*dmats1[31][46] + coeff0_32*dmats1[32][46] + coeff0_33*dmats1[33][46] + coeff0_34*dmats1[34][46] + coeff0_35*dmats1[35][46] + coeff0_36*dmats1[36][46] + coeff0_37*dmats1[37][46] + coeff0_38*dmats1[38][46] + coeff0_39*dmats1[39][46] + coeff0_40*dmats1[40][46] + coeff0_41*dmats1[41][46] + coeff0_42*dmats1[42][46] + coeff0_43*dmats1[43][46] + coeff0_44*dmats1[44][46] + coeff0_45*dmats1[45][46] + coeff0_46*dmats1[46][46] + coeff0_47*dmats1[47][46] + coeff0_48*dmats1[48][46] + coeff0_49*dmats1[49][46] + coeff0_50*dmats1[50][46] + coeff0_51*dmats1[51][46] + coeff0_52*dmats1[52][46] + coeff0_53*dmats1[53][46] + coeff0_54*dmats1[54][46] + coeff0_55*dmats1[55][46];
          new_coeff0_47 = coeff0_0*dmats1[0][47] + coeff0_1*dmats1[1][47] + coeff0_2*dmats1[2][47] + coeff0_3*dmats1[3][47] + coeff0_4*dmats1[4][47] + coeff0_5*dmats1[5][47] + coeff0_6*dmats1[6][47] + coeff0_7*dmats1[7][47] + coeff0_8*dmats1[8][47] + coeff0_9*dmats1[9][47] + coeff0_10*dmats1[10][47] + coeff0_11*dmats1[11][47] + coeff0_12*dmats1[12][47] + coeff0_13*dmats1[13][47] + coeff0_14*dmats1[14][47] + coeff0_15*dmats1[15][47] + coeff0_16*dmats1[16][47] + coeff0_17*dmats1[17][47] + coeff0_18*dmats1[18][47] + coeff0_19*dmats1[19][47] + coeff0_20*dmats1[20][47] + coeff0_21*dmats1[21][47] + coeff0_22*dmats1[22][47] + coeff0_23*dmats1[23][47] + coeff0_24*dmats1[24][47] + coeff0_25*dmats1[25][47] + coeff0_26*dmats1[26][47] + coeff0_27*dmats1[27][47] + coeff0_28*dmats1[28][47] + coeff0_29*dmats1[29][47] + coeff0_30*dmats1[30][47] + coeff0_31*dmats1[31][47] + coeff0_32*dmats1[32][47] + coeff0_33*dmats1[33][47] + coeff0_34*dmats1[34][47] + coeff0_35*dmats1[35][47] + coeff0_36*dmats1[36][47] + coeff0_37*dmats1[37][47] + coeff0_38*dmats1[38][47] + coeff0_39*dmats1[39][47] + coeff0_40*dmats1[40][47] + coeff0_41*dmats1[41][47] + coeff0_42*dmats1[42][47] + coeff0_43*dmats1[43][47] + coeff0_44*dmats1[44][47] + coeff0_45*dmats1[45][47] + coeff0_46*dmats1[46][47] + coeff0_47*dmats1[47][47] + coeff0_48*dmats1[48][47] + coeff0_49*dmats1[49][47] + coeff0_50*dmats1[50][47] + coeff0_51*dmats1[51][47] + coeff0_52*dmats1[52][47] + coeff0_53*dmats1[53][47] + coeff0_54*dmats1[54][47] + coeff0_55*dmats1[55][47];
          new_coeff0_48 = coeff0_0*dmats1[0][48] + coeff0_1*dmats1[1][48] + coeff0_2*dmats1[2][48] + coeff0_3*dmats1[3][48] + coeff0_4*dmats1[4][48] + coeff0_5*dmats1[5][48] + coeff0_6*dmats1[6][48] + coeff0_7*dmats1[7][48] + coeff0_8*dmats1[8][48] + coeff0_9*dmats1[9][48] + coeff0_10*dmats1[10][48] + coeff0_11*dmats1[11][48] + coeff0_12*dmats1[12][48] + coeff0_13*dmats1[13][48] + coeff0_14*dmats1[14][48] + coeff0_15*dmats1[15][48] + coeff0_16*dmats1[16][48] + coeff0_17*dmats1[17][48] + coeff0_18*dmats1[18][48] + coeff0_19*dmats1[19][48] + coeff0_20*dmats1[20][48] + coeff0_21*dmats1[21][48] + coeff0_22*dmats1[22][48] + coeff0_23*dmats1[23][48] + coeff0_24*dmats1[24][48] + coeff0_25*dmats1[25][48] + coeff0_26*dmats1[26][48] + coeff0_27*dmats1[27][48] + coeff0_28*dmats1[28][48] + coeff0_29*dmats1[29][48] + coeff0_30*dmats1[30][48] + coeff0_31*dmats1[31][48] + coeff0_32*dmats1[32][48] + coeff0_33*dmats1[33][48] + coeff0_34*dmats1[34][48] + coeff0_35*dmats1[35][48] + coeff0_36*dmats1[36][48] + coeff0_37*dmats1[37][48] + coeff0_38*dmats1[38][48] + coeff0_39*dmats1[39][48] + coeff0_40*dmats1[40][48] + coeff0_41*dmats1[41][48] + coeff0_42*dmats1[42][48] + coeff0_43*dmats1[43][48] + coeff0_44*dmats1[44][48] + coeff0_45*dmats1[45][48] + coeff0_46*dmats1[46][48] + coeff0_47*dmats1[47][48] + coeff0_48*dmats1[48][48] + coeff0_49*dmats1[49][48] + coeff0_50*dmats1[50][48] + coeff0_51*dmats1[51][48] + coeff0_52*dmats1[52][48] + coeff0_53*dmats1[53][48] + coeff0_54*dmats1[54][48] + coeff0_55*dmats1[55][48];
          new_coeff0_49 = coeff0_0*dmats1[0][49] + coeff0_1*dmats1[1][49] + coeff0_2*dmats1[2][49] + coeff0_3*dmats1[3][49] + coeff0_4*dmats1[4][49] + coeff0_5*dmats1[5][49] + coeff0_6*dmats1[6][49] + coeff0_7*dmats1[7][49] + coeff0_8*dmats1[8][49] + coeff0_9*dmats1[9][49] + coeff0_10*dmats1[10][49] + coeff0_11*dmats1[11][49] + coeff0_12*dmats1[12][49] + coeff0_13*dmats1[13][49] + coeff0_14*dmats1[14][49] + coeff0_15*dmats1[15][49] + coeff0_16*dmats1[16][49] + coeff0_17*dmats1[17][49] + coeff0_18*dmats1[18][49] + coeff0_19*dmats1[19][49] + coeff0_20*dmats1[20][49] + coeff0_21*dmats1[21][49] + coeff0_22*dmats1[22][49] + coeff0_23*dmats1[23][49] + coeff0_24*dmats1[24][49] + coeff0_25*dmats1[25][49] + coeff0_26*dmats1[26][49] + coeff0_27*dmats1[27][49] + coeff0_28*dmats1[28][49] + coeff0_29*dmats1[29][49] + coeff0_30*dmats1[30][49] + coeff0_31*dmats1[31][49] + coeff0_32*dmats1[32][49] + coeff0_33*dmats1[33][49] + coeff0_34*dmats1[34][49] + coeff0_35*dmats1[35][49] + coeff0_36*dmats1[36][49] + coeff0_37*dmats1[37][49] + coeff0_38*dmats1[38][49] + coeff0_39*dmats1[39][49] + coeff0_40*dmats1[40][49] + coeff0_41*dmats1[41][49] + coeff0_42*dmats1[42][49] + coeff0_43*dmats1[43][49] + coeff0_44*dmats1[44][49] + coeff0_45*dmats1[45][49] + coeff0_46*dmats1[46][49] + coeff0_47*dmats1[47][49] + coeff0_48*dmats1[48][49] + coeff0_49*dmats1[49][49] + coeff0_50*dmats1[50][49] + coeff0_51*dmats1[51][49] + coeff0_52*dmats1[52][49] + coeff0_53*dmats1[53][49] + coeff0_54*dmats1[54][49] + coeff0_55*dmats1[55][49];
          new_coeff0_50 = coeff0_0*dmats1[0][50] + coeff0_1*dmats1[1][50] + coeff0_2*dmats1[2][50] + coeff0_3*dmats1[3][50] + coeff0_4*dmats1[4][50] + coeff0_5*dmats1[5][50] + coeff0_6*dmats1[6][50] + coeff0_7*dmats1[7][50] + coeff0_8*dmats1[8][50] + coeff0_9*dmats1[9][50] + coeff0_10*dmats1[10][50] + coeff0_11*dmats1[11][50] + coeff0_12*dmats1[12][50] + coeff0_13*dmats1[13][50] + coeff0_14*dmats1[14][50] + coeff0_15*dmats1[15][50] + coeff0_16*dmats1[16][50] + coeff0_17*dmats1[17][50] + coeff0_18*dmats1[18][50] + coeff0_19*dmats1[19][50] + coeff0_20*dmats1[20][50] + coeff0_21*dmats1[21][50] + coeff0_22*dmats1[22][50] + coeff0_23*dmats1[23][50] + coeff0_24*dmats1[24][50] + coeff0_25*dmats1[25][50] + coeff0_26*dmats1[26][50] + coeff0_27*dmats1[27][50] + coeff0_28*dmats1[28][50] + coeff0_29*dmats1[29][50] + coeff0_30*dmats1[30][50] + coeff0_31*dmats1[31][50] + coeff0_32*dmats1[32][50] + coeff0_33*dmats1[33][50] + coeff0_34*dmats1[34][50] + coeff0_35*dmats1[35][50] + coeff0_36*dmats1[36][50] + coeff0_37*dmats1[37][50] + coeff0_38*dmats1[38][50] + coeff0_39*dmats1[39][50] + coeff0_40*dmats1[40][50] + coeff0_41*dmats1[41][50] + coeff0_42*dmats1[42][50] + coeff0_43*dmats1[43][50] + coeff0_44*dmats1[44][50] + coeff0_45*dmats1[45][50] + coeff0_46*dmats1[46][50] + coeff0_47*dmats1[47][50] + coeff0_48*dmats1[48][50] + coeff0_49*dmats1[49][50] + coeff0_50*dmats1[50][50] + coeff0_51*dmats1[51][50] + coeff0_52*dmats1[52][50] + coeff0_53*dmats1[53][50] + coeff0_54*dmats1[54][50] + coeff0_55*dmats1[55][50];
          new_coeff0_51 = coeff0_0*dmats1[0][51] + coeff0_1*dmats1[1][51] + coeff0_2*dmats1[2][51] + coeff0_3*dmats1[3][51] + coeff0_4*dmats1[4][51] + coeff0_5*dmats1[5][51] + coeff0_6*dmats1[6][51] + coeff0_7*dmats1[7][51] + coeff0_8*dmats1[8][51] + coeff0_9*dmats1[9][51] + coeff0_10*dmats1[10][51] + coeff0_11*dmats1[11][51] + coeff0_12*dmats1[12][51] + coeff0_13*dmats1[13][51] + coeff0_14*dmats1[14][51] + coeff0_15*dmats1[15][51] + coeff0_16*dmats1[16][51] + coeff0_17*dmats1[17][51] + coeff0_18*dmats1[18][51] + coeff0_19*dmats1[19][51] + coeff0_20*dmats1[20][51] + coeff0_21*dmats1[21][51] + coeff0_22*dmats1[22][51] + coeff0_23*dmats1[23][51] + coeff0_24*dmats1[24][51] + coeff0_25*dmats1[25][51] + coeff0_26*dmats1[26][51] + coeff0_27*dmats1[27][51] + coeff0_28*dmats1[28][51] + coeff0_29*dmats1[29][51] + coeff0_30*dmats1[30][51] + coeff0_31*dmats1[31][51] + coeff0_32*dmats1[32][51] + coeff0_33*dmats1[33][51] + coeff0_34*dmats1[34][51] + coeff0_35*dmats1[35][51] + coeff0_36*dmats1[36][51] + coeff0_37*dmats1[37][51] + coeff0_38*dmats1[38][51] + coeff0_39*dmats1[39][51] + coeff0_40*dmats1[40][51] + coeff0_41*dmats1[41][51] + coeff0_42*dmats1[42][51] + coeff0_43*dmats1[43][51] + coeff0_44*dmats1[44][51] + coeff0_45*dmats1[45][51] + coeff0_46*dmats1[46][51] + coeff0_47*dmats1[47][51] + coeff0_48*dmats1[48][51] + coeff0_49*dmats1[49][51] + coeff0_50*dmats1[50][51] + coeff0_51*dmats1[51][51] + coeff0_52*dmats1[52][51] + coeff0_53*dmats1[53][51] + coeff0_54*dmats1[54][51] + coeff0_55*dmats1[55][51];
          new_coeff0_52 = coeff0_0*dmats1[0][52] + coeff0_1*dmats1[1][52] + coeff0_2*dmats1[2][52] + coeff0_3*dmats1[3][52] + coeff0_4*dmats1[4][52] + coeff0_5*dmats1[5][52] + coeff0_6*dmats1[6][52] + coeff0_7*dmats1[7][52] + coeff0_8*dmats1[8][52] + coeff0_9*dmats1[9][52] + coeff0_10*dmats1[10][52] + coeff0_11*dmats1[11][52] + coeff0_12*dmats1[12][52] + coeff0_13*dmats1[13][52] + coeff0_14*dmats1[14][52] + coeff0_15*dmats1[15][52] + coeff0_16*dmats1[16][52] + coeff0_17*dmats1[17][52] + coeff0_18*dmats1[18][52] + coeff0_19*dmats1[19][52] + coeff0_20*dmats1[20][52] + coeff0_21*dmats1[21][52] + coeff0_22*dmats1[22][52] + coeff0_23*dmats1[23][52] + coeff0_24*dmats1[24][52] + coeff0_25*dmats1[25][52] + coeff0_26*dmats1[26][52] + coeff0_27*dmats1[27][52] + coeff0_28*dmats1[28][52] + coeff0_29*dmats1[29][52] + coeff0_30*dmats1[30][52] + coeff0_31*dmats1[31][52] + coeff0_32*dmats1[32][52] + coeff0_33*dmats1[33][52] + coeff0_34*dmats1[34][52] + coeff0_35*dmats1[35][52] + coeff0_36*dmats1[36][52] + coeff0_37*dmats1[37][52] + coeff0_38*dmats1[38][52] + coeff0_39*dmats1[39][52] + coeff0_40*dmats1[40][52] + coeff0_41*dmats1[41][52] + coeff0_42*dmats1[42][52] + coeff0_43*dmats1[43][52] + coeff0_44*dmats1[44][52] + coeff0_45*dmats1[45][52] + coeff0_46*dmats1[46][52] + coeff0_47*dmats1[47][52] + coeff0_48*dmats1[48][52] + coeff0_49*dmats1[49][52] + coeff0_50*dmats1[50][52] + coeff0_51*dmats1[51][52] + coeff0_52*dmats1[52][52] + coeff0_53*dmats1[53][52] + coeff0_54*dmats1[54][52] + coeff0_55*dmats1[55][52];
          new_coeff0_53 = coeff0_0*dmats1[0][53] + coeff0_1*dmats1[1][53] + coeff0_2*dmats1[2][53] + coeff0_3*dmats1[3][53] + coeff0_4*dmats1[4][53] + coeff0_5*dmats1[5][53] + coeff0_6*dmats1[6][53] + coeff0_7*dmats1[7][53] + coeff0_8*dmats1[8][53] + coeff0_9*dmats1[9][53] + coeff0_10*dmats1[10][53] + coeff0_11*dmats1[11][53] + coeff0_12*dmats1[12][53] + coeff0_13*dmats1[13][53] + coeff0_14*dmats1[14][53] + coeff0_15*dmats1[15][53] + coeff0_16*dmats1[16][53] + coeff0_17*dmats1[17][53] + coeff0_18*dmats1[18][53] + coeff0_19*dmats1[19][53] + coeff0_20*dmats1[20][53] + coeff0_21*dmats1[21][53] + coeff0_22*dmats1[22][53] + coeff0_23*dmats1[23][53] + coeff0_24*dmats1[24][53] + coeff0_25*dmats1[25][53] + coeff0_26*dmats1[26][53] + coeff0_27*dmats1[27][53] + coeff0_28*dmats1[28][53] + coeff0_29*dmats1[29][53] + coeff0_30*dmats1[30][53] + coeff0_31*dmats1[31][53] + coeff0_32*dmats1[32][53] + coeff0_33*dmats1[33][53] + coeff0_34*dmats1[34][53] + coeff0_35*dmats1[35][53] + coeff0_36*dmats1[36][53] + coeff0_37*dmats1[37][53] + coeff0_38*dmats1[38][53] + coeff0_39*dmats1[39][53] + coeff0_40*dmats1[40][53] + coeff0_41*dmats1[41][53] + coeff0_42*dmats1[42][53] + coeff0_43*dmats1[43][53] + coeff0_44*dmats1[44][53] + coeff0_45*dmats1[45][53] + coeff0_46*dmats1[46][53] + coeff0_47*dmats1[47][53] + coeff0_48*dmats1[48][53] + coeff0_49*dmats1[49][53] + coeff0_50*dmats1[50][53] + coeff0_51*dmats1[51][53] + coeff0_52*dmats1[52][53] + coeff0_53*dmats1[53][53] + coeff0_54*dmats1[54][53] + coeff0_55*dmats1[55][53];
          new_coeff0_54 = coeff0_0*dmats1[0][54] + coeff0_1*dmats1[1][54] + coeff0_2*dmats1[2][54] + coeff0_3*dmats1[3][54] + coeff0_4*dmats1[4][54] + coeff0_5*dmats1[5][54] + coeff0_6*dmats1[6][54] + coeff0_7*dmats1[7][54] + coeff0_8*dmats1[8][54] + coeff0_9*dmats1[9][54] + coeff0_10*dmats1[10][54] + coeff0_11*dmats1[11][54] + coeff0_12*dmats1[12][54] + coeff0_13*dmats1[13][54] + coeff0_14*dmats1[14][54] + coeff0_15*dmats1[15][54] + coeff0_16*dmats1[16][54] + coeff0_17*dmats1[17][54] + coeff0_18*dmats1[18][54] + coeff0_19*dmats1[19][54] + coeff0_20*dmats1[20][54] + coeff0_21*dmats1[21][54] + coeff0_22*dmats1[22][54] + coeff0_23*dmats1[23][54] + coeff0_24*dmats1[24][54] + coeff0_25*dmats1[25][54] + coeff0_26*dmats1[26][54] + coeff0_27*dmats1[27][54] + coeff0_28*dmats1[28][54] + coeff0_29*dmats1[29][54] + coeff0_30*dmats1[30][54] + coeff0_31*dmats1[31][54] + coeff0_32*dmats1[32][54] + coeff0_33*dmats1[33][54] + coeff0_34*dmats1[34][54] + coeff0_35*dmats1[35][54] + coeff0_36*dmats1[36][54] + coeff0_37*dmats1[37][54] + coeff0_38*dmats1[38][54] + coeff0_39*dmats1[39][54] + coeff0_40*dmats1[40][54] + coeff0_41*dmats1[41][54] + coeff0_42*dmats1[42][54] + coeff0_43*dmats1[43][54] + coeff0_44*dmats1[44][54] + coeff0_45*dmats1[45][54] + coeff0_46*dmats1[46][54] + coeff0_47*dmats1[47][54] + coeff0_48*dmats1[48][54] + coeff0_49*dmats1[49][54] + coeff0_50*dmats1[50][54] + coeff0_51*dmats1[51][54] + coeff0_52*dmats1[52][54] + coeff0_53*dmats1[53][54] + coeff0_54*dmats1[54][54] + coeff0_55*dmats1[55][54];
          new_coeff0_55 = coeff0_0*dmats1[0][55] + coeff0_1*dmats1[1][55] + coeff0_2*dmats1[2][55] + coeff0_3*dmats1[3][55] + coeff0_4*dmats1[4][55] + coeff0_5*dmats1[5][55] + coeff0_6*dmats1[6][55] + coeff0_7*dmats1[7][55] + coeff0_8*dmats1[8][55] + coeff0_9*dmats1[9][55] + coeff0_10*dmats1[10][55] + coeff0_11*dmats1[11][55] + coeff0_12*dmats1[12][55] + coeff0_13*dmats1[13][55] + coeff0_14*dmats1[14][55] + coeff0_15*dmats1[15][55] + coeff0_16*dmats1[16][55] + coeff0_17*dmats1[17][55] + coeff0_18*dmats1[18][55] + coeff0_19*dmats1[19][55] + coeff0_20*dmats1[20][55] + coeff0_21*dmats1[21][55] + coeff0_22*dmats1[22][55] + coeff0_23*dmats1[23][55] + coeff0_24*dmats1[24][55] + coeff0_25*dmats1[25][55] + coeff0_26*dmats1[26][55] + coeff0_27*dmats1[27][55] + coeff0_28*dmats1[28][55] + coeff0_29*dmats1[29][55] + coeff0_30*dmats1[30][55] + coeff0_31*dmats1[31][55] + coeff0_32*dmats1[32][55] + coeff0_33*dmats1[33][55] + coeff0_34*dmats1[34][55] + coeff0_35*dmats1[35][55] + coeff0_36*dmats1[36][55] + coeff0_37*dmats1[37][55] + coeff0_38*dmats1[38][55] + coeff0_39*dmats1[39][55] + coeff0_40*dmats1[40][55] + coeff0_41*dmats1[41][55] + coeff0_42*dmats1[42][55] + coeff0_43*dmats1[43][55] + coeff0_44*dmats1[44][55] + coeff0_45*dmats1[45][55] + coeff0_46*dmats1[46][55] + coeff0_47*dmats1[47][55] + coeff0_48*dmats1[48][55] + coeff0_49*dmats1[49][55] + coeff0_50*dmats1[50][55] + coeff0_51*dmats1[51][55] + coeff0_52*dmats1[52][55] + coeff0_53*dmats1[53][55] + coeff0_54*dmats1[54][55] + coeff0_55*dmats1[55][55];
        }
        if(combinations[deriv_num][j] == 2)
        {
          new_coeff0_0 = coeff0_0*dmats2[0][0] + coeff0_1*dmats2[1][0] + coeff0_2*dmats2[2][0] + coeff0_3*dmats2[3][0] + coeff0_4*dmats2[4][0] + coeff0_5*dmats2[5][0] + coeff0_6*dmats2[6][0] + coeff0_7*dmats2[7][0] + coeff0_8*dmats2[8][0] + coeff0_9*dmats2[9][0] + coeff0_10*dmats2[10][0] + coeff0_11*dmats2[11][0] + coeff0_12*dmats2[12][0] + coeff0_13*dmats2[13][0] + coeff0_14*dmats2[14][0] + coeff0_15*dmats2[15][0] + coeff0_16*dmats2[16][0] + coeff0_17*dmats2[17][0] + coeff0_18*dmats2[18][0] + coeff0_19*dmats2[19][0] + coeff0_20*dmats2[20][0] + coeff0_21*dmats2[21][0] + coeff0_22*dmats2[22][0] + coeff0_23*dmats2[23][0] + coeff0_24*dmats2[24][0] + coeff0_25*dmats2[25][0] + coeff0_26*dmats2[26][0] + coeff0_27*dmats2[27][0] + coeff0_28*dmats2[28][0] + coeff0_29*dmats2[29][0] + coeff0_30*dmats2[30][0] + coeff0_31*dmats2[31][0] + coeff0_32*dmats2[32][0] + coeff0_33*dmats2[33][0] + coeff0_34*dmats2[34][0] + coeff0_35*dmats2[35][0] + coeff0_36*dmats2[36][0] + coeff0_37*dmats2[37][0] + coeff0_38*dmats2[38][0] + coeff0_39*dmats2[39][0] + coeff0_40*dmats2[40][0] + coeff0_41*dmats2[41][0] + coeff0_42*dmats2[42][0] + coeff0_43*dmats2[43][0] + coeff0_44*dmats2[44][0] + coeff0_45*dmats2[45][0] + coeff0_46*dmats2[46][0] + coeff0_47*dmats2[47][0] + coeff0_48*dmats2[48][0] + coeff0_49*dmats2[49][0] + coeff0_50*dmats2[50][0] + coeff0_51*dmats2[51][0] + coeff0_52*dmats2[52][0] + coeff0_53*dmats2[53][0] + coeff0_54*dmats2[54][0] + coeff0_55*dmats2[55][0];
          new_coeff0_1 = coeff0_0*dmats2[0][1] + coeff0_1*dmats2[1][1] + coeff0_2*dmats2[2][1] + coeff0_3*dmats2[3][1] + coeff0_4*dmats2[4][1] + coeff0_5*dmats2[5][1] + coeff0_6*dmats2[6][1] + coeff0_7*dmats2[7][1] + coeff0_8*dmats2[8][1] + coeff0_9*dmats2[9][1] + coeff0_10*dmats2[10][1] + coeff0_11*dmats2[11][1] + coeff0_12*dmats2[12][1] + coeff0_13*dmats2[13][1] + coeff0_14*dmats2[14][1] + coeff0_15*dmats2[15][1] + coeff0_16*dmats2[16][1] + coeff0_17*dmats2[17][1] + coeff0_18*dmats2[18][1] + coeff0_19*dmats2[19][1] + coeff0_20*dmats2[20][1] + coeff0_21*dmats2[21][1] + coeff0_22*dmats2[22][1] + coeff0_23*dmats2[23][1] + coeff0_24*dmats2[24][1] + coeff0_25*dmats2[25][1] + coeff0_26*dmats2[26][1] + coeff0_27*dmats2[27][1] + coeff0_28*dmats2[28][1] + coeff0_29*dmats2[29][1] + coeff0_30*dmats2[30][1] + coeff0_31*dmats2[31][1] + coeff0_32*dmats2[32][1] + coeff0_33*dmats2[33][1] + coeff0_34*dmats2[34][1] + coeff0_35*dmats2[35][1] + coeff0_36*dmats2[36][1] + coeff0_37*dmats2[37][1] + coeff0_38*dmats2[38][1] + coeff0_39*dmats2[39][1] + coeff0_40*dmats2[40][1] + coeff0_41*dmats2[41][1] + coeff0_42*dmats2[42][1] + coeff0_43*dmats2[43][1] + coeff0_44*dmats2[44][1] + coeff0_45*dmats2[45][1] + coeff0_46*dmats2[46][1] + coeff0_47*dmats2[47][1] + coeff0_48*dmats2[48][1] + coeff0_49*dmats2[49][1] + coeff0_50*dmats2[50][1] + coeff0_51*dmats2[51][1] + coeff0_52*dmats2[52][1] + coeff0_53*dmats2[53][1] + coeff0_54*dmats2[54][1] + coeff0_55*dmats2[55][1];
          new_coeff0_2 = coeff0_0*dmats2[0][2] + coeff0_1*dmats2[1][2] + coeff0_2*dmats2[2][2] + coeff0_3*dmats2[3][2] + coeff0_4*dmats2[4][2] + coeff0_5*dmats2[5][2] + coeff0_6*dmats2[6][2] + coeff0_7*dmats2[7][2] + coeff0_8*dmats2[8][2] + coeff0_9*dmats2[9][2] + coeff0_10*dmats2[10][2] + coeff0_11*dmats2[11][2] + coeff0_12*dmats2[12][2] + coeff0_13*dmats2[13][2] + coeff0_14*dmats2[14][2] + coeff0_15*dmats2[15][2] + coeff0_16*dmats2[16][2] + coeff0_17*dmats2[17][2] + coeff0_18*dmats2[18][2] + coeff0_19*dmats2[19][2] + coeff0_20*dmats2[20][2] + coeff0_21*dmats2[21][2] + coeff0_22*dmats2[22][2] + coeff0_23*dmats2[23][2] + coeff0_24*dmats2[24][2] + coeff0_25*dmats2[25][2] + coeff0_26*dmats2[26][2] + coeff0_27*dmats2[27][2] + coeff0_28*dmats2[28][2] + coeff0_29*dmats2[29][2] + coeff0_30*dmats2[30][2] + coeff0_31*dmats2[31][2] + coeff0_32*dmats2[32][2] + coeff0_33*dmats2[33][2] + coeff0_34*dmats2[34][2] + coeff0_35*dmats2[35][2] + coeff0_36*dmats2[36][2] + coeff0_37*dmats2[37][2] + coeff0_38*dmats2[38][2] + coeff0_39*dmats2[39][2] + coeff0_40*dmats2[40][2] + coeff0_41*dmats2[41][2] + coeff0_42*dmats2[42][2] + coeff0_43*dmats2[43][2] + coeff0_44*dmats2[44][2] + coeff0_45*dmats2[45][2] + coeff0_46*dmats2[46][2] + coeff0_47*dmats2[47][2] + coeff0_48*dmats2[48][2] + coeff0_49*dmats2[49][2] + coeff0_50*dmats2[50][2] + coeff0_51*dmats2[51][2] + coeff0_52*dmats2[52][2] + coeff0_53*dmats2[53][2] + coeff0_54*dmats2[54][2] + coeff0_55*dmats2[55][2];
          new_coeff0_3 = coeff0_0*dmats2[0][3] + coeff0_1*dmats2[1][3] + coeff0_2*dmats2[2][3] + coeff0_3*dmats2[3][3] + coeff0_4*dmats2[4][3] + coeff0_5*dmats2[5][3] + coeff0_6*dmats2[6][3] + coeff0_7*dmats2[7][3] + coeff0_8*dmats2[8][3] + coeff0_9*dmats2[9][3] + coeff0_10*dmats2[10][3] + coeff0_11*dmats2[11][3] + coeff0_12*dmats2[12][3] + coeff0_13*dmats2[13][3] + coeff0_14*dmats2[14][3] + coeff0_15*dmats2[15][3] + coeff0_16*dmats2[16][3] + coeff0_17*dmats2[17][3] + coeff0_18*dmats2[18][3] + coeff0_19*dmats2[19][3] + coeff0_20*dmats2[20][3] + coeff0_21*dmats2[21][3] + coeff0_22*dmats2[22][3] + coeff0_23*dmats2[23][3] + coeff0_24*dmats2[24][3] + coeff0_25*dmats2[25][3] + coeff0_26*dmats2[26][3] + coeff0_27*dmats2[27][3] + coeff0_28*dmats2[28][3] + coeff0_29*dmats2[29][3] + coeff0_30*dmats2[30][3] + coeff0_31*dmats2[31][3] + coeff0_32*dmats2[32][3] + coeff0_33*dmats2[33][3] + coeff0_34*dmats2[34][3] + coeff0_35*dmats2[35][3] + coeff0_36*dmats2[36][3] + coeff0_37*dmats2[37][3] + coeff0_38*dmats2[38][3] + coeff0_39*dmats2[39][3] + coeff0_40*dmats2[40][3] + coeff0_41*dmats2[41][3] + coeff0_42*dmats2[42][3] + coeff0_43*dmats2[43][3] + coeff0_44*dmats2[44][3] + coeff0_45*dmats2[45][3] + coeff0_46*dmats2[46][3] + coeff0_47*dmats2[47][3] + coeff0_48*dmats2[48][3] + coeff0_49*dmats2[49][3] + coeff0_50*dmats2[50][3] + coeff0_51*dmats2[51][3] + coeff0_52*dmats2[52][3] + coeff0_53*dmats2[53][3] + coeff0_54*dmats2[54][3] + coeff0_55*dmats2[55][3];
          new_coeff0_4 = coeff0_0*dmats2[0][4] + coeff0_1*dmats2[1][4] + coeff0_2*dmats2[2][4] + coeff0_3*dmats2[3][4] + coeff0_4*dmats2[4][4] + coeff0_5*dmats2[5][4] + coeff0_6*dmats2[6][4] + coeff0_7*dmats2[7][4] + coeff0_8*dmats2[8][4] + coeff0_9*dmats2[9][4] + coeff0_10*dmats2[10][4] + coeff0_11*dmats2[11][4] + coeff0_12*dmats2[12][4] + coeff0_13*dmats2[13][4] + coeff0_14*dmats2[14][4] + coeff0_15*dmats2[15][4] + coeff0_16*dmats2[16][4] + coeff0_17*dmats2[17][4] + coeff0_18*dmats2[18][4] + coeff0_19*dmats2[19][4] + coeff0_20*dmats2[20][4] + coeff0_21*dmats2[21][4] + coeff0_22*dmats2[22][4] + coeff0_23*dmats2[23][4] + coeff0_24*dmats2[24][4] + coeff0_25*dmats2[25][4] + coeff0_26*dmats2[26][4] + coeff0_27*dmats2[27][4] + coeff0_28*dmats2[28][4] + coeff0_29*dmats2[29][4] + coeff0_30*dmats2[30][4] + coeff0_31*dmats2[31][4] + coeff0_32*dmats2[32][4] + coeff0_33*dmats2[33][4] + coeff0_34*dmats2[34][4] + coeff0_35*dmats2[35][4] + coeff0_36*dmats2[36][4] + coeff0_37*dmats2[37][4] + coeff0_38*dmats2[38][4] + coeff0_39*dmats2[39][4] + coeff0_40*dmats2[40][4] + coeff0_41*dmats2[41][4] + coeff0_42*dmats2[42][4] + coeff0_43*dmats2[43][4] + coeff0_44*dmats2[44][4] + coeff0_45*dmats2[45][4] + coeff0_46*dmats2[46][4] + coeff0_47*dmats2[47][4] + coeff0_48*dmats2[48][4] + coeff0_49*dmats2[49][4] + coeff0_50*dmats2[50][4] + coeff0_51*dmats2[51][4] + coeff0_52*dmats2[52][4] + coeff0_53*dmats2[53][4] + coeff0_54*dmats2[54][4] + coeff0_55*dmats2[55][4];
          new_coeff0_5 = coeff0_0*dmats2[0][5] + coeff0_1*dmats2[1][5] + coeff0_2*dmats2[2][5] + coeff0_3*dmats2[3][5] + coeff0_4*dmats2[4][5] + coeff0_5*dmats2[5][5] + coeff0_6*dmats2[6][5] + coeff0_7*dmats2[7][5] + coeff0_8*dmats2[8][5] + coeff0_9*dmats2[9][5] + coeff0_10*dmats2[10][5] + coeff0_11*dmats2[11][5] + coeff0_12*dmats2[12][5] + coeff0_13*dmats2[13][5] + coeff0_14*dmats2[14][5] + coeff0_15*dmats2[15][5] + coeff0_16*dmats2[16][5] + coeff0_17*dmats2[17][5] + coeff0_18*dmats2[18][5] + coeff0_19*dmats2[19][5] + coeff0_20*dmats2[20][5] + coeff0_21*dmats2[21][5] + coeff0_22*dmats2[22][5] + coeff0_23*dmats2[23][5] + coeff0_24*dmats2[24][5] + coeff0_25*dmats2[25][5] + coeff0_26*dmats2[26][5] + coeff0_27*dmats2[27][5] + coeff0_28*dmats2[28][5] + coeff0_29*dmats2[29][5] + coeff0_30*dmats2[30][5] + coeff0_31*dmats2[31][5] + coeff0_32*dmats2[32][5] + coeff0_33*dmats2[33][5] + coeff0_34*dmats2[34][5] + coeff0_35*dmats2[35][5] + coeff0_36*dmats2[36][5] + coeff0_37*dmats2[37][5] + coeff0_38*dmats2[38][5] + coeff0_39*dmats2[39][5] + coeff0_40*dmats2[40][5] + coeff0_41*dmats2[41][5] + coeff0_42*dmats2[42][5] + coeff0_43*dmats2[43][5] + coeff0_44*dmats2[44][5] + coeff0_45*dmats2[45][5] + coeff0_46*dmats2[46][5] + coeff0_47*dmats2[47][5] + coeff0_48*dmats2[48][5] + coeff0_49*dmats2[49][5] + coeff0_50*dmats2[50][5] + coeff0_51*dmats2[51][5] + coeff0_52*dmats2[52][5] + coeff0_53*dmats2[53][5] + coeff0_54*dmats2[54][5] + coeff0_55*dmats2[55][5];
          new_coeff0_6 = coeff0_0*dmats2[0][6] + coeff0_1*dmats2[1][6] + coeff0_2*dmats2[2][6] + coeff0_3*dmats2[3][6] + coeff0_4*dmats2[4][6] + coeff0_5*dmats2[5][6] + coeff0_6*dmats2[6][6] + coeff0_7*dmats2[7][6] + coeff0_8*dmats2[8][6] + coeff0_9*dmats2[9][6] + coeff0_10*dmats2[10][6] + coeff0_11*dmats2[11][6] + coeff0_12*dmats2[12][6] + coeff0_13*dmats2[13][6] + coeff0_14*dmats2[14][6] + coeff0_15*dmats2[15][6] + coeff0_16*dmats2[16][6] + coeff0_17*dmats2[17][6] + coeff0_18*dmats2[18][6] + coeff0_19*dmats2[19][6] + coeff0_20*dmats2[20][6] + coeff0_21*dmats2[21][6] + coeff0_22*dmats2[22][6] + coeff0_23*dmats2[23][6] + coeff0_24*dmats2[24][6] + coeff0_25*dmats2[25][6] + coeff0_26*dmats2[26][6] + coeff0_27*dmats2[27][6] + coeff0_28*dmats2[28][6] + coeff0_29*dmats2[29][6] + coeff0_30*dmats2[30][6] + coeff0_31*dmats2[31][6] + coeff0_32*dmats2[32][6] + coeff0_33*dmats2[33][6] + coeff0_34*dmats2[34][6] + coeff0_35*dmats2[35][6] + coeff0_36*dmats2[36][6] + coeff0_37*dmats2[37][6] + coeff0_38*dmats2[38][6] + coeff0_39*dmats2[39][6] + coeff0_40*dmats2[40][6] + coeff0_41*dmats2[41][6] + coeff0_42*dmats2[42][6] + coeff0_43*dmats2[43][6] + coeff0_44*dmats2[44][6] + coeff0_45*dmats2[45][6] + coeff0_46*dmats2[46][6] + coeff0_47*dmats2[47][6] + coeff0_48*dmats2[48][6] + coeff0_49*dmats2[49][6] + coeff0_50*dmats2[50][6] + coeff0_51*dmats2[51][6] + coeff0_52*dmats2[52][6] + coeff0_53*dmats2[53][6] + coeff0_54*dmats2[54][6] + coeff0_55*dmats2[55][6];
          new_coeff0_7 = coeff0_0*dmats2[0][7] + coeff0_1*dmats2[1][7] + coeff0_2*dmats2[2][7] + coeff0_3*dmats2[3][7] + coeff0_4*dmats2[4][7] + coeff0_5*dmats2[5][7] + coeff0_6*dmats2[6][7] + coeff0_7*dmats2[7][7] + coeff0_8*dmats2[8][7] + coeff0_9*dmats2[9][7] + coeff0_10*dmats2[10][7] + coeff0_11*dmats2[11][7] + coeff0_12*dmats2[12][7] + coeff0_13*dmats2[13][7] + coeff0_14*dmats2[14][7] + coeff0_15*dmats2[15][7] + coeff0_16*dmats2[16][7] + coeff0_17*dmats2[17][7] + coeff0_18*dmats2[18][7] + coeff0_19*dmats2[19][7] + coeff0_20*dmats2[20][7] + coeff0_21*dmats2[21][7] + coeff0_22*dmats2[22][7] + coeff0_23*dmats2[23][7] + coeff0_24*dmats2[24][7] + coeff0_25*dmats2[25][7] + coeff0_26*dmats2[26][7] + coeff0_27*dmats2[27][7] + coeff0_28*dmats2[28][7] + coeff0_29*dmats2[29][7] + coeff0_30*dmats2[30][7] + coeff0_31*dmats2[31][7] + coeff0_32*dmats2[32][7] + coeff0_33*dmats2[33][7] + coeff0_34*dmats2[34][7] + coeff0_35*dmats2[35][7] + coeff0_36*dmats2[36][7] + coeff0_37*dmats2[37][7] + coeff0_38*dmats2[38][7] + coeff0_39*dmats2[39][7] + coeff0_40*dmats2[40][7] + coeff0_41*dmats2[41][7] + coeff0_42*dmats2[42][7] + coeff0_43*dmats2[43][7] + coeff0_44*dmats2[44][7] + coeff0_45*dmats2[45][7] + coeff0_46*dmats2[46][7] + coeff0_47*dmats2[47][7] + coeff0_48*dmats2[48][7] + coeff0_49*dmats2[49][7] + coeff0_50*dmats2[50][7] + coeff0_51*dmats2[51][7] + coeff0_52*dmats2[52][7] + coeff0_53*dmats2[53][7] + coeff0_54*dmats2[54][7] + coeff0_55*dmats2[55][7];
          new_coeff0_8 = coeff0_0*dmats2[0][8] + coeff0_1*dmats2[1][8] + coeff0_2*dmats2[2][8] + coeff0_3*dmats2[3][8] + coeff0_4*dmats2[4][8] + coeff0_5*dmats2[5][8] + coeff0_6*dmats2[6][8] + coeff0_7*dmats2[7][8] + coeff0_8*dmats2[8][8] + coeff0_9*dmats2[9][8] + coeff0_10*dmats2[10][8] + coeff0_11*dmats2[11][8] + coeff0_12*dmats2[12][8] + coeff0_13*dmats2[13][8] + coeff0_14*dmats2[14][8] + coeff0_15*dmats2[15][8] + coeff0_16*dmats2[16][8] + coeff0_17*dmats2[17][8] + coeff0_18*dmats2[18][8] + coeff0_19*dmats2[19][8] + coeff0_20*dmats2[20][8] + coeff0_21*dmats2[21][8] + coeff0_22*dmats2[22][8] + coeff0_23*dmats2[23][8] + coeff0_24*dmats2[24][8] + coeff0_25*dmats2[25][8] + coeff0_26*dmats2[26][8] + coeff0_27*dmats2[27][8] + coeff0_28*dmats2[28][8] + coeff0_29*dmats2[29][8] + coeff0_30*dmats2[30][8] + coeff0_31*dmats2[31][8] + coeff0_32*dmats2[32][8] + coeff0_33*dmats2[33][8] + coeff0_34*dmats2[34][8] + coeff0_35*dmats2[35][8] + coeff0_36*dmats2[36][8] + coeff0_37*dmats2[37][8] + coeff0_38*dmats2[38][8] + coeff0_39*dmats2[39][8] + coeff0_40*dmats2[40][8] + coeff0_41*dmats2[41][8] + coeff0_42*dmats2[42][8] + coeff0_43*dmats2[43][8] + coeff0_44*dmats2[44][8] + coeff0_45*dmats2[45][8] + coeff0_46*dmats2[46][8] + coeff0_47*dmats2[47][8] + coeff0_48*dmats2[48][8] + coeff0_49*dmats2[49][8] + coeff0_50*dmats2[50][8] + coeff0_51*dmats2[51][8] + coeff0_52*dmats2[52][8] + coeff0_53*dmats2[53][8] + coeff0_54*dmats2[54][8] + coeff0_55*dmats2[55][8];
          new_coeff0_9 = coeff0_0*dmats2[0][9] + coeff0_1*dmats2[1][9] + coeff0_2*dmats2[2][9] + coeff0_3*dmats2[3][9] + coeff0_4*dmats2[4][9] + coeff0_5*dmats2[5][9] + coeff0_6*dmats2[6][9] + coeff0_7*dmats2[7][9] + coeff0_8*dmats2[8][9] + coeff0_9*dmats2[9][9] + coeff0_10*dmats2[10][9] + coeff0_11*dmats2[11][9] + coeff0_12*dmats2[12][9] + coeff0_13*dmats2[13][9] + coeff0_14*dmats2[14][9] + coeff0_15*dmats2[15][9] + coeff0_16*dmats2[16][9] + coeff0_17*dmats2[17][9] + coeff0_18*dmats2[18][9] + coeff0_19*dmats2[19][9] + coeff0_20*dmats2[20][9] + coeff0_21*dmats2[21][9] + coeff0_22*dmats2[22][9] + coeff0_23*dmats2[23][9] + coeff0_24*dmats2[24][9] + coeff0_25*dmats2[25][9] + coeff0_26*dmats2[26][9] + coeff0_27*dmats2[27][9] + coeff0_28*dmats2[28][9] + coeff0_29*dmats2[29][9] + coeff0_30*dmats2[30][9] + coeff0_31*dmats2[31][9] + coeff0_32*dmats2[32][9] + coeff0_33*dmats2[33][9] + coeff0_34*dmats2[34][9] + coeff0_35*dmats2[35][9] + coeff0_36*dmats2[36][9] + coeff0_37*dmats2[37][9] + coeff0_38*dmats2[38][9] + coeff0_39*dmats2[39][9] + coeff0_40*dmats2[40][9] + coeff0_41*dmats2[41][9] + coeff0_42*dmats2[42][9] + coeff0_43*dmats2[43][9] + coeff0_44*dmats2[44][9] + coeff0_45*dmats2[45][9] + coeff0_46*dmats2[46][9] + coeff0_47*dmats2[47][9] + coeff0_48*dmats2[48][9] + coeff0_49*dmats2[49][9] + coeff0_50*dmats2[50][9] + coeff0_51*dmats2[51][9] + coeff0_52*dmats2[52][9] + coeff0_53*dmats2[53][9] + coeff0_54*dmats2[54][9] + coeff0_55*dmats2[55][9];
          new_coeff0_10 = coeff0_0*dmats2[0][10] + coeff0_1*dmats2[1][10] + coeff0_2*dmats2[2][10] + coeff0_3*dmats2[3][10] + coeff0_4*dmats2[4][10] + coeff0_5*dmats2[5][10] + coeff0_6*dmats2[6][10] + coeff0_7*dmats2[7][10] + coeff0_8*dmats2[8][10] + coeff0_9*dmats2[9][10] + coeff0_10*dmats2[10][10] + coeff0_11*dmats2[11][10] + coeff0_12*dmats2[12][10] + coeff0_13*dmats2[13][10] + coeff0_14*dmats2[14][10] + coeff0_15*dmats2[15][10] + coeff0_16*dmats2[16][10] + coeff0_17*dmats2[17][10] + coeff0_18*dmats2[18][10] + coeff0_19*dmats2[19][10] + coeff0_20*dmats2[20][10] + coeff0_21*dmats2[21][10] + coeff0_22*dmats2[22][10] + coeff0_23*dmats2[23][10] + coeff0_24*dmats2[24][10] + coeff0_25*dmats2[25][10] + coeff0_26*dmats2[26][10] + coeff0_27*dmats2[27][10] + coeff0_28*dmats2[28][10] + coeff0_29*dmats2[29][10] + coeff0_30*dmats2[30][10] + coeff0_31*dmats2[31][10] + coeff0_32*dmats2[32][10] + coeff0_33*dmats2[33][10] + coeff0_34*dmats2[34][10] + coeff0_35*dmats2[35][10] + coeff0_36*dmats2[36][10] + coeff0_37*dmats2[37][10] + coeff0_38*dmats2[38][10] + coeff0_39*dmats2[39][10] + coeff0_40*dmats2[40][10] + coeff0_41*dmats2[41][10] + coeff0_42*dmats2[42][10] + coeff0_43*dmats2[43][10] + coeff0_44*dmats2[44][10] + coeff0_45*dmats2[45][10] + coeff0_46*dmats2[46][10] + coeff0_47*dmats2[47][10] + coeff0_48*dmats2[48][10] + coeff0_49*dmats2[49][10] + coeff0_50*dmats2[50][10] + coeff0_51*dmats2[51][10] + coeff0_52*dmats2[52][10] + coeff0_53*dmats2[53][10] + coeff0_54*dmats2[54][10] + coeff0_55*dmats2[55][10];
          new_coeff0_11 = coeff0_0*dmats2[0][11] + coeff0_1*dmats2[1][11] + coeff0_2*dmats2[2][11] + coeff0_3*dmats2[3][11] + coeff0_4*dmats2[4][11] + coeff0_5*dmats2[5][11] + coeff0_6*dmats2[6][11] + coeff0_7*dmats2[7][11] + coeff0_8*dmats2[8][11] + coeff0_9*dmats2[9][11] + coeff0_10*dmats2[10][11] + coeff0_11*dmats2[11][11] + coeff0_12*dmats2[12][11] + coeff0_13*dmats2[13][11] + coeff0_14*dmats2[14][11] + coeff0_15*dmats2[15][11] + coeff0_16*dmats2[16][11] + coeff0_17*dmats2[17][11] + coeff0_18*dmats2[18][11] + coeff0_19*dmats2[19][11] + coeff0_20*dmats2[20][11] + coeff0_21*dmats2[21][11] + coeff0_22*dmats2[22][11] + coeff0_23*dmats2[23][11] + coeff0_24*dmats2[24][11] + coeff0_25*dmats2[25][11] + coeff0_26*dmats2[26][11] + coeff0_27*dmats2[27][11] + coeff0_28*dmats2[28][11] + coeff0_29*dmats2[29][11] + coeff0_30*dmats2[30][11] + coeff0_31*dmats2[31][11] + coeff0_32*dmats2[32][11] + coeff0_33*dmats2[33][11] + coeff0_34*dmats2[34][11] + coeff0_35*dmats2[35][11] + coeff0_36*dmats2[36][11] + coeff0_37*dmats2[37][11] + coeff0_38*dmats2[38][11] + coeff0_39*dmats2[39][11] + coeff0_40*dmats2[40][11] + coeff0_41*dmats2[41][11] + coeff0_42*dmats2[42][11] + coeff0_43*dmats2[43][11] + coeff0_44*dmats2[44][11] + coeff0_45*dmats2[45][11] + coeff0_46*dmats2[46][11] + coeff0_47*dmats2[47][11] + coeff0_48*dmats2[48][11] + coeff0_49*dmats2[49][11] + coeff0_50*dmats2[50][11] + coeff0_51*dmats2[51][11] + coeff0_52*dmats2[52][11] + coeff0_53*dmats2[53][11] + coeff0_54*dmats2[54][11] + coeff0_55*dmats2[55][11];
          new_coeff0_12 = coeff0_0*dmats2[0][12] + coeff0_1*dmats2[1][12] + coeff0_2*dmats2[2][12] + coeff0_3*dmats2[3][12] + coeff0_4*dmats2[4][12] + coeff0_5*dmats2[5][12] + coeff0_6*dmats2[6][12] + coeff0_7*dmats2[7][12] + coeff0_8*dmats2[8][12] + coeff0_9*dmats2[9][12] + coeff0_10*dmats2[10][12] + coeff0_11*dmats2[11][12] + coeff0_12*dmats2[12][12] + coeff0_13*dmats2[13][12] + coeff0_14*dmats2[14][12] + coeff0_15*dmats2[15][12] + coeff0_16*dmats2[16][12] + coeff0_17*dmats2[17][12] + coeff0_18*dmats2[18][12] + coeff0_19*dmats2[19][12] + coeff0_20*dmats2[20][12] + coeff0_21*dmats2[21][12] + coeff0_22*dmats2[22][12] + coeff0_23*dmats2[23][12] + coeff0_24*dmats2[24][12] + coeff0_25*dmats2[25][12] + coeff0_26*dmats2[26][12] + coeff0_27*dmats2[27][12] + coeff0_28*dmats2[28][12] + coeff0_29*dmats2[29][12] + coeff0_30*dmats2[30][12] + coeff0_31*dmats2[31][12] + coeff0_32*dmats2[32][12] + coeff0_33*dmats2[33][12] + coeff0_34*dmats2[34][12] + coeff0_35*dmats2[35][12] + coeff0_36*dmats2[36][12] + coeff0_37*dmats2[37][12] + coeff0_38*dmats2[38][12] + coeff0_39*dmats2[39][12] + coeff0_40*dmats2[40][12] + coeff0_41*dmats2[41][12] + coeff0_42*dmats2[42][12] + coeff0_43*dmats2[43][12] + coeff0_44*dmats2[44][12] + coeff0_45*dmats2[45][12] + coeff0_46*dmats2[46][12] + coeff0_47*dmats2[47][12] + coeff0_48*dmats2[48][12] + coeff0_49*dmats2[49][12] + coeff0_50*dmats2[50][12] + coeff0_51*dmats2[51][12] + coeff0_52*dmats2[52][12] + coeff0_53*dmats2[53][12] + coeff0_54*dmats2[54][12] + coeff0_55*dmats2[55][12];
          new_coeff0_13 = coeff0_0*dmats2[0][13] + coeff0_1*dmats2[1][13] + coeff0_2*dmats2[2][13] + coeff0_3*dmats2[3][13] + coeff0_4*dmats2[4][13] + coeff0_5*dmats2[5][13] + coeff0_6*dmats2[6][13] + coeff0_7*dmats2[7][13] + coeff0_8*dmats2[8][13] + coeff0_9*dmats2[9][13] + coeff0_10*dmats2[10][13] + coeff0_11*dmats2[11][13] + coeff0_12*dmats2[12][13] + coeff0_13*dmats2[13][13] + coeff0_14*dmats2[14][13] + coeff0_15*dmats2[15][13] + coeff0_16*dmats2[16][13] + coeff0_17*dmats2[17][13] + coeff0_18*dmats2[18][13] + coeff0_19*dmats2[19][13] + coeff0_20*dmats2[20][13] + coeff0_21*dmats2[21][13] + coeff0_22*dmats2[22][13] + coeff0_23*dmats2[23][13] + coeff0_24*dmats2[24][13] + coeff0_25*dmats2[25][13] + coeff0_26*dmats2[26][13] + coeff0_27*dmats2[27][13] + coeff0_28*dmats2[28][13] + coeff0_29*dmats2[29][13] + coeff0_30*dmats2[30][13] + coeff0_31*dmats2[31][13] + coeff0_32*dmats2[32][13] + coeff0_33*dmats2[33][13] + coeff0_34*dmats2[34][13] + coeff0_35*dmats2[35][13] + coeff0_36*dmats2[36][13] + coeff0_37*dmats2[37][13] + coeff0_38*dmats2[38][13] + coeff0_39*dmats2[39][13] + coeff0_40*dmats2[40][13] + coeff0_41*dmats2[41][13] + coeff0_42*dmats2[42][13] + coeff0_43*dmats2[43][13] + coeff0_44*dmats2[44][13] + coeff0_45*dmats2[45][13] + coeff0_46*dmats2[46][13] + coeff0_47*dmats2[47][13] + coeff0_48*dmats2[48][13] + coeff0_49*dmats2[49][13] + coeff0_50*dmats2[50][13] + coeff0_51*dmats2[51][13] + coeff0_52*dmats2[52][13] + coeff0_53*dmats2[53][13] + coeff0_54*dmats2[54][13] + coeff0_55*dmats2[55][13];
          new_coeff0_14 = coeff0_0*dmats2[0][14] + coeff0_1*dmats2[1][14] + coeff0_2*dmats2[2][14] + coeff0_3*dmats2[3][14] + coeff0_4*dmats2[4][14] + coeff0_5*dmats2[5][14] + coeff0_6*dmats2[6][14] + coeff0_7*dmats2[7][14] + coeff0_8*dmats2[8][14] + coeff0_9*dmats2[9][14] + coeff0_10*dmats2[10][14] + coeff0_11*dmats2[11][14] + coeff0_12*dmats2[12][14] + coeff0_13*dmats2[13][14] + coeff0_14*dmats2[14][14] + coeff0_15*dmats2[15][14] + coeff0_16*dmats2[16][14] + coeff0_17*dmats2[17][14] + coeff0_18*dmats2[18][14] + coeff0_19*dmats2[19][14] + coeff0_20*dmats2[20][14] + coeff0_21*dmats2[21][14] + coeff0_22*dmats2[22][14] + coeff0_23*dmats2[23][14] + coeff0_24*dmats2[24][14] + coeff0_25*dmats2[25][14] + coeff0_26*dmats2[26][14] + coeff0_27*dmats2[27][14] + coeff0_28*dmats2[28][14] + coeff0_29*dmats2[29][14] + coeff0_30*dmats2[30][14] + coeff0_31*dmats2[31][14] + coeff0_32*dmats2[32][14] + coeff0_33*dmats2[33][14] + coeff0_34*dmats2[34][14] + coeff0_35*dmats2[35][14] + coeff0_36*dmats2[36][14] + coeff0_37*dmats2[37][14] + coeff0_38*dmats2[38][14] + coeff0_39*dmats2[39][14] + coeff0_40*dmats2[40][14] + coeff0_41*dmats2[41][14] + coeff0_42*dmats2[42][14] + coeff0_43*dmats2[43][14] + coeff0_44*dmats2[44][14] + coeff0_45*dmats2[45][14] + coeff0_46*dmats2[46][14] + coeff0_47*dmats2[47][14] + coeff0_48*dmats2[48][14] + coeff0_49*dmats2[49][14] + coeff0_50*dmats2[50][14] + coeff0_51*dmats2[51][14] + coeff0_52*dmats2[52][14] + coeff0_53*dmats2[53][14] + coeff0_54*dmats2[54][14] + coeff0_55*dmats2[55][14];
          new_coeff0_15 = coeff0_0*dmats2[0][15] + coeff0_1*dmats2[1][15] + coeff0_2*dmats2[2][15] + coeff0_3*dmats2[3][15] + coeff0_4*dmats2[4][15] + coeff0_5*dmats2[5][15] + coeff0_6*dmats2[6][15] + coeff0_7*dmats2[7][15] + coeff0_8*dmats2[8][15] + coeff0_9*dmats2[9][15] + coeff0_10*dmats2[10][15] + coeff0_11*dmats2[11][15] + coeff0_12*dmats2[12][15] + coeff0_13*dmats2[13][15] + coeff0_14*dmats2[14][15] + coeff0_15*dmats2[15][15] + coeff0_16*dmats2[16][15] + coeff0_17*dmats2[17][15] + coeff0_18*dmats2[18][15] + coeff0_19*dmats2[19][15] + coeff0_20*dmats2[20][15] + coeff0_21*dmats2[21][15] + coeff0_22*dmats2[22][15] + coeff0_23*dmats2[23][15] + coeff0_24*dmats2[24][15] + coeff0_25*dmats2[25][15] + coeff0_26*dmats2[26][15] + coeff0_27*dmats2[27][15] + coeff0_28*dmats2[28][15] + coeff0_29*dmats2[29][15] + coeff0_30*dmats2[30][15] + coeff0_31*dmats2[31][15] + coeff0_32*dmats2[32][15] + coeff0_33*dmats2[33][15] + coeff0_34*dmats2[34][15] + coeff0_35*dmats2[35][15] + coeff0_36*dmats2[36][15] + coeff0_37*dmats2[37][15] + coeff0_38*dmats2[38][15] + coeff0_39*dmats2[39][15] + coeff0_40*dmats2[40][15] + coeff0_41*dmats2[41][15] + coeff0_42*dmats2[42][15] + coeff0_43*dmats2[43][15] + coeff0_44*dmats2[44][15] + coeff0_45*dmats2[45][15] + coeff0_46*dmats2[46][15] + coeff0_47*dmats2[47][15] + coeff0_48*dmats2[48][15] + coeff0_49*dmats2[49][15] + coeff0_50*dmats2[50][15] + coeff0_51*dmats2[51][15] + coeff0_52*dmats2[52][15] + coeff0_53*dmats2[53][15] + coeff0_54*dmats2[54][15] + coeff0_55*dmats2[55][15];
          new_coeff0_16 = coeff0_0*dmats2[0][16] + coeff0_1*dmats2[1][16] + coeff0_2*dmats2[2][16] + coeff0_3*dmats2[3][16] + coeff0_4*dmats2[4][16] + coeff0_5*dmats2[5][16] + coeff0_6*dmats2[6][16] + coeff0_7*dmats2[7][16] + coeff0_8*dmats2[8][16] + coeff0_9*dmats2[9][16] + coeff0_10*dmats2[10][16] + coeff0_11*dmats2[11][16] + coeff0_12*dmats2[12][16] + coeff0_13*dmats2[13][16] + coeff0_14*dmats2[14][16] + coeff0_15*dmats2[15][16] + coeff0_16*dmats2[16][16] + coeff0_17*dmats2[17][16] + coeff0_18*dmats2[18][16] + coeff0_19*dmats2[19][16] + coeff0_20*dmats2[20][16] + coeff0_21*dmats2[21][16] + coeff0_22*dmats2[22][16] + coeff0_23*dmats2[23][16] + coeff0_24*dmats2[24][16] + coeff0_25*dmats2[25][16] + coeff0_26*dmats2[26][16] + coeff0_27*dmats2[27][16] + coeff0_28*dmats2[28][16] + coeff0_29*dmats2[29][16] + coeff0_30*dmats2[30][16] + coeff0_31*dmats2[31][16] + coeff0_32*dmats2[32][16] + coeff0_33*dmats2[33][16] + coeff0_34*dmats2[34][16] + coeff0_35*dmats2[35][16] + coeff0_36*dmats2[36][16] + coeff0_37*dmats2[37][16] + coeff0_38*dmats2[38][16] + coeff0_39*dmats2[39][16] + coeff0_40*dmats2[40][16] + coeff0_41*dmats2[41][16] + coeff0_42*dmats2[42][16] + coeff0_43*dmats2[43][16] + coeff0_44*dmats2[44][16] + coeff0_45*dmats2[45][16] + coeff0_46*dmats2[46][16] + coeff0_47*dmats2[47][16] + coeff0_48*dmats2[48][16] + coeff0_49*dmats2[49][16] + coeff0_50*dmats2[50][16] + coeff0_51*dmats2[51][16] + coeff0_52*dmats2[52][16] + coeff0_53*dmats2[53][16] + coeff0_54*dmats2[54][16] + coeff0_55*dmats2[55][16];
          new_coeff0_17 = coeff0_0*dmats2[0][17] + coeff0_1*dmats2[1][17] + coeff0_2*dmats2[2][17] + coeff0_3*dmats2[3][17] + coeff0_4*dmats2[4][17] + coeff0_5*dmats2[5][17] + coeff0_6*dmats2[6][17] + coeff0_7*dmats2[7][17] + coeff0_8*dmats2[8][17] + coeff0_9*dmats2[9][17] + coeff0_10*dmats2[10][17] + coeff0_11*dmats2[11][17] + coeff0_12*dmats2[12][17] + coeff0_13*dmats2[13][17] + coeff0_14*dmats2[14][17] + coeff0_15*dmats2[15][17] + coeff0_16*dmats2[16][17] + coeff0_17*dmats2[17][17] + coeff0_18*dmats2[18][17] + coeff0_19*dmats2[19][17] + coeff0_20*dmats2[20][17] + coeff0_21*dmats2[21][17] + coeff0_22*dmats2[22][17] + coeff0_23*dmats2[23][17] + coeff0_24*dmats2[24][17] + coeff0_25*dmats2[25][17] + coeff0_26*dmats2[26][17] + coeff0_27*dmats2[27][17] + coeff0_28*dmats2[28][17] + coeff0_29*dmats2[29][17] + coeff0_30*dmats2[30][17] + coeff0_31*dmats2[31][17] + coeff0_32*dmats2[32][17] + coeff0_33*dmats2[33][17] + coeff0_34*dmats2[34][17] + coeff0_35*dmats2[35][17] + coeff0_36*dmats2[36][17] + coeff0_37*dmats2[37][17] + coeff0_38*dmats2[38][17] + coeff0_39*dmats2[39][17] + coeff0_40*dmats2[40][17] + coeff0_41*dmats2[41][17] + coeff0_42*dmats2[42][17] + coeff0_43*dmats2[43][17] + coeff0_44*dmats2[44][17] + coeff0_45*dmats2[45][17] + coeff0_46*dmats2[46][17] + coeff0_47*dmats2[47][17] + coeff0_48*dmats2[48][17] + coeff0_49*dmats2[49][17] + coeff0_50*dmats2[50][17] + coeff0_51*dmats2[51][17] + coeff0_52*dmats2[52][17] + coeff0_53*dmats2[53][17] + coeff0_54*dmats2[54][17] + coeff0_55*dmats2[55][17];
          new_coeff0_18 = coeff0_0*dmats2[0][18] + coeff0_1*dmats2[1][18] + coeff0_2*dmats2[2][18] + coeff0_3*dmats2[3][18] + coeff0_4*dmats2[4][18] + coeff0_5*dmats2[5][18] + coeff0_6*dmats2[6][18] + coeff0_7*dmats2[7][18] + coeff0_8*dmats2[8][18] + coeff0_9*dmats2[9][18] + coeff0_10*dmats2[10][18] + coeff0_11*dmats2[11][18] + coeff0_12*dmats2[12][18] + coeff0_13*dmats2[13][18] + coeff0_14*dmats2[14][18] + coeff0_15*dmats2[15][18] + coeff0_16*dmats2[16][18] + coeff0_17*dmats2[17][18] + coeff0_18*dmats2[18][18] + coeff0_19*dmats2[19][18] + coeff0_20*dmats2[20][18] + coeff0_21*dmats2[21][18] + coeff0_22*dmats2[22][18] + coeff0_23*dmats2[23][18] + coeff0_24*dmats2[24][18] + coeff0_25*dmats2[25][18] + coeff0_26*dmats2[26][18] + coeff0_27*dmats2[27][18] + coeff0_28*dmats2[28][18] + coeff0_29*dmats2[29][18] + coeff0_30*dmats2[30][18] + coeff0_31*dmats2[31][18] + coeff0_32*dmats2[32][18] + coeff0_33*dmats2[33][18] + coeff0_34*dmats2[34][18] + coeff0_35*dmats2[35][18] + coeff0_36*dmats2[36][18] + coeff0_37*dmats2[37][18] + coeff0_38*dmats2[38][18] + coeff0_39*dmats2[39][18] + coeff0_40*dmats2[40][18] + coeff0_41*dmats2[41][18] + coeff0_42*dmats2[42][18] + coeff0_43*dmats2[43][18] + coeff0_44*dmats2[44][18] + coeff0_45*dmats2[45][18] + coeff0_46*dmats2[46][18] + coeff0_47*dmats2[47][18] + coeff0_48*dmats2[48][18] + coeff0_49*dmats2[49][18] + coeff0_50*dmats2[50][18] + coeff0_51*dmats2[51][18] + coeff0_52*dmats2[52][18] + coeff0_53*dmats2[53][18] + coeff0_54*dmats2[54][18] + coeff0_55*dmats2[55][18];
          new_coeff0_19 = coeff0_0*dmats2[0][19] + coeff0_1*dmats2[1][19] + coeff0_2*dmats2[2][19] + coeff0_3*dmats2[3][19] + coeff0_4*dmats2[4][19] + coeff0_5*dmats2[5][19] + coeff0_6*dmats2[6][19] + coeff0_7*dmats2[7][19] + coeff0_8*dmats2[8][19] + coeff0_9*dmats2[9][19] + coeff0_10*dmats2[10][19] + coeff0_11*dmats2[11][19] + coeff0_12*dmats2[12][19] + coeff0_13*dmats2[13][19] + coeff0_14*dmats2[14][19] + coeff0_15*dmats2[15][19] + coeff0_16*dmats2[16][19] + coeff0_17*dmats2[17][19] + coeff0_18*dmats2[18][19] + coeff0_19*dmats2[19][19] + coeff0_20*dmats2[20][19] + coeff0_21*dmats2[21][19] + coeff0_22*dmats2[22][19] + coeff0_23*dmats2[23][19] + coeff0_24*dmats2[24][19] + coeff0_25*dmats2[25][19] + coeff0_26*dmats2[26][19] + coeff0_27*dmats2[27][19] + coeff0_28*dmats2[28][19] + coeff0_29*dmats2[29][19] + coeff0_30*dmats2[30][19] + coeff0_31*dmats2[31][19] + coeff0_32*dmats2[32][19] + coeff0_33*dmats2[33][19] + coeff0_34*dmats2[34][19] + coeff0_35*dmats2[35][19] + coeff0_36*dmats2[36][19] + coeff0_37*dmats2[37][19] + coeff0_38*dmats2[38][19] + coeff0_39*dmats2[39][19] + coeff0_40*dmats2[40][19] + coeff0_41*dmats2[41][19] + coeff0_42*dmats2[42][19] + coeff0_43*dmats2[43][19] + coeff0_44*dmats2[44][19] + coeff0_45*dmats2[45][19] + coeff0_46*dmats2[46][19] + coeff0_47*dmats2[47][19] + coeff0_48*dmats2[48][19] + coeff0_49*dmats2[49][19] + coeff0_50*dmats2[50][19] + coeff0_51*dmats2[51][19] + coeff0_52*dmats2[52][19] + coeff0_53*dmats2[53][19] + coeff0_54*dmats2[54][19] + coeff0_55*dmats2[55][19];
          new_coeff0_20 = coeff0_0*dmats2[0][20] + coeff0_1*dmats2[1][20] + coeff0_2*dmats2[2][20] + coeff0_3*dmats2[3][20] + coeff0_4*dmats2[4][20] + coeff0_5*dmats2[5][20] + coeff0_6*dmats2[6][20] + coeff0_7*dmats2[7][20] + coeff0_8*dmats2[8][20] + coeff0_9*dmats2[9][20] + coeff0_10*dmats2[10][20] + coeff0_11*dmats2[11][20] + coeff0_12*dmats2[12][20] + coeff0_13*dmats2[13][20] + coeff0_14*dmats2[14][20] + coeff0_15*dmats2[15][20] + coeff0_16*dmats2[16][20] + coeff0_17*dmats2[17][20] + coeff0_18*dmats2[18][20] + coeff0_19*dmats2[19][20] + coeff0_20*dmats2[20][20] + coeff0_21*dmats2[21][20] + coeff0_22*dmats2[22][20] + coeff0_23*dmats2[23][20] + coeff0_24*dmats2[24][20] + coeff0_25*dmats2[25][20] + coeff0_26*dmats2[26][20] + coeff0_27*dmats2[27][20] + coeff0_28*dmats2[28][20] + coeff0_29*dmats2[29][20] + coeff0_30*dmats2[30][20] + coeff0_31*dmats2[31][20] + coeff0_32*dmats2[32][20] + coeff0_33*dmats2[33][20] + coeff0_34*dmats2[34][20] + coeff0_35*dmats2[35][20] + coeff0_36*dmats2[36][20] + coeff0_37*dmats2[37][20] + coeff0_38*dmats2[38][20] + coeff0_39*dmats2[39][20] + coeff0_40*dmats2[40][20] + coeff0_41*dmats2[41][20] + coeff0_42*dmats2[42][20] + coeff0_43*dmats2[43][20] + coeff0_44*dmats2[44][20] + coeff0_45*dmats2[45][20] + coeff0_46*dmats2[46][20] + coeff0_47*dmats2[47][20] + coeff0_48*dmats2[48][20] + coeff0_49*dmats2[49][20] + coeff0_50*dmats2[50][20] + coeff0_51*dmats2[51][20] + coeff0_52*dmats2[52][20] + coeff0_53*dmats2[53][20] + coeff0_54*dmats2[54][20] + coeff0_55*dmats2[55][20];
          new_coeff0_21 = coeff0_0*dmats2[0][21] + coeff0_1*dmats2[1][21] + coeff0_2*dmats2[2][21] + coeff0_3*dmats2[3][21] + coeff0_4*dmats2[4][21] + coeff0_5*dmats2[5][21] + coeff0_6*dmats2[6][21] + coeff0_7*dmats2[7][21] + coeff0_8*dmats2[8][21] + coeff0_9*dmats2[9][21] + coeff0_10*dmats2[10][21] + coeff0_11*dmats2[11][21] + coeff0_12*dmats2[12][21] + coeff0_13*dmats2[13][21] + coeff0_14*dmats2[14][21] + coeff0_15*dmats2[15][21] + coeff0_16*dmats2[16][21] + coeff0_17*dmats2[17][21] + coeff0_18*dmats2[18][21] + coeff0_19*dmats2[19][21] + coeff0_20*dmats2[20][21] + coeff0_21*dmats2[21][21] + coeff0_22*dmats2[22][21] + coeff0_23*dmats2[23][21] + coeff0_24*dmats2[24][21] + coeff0_25*dmats2[25][21] + coeff0_26*dmats2[26][21] + coeff0_27*dmats2[27][21] + coeff0_28*dmats2[28][21] + coeff0_29*dmats2[29][21] + coeff0_30*dmats2[30][21] + coeff0_31*dmats2[31][21] + coeff0_32*dmats2[32][21] + coeff0_33*dmats2[33][21] + coeff0_34*dmats2[34][21] + coeff0_35*dmats2[35][21] + coeff0_36*dmats2[36][21] + coeff0_37*dmats2[37][21] + coeff0_38*dmats2[38][21] + coeff0_39*dmats2[39][21] + coeff0_40*dmats2[40][21] + coeff0_41*dmats2[41][21] + coeff0_42*dmats2[42][21] + coeff0_43*dmats2[43][21] + coeff0_44*dmats2[44][21] + coeff0_45*dmats2[45][21] + coeff0_46*dmats2[46][21] + coeff0_47*dmats2[47][21] + coeff0_48*dmats2[48][21] + coeff0_49*dmats2[49][21] + coeff0_50*dmats2[50][21] + coeff0_51*dmats2[51][21] + coeff0_52*dmats2[52][21] + coeff0_53*dmats2[53][21] + coeff0_54*dmats2[54][21] + coeff0_55*dmats2[55][21];
          new_coeff0_22 = coeff0_0*dmats2[0][22] + coeff0_1*dmats2[1][22] + coeff0_2*dmats2[2][22] + coeff0_3*dmats2[3][22] + coeff0_4*dmats2[4][22] + coeff0_5*dmats2[5][22] + coeff0_6*dmats2[6][22] + coeff0_7*dmats2[7][22] + coeff0_8*dmats2[8][22] + coeff0_9*dmats2[9][22] + coeff0_10*dmats2[10][22] + coeff0_11*dmats2[11][22] + coeff0_12*dmats2[12][22] + coeff0_13*dmats2[13][22] + coeff0_14*dmats2[14][22] + coeff0_15*dmats2[15][22] + coeff0_16*dmats2[16][22] + coeff0_17*dmats2[17][22] + coeff0_18*dmats2[18][22] + coeff0_19*dmats2[19][22] + coeff0_20*dmats2[20][22] + coeff0_21*dmats2[21][22] + coeff0_22*dmats2[22][22] + coeff0_23*dmats2[23][22] + coeff0_24*dmats2[24][22] + coeff0_25*dmats2[25][22] + coeff0_26*dmats2[26][22] + coeff0_27*dmats2[27][22] + coeff0_28*dmats2[28][22] + coeff0_29*dmats2[29][22] + coeff0_30*dmats2[30][22] + coeff0_31*dmats2[31][22] + coeff0_32*dmats2[32][22] + coeff0_33*dmats2[33][22] + coeff0_34*dmats2[34][22] + coeff0_35*dmats2[35][22] + coeff0_36*dmats2[36][22] + coeff0_37*dmats2[37][22] + coeff0_38*dmats2[38][22] + coeff0_39*dmats2[39][22] + coeff0_40*dmats2[40][22] + coeff0_41*dmats2[41][22] + coeff0_42*dmats2[42][22] + coeff0_43*dmats2[43][22] + coeff0_44*dmats2[44][22] + coeff0_45*dmats2[45][22] + coeff0_46*dmats2[46][22] + coeff0_47*dmats2[47][22] + coeff0_48*dmats2[48][22] + coeff0_49*dmats2[49][22] + coeff0_50*dmats2[50][22] + coeff0_51*dmats2[51][22] + coeff0_52*dmats2[52][22] + coeff0_53*dmats2[53][22] + coeff0_54*dmats2[54][22] + coeff0_55*dmats2[55][22];
          new_coeff0_23 = coeff0_0*dmats2[0][23] + coeff0_1*dmats2[1][23] + coeff0_2*dmats2[2][23] + coeff0_3*dmats2[3][23] + coeff0_4*dmats2[4][23] + coeff0_5*dmats2[5][23] + coeff0_6*dmats2[6][23] + coeff0_7*dmats2[7][23] + coeff0_8*dmats2[8][23] + coeff0_9*dmats2[9][23] + coeff0_10*dmats2[10][23] + coeff0_11*dmats2[11][23] + coeff0_12*dmats2[12][23] + coeff0_13*dmats2[13][23] + coeff0_14*dmats2[14][23] + coeff0_15*dmats2[15][23] + coeff0_16*dmats2[16][23] + coeff0_17*dmats2[17][23] + coeff0_18*dmats2[18][23] + coeff0_19*dmats2[19][23] + coeff0_20*dmats2[20][23] + coeff0_21*dmats2[21][23] + coeff0_22*dmats2[22][23] + coeff0_23*dmats2[23][23] + coeff0_24*dmats2[24][23] + coeff0_25*dmats2[25][23] + coeff0_26*dmats2[26][23] + coeff0_27*dmats2[27][23] + coeff0_28*dmats2[28][23] + coeff0_29*dmats2[29][23] + coeff0_30*dmats2[30][23] + coeff0_31*dmats2[31][23] + coeff0_32*dmats2[32][23] + coeff0_33*dmats2[33][23] + coeff0_34*dmats2[34][23] + coeff0_35*dmats2[35][23] + coeff0_36*dmats2[36][23] + coeff0_37*dmats2[37][23] + coeff0_38*dmats2[38][23] + coeff0_39*dmats2[39][23] + coeff0_40*dmats2[40][23] + coeff0_41*dmats2[41][23] + coeff0_42*dmats2[42][23] + coeff0_43*dmats2[43][23] + coeff0_44*dmats2[44][23] + coeff0_45*dmats2[45][23] + coeff0_46*dmats2[46][23] + coeff0_47*dmats2[47][23] + coeff0_48*dmats2[48][23] + coeff0_49*dmats2[49][23] + coeff0_50*dmats2[50][23] + coeff0_51*dmats2[51][23] + coeff0_52*dmats2[52][23] + coeff0_53*dmats2[53][23] + coeff0_54*dmats2[54][23] + coeff0_55*dmats2[55][23];
          new_coeff0_24 = coeff0_0*dmats2[0][24] + coeff0_1*dmats2[1][24] + coeff0_2*dmats2[2][24] + coeff0_3*dmats2[3][24] + coeff0_4*dmats2[4][24] + coeff0_5*dmats2[5][24] + coeff0_6*dmats2[6][24] + coeff0_7*dmats2[7][24] + coeff0_8*dmats2[8][24] + coeff0_9*dmats2[9][24] + coeff0_10*dmats2[10][24] + coeff0_11*dmats2[11][24] + coeff0_12*dmats2[12][24] + coeff0_13*dmats2[13][24] + coeff0_14*dmats2[14][24] + coeff0_15*dmats2[15][24] + coeff0_16*dmats2[16][24] + coeff0_17*dmats2[17][24] + coeff0_18*dmats2[18][24] + coeff0_19*dmats2[19][24] + coeff0_20*dmats2[20][24] + coeff0_21*dmats2[21][24] + coeff0_22*dmats2[22][24] + coeff0_23*dmats2[23][24] + coeff0_24*dmats2[24][24] + coeff0_25*dmats2[25][24] + coeff0_26*dmats2[26][24] + coeff0_27*dmats2[27][24] + coeff0_28*dmats2[28][24] + coeff0_29*dmats2[29][24] + coeff0_30*dmats2[30][24] + coeff0_31*dmats2[31][24] + coeff0_32*dmats2[32][24] + coeff0_33*dmats2[33][24] + coeff0_34*dmats2[34][24] + coeff0_35*dmats2[35][24] + coeff0_36*dmats2[36][24] + coeff0_37*dmats2[37][24] + coeff0_38*dmats2[38][24] + coeff0_39*dmats2[39][24] + coeff0_40*dmats2[40][24] + coeff0_41*dmats2[41][24] + coeff0_42*dmats2[42][24] + coeff0_43*dmats2[43][24] + coeff0_44*dmats2[44][24] + coeff0_45*dmats2[45][24] + coeff0_46*dmats2[46][24] + coeff0_47*dmats2[47][24] + coeff0_48*dmats2[48][24] + coeff0_49*dmats2[49][24] + coeff0_50*dmats2[50][24] + coeff0_51*dmats2[51][24] + coeff0_52*dmats2[52][24] + coeff0_53*dmats2[53][24] + coeff0_54*dmats2[54][24] + coeff0_55*dmats2[55][24];
          new_coeff0_25 = coeff0_0*dmats2[0][25] + coeff0_1*dmats2[1][25] + coeff0_2*dmats2[2][25] + coeff0_3*dmats2[3][25] + coeff0_4*dmats2[4][25] + coeff0_5*dmats2[5][25] + coeff0_6*dmats2[6][25] + coeff0_7*dmats2[7][25] + coeff0_8*dmats2[8][25] + coeff0_9*dmats2[9][25] + coeff0_10*dmats2[10][25] + coeff0_11*dmats2[11][25] + coeff0_12*dmats2[12][25] + coeff0_13*dmats2[13][25] + coeff0_14*dmats2[14][25] + coeff0_15*dmats2[15][25] + coeff0_16*dmats2[16][25] + coeff0_17*dmats2[17][25] + coeff0_18*dmats2[18][25] + coeff0_19*dmats2[19][25] + coeff0_20*dmats2[20][25] + coeff0_21*dmats2[21][25] + coeff0_22*dmats2[22][25] + coeff0_23*dmats2[23][25] + coeff0_24*dmats2[24][25] + coeff0_25*dmats2[25][25] + coeff0_26*dmats2[26][25] + coeff0_27*dmats2[27][25] + coeff0_28*dmats2[28][25] + coeff0_29*dmats2[29][25] + coeff0_30*dmats2[30][25] + coeff0_31*dmats2[31][25] + coeff0_32*dmats2[32][25] + coeff0_33*dmats2[33][25] + coeff0_34*dmats2[34][25] + coeff0_35*dmats2[35][25] + coeff0_36*dmats2[36][25] + coeff0_37*dmats2[37][25] + coeff0_38*dmats2[38][25] + coeff0_39*dmats2[39][25] + coeff0_40*dmats2[40][25] + coeff0_41*dmats2[41][25] + coeff0_42*dmats2[42][25] + coeff0_43*dmats2[43][25] + coeff0_44*dmats2[44][25] + coeff0_45*dmats2[45][25] + coeff0_46*dmats2[46][25] + coeff0_47*dmats2[47][25] + coeff0_48*dmats2[48][25] + coeff0_49*dmats2[49][25] + coeff0_50*dmats2[50][25] + coeff0_51*dmats2[51][25] + coeff0_52*dmats2[52][25] + coeff0_53*dmats2[53][25] + coeff0_54*dmats2[54][25] + coeff0_55*dmats2[55][25];
          new_coeff0_26 = coeff0_0*dmats2[0][26] + coeff0_1*dmats2[1][26] + coeff0_2*dmats2[2][26] + coeff0_3*dmats2[3][26] + coeff0_4*dmats2[4][26] + coeff0_5*dmats2[5][26] + coeff0_6*dmats2[6][26] + coeff0_7*dmats2[7][26] + coeff0_8*dmats2[8][26] + coeff0_9*dmats2[9][26] + coeff0_10*dmats2[10][26] + coeff0_11*dmats2[11][26] + coeff0_12*dmats2[12][26] + coeff0_13*dmats2[13][26] + coeff0_14*dmats2[14][26] + coeff0_15*dmats2[15][26] + coeff0_16*dmats2[16][26] + coeff0_17*dmats2[17][26] + coeff0_18*dmats2[18][26] + coeff0_19*dmats2[19][26] + coeff0_20*dmats2[20][26] + coeff0_21*dmats2[21][26] + coeff0_22*dmats2[22][26] + coeff0_23*dmats2[23][26] + coeff0_24*dmats2[24][26] + coeff0_25*dmats2[25][26] + coeff0_26*dmats2[26][26] + coeff0_27*dmats2[27][26] + coeff0_28*dmats2[28][26] + coeff0_29*dmats2[29][26] + coeff0_30*dmats2[30][26] + coeff0_31*dmats2[31][26] + coeff0_32*dmats2[32][26] + coeff0_33*dmats2[33][26] + coeff0_34*dmats2[34][26] + coeff0_35*dmats2[35][26] + coeff0_36*dmats2[36][26] + coeff0_37*dmats2[37][26] + coeff0_38*dmats2[38][26] + coeff0_39*dmats2[39][26] + coeff0_40*dmats2[40][26] + coeff0_41*dmats2[41][26] + coeff0_42*dmats2[42][26] + coeff0_43*dmats2[43][26] + coeff0_44*dmats2[44][26] + coeff0_45*dmats2[45][26] + coeff0_46*dmats2[46][26] + coeff0_47*dmats2[47][26] + coeff0_48*dmats2[48][26] + coeff0_49*dmats2[49][26] + coeff0_50*dmats2[50][26] + coeff0_51*dmats2[51][26] + coeff0_52*dmats2[52][26] + coeff0_53*dmats2[53][26] + coeff0_54*dmats2[54][26] + coeff0_55*dmats2[55][26];
          new_coeff0_27 = coeff0_0*dmats2[0][27] + coeff0_1*dmats2[1][27] + coeff0_2*dmats2[2][27] + coeff0_3*dmats2[3][27] + coeff0_4*dmats2[4][27] + coeff0_5*dmats2[5][27] + coeff0_6*dmats2[6][27] + coeff0_7*dmats2[7][27] + coeff0_8*dmats2[8][27] + coeff0_9*dmats2[9][27] + coeff0_10*dmats2[10][27] + coeff0_11*dmats2[11][27] + coeff0_12*dmats2[12][27] + coeff0_13*dmats2[13][27] + coeff0_14*dmats2[14][27] + coeff0_15*dmats2[15][27] + coeff0_16*dmats2[16][27] + coeff0_17*dmats2[17][27] + coeff0_18*dmats2[18][27] + coeff0_19*dmats2[19][27] + coeff0_20*dmats2[20][27] + coeff0_21*dmats2[21][27] + coeff0_22*dmats2[22][27] + coeff0_23*dmats2[23][27] + coeff0_24*dmats2[24][27] + coeff0_25*dmats2[25][27] + coeff0_26*dmats2[26][27] + coeff0_27*dmats2[27][27] + coeff0_28*dmats2[28][27] + coeff0_29*dmats2[29][27] + coeff0_30*dmats2[30][27] + coeff0_31*dmats2[31][27] + coeff0_32*dmats2[32][27] + coeff0_33*dmats2[33][27] + coeff0_34*dmats2[34][27] + coeff0_35*dmats2[35][27] + coeff0_36*dmats2[36][27] + coeff0_37*dmats2[37][27] + coeff0_38*dmats2[38][27] + coeff0_39*dmats2[39][27] + coeff0_40*dmats2[40][27] + coeff0_41*dmats2[41][27] + coeff0_42*dmats2[42][27] + coeff0_43*dmats2[43][27] + coeff0_44*dmats2[44][27] + coeff0_45*dmats2[45][27] + coeff0_46*dmats2[46][27] + coeff0_47*dmats2[47][27] + coeff0_48*dmats2[48][27] + coeff0_49*dmats2[49][27] + coeff0_50*dmats2[50][27] + coeff0_51*dmats2[51][27] + coeff0_52*dmats2[52][27] + coeff0_53*dmats2[53][27] + coeff0_54*dmats2[54][27] + coeff0_55*dmats2[55][27];
          new_coeff0_28 = coeff0_0*dmats2[0][28] + coeff0_1*dmats2[1][28] + coeff0_2*dmats2[2][28] + coeff0_3*dmats2[3][28] + coeff0_4*dmats2[4][28] + coeff0_5*dmats2[5][28] + coeff0_6*dmats2[6][28] + coeff0_7*dmats2[7][28] + coeff0_8*dmats2[8][28] + coeff0_9*dmats2[9][28] + coeff0_10*dmats2[10][28] + coeff0_11*dmats2[11][28] + coeff0_12*dmats2[12][28] + coeff0_13*dmats2[13][28] + coeff0_14*dmats2[14][28] + coeff0_15*dmats2[15][28] + coeff0_16*dmats2[16][28] + coeff0_17*dmats2[17][28] + coeff0_18*dmats2[18][28] + coeff0_19*dmats2[19][28] + coeff0_20*dmats2[20][28] + coeff0_21*dmats2[21][28] + coeff0_22*dmats2[22][28] + coeff0_23*dmats2[23][28] + coeff0_24*dmats2[24][28] + coeff0_25*dmats2[25][28] + coeff0_26*dmats2[26][28] + coeff0_27*dmats2[27][28] + coeff0_28*dmats2[28][28] + coeff0_29*dmats2[29][28] + coeff0_30*dmats2[30][28] + coeff0_31*dmats2[31][28] + coeff0_32*dmats2[32][28] + coeff0_33*dmats2[33][28] + coeff0_34*dmats2[34][28] + coeff0_35*dmats2[35][28] + coeff0_36*dmats2[36][28] + coeff0_37*dmats2[37][28] + coeff0_38*dmats2[38][28] + coeff0_39*dmats2[39][28] + coeff0_40*dmats2[40][28] + coeff0_41*dmats2[41][28] + coeff0_42*dmats2[42][28] + coeff0_43*dmats2[43][28] + coeff0_44*dmats2[44][28] + coeff0_45*dmats2[45][28] + coeff0_46*dmats2[46][28] + coeff0_47*dmats2[47][28] + coeff0_48*dmats2[48][28] + coeff0_49*dmats2[49][28] + coeff0_50*dmats2[50][28] + coeff0_51*dmats2[51][28] + coeff0_52*dmats2[52][28] + coeff0_53*dmats2[53][28] + coeff0_54*dmats2[54][28] + coeff0_55*dmats2[55][28];
          new_coeff0_29 = coeff0_0*dmats2[0][29] + coeff0_1*dmats2[1][29] + coeff0_2*dmats2[2][29] + coeff0_3*dmats2[3][29] + coeff0_4*dmats2[4][29] + coeff0_5*dmats2[5][29] + coeff0_6*dmats2[6][29] + coeff0_7*dmats2[7][29] + coeff0_8*dmats2[8][29] + coeff0_9*dmats2[9][29] + coeff0_10*dmats2[10][29] + coeff0_11*dmats2[11][29] + coeff0_12*dmats2[12][29] + coeff0_13*dmats2[13][29] + coeff0_14*dmats2[14][29] + coeff0_15*dmats2[15][29] + coeff0_16*dmats2[16][29] + coeff0_17*dmats2[17][29] + coeff0_18*dmats2[18][29] + coeff0_19*dmats2[19][29] + coeff0_20*dmats2[20][29] + coeff0_21*dmats2[21][29] + coeff0_22*dmats2[22][29] + coeff0_23*dmats2[23][29] + coeff0_24*dmats2[24][29] + coeff0_25*dmats2[25][29] + coeff0_26*dmats2[26][29] + coeff0_27*dmats2[27][29] + coeff0_28*dmats2[28][29] + coeff0_29*dmats2[29][29] + coeff0_30*dmats2[30][29] + coeff0_31*dmats2[31][29] + coeff0_32*dmats2[32][29] + coeff0_33*dmats2[33][29] + coeff0_34*dmats2[34][29] + coeff0_35*dmats2[35][29] + coeff0_36*dmats2[36][29] + coeff0_37*dmats2[37][29] + coeff0_38*dmats2[38][29] + coeff0_39*dmats2[39][29] + coeff0_40*dmats2[40][29] + coeff0_41*dmats2[41][29] + coeff0_42*dmats2[42][29] + coeff0_43*dmats2[43][29] + coeff0_44*dmats2[44][29] + coeff0_45*dmats2[45][29] + coeff0_46*dmats2[46][29] + coeff0_47*dmats2[47][29] + coeff0_48*dmats2[48][29] + coeff0_49*dmats2[49][29] + coeff0_50*dmats2[50][29] + coeff0_51*dmats2[51][29] + coeff0_52*dmats2[52][29] + coeff0_53*dmats2[53][29] + coeff0_54*dmats2[54][29] + coeff0_55*dmats2[55][29];
          new_coeff0_30 = coeff0_0*dmats2[0][30] + coeff0_1*dmats2[1][30] + coeff0_2*dmats2[2][30] + coeff0_3*dmats2[3][30] + coeff0_4*dmats2[4][30] + coeff0_5*dmats2[5][30] + coeff0_6*dmats2[6][30] + coeff0_7*dmats2[7][30] + coeff0_8*dmats2[8][30] + coeff0_9*dmats2[9][30] + coeff0_10*dmats2[10][30] + coeff0_11*dmats2[11][30] + coeff0_12*dmats2[12][30] + coeff0_13*dmats2[13][30] + coeff0_14*dmats2[14][30] + coeff0_15*dmats2[15][30] + coeff0_16*dmats2[16][30] + coeff0_17*dmats2[17][30] + coeff0_18*dmats2[18][30] + coeff0_19*dmats2[19][30] + coeff0_20*dmats2[20][30] + coeff0_21*dmats2[21][30] + coeff0_22*dmats2[22][30] + coeff0_23*dmats2[23][30] + coeff0_24*dmats2[24][30] + coeff0_25*dmats2[25][30] + coeff0_26*dmats2[26][30] + coeff0_27*dmats2[27][30] + coeff0_28*dmats2[28][30] + coeff0_29*dmats2[29][30] + coeff0_30*dmats2[30][30] + coeff0_31*dmats2[31][30] + coeff0_32*dmats2[32][30] + coeff0_33*dmats2[33][30] + coeff0_34*dmats2[34][30] + coeff0_35*dmats2[35][30] + coeff0_36*dmats2[36][30] + coeff0_37*dmats2[37][30] + coeff0_38*dmats2[38][30] + coeff0_39*dmats2[39][30] + coeff0_40*dmats2[40][30] + coeff0_41*dmats2[41][30] + coeff0_42*dmats2[42][30] + coeff0_43*dmats2[43][30] + coeff0_44*dmats2[44][30] + coeff0_45*dmats2[45][30] + coeff0_46*dmats2[46][30] + coeff0_47*dmats2[47][30] + coeff0_48*dmats2[48][30] + coeff0_49*dmats2[49][30] + coeff0_50*dmats2[50][30] + coeff0_51*dmats2[51][30] + coeff0_52*dmats2[52][30] + coeff0_53*dmats2[53][30] + coeff0_54*dmats2[54][30] + coeff0_55*dmats2[55][30];
          new_coeff0_31 = coeff0_0*dmats2[0][31] + coeff0_1*dmats2[1][31] + coeff0_2*dmats2[2][31] + coeff0_3*dmats2[3][31] + coeff0_4*dmats2[4][31] + coeff0_5*dmats2[5][31] + coeff0_6*dmats2[6][31] + coeff0_7*dmats2[7][31] + coeff0_8*dmats2[8][31] + coeff0_9*dmats2[9][31] + coeff0_10*dmats2[10][31] + coeff0_11*dmats2[11][31] + coeff0_12*dmats2[12][31] + coeff0_13*dmats2[13][31] + coeff0_14*dmats2[14][31] + coeff0_15*dmats2[15][31] + coeff0_16*dmats2[16][31] + coeff0_17*dmats2[17][31] + coeff0_18*dmats2[18][31] + coeff0_19*dmats2[19][31] + coeff0_20*dmats2[20][31] + coeff0_21*dmats2[21][31] + coeff0_22*dmats2[22][31] + coeff0_23*dmats2[23][31] + coeff0_24*dmats2[24][31] + coeff0_25*dmats2[25][31] + coeff0_26*dmats2[26][31] + coeff0_27*dmats2[27][31] + coeff0_28*dmats2[28][31] + coeff0_29*dmats2[29][31] + coeff0_30*dmats2[30][31] + coeff0_31*dmats2[31][31] + coeff0_32*dmats2[32][31] + coeff0_33*dmats2[33][31] + coeff0_34*dmats2[34][31] + coeff0_35*dmats2[35][31] + coeff0_36*dmats2[36][31] + coeff0_37*dmats2[37][31] + coeff0_38*dmats2[38][31] + coeff0_39*dmats2[39][31] + coeff0_40*dmats2[40][31] + coeff0_41*dmats2[41][31] + coeff0_42*dmats2[42][31] + coeff0_43*dmats2[43][31] + coeff0_44*dmats2[44][31] + coeff0_45*dmats2[45][31] + coeff0_46*dmats2[46][31] + coeff0_47*dmats2[47][31] + coeff0_48*dmats2[48][31] + coeff0_49*dmats2[49][31] + coeff0_50*dmats2[50][31] + coeff0_51*dmats2[51][31] + coeff0_52*dmats2[52][31] + coeff0_53*dmats2[53][31] + coeff0_54*dmats2[54][31] + coeff0_55*dmats2[55][31];
          new_coeff0_32 = coeff0_0*dmats2[0][32] + coeff0_1*dmats2[1][32] + coeff0_2*dmats2[2][32] + coeff0_3*dmats2[3][32] + coeff0_4*dmats2[4][32] + coeff0_5*dmats2[5][32] + coeff0_6*dmats2[6][32] + coeff0_7*dmats2[7][32] + coeff0_8*dmats2[8][32] + coeff0_9*dmats2[9][32] + coeff0_10*dmats2[10][32] + coeff0_11*dmats2[11][32] + coeff0_12*dmats2[12][32] + coeff0_13*dmats2[13][32] + coeff0_14*dmats2[14][32] + coeff0_15*dmats2[15][32] + coeff0_16*dmats2[16][32] + coeff0_17*dmats2[17][32] + coeff0_18*dmats2[18][32] + coeff0_19*dmats2[19][32] + coeff0_20*dmats2[20][32] + coeff0_21*dmats2[21][32] + coeff0_22*dmats2[22][32] + coeff0_23*dmats2[23][32] + coeff0_24*dmats2[24][32] + coeff0_25*dmats2[25][32] + coeff0_26*dmats2[26][32] + coeff0_27*dmats2[27][32] + coeff0_28*dmats2[28][32] + coeff0_29*dmats2[29][32] + coeff0_30*dmats2[30][32] + coeff0_31*dmats2[31][32] + coeff0_32*dmats2[32][32] + coeff0_33*dmats2[33][32] + coeff0_34*dmats2[34][32] + coeff0_35*dmats2[35][32] + coeff0_36*dmats2[36][32] + coeff0_37*dmats2[37][32] + coeff0_38*dmats2[38][32] + coeff0_39*dmats2[39][32] + coeff0_40*dmats2[40][32] + coeff0_41*dmats2[41][32] + coeff0_42*dmats2[42][32] + coeff0_43*dmats2[43][32] + coeff0_44*dmats2[44][32] + coeff0_45*dmats2[45][32] + coeff0_46*dmats2[46][32] + coeff0_47*dmats2[47][32] + coeff0_48*dmats2[48][32] + coeff0_49*dmats2[49][32] + coeff0_50*dmats2[50][32] + coeff0_51*dmats2[51][32] + coeff0_52*dmats2[52][32] + coeff0_53*dmats2[53][32] + coeff0_54*dmats2[54][32] + coeff0_55*dmats2[55][32];
          new_coeff0_33 = coeff0_0*dmats2[0][33] + coeff0_1*dmats2[1][33] + coeff0_2*dmats2[2][33] + coeff0_3*dmats2[3][33] + coeff0_4*dmats2[4][33] + coeff0_5*dmats2[5][33] + coeff0_6*dmats2[6][33] + coeff0_7*dmats2[7][33] + coeff0_8*dmats2[8][33] + coeff0_9*dmats2[9][33] + coeff0_10*dmats2[10][33] + coeff0_11*dmats2[11][33] + coeff0_12*dmats2[12][33] + coeff0_13*dmats2[13][33] + coeff0_14*dmats2[14][33] + coeff0_15*dmats2[15][33] + coeff0_16*dmats2[16][33] + coeff0_17*dmats2[17][33] + coeff0_18*dmats2[18][33] + coeff0_19*dmats2[19][33] + coeff0_20*dmats2[20][33] + coeff0_21*dmats2[21][33] + coeff0_22*dmats2[22][33] + coeff0_23*dmats2[23][33] + coeff0_24*dmats2[24][33] + coeff0_25*dmats2[25][33] + coeff0_26*dmats2[26][33] + coeff0_27*dmats2[27][33] + coeff0_28*dmats2[28][33] + coeff0_29*dmats2[29][33] + coeff0_30*dmats2[30][33] + coeff0_31*dmats2[31][33] + coeff0_32*dmats2[32][33] + coeff0_33*dmats2[33][33] + coeff0_34*dmats2[34][33] + coeff0_35*dmats2[35][33] + coeff0_36*dmats2[36][33] + coeff0_37*dmats2[37][33] + coeff0_38*dmats2[38][33] + coeff0_39*dmats2[39][33] + coeff0_40*dmats2[40][33] + coeff0_41*dmats2[41][33] + coeff0_42*dmats2[42][33] + coeff0_43*dmats2[43][33] + coeff0_44*dmats2[44][33] + coeff0_45*dmats2[45][33] + coeff0_46*dmats2[46][33] + coeff0_47*dmats2[47][33] + coeff0_48*dmats2[48][33] + coeff0_49*dmats2[49][33] + coeff0_50*dmats2[50][33] + coeff0_51*dmats2[51][33] + coeff0_52*dmats2[52][33] + coeff0_53*dmats2[53][33] + coeff0_54*dmats2[54][33] + coeff0_55*dmats2[55][33];
          new_coeff0_34 = coeff0_0*dmats2[0][34] + coeff0_1*dmats2[1][34] + coeff0_2*dmats2[2][34] + coeff0_3*dmats2[3][34] + coeff0_4*dmats2[4][34] + coeff0_5*dmats2[5][34] + coeff0_6*dmats2[6][34] + coeff0_7*dmats2[7][34] + coeff0_8*dmats2[8][34] + coeff0_9*dmats2[9][34] + coeff0_10*dmats2[10][34] + coeff0_11*dmats2[11][34] + coeff0_12*dmats2[12][34] + coeff0_13*dmats2[13][34] + coeff0_14*dmats2[14][34] + coeff0_15*dmats2[15][34] + coeff0_16*dmats2[16][34] + coeff0_17*dmats2[17][34] + coeff0_18*dmats2[18][34] + coeff0_19*dmats2[19][34] + coeff0_20*dmats2[20][34] + coeff0_21*dmats2[21][34] + coeff0_22*dmats2[22][34] + coeff0_23*dmats2[23][34] + coeff0_24*dmats2[24][34] + coeff0_25*dmats2[25][34] + coeff0_26*dmats2[26][34] + coeff0_27*dmats2[27][34] + coeff0_28*dmats2[28][34] + coeff0_29*dmats2[29][34] + coeff0_30*dmats2[30][34] + coeff0_31*dmats2[31][34] + coeff0_32*dmats2[32][34] + coeff0_33*dmats2[33][34] + coeff0_34*dmats2[34][34] + coeff0_35*dmats2[35][34] + coeff0_36*dmats2[36][34] + coeff0_37*dmats2[37][34] + coeff0_38*dmats2[38][34] + coeff0_39*dmats2[39][34] + coeff0_40*dmats2[40][34] + coeff0_41*dmats2[41][34] + coeff0_42*dmats2[42][34] + coeff0_43*dmats2[43][34] + coeff0_44*dmats2[44][34] + coeff0_45*dmats2[45][34] + coeff0_46*dmats2[46][34] + coeff0_47*dmats2[47][34] + coeff0_48*dmats2[48][34] + coeff0_49*dmats2[49][34] + coeff0_50*dmats2[50][34] + coeff0_51*dmats2[51][34] + coeff0_52*dmats2[52][34] + coeff0_53*dmats2[53][34] + coeff0_54*dmats2[54][34] + coeff0_55*dmats2[55][34];
          new_coeff0_35 = coeff0_0*dmats2[0][35] + coeff0_1*dmats2[1][35] + coeff0_2*dmats2[2][35] + coeff0_3*dmats2[3][35] + coeff0_4*dmats2[4][35] + coeff0_5*dmats2[5][35] + coeff0_6*dmats2[6][35] + coeff0_7*dmats2[7][35] + coeff0_8*dmats2[8][35] + coeff0_9*dmats2[9][35] + coeff0_10*dmats2[10][35] + coeff0_11*dmats2[11][35] + coeff0_12*dmats2[12][35] + coeff0_13*dmats2[13][35] + coeff0_14*dmats2[14][35] + coeff0_15*dmats2[15][35] + coeff0_16*dmats2[16][35] + coeff0_17*dmats2[17][35] + coeff0_18*dmats2[18][35] + coeff0_19*dmats2[19][35] + coeff0_20*dmats2[20][35] + coeff0_21*dmats2[21][35] + coeff0_22*dmats2[22][35] + coeff0_23*dmats2[23][35] + coeff0_24*dmats2[24][35] + coeff0_25*dmats2[25][35] + coeff0_26*dmats2[26][35] + coeff0_27*dmats2[27][35] + coeff0_28*dmats2[28][35] + coeff0_29*dmats2[29][35] + coeff0_30*dmats2[30][35] + coeff0_31*dmats2[31][35] + coeff0_32*dmats2[32][35] + coeff0_33*dmats2[33][35] + coeff0_34*dmats2[34][35] + coeff0_35*dmats2[35][35] + coeff0_36*dmats2[36][35] + coeff0_37*dmats2[37][35] + coeff0_38*dmats2[38][35] + coeff0_39*dmats2[39][35] + coeff0_40*dmats2[40][35] + coeff0_41*dmats2[41][35] + coeff0_42*dmats2[42][35] + coeff0_43*dmats2[43][35] + coeff0_44*dmats2[44][35] + coeff0_45*dmats2[45][35] + coeff0_46*dmats2[46][35] + coeff0_47*dmats2[47][35] + coeff0_48*dmats2[48][35] + coeff0_49*dmats2[49][35] + coeff0_50*dmats2[50][35] + coeff0_51*dmats2[51][35] + coeff0_52*dmats2[52][35] + coeff0_53*dmats2[53][35] + coeff0_54*dmats2[54][35] + coeff0_55*dmats2[55][35];
          new_coeff0_36 = coeff0_0*dmats2[0][36] + coeff0_1*dmats2[1][36] + coeff0_2*dmats2[2][36] + coeff0_3*dmats2[3][36] + coeff0_4*dmats2[4][36] + coeff0_5*dmats2[5][36] + coeff0_6*dmats2[6][36] + coeff0_7*dmats2[7][36] + coeff0_8*dmats2[8][36] + coeff0_9*dmats2[9][36] + coeff0_10*dmats2[10][36] + coeff0_11*dmats2[11][36] + coeff0_12*dmats2[12][36] + coeff0_13*dmats2[13][36] + coeff0_14*dmats2[14][36] + coeff0_15*dmats2[15][36] + coeff0_16*dmats2[16][36] + coeff0_17*dmats2[17][36] + coeff0_18*dmats2[18][36] + coeff0_19*dmats2[19][36] + coeff0_20*dmats2[20][36] + coeff0_21*dmats2[21][36] + coeff0_22*dmats2[22][36] + coeff0_23*dmats2[23][36] + coeff0_24*dmats2[24][36] + coeff0_25*dmats2[25][36] + coeff0_26*dmats2[26][36] + coeff0_27*dmats2[27][36] + coeff0_28*dmats2[28][36] + coeff0_29*dmats2[29][36] + coeff0_30*dmats2[30][36] + coeff0_31*dmats2[31][36] + coeff0_32*dmats2[32][36] + coeff0_33*dmats2[33][36] + coeff0_34*dmats2[34][36] + coeff0_35*dmats2[35][36] + coeff0_36*dmats2[36][36] + coeff0_37*dmats2[37][36] + coeff0_38*dmats2[38][36] + coeff0_39*dmats2[39][36] + coeff0_40*dmats2[40][36] + coeff0_41*dmats2[41][36] + coeff0_42*dmats2[42][36] + coeff0_43*dmats2[43][36] + coeff0_44*dmats2[44][36] + coeff0_45*dmats2[45][36] + coeff0_46*dmats2[46][36] + coeff0_47*dmats2[47][36] + coeff0_48*dmats2[48][36] + coeff0_49*dmats2[49][36] + coeff0_50*dmats2[50][36] + coeff0_51*dmats2[51][36] + coeff0_52*dmats2[52][36] + coeff0_53*dmats2[53][36] + coeff0_54*dmats2[54][36] + coeff0_55*dmats2[55][36];
          new_coeff0_37 = coeff0_0*dmats2[0][37] + coeff0_1*dmats2[1][37] + coeff0_2*dmats2[2][37] + coeff0_3*dmats2[3][37] + coeff0_4*dmats2[4][37] + coeff0_5*dmats2[5][37] + coeff0_6*dmats2[6][37] + coeff0_7*dmats2[7][37] + coeff0_8*dmats2[8][37] + coeff0_9*dmats2[9][37] + coeff0_10*dmats2[10][37] + coeff0_11*dmats2[11][37] + coeff0_12*dmats2[12][37] + coeff0_13*dmats2[13][37] + coeff0_14*dmats2[14][37] + coeff0_15*dmats2[15][37] + coeff0_16*dmats2[16][37] + coeff0_17*dmats2[17][37] + coeff0_18*dmats2[18][37] + coeff0_19*dmats2[19][37] + coeff0_20*dmats2[20][37] + coeff0_21*dmats2[21][37] + coeff0_22*dmats2[22][37] + coeff0_23*dmats2[23][37] + coeff0_24*dmats2[24][37] + coeff0_25*dmats2[25][37] + coeff0_26*dmats2[26][37] + coeff0_27*dmats2[27][37] + coeff0_28*dmats2[28][37] + coeff0_29*dmats2[29][37] + coeff0_30*dmats2[30][37] + coeff0_31*dmats2[31][37] + coeff0_32*dmats2[32][37] + coeff0_33*dmats2[33][37] + coeff0_34*dmats2[34][37] + coeff0_35*dmats2[35][37] + coeff0_36*dmats2[36][37] + coeff0_37*dmats2[37][37] + coeff0_38*dmats2[38][37] + coeff0_39*dmats2[39][37] + coeff0_40*dmats2[40][37] + coeff0_41*dmats2[41][37] + coeff0_42*dmats2[42][37] + coeff0_43*dmats2[43][37] + coeff0_44*dmats2[44][37] + coeff0_45*dmats2[45][37] + coeff0_46*dmats2[46][37] + coeff0_47*dmats2[47][37] + coeff0_48*dmats2[48][37] + coeff0_49*dmats2[49][37] + coeff0_50*dmats2[50][37] + coeff0_51*dmats2[51][37] + coeff0_52*dmats2[52][37] + coeff0_53*dmats2[53][37] + coeff0_54*dmats2[54][37] + coeff0_55*dmats2[55][37];
          new_coeff0_38 = coeff0_0*dmats2[0][38] + coeff0_1*dmats2[1][38] + coeff0_2*dmats2[2][38] + coeff0_3*dmats2[3][38] + coeff0_4*dmats2[4][38] + coeff0_5*dmats2[5][38] + coeff0_6*dmats2[6][38] + coeff0_7*dmats2[7][38] + coeff0_8*dmats2[8][38] + coeff0_9*dmats2[9][38] + coeff0_10*dmats2[10][38] + coeff0_11*dmats2[11][38] + coeff0_12*dmats2[12][38] + coeff0_13*dmats2[13][38] + coeff0_14*dmats2[14][38] + coeff0_15*dmats2[15][38] + coeff0_16*dmats2[16][38] + coeff0_17*dmats2[17][38] + coeff0_18*dmats2[18][38] + coeff0_19*dmats2[19][38] + coeff0_20*dmats2[20][38] + coeff0_21*dmats2[21][38] + coeff0_22*dmats2[22][38] + coeff0_23*dmats2[23][38] + coeff0_24*dmats2[24][38] + coeff0_25*dmats2[25][38] + coeff0_26*dmats2[26][38] + coeff0_27*dmats2[27][38] + coeff0_28*dmats2[28][38] + coeff0_29*dmats2[29][38] + coeff0_30*dmats2[30][38] + coeff0_31*dmats2[31][38] + coeff0_32*dmats2[32][38] + coeff0_33*dmats2[33][38] + coeff0_34*dmats2[34][38] + coeff0_35*dmats2[35][38] + coeff0_36*dmats2[36][38] + coeff0_37*dmats2[37][38] + coeff0_38*dmats2[38][38] + coeff0_39*dmats2[39][38] + coeff0_40*dmats2[40][38] + coeff0_41*dmats2[41][38] + coeff0_42*dmats2[42][38] + coeff0_43*dmats2[43][38] + coeff0_44*dmats2[44][38] + coeff0_45*dmats2[45][38] + coeff0_46*dmats2[46][38] + coeff0_47*dmats2[47][38] + coeff0_48*dmats2[48][38] + coeff0_49*dmats2[49][38] + coeff0_50*dmats2[50][38] + coeff0_51*dmats2[51][38] + coeff0_52*dmats2[52][38] + coeff0_53*dmats2[53][38] + coeff0_54*dmats2[54][38] + coeff0_55*dmats2[55][38];
          new_coeff0_39 = coeff0_0*dmats2[0][39] + coeff0_1*dmats2[1][39] + coeff0_2*dmats2[2][39] + coeff0_3*dmats2[3][39] + coeff0_4*dmats2[4][39] + coeff0_5*dmats2[5][39] + coeff0_6*dmats2[6][39] + coeff0_7*dmats2[7][39] + coeff0_8*dmats2[8][39] + coeff0_9*dmats2[9][39] + coeff0_10*dmats2[10][39] + coeff0_11*dmats2[11][39] + coeff0_12*dmats2[12][39] + coeff0_13*dmats2[13][39] + coeff0_14*dmats2[14][39] + coeff0_15*dmats2[15][39] + coeff0_16*dmats2[16][39] + coeff0_17*dmats2[17][39] + coeff0_18*dmats2[18][39] + coeff0_19*dmats2[19][39] + coeff0_20*dmats2[20][39] + coeff0_21*dmats2[21][39] + coeff0_22*dmats2[22][39] + coeff0_23*dmats2[23][39] + coeff0_24*dmats2[24][39] + coeff0_25*dmats2[25][39] + coeff0_26*dmats2[26][39] + coeff0_27*dmats2[27][39] + coeff0_28*dmats2[28][39] + coeff0_29*dmats2[29][39] + coeff0_30*dmats2[30][39] + coeff0_31*dmats2[31][39] + coeff0_32*dmats2[32][39] + coeff0_33*dmats2[33][39] + coeff0_34*dmats2[34][39] + coeff0_35*dmats2[35][39] + coeff0_36*dmats2[36][39] + coeff0_37*dmats2[37][39] + coeff0_38*dmats2[38][39] + coeff0_39*dmats2[39][39] + coeff0_40*dmats2[40][39] + coeff0_41*dmats2[41][39] + coeff0_42*dmats2[42][39] + coeff0_43*dmats2[43][39] + coeff0_44*dmats2[44][39] + coeff0_45*dmats2[45][39] + coeff0_46*dmats2[46][39] + coeff0_47*dmats2[47][39] + coeff0_48*dmats2[48][39] + coeff0_49*dmats2[49][39] + coeff0_50*dmats2[50][39] + coeff0_51*dmats2[51][39] + coeff0_52*dmats2[52][39] + coeff0_53*dmats2[53][39] + coeff0_54*dmats2[54][39] + coeff0_55*dmats2[55][39];
          new_coeff0_40 = coeff0_0*dmats2[0][40] + coeff0_1*dmats2[1][40] + coeff0_2*dmats2[2][40] + coeff0_3*dmats2[3][40] + coeff0_4*dmats2[4][40] + coeff0_5*dmats2[5][40] + coeff0_6*dmats2[6][40] + coeff0_7*dmats2[7][40] + coeff0_8*dmats2[8][40] + coeff0_9*dmats2[9][40] + coeff0_10*dmats2[10][40] + coeff0_11*dmats2[11][40] + coeff0_12*dmats2[12][40] + coeff0_13*dmats2[13][40] + coeff0_14*dmats2[14][40] + coeff0_15*dmats2[15][40] + coeff0_16*dmats2[16][40] + coeff0_17*dmats2[17][40] + coeff0_18*dmats2[18][40] + coeff0_19*dmats2[19][40] + coeff0_20*dmats2[20][40] + coeff0_21*dmats2[21][40] + coeff0_22*dmats2[22][40] + coeff0_23*dmats2[23][40] + coeff0_24*dmats2[24][40] + coeff0_25*dmats2[25][40] + coeff0_26*dmats2[26][40] + coeff0_27*dmats2[27][40] + coeff0_28*dmats2[28][40] + coeff0_29*dmats2[29][40] + coeff0_30*dmats2[30][40] + coeff0_31*dmats2[31][40] + coeff0_32*dmats2[32][40] + coeff0_33*dmats2[33][40] + coeff0_34*dmats2[34][40] + coeff0_35*dmats2[35][40] + coeff0_36*dmats2[36][40] + coeff0_37*dmats2[37][40] + coeff0_38*dmats2[38][40] + coeff0_39*dmats2[39][40] + coeff0_40*dmats2[40][40] + coeff0_41*dmats2[41][40] + coeff0_42*dmats2[42][40] + coeff0_43*dmats2[43][40] + coeff0_44*dmats2[44][40] + coeff0_45*dmats2[45][40] + coeff0_46*dmats2[46][40] + coeff0_47*dmats2[47][40] + coeff0_48*dmats2[48][40] + coeff0_49*dmats2[49][40] + coeff0_50*dmats2[50][40] + coeff0_51*dmats2[51][40] + coeff0_52*dmats2[52][40] + coeff0_53*dmats2[53][40] + coeff0_54*dmats2[54][40] + coeff0_55*dmats2[55][40];
          new_coeff0_41 = coeff0_0*dmats2[0][41] + coeff0_1*dmats2[1][41] + coeff0_2*dmats2[2][41] + coeff0_3*dmats2[3][41] + coeff0_4*dmats2[4][41] + coeff0_5*dmats2[5][41] + coeff0_6*dmats2[6][41] + coeff0_7*dmats2[7][41] + coeff0_8*dmats2[8][41] + coeff0_9*dmats2[9][41] + coeff0_10*dmats2[10][41] + coeff0_11*dmats2[11][41] + coeff0_12*dmats2[12][41] + coeff0_13*dmats2[13][41] + coeff0_14*dmats2[14][41] + coeff0_15*dmats2[15][41] + coeff0_16*dmats2[16][41] + coeff0_17*dmats2[17][41] + coeff0_18*dmats2[18][41] + coeff0_19*dmats2[19][41] + coeff0_20*dmats2[20][41] + coeff0_21*dmats2[21][41] + coeff0_22*dmats2[22][41] + coeff0_23*dmats2[23][41] + coeff0_24*dmats2[24][41] + coeff0_25*dmats2[25][41] + coeff0_26*dmats2[26][41] + coeff0_27*dmats2[27][41] + coeff0_28*dmats2[28][41] + coeff0_29*dmats2[29][41] + coeff0_30*dmats2[30][41] + coeff0_31*dmats2[31][41] + coeff0_32*dmats2[32][41] + coeff0_33*dmats2[33][41] + coeff0_34*dmats2[34][41] + coeff0_35*dmats2[35][41] + coeff0_36*dmats2[36][41] + coeff0_37*dmats2[37][41] + coeff0_38*dmats2[38][41] + coeff0_39*dmats2[39][41] + coeff0_40*dmats2[40][41] + coeff0_41*dmats2[41][41] + coeff0_42*dmats2[42][41] + coeff0_43*dmats2[43][41] + coeff0_44*dmats2[44][41] + coeff0_45*dmats2[45][41] + coeff0_46*dmats2[46][41] + coeff0_47*dmats2[47][41] + coeff0_48*dmats2[48][41] + coeff0_49*dmats2[49][41] + coeff0_50*dmats2[50][41] + coeff0_51*dmats2[51][41] + coeff0_52*dmats2[52][41] + coeff0_53*dmats2[53][41] + coeff0_54*dmats2[54][41] + coeff0_55*dmats2[55][41];
          new_coeff0_42 = coeff0_0*dmats2[0][42] + coeff0_1*dmats2[1][42] + coeff0_2*dmats2[2][42] + coeff0_3*dmats2[3][42] + coeff0_4*dmats2[4][42] + coeff0_5*dmats2[5][42] + coeff0_6*dmats2[6][42] + coeff0_7*dmats2[7][42] + coeff0_8*dmats2[8][42] + coeff0_9*dmats2[9][42] + coeff0_10*dmats2[10][42] + coeff0_11*dmats2[11][42] + coeff0_12*dmats2[12][42] + coeff0_13*dmats2[13][42] + coeff0_14*dmats2[14][42] + coeff0_15*dmats2[15][42] + coeff0_16*dmats2[16][42] + coeff0_17*dmats2[17][42] + coeff0_18*dmats2[18][42] + coeff0_19*dmats2[19][42] + coeff0_20*dmats2[20][42] + coeff0_21*dmats2[21][42] + coeff0_22*dmats2[22][42] + coeff0_23*dmats2[23][42] + coeff0_24*dmats2[24][42] + coeff0_25*dmats2[25][42] + coeff0_26*dmats2[26][42] + coeff0_27*dmats2[27][42] + coeff0_28*dmats2[28][42] + coeff0_29*dmats2[29][42] + coeff0_30*dmats2[30][42] + coeff0_31*dmats2[31][42] + coeff0_32*dmats2[32][42] + coeff0_33*dmats2[33][42] + coeff0_34*dmats2[34][42] + coeff0_35*dmats2[35][42] + coeff0_36*dmats2[36][42] + coeff0_37*dmats2[37][42] + coeff0_38*dmats2[38][42] + coeff0_39*dmats2[39][42] + coeff0_40*dmats2[40][42] + coeff0_41*dmats2[41][42] + coeff0_42*dmats2[42][42] + coeff0_43*dmats2[43][42] + coeff0_44*dmats2[44][42] + coeff0_45*dmats2[45][42] + coeff0_46*dmats2[46][42] + coeff0_47*dmats2[47][42] + coeff0_48*dmats2[48][42] + coeff0_49*dmats2[49][42] + coeff0_50*dmats2[50][42] + coeff0_51*dmats2[51][42] + coeff0_52*dmats2[52][42] + coeff0_53*dmats2[53][42] + coeff0_54*dmats2[54][42] + coeff0_55*dmats2[55][42];
          new_coeff0_43 = coeff0_0*dmats2[0][43] + coeff0_1*dmats2[1][43] + coeff0_2*dmats2[2][43] + coeff0_3*dmats2[3][43] + coeff0_4*dmats2[4][43] + coeff0_5*dmats2[5][43] + coeff0_6*dmats2[6][43] + coeff0_7*dmats2[7][43] + coeff0_8*dmats2[8][43] + coeff0_9*dmats2[9][43] + coeff0_10*dmats2[10][43] + coeff0_11*dmats2[11][43] + coeff0_12*dmats2[12][43] + coeff0_13*dmats2[13][43] + coeff0_14*dmats2[14][43] + coeff0_15*dmats2[15][43] + coeff0_16*dmats2[16][43] + coeff0_17*dmats2[17][43] + coeff0_18*dmats2[18][43] + coeff0_19*dmats2[19][43] + coeff0_20*dmats2[20][43] + coeff0_21*dmats2[21][43] + coeff0_22*dmats2[22][43] + coeff0_23*dmats2[23][43] + coeff0_24*dmats2[24][43] + coeff0_25*dmats2[25][43] + coeff0_26*dmats2[26][43] + coeff0_27*dmats2[27][43] + coeff0_28*dmats2[28][43] + coeff0_29*dmats2[29][43] + coeff0_30*dmats2[30][43] + coeff0_31*dmats2[31][43] + coeff0_32*dmats2[32][43] + coeff0_33*dmats2[33][43] + coeff0_34*dmats2[34][43] + coeff0_35*dmats2[35][43] + coeff0_36*dmats2[36][43] + coeff0_37*dmats2[37][43] + coeff0_38*dmats2[38][43] + coeff0_39*dmats2[39][43] + coeff0_40*dmats2[40][43] + coeff0_41*dmats2[41][43] + coeff0_42*dmats2[42][43] + coeff0_43*dmats2[43][43] + coeff0_44*dmats2[44][43] + coeff0_45*dmats2[45][43] + coeff0_46*dmats2[46][43] + coeff0_47*dmats2[47][43] + coeff0_48*dmats2[48][43] + coeff0_49*dmats2[49][43] + coeff0_50*dmats2[50][43] + coeff0_51*dmats2[51][43] + coeff0_52*dmats2[52][43] + coeff0_53*dmats2[53][43] + coeff0_54*dmats2[54][43] + coeff0_55*dmats2[55][43];
          new_coeff0_44 = coeff0_0*dmats2[0][44] + coeff0_1*dmats2[1][44] + coeff0_2*dmats2[2][44] + coeff0_3*dmats2[3][44] + coeff0_4*dmats2[4][44] + coeff0_5*dmats2[5][44] + coeff0_6*dmats2[6][44] + coeff0_7*dmats2[7][44] + coeff0_8*dmats2[8][44] + coeff0_9*dmats2[9][44] + coeff0_10*dmats2[10][44] + coeff0_11*dmats2[11][44] + coeff0_12*dmats2[12][44] + coeff0_13*dmats2[13][44] + coeff0_14*dmats2[14][44] + coeff0_15*dmats2[15][44] + coeff0_16*dmats2[16][44] + coeff0_17*dmats2[17][44] + coeff0_18*dmats2[18][44] + coeff0_19*dmats2[19][44] + coeff0_20*dmats2[20][44] + coeff0_21*dmats2[21][44] + coeff0_22*dmats2[22][44] + coeff0_23*dmats2[23][44] + coeff0_24*dmats2[24][44] + coeff0_25*dmats2[25][44] + coeff0_26*dmats2[26][44] + coeff0_27*dmats2[27][44] + coeff0_28*dmats2[28][44] + coeff0_29*dmats2[29][44] + coeff0_30*dmats2[30][44] + coeff0_31*dmats2[31][44] + coeff0_32*dmats2[32][44] + coeff0_33*dmats2[33][44] + coeff0_34*dmats2[34][44] + coeff0_35*dmats2[35][44] + coeff0_36*dmats2[36][44] + coeff0_37*dmats2[37][44] + coeff0_38*dmats2[38][44] + coeff0_39*dmats2[39][44] + coeff0_40*dmats2[40][44] + coeff0_41*dmats2[41][44] + coeff0_42*dmats2[42][44] + coeff0_43*dmats2[43][44] + coeff0_44*dmats2[44][44] + coeff0_45*dmats2[45][44] + coeff0_46*dmats2[46][44] + coeff0_47*dmats2[47][44] + coeff0_48*dmats2[48][44] + coeff0_49*dmats2[49][44] + coeff0_50*dmats2[50][44] + coeff0_51*dmats2[51][44] + coeff0_52*dmats2[52][44] + coeff0_53*dmats2[53][44] + coeff0_54*dmats2[54][44] + coeff0_55*dmats2[55][44];
          new_coeff0_45 = coeff0_0*dmats2[0][45] + coeff0_1*dmats2[1][45] + coeff0_2*dmats2[2][45] + coeff0_3*dmats2[3][45] + coeff0_4*dmats2[4][45] + coeff0_5*dmats2[5][45] + coeff0_6*dmats2[6][45] + coeff0_7*dmats2[7][45] + coeff0_8*dmats2[8][45] + coeff0_9*dmats2[9][45] + coeff0_10*dmats2[10][45] + coeff0_11*dmats2[11][45] + coeff0_12*dmats2[12][45] + coeff0_13*dmats2[13][45] + coeff0_14*dmats2[14][45] + coeff0_15*dmats2[15][45] + coeff0_16*dmats2[16][45] + coeff0_17*dmats2[17][45] + coeff0_18*dmats2[18][45] + coeff0_19*dmats2[19][45] + coeff0_20*dmats2[20][45] + coeff0_21*dmats2[21][45] + coeff0_22*dmats2[22][45] + coeff0_23*dmats2[23][45] + coeff0_24*dmats2[24][45] + coeff0_25*dmats2[25][45] + coeff0_26*dmats2[26][45] + coeff0_27*dmats2[27][45] + coeff0_28*dmats2[28][45] + coeff0_29*dmats2[29][45] + coeff0_30*dmats2[30][45] + coeff0_31*dmats2[31][45] + coeff0_32*dmats2[32][45] + coeff0_33*dmats2[33][45] + coeff0_34*dmats2[34][45] + coeff0_35*dmats2[35][45] + coeff0_36*dmats2[36][45] + coeff0_37*dmats2[37][45] + coeff0_38*dmats2[38][45] + coeff0_39*dmats2[39][45] + coeff0_40*dmats2[40][45] + coeff0_41*dmats2[41][45] + coeff0_42*dmats2[42][45] + coeff0_43*dmats2[43][45] + coeff0_44*dmats2[44][45] + coeff0_45*dmats2[45][45] + coeff0_46*dmats2[46][45] + coeff0_47*dmats2[47][45] + coeff0_48*dmats2[48][45] + coeff0_49*dmats2[49][45] + coeff0_50*dmats2[50][45] + coeff0_51*dmats2[51][45] + coeff0_52*dmats2[52][45] + coeff0_53*dmats2[53][45] + coeff0_54*dmats2[54][45] + coeff0_55*dmats2[55][45];
          new_coeff0_46 = coeff0_0*dmats2[0][46] + coeff0_1*dmats2[1][46] + coeff0_2*dmats2[2][46] + coeff0_3*dmats2[3][46] + coeff0_4*dmats2[4][46] + coeff0_5*dmats2[5][46] + coeff0_6*dmats2[6][46] + coeff0_7*dmats2[7][46] + coeff0_8*dmats2[8][46] + coeff0_9*dmats2[9][46] + coeff0_10*dmats2[10][46] + coeff0_11*dmats2[11][46] + coeff0_12*dmats2[12][46] + coeff0_13*dmats2[13][46] + coeff0_14*dmats2[14][46] + coeff0_15*dmats2[15][46] + coeff0_16*dmats2[16][46] + coeff0_17*dmats2[17][46] + coeff0_18*dmats2[18][46] + coeff0_19*dmats2[19][46] + coeff0_20*dmats2[20][46] + coeff0_21*dmats2[21][46] + coeff0_22*dmats2[22][46] + coeff0_23*dmats2[23][46] + coeff0_24*dmats2[24][46] + coeff0_25*dmats2[25][46] + coeff0_26*dmats2[26][46] + coeff0_27*dmats2[27][46] + coeff0_28*dmats2[28][46] + coeff0_29*dmats2[29][46] + coeff0_30*dmats2[30][46] + coeff0_31*dmats2[31][46] + coeff0_32*dmats2[32][46] + coeff0_33*dmats2[33][46] + coeff0_34*dmats2[34][46] + coeff0_35*dmats2[35][46] + coeff0_36*dmats2[36][46] + coeff0_37*dmats2[37][46] + coeff0_38*dmats2[38][46] + coeff0_39*dmats2[39][46] + coeff0_40*dmats2[40][46] + coeff0_41*dmats2[41][46] + coeff0_42*dmats2[42][46] + coeff0_43*dmats2[43][46] + coeff0_44*dmats2[44][46] + coeff0_45*dmats2[45][46] + coeff0_46*dmats2[46][46] + coeff0_47*dmats2[47][46] + coeff0_48*dmats2[48][46] + coeff0_49*dmats2[49][46] + coeff0_50*dmats2[50][46] + coeff0_51*dmats2[51][46] + coeff0_52*dmats2[52][46] + coeff0_53*dmats2[53][46] + coeff0_54*dmats2[54][46] + coeff0_55*dmats2[55][46];
          new_coeff0_47 = coeff0_0*dmats2[0][47] + coeff0_1*dmats2[1][47] + coeff0_2*dmats2[2][47] + coeff0_3*dmats2[3][47] + coeff0_4*dmats2[4][47] + coeff0_5*dmats2[5][47] + coeff0_6*dmats2[6][47] + coeff0_7*dmats2[7][47] + coeff0_8*dmats2[8][47] + coeff0_9*dmats2[9][47] + coeff0_10*dmats2[10][47] + coeff0_11*dmats2[11][47] + coeff0_12*dmats2[12][47] + coeff0_13*dmats2[13][47] + coeff0_14*dmats2[14][47] + coeff0_15*dmats2[15][47] + coeff0_16*dmats2[16][47] + coeff0_17*dmats2[17][47] + coeff0_18*dmats2[18][47] + coeff0_19*dmats2[19][47] + coeff0_20*dmats2[20][47] + coeff0_21*dmats2[21][47] + coeff0_22*dmats2[22][47] + coeff0_23*dmats2[23][47] + coeff0_24*dmats2[24][47] + coeff0_25*dmats2[25][47] + coeff0_26*dmats2[26][47] + coeff0_27*dmats2[27][47] + coeff0_28*dmats2[28][47] + coeff0_29*dmats2[29][47] + coeff0_30*dmats2[30][47] + coeff0_31*dmats2[31][47] + coeff0_32*dmats2[32][47] + coeff0_33*dmats2[33][47] + coeff0_34*dmats2[34][47] + coeff0_35*dmats2[35][47] + coeff0_36*dmats2[36][47] + coeff0_37*dmats2[37][47] + coeff0_38*dmats2[38][47] + coeff0_39*dmats2[39][47] + coeff0_40*dmats2[40][47] + coeff0_41*dmats2[41][47] + coeff0_42*dmats2[42][47] + coeff0_43*dmats2[43][47] + coeff0_44*dmats2[44][47] + coeff0_45*dmats2[45][47] + coeff0_46*dmats2[46][47] + coeff0_47*dmats2[47][47] + coeff0_48*dmats2[48][47] + coeff0_49*dmats2[49][47] + coeff0_50*dmats2[50][47] + coeff0_51*dmats2[51][47] + coeff0_52*dmats2[52][47] + coeff0_53*dmats2[53][47] + coeff0_54*dmats2[54][47] + coeff0_55*dmats2[55][47];
          new_coeff0_48 = coeff0_0*dmats2[0][48] + coeff0_1*dmats2[1][48] + coeff0_2*dmats2[2][48] + coeff0_3*dmats2[3][48] + coeff0_4*dmats2[4][48] + coeff0_5*dmats2[5][48] + coeff0_6*dmats2[6][48] + coeff0_7*dmats2[7][48] + coeff0_8*dmats2[8][48] + coeff0_9*dmats2[9][48] + coeff0_10*dmats2[10][48] + coeff0_11*dmats2[11][48] + coeff0_12*dmats2[12][48] + coeff0_13*dmats2[13][48] + coeff0_14*dmats2[14][48] + coeff0_15*dmats2[15][48] + coeff0_16*dmats2[16][48] + coeff0_17*dmats2[17][48] + coeff0_18*dmats2[18][48] + coeff0_19*dmats2[19][48] + coeff0_20*dmats2[20][48] + coeff0_21*dmats2[21][48] + coeff0_22*dmats2[22][48] + coeff0_23*dmats2[23][48] + coeff0_24*dmats2[24][48] + coeff0_25*dmats2[25][48] + coeff0_26*dmats2[26][48] + coeff0_27*dmats2[27][48] + coeff0_28*dmats2[28][48] + coeff0_29*dmats2[29][48] + coeff0_30*dmats2[30][48] + coeff0_31*dmats2[31][48] + coeff0_32*dmats2[32][48] + coeff0_33*dmats2[33][48] + coeff0_34*dmats2[34][48] + coeff0_35*dmats2[35][48] + coeff0_36*dmats2[36][48] + coeff0_37*dmats2[37][48] + coeff0_38*dmats2[38][48] + coeff0_39*dmats2[39][48] + coeff0_40*dmats2[40][48] + coeff0_41*dmats2[41][48] + coeff0_42*dmats2[42][48] + coeff0_43*dmats2[43][48] + coeff0_44*dmats2[44][48] + coeff0_45*dmats2[45][48] + coeff0_46*dmats2[46][48] + coeff0_47*dmats2[47][48] + coeff0_48*dmats2[48][48] + coeff0_49*dmats2[49][48] + coeff0_50*dmats2[50][48] + coeff0_51*dmats2[51][48] + coeff0_52*dmats2[52][48] + coeff0_53*dmats2[53][48] + coeff0_54*dmats2[54][48] + coeff0_55*dmats2[55][48];
          new_coeff0_49 = coeff0_0*dmats2[0][49] + coeff0_1*dmats2[1][49] + coeff0_2*dmats2[2][49] + coeff0_3*dmats2[3][49] + coeff0_4*dmats2[4][49] + coeff0_5*dmats2[5][49] + coeff0_6*dmats2[6][49] + coeff0_7*dmats2[7][49] + coeff0_8*dmats2[8][49] + coeff0_9*dmats2[9][49] + coeff0_10*dmats2[10][49] + coeff0_11*dmats2[11][49] + coeff0_12*dmats2[12][49] + coeff0_13*dmats2[13][49] + coeff0_14*dmats2[14][49] + coeff0_15*dmats2[15][49] + coeff0_16*dmats2[16][49] + coeff0_17*dmats2[17][49] + coeff0_18*dmats2[18][49] + coeff0_19*dmats2[19][49] + coeff0_20*dmats2[20][49] + coeff0_21*dmats2[21][49] + coeff0_22*dmats2[22][49] + coeff0_23*dmats2[23][49] + coeff0_24*dmats2[24][49] + coeff0_25*dmats2[25][49] + coeff0_26*dmats2[26][49] + coeff0_27*dmats2[27][49] + coeff0_28*dmats2[28][49] + coeff0_29*dmats2[29][49] + coeff0_30*dmats2[30][49] + coeff0_31*dmats2[31][49] + coeff0_32*dmats2[32][49] + coeff0_33*dmats2[33][49] + coeff0_34*dmats2[34][49] + coeff0_35*dmats2[35][49] + coeff0_36*dmats2[36][49] + coeff0_37*dmats2[37][49] + coeff0_38*dmats2[38][49] + coeff0_39*dmats2[39][49] + coeff0_40*dmats2[40][49] + coeff0_41*dmats2[41][49] + coeff0_42*dmats2[42][49] + coeff0_43*dmats2[43][49] + coeff0_44*dmats2[44][49] + coeff0_45*dmats2[45][49] + coeff0_46*dmats2[46][49] + coeff0_47*dmats2[47][49] + coeff0_48*dmats2[48][49] + coeff0_49*dmats2[49][49] + coeff0_50*dmats2[50][49] + coeff0_51*dmats2[51][49] + coeff0_52*dmats2[52][49] + coeff0_53*dmats2[53][49] + coeff0_54*dmats2[54][49] + coeff0_55*dmats2[55][49];
          new_coeff0_50 = coeff0_0*dmats2[0][50] + coeff0_1*dmats2[1][50] + coeff0_2*dmats2[2][50] + coeff0_3*dmats2[3][50] + coeff0_4*dmats2[4][50] + coeff0_5*dmats2[5][50] + coeff0_6*dmats2[6][50] + coeff0_7*dmats2[7][50] + coeff0_8*dmats2[8][50] + coeff0_9*dmats2[9][50] + coeff0_10*dmats2[10][50] + coeff0_11*dmats2[11][50] + coeff0_12*dmats2[12][50] + coeff0_13*dmats2[13][50] + coeff0_14*dmats2[14][50] + coeff0_15*dmats2[15][50] + coeff0_16*dmats2[16][50] + coeff0_17*dmats2[17][50] + coeff0_18*dmats2[18][50] + coeff0_19*dmats2[19][50] + coeff0_20*dmats2[20][50] + coeff0_21*dmats2[21][50] + coeff0_22*dmats2[22][50] + coeff0_23*dmats2[23][50] + coeff0_24*dmats2[24][50] + coeff0_25*dmats2[25][50] + coeff0_26*dmats2[26][50] + coeff0_27*dmats2[27][50] + coeff0_28*dmats2[28][50] + coeff0_29*dmats2[29][50] + coeff0_30*dmats2[30][50] + coeff0_31*dmats2[31][50] + coeff0_32*dmats2[32][50] + coeff0_33*dmats2[33][50] + coeff0_34*dmats2[34][50] + coeff0_35*dmats2[35][50] + coeff0_36*dmats2[36][50] + coeff0_37*dmats2[37][50] + coeff0_38*dmats2[38][50] + coeff0_39*dmats2[39][50] + coeff0_40*dmats2[40][50] + coeff0_41*dmats2[41][50] + coeff0_42*dmats2[42][50] + coeff0_43*dmats2[43][50] + coeff0_44*dmats2[44][50] + coeff0_45*dmats2[45][50] + coeff0_46*dmats2[46][50] + coeff0_47*dmats2[47][50] + coeff0_48*dmats2[48][50] + coeff0_49*dmats2[49][50] + coeff0_50*dmats2[50][50] + coeff0_51*dmats2[51][50] + coeff0_52*dmats2[52][50] + coeff0_53*dmats2[53][50] + coeff0_54*dmats2[54][50] + coeff0_55*dmats2[55][50];
          new_coeff0_51 = coeff0_0*dmats2[0][51] + coeff0_1*dmats2[1][51] + coeff0_2*dmats2[2][51] + coeff0_3*dmats2[3][51] + coeff0_4*dmats2[4][51] + coeff0_5*dmats2[5][51] + coeff0_6*dmats2[6][51] + coeff0_7*dmats2[7][51] + coeff0_8*dmats2[8][51] + coeff0_9*dmats2[9][51] + coeff0_10*dmats2[10][51] + coeff0_11*dmats2[11][51] + coeff0_12*dmats2[12][51] + coeff0_13*dmats2[13][51] + coeff0_14*dmats2[14][51] + coeff0_15*dmats2[15][51] + coeff0_16*dmats2[16][51] + coeff0_17*dmats2[17][51] + coeff0_18*dmats2[18][51] + coeff0_19*dmats2[19][51] + coeff0_20*dmats2[20][51] + coeff0_21*dmats2[21][51] + coeff0_22*dmats2[22][51] + coeff0_23*dmats2[23][51] + coeff0_24*dmats2[24][51] + coeff0_25*dmats2[25][51] + coeff0_26*dmats2[26][51] + coeff0_27*dmats2[27][51] + coeff0_28*dmats2[28][51] + coeff0_29*dmats2[29][51] + coeff0_30*dmats2[30][51] + coeff0_31*dmats2[31][51] + coeff0_32*dmats2[32][51] + coeff0_33*dmats2[33][51] + coeff0_34*dmats2[34][51] + coeff0_35*dmats2[35][51] + coeff0_36*dmats2[36][51] + coeff0_37*dmats2[37][51] + coeff0_38*dmats2[38][51] + coeff0_39*dmats2[39][51] + coeff0_40*dmats2[40][51] + coeff0_41*dmats2[41][51] + coeff0_42*dmats2[42][51] + coeff0_43*dmats2[43][51] + coeff0_44*dmats2[44][51] + coeff0_45*dmats2[45][51] + coeff0_46*dmats2[46][51] + coeff0_47*dmats2[47][51] + coeff0_48*dmats2[48][51] + coeff0_49*dmats2[49][51] + coeff0_50*dmats2[50][51] + coeff0_51*dmats2[51][51] + coeff0_52*dmats2[52][51] + coeff0_53*dmats2[53][51] + coeff0_54*dmats2[54][51] + coeff0_55*dmats2[55][51];
          new_coeff0_52 = coeff0_0*dmats2[0][52] + coeff0_1*dmats2[1][52] + coeff0_2*dmats2[2][52] + coeff0_3*dmats2[3][52] + coeff0_4*dmats2[4][52] + coeff0_5*dmats2[5][52] + coeff0_6*dmats2[6][52] + coeff0_7*dmats2[7][52] + coeff0_8*dmats2[8][52] + coeff0_9*dmats2[9][52] + coeff0_10*dmats2[10][52] + coeff0_11*dmats2[11][52] + coeff0_12*dmats2[12][52] + coeff0_13*dmats2[13][52] + coeff0_14*dmats2[14][52] + coeff0_15*dmats2[15][52] + coeff0_16*dmats2[16][52] + coeff0_17*dmats2[17][52] + coeff0_18*dmats2[18][52] + coeff0_19*dmats2[19][52] + coeff0_20*dmats2[20][52] + coeff0_21*dmats2[21][52] + coeff0_22*dmats2[22][52] + coeff0_23*dmats2[23][52] + coeff0_24*dmats2[24][52] + coeff0_25*dmats2[25][52] + coeff0_26*dmats2[26][52] + coeff0_27*dmats2[27][52] + coeff0_28*dmats2[28][52] + coeff0_29*dmats2[29][52] + coeff0_30*dmats2[30][52] + coeff0_31*dmats2[31][52] + coeff0_32*dmats2[32][52] + coeff0_33*dmats2[33][52] + coeff0_34*dmats2[34][52] + coeff0_35*dmats2[35][52] + coeff0_36*dmats2[36][52] + coeff0_37*dmats2[37][52] + coeff0_38*dmats2[38][52] + coeff0_39*dmats2[39][52] + coeff0_40*dmats2[40][52] + coeff0_41*dmats2[41][52] + coeff0_42*dmats2[42][52] + coeff0_43*dmats2[43][52] + coeff0_44*dmats2[44][52] + coeff0_45*dmats2[45][52] + coeff0_46*dmats2[46][52] + coeff0_47*dmats2[47][52] + coeff0_48*dmats2[48][52] + coeff0_49*dmats2[49][52] + coeff0_50*dmats2[50][52] + coeff0_51*dmats2[51][52] + coeff0_52*dmats2[52][52] + coeff0_53*dmats2[53][52] + coeff0_54*dmats2[54][52] + coeff0_55*dmats2[55][52];
          new_coeff0_53 = coeff0_0*dmats2[0][53] + coeff0_1*dmats2[1][53] + coeff0_2*dmats2[2][53] + coeff0_3*dmats2[3][53] + coeff0_4*dmats2[4][53] + coeff0_5*dmats2[5][53] + coeff0_6*dmats2[6][53] + coeff0_7*dmats2[7][53] + coeff0_8*dmats2[8][53] + coeff0_9*dmats2[9][53] + coeff0_10*dmats2[10][53] + coeff0_11*dmats2[11][53] + coeff0_12*dmats2[12][53] + coeff0_13*dmats2[13][53] + coeff0_14*dmats2[14][53] + coeff0_15*dmats2[15][53] + coeff0_16*dmats2[16][53] + coeff0_17*dmats2[17][53] + coeff0_18*dmats2[18][53] + coeff0_19*dmats2[19][53] + coeff0_20*dmats2[20][53] + coeff0_21*dmats2[21][53] + coeff0_22*dmats2[22][53] + coeff0_23*dmats2[23][53] + coeff0_24*dmats2[24][53] + coeff0_25*dmats2[25][53] + coeff0_26*dmats2[26][53] + coeff0_27*dmats2[27][53] + coeff0_28*dmats2[28][53] + coeff0_29*dmats2[29][53] + coeff0_30*dmats2[30][53] + coeff0_31*dmats2[31][53] + coeff0_32*dmats2[32][53] + coeff0_33*dmats2[33][53] + coeff0_34*dmats2[34][53] + coeff0_35*dmats2[35][53] + coeff0_36*dmats2[36][53] + coeff0_37*dmats2[37][53] + coeff0_38*dmats2[38][53] + coeff0_39*dmats2[39][53] + coeff0_40*dmats2[40][53] + coeff0_41*dmats2[41][53] + coeff0_42*dmats2[42][53] + coeff0_43*dmats2[43][53] + coeff0_44*dmats2[44][53] + coeff0_45*dmats2[45][53] + coeff0_46*dmats2[46][53] + coeff0_47*dmats2[47][53] + coeff0_48*dmats2[48][53] + coeff0_49*dmats2[49][53] + coeff0_50*dmats2[50][53] + coeff0_51*dmats2[51][53] + coeff0_52*dmats2[52][53] + coeff0_53*dmats2[53][53] + coeff0_54*dmats2[54][53] + coeff0_55*dmats2[55][53];
          new_coeff0_54 = coeff0_0*dmats2[0][54] + coeff0_1*dmats2[1][54] + coeff0_2*dmats2[2][54] + coeff0_3*dmats2[3][54] + coeff0_4*dmats2[4][54] + coeff0_5*dmats2[5][54] + coeff0_6*dmats2[6][54] + coeff0_7*dmats2[7][54] + coeff0_8*dmats2[8][54] + coeff0_9*dmats2[9][54] + coeff0_10*dmats2[10][54] + coeff0_11*dmats2[11][54] + coeff0_12*dmats2[12][54] + coeff0_13*dmats2[13][54] + coeff0_14*dmats2[14][54] + coeff0_15*dmats2[15][54] + coeff0_16*dmats2[16][54] + coeff0_17*dmats2[17][54] + coeff0_18*dmats2[18][54] + coeff0_19*dmats2[19][54] + coeff0_20*dmats2[20][54] + coeff0_21*dmats2[21][54] + coeff0_22*dmats2[22][54] + coeff0_23*dmats2[23][54] + coeff0_24*dmats2[24][54] + coeff0_25*dmats2[25][54] + coeff0_26*dmats2[26][54] + coeff0_27*dmats2[27][54] + coeff0_28*dmats2[28][54] + coeff0_29*dmats2[29][54] + coeff0_30*dmats2[30][54] + coeff0_31*dmats2[31][54] + coeff0_32*dmats2[32][54] + coeff0_33*dmats2[33][54] + coeff0_34*dmats2[34][54] + coeff0_35*dmats2[35][54] + coeff0_36*dmats2[36][54] + coeff0_37*dmats2[37][54] + coeff0_38*dmats2[38][54] + coeff0_39*dmats2[39][54] + coeff0_40*dmats2[40][54] + coeff0_41*dmats2[41][54] + coeff0_42*dmats2[42][54] + coeff0_43*dmats2[43][54] + coeff0_44*dmats2[44][54] + coeff0_45*dmats2[45][54] + coeff0_46*dmats2[46][54] + coeff0_47*dmats2[47][54] + coeff0_48*dmats2[48][54] + coeff0_49*dmats2[49][54] + coeff0_50*dmats2[50][54] + coeff0_51*dmats2[51][54] + coeff0_52*dmats2[52][54] + coeff0_53*dmats2[53][54] + coeff0_54*dmats2[54][54] + coeff0_55*dmats2[55][54];
          new_coeff0_55 = coeff0_0*dmats2[0][55] + coeff0_1*dmats2[1][55] + coeff0_2*dmats2[2][55] + coeff0_3*dmats2[3][55] + coeff0_4*dmats2[4][55] + coeff0_5*dmats2[5][55] + coeff0_6*dmats2[6][55] + coeff0_7*dmats2[7][55] + coeff0_8*dmats2[8][55] + coeff0_9*dmats2[9][55] + coeff0_10*dmats2[10][55] + coeff0_11*dmats2[11][55] + coeff0_12*dmats2[12][55] + coeff0_13*dmats2[13][55] + coeff0_14*dmats2[14][55] + coeff0_15*dmats2[15][55] + coeff0_16*dmats2[16][55] + coeff0_17*dmats2[17][55] + coeff0_18*dmats2[18][55] + coeff0_19*dmats2[19][55] + coeff0_20*dmats2[20][55] + coeff0_21*dmats2[21][55] + coeff0_22*dmats2[22][55] + coeff0_23*dmats2[23][55] + coeff0_24*dmats2[24][55] + coeff0_25*dmats2[25][55] + coeff0_26*dmats2[26][55] + coeff0_27*dmats2[27][55] + coeff0_28*dmats2[28][55] + coeff0_29*dmats2[29][55] + coeff0_30*dmats2[30][55] + coeff0_31*dmats2[31][55] + coeff0_32*dmats2[32][55] + coeff0_33*dmats2[33][55] + coeff0_34*dmats2[34][55] + coeff0_35*dmats2[35][55] + coeff0_36*dmats2[36][55] + coeff0_37*dmats2[37][55] + coeff0_38*dmats2[38][55] + coeff0_39*dmats2[39][55] + coeff0_40*dmats2[40][55] + coeff0_41*dmats2[41][55] + coeff0_42*dmats2[42][55] + coeff0_43*dmats2[43][55] + coeff0_44*dmats2[44][55] + coeff0_45*dmats2[45][55] + coeff0_46*dmats2[46][55] + coeff0_47*dmats2[47][55] + coeff0_48*dmats2[48][55] + coeff0_49*dmats2[49][55] + coeff0_50*dmats2[50][55] + coeff0_51*dmats2[51][55] + coeff0_52*dmats2[52][55] + coeff0_53*dmats2[53][55] + coeff0_54*dmats2[54][55] + coeff0_55*dmats2[55][55];
        }
    
      }
      // Compute derivatives on reference element as dot product of coefficients and basisvalues
      derivatives[deriv_num] = new_coeff0_0*basisvalue0 + new_coeff0_1*basisvalue1 + new_coeff0_2*basisvalue2 + new_coeff0_3*basisvalue3 + new_coeff0_4*basisvalue4 + new_coeff0_5*basisvalue5 + new_coeff0_6*basisvalue6 + new_coeff0_7*basisvalue7 + new_coeff0_8*basisvalue8 + new_coeff0_9*basisvalue9 + new_coeff0_10*basisvalue10 + new_coeff0_11*basisvalue11 + new_coeff0_12*basisvalue12 + new_coeff0_13*basisvalue13 + new_coeff0_14*basisvalue14 + new_coeff0_15*basisvalue15 + new_coeff0_16*basisvalue16 + new_coeff0_17*basisvalue17 + new_coeff0_18*basisvalue18 + new_coeff0_19*basisvalue19 + new_coeff0_20*basisvalue20 + new_coeff0_21*basisvalue21 + new_coeff0_22*basisvalue22 + new_coeff0_23*basisvalue23 + new_coeff0_24*basisvalue24 + new_coeff0_25*basisvalue25 + new_coeff0_26*basisvalue26 + new_coeff0_27*basisvalue27 + new_coeff0_28*basisvalue28 + new_coeff0_29*basisvalue29 + new_coeff0_30*basisvalue30 + new_coeff0_31*basisvalue31 + new_coeff0_32*basisvalue32 + new_coeff0_33*basisvalue33 + new_coeff0_34*basisvalue34 + new_coeff0_35*basisvalue35 + new_coeff0_36*basisvalue36 + new_coeff0_37*basisvalue37 + new_coeff0_38*basisvalue38 + new_coeff0_39*basisvalue39 + new_coeff0_40*basisvalue40 + new_coeff0_41*basisvalue41 + new_coeff0_42*basisvalue42 + new_coeff0_43*basisvalue43 + new_coeff0_44*basisvalue44 + new_coeff0_45*basisvalue45 + new_coeff0_46*basisvalue46 + new_coeff0_47*basisvalue47 + new_coeff0_48*basisvalue48 + new_coeff0_49*basisvalue49 + new_coeff0_50*basisvalue50 + new_coeff0_51*basisvalue51 + new_coeff0_52*basisvalue52 + new_coeff0_53*basisvalue53 + new_coeff0_54*basisvalue54 + new_coeff0_55*basisvalue55;
    }
    
    // Transform derivatives back to physical element
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        values[row] += transform[row][col]*derivatives[col];
      }
    }
    // Delete pointer to array of derivatives on FIAT element
    delete [] derivatives;
    
    // Delete pointer to array of combinations of derivatives and transform
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      delete [] combinations[row];
      delete [] transform[row];
    }
    
    delete [] combinations;
    delete [] transform;
  }

  /// Evaluate order n derivatives of all basis functions at given point in cell
  virtual void evaluate_basis_derivatives_all(unsigned int n,
                                              double* values,
                                              const double* coordinates,
                                              const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis_derivatives() is not yet implemented.");
  }

  /// Evaluate linear functional for dof i on the function f
  virtual double evaluate_dof(unsigned int i,
                              const ufc::function& f,
                              const ufc::cell& c) const
  {
    // The reference points, direction and weights:
    const static double X[56][1][3] = {{{0, 0, 0}}, {{1, 0, 0}}, {{0, 1, 0}}, {{0, 0, 1}}, {{0, 0.8, 0.2}}, {{0, 0.6, 0.4}}, {{0, 0.4, 0.6}}, {{0, 0.2, 0.8}}, {{0.8, 0, 0.2}}, {{0.6, 0, 0.4}}, {{0.4, 0, 0.6}}, {{0.2, 0, 0.8}}, {{0.8, 0.2, 0}}, {{0.6, 0.4, 0}}, {{0.4, 0.6, 0}}, {{0.2, 0.8, 0}}, {{0, 0, 0.2}}, {{0, 0, 0.4}}, {{0, 0, 0.6}}, {{0, 0, 0.8}}, {{0, 0.2, 0}}, {{0, 0.4, 0}}, {{0, 0.6, 0}}, {{0, 0.8, 0}}, {{0.2, 0, 0}}, {{0.4, 0, 0}}, {{0.6, 0, 0}}, {{0.8, 0, 0}}, {{0.6, 0.2, 0.2}}, {{0.4, 0.4, 0.2}}, {{0.2, 0.6, 0.2}}, {{0.4, 0.2, 0.4}}, {{0.2, 0.4, 0.4}}, {{0.2, 0.2, 0.6}}, {{0, 0.2, 0.2}}, {{0, 0.4, 0.2}}, {{0, 0.6, 0.2}}, {{0, 0.2, 0.4}}, {{0, 0.4, 0.4}}, {{0, 0.2, 0.6}}, {{0.2, 0, 0.2}}, {{0.4, 0, 0.2}}, {{0.6, 0, 0.2}}, {{0.2, 0, 0.4}}, {{0.4, 0, 0.4}}, {{0.2, 0, 0.6}}, {{0.2, 0.2, 0}}, {{0.4, 0.2, 0}}, {{0.6, 0.2, 0}}, {{0.2, 0.4, 0}}, {{0.4, 0.4, 0}}, {{0.2, 0.6, 0}}, {{0.2, 0.2, 0.2}}, {{0.4, 0.2, 0.2}}, {{0.2, 0.4, 0.2}}, {{0.2, 0.2, 0.4}}};
    const static double W[56][1] = {{1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}};
    const static double D[56][1][1] = {{{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}};
    
    const double * const * x = c.coordinates;
    double result = 0.0;
    // Iterate over the points:
    // Evaluate basis functions for affine mapping
    const double w0 = 1.0 - X[i][0][0] - X[i][0][1] - X[i][0][2];
    const double w1 = X[i][0][0];
    const double w2 = X[i][0][1];
    const double w3 = X[i][0][2];
    
    // Compute affine mapping y = F(X)
    double y[3];
    y[0] = w0*x[0][0] + w1*x[1][0] + w2*x[2][0] + w3*x[3][0];
    y[1] = w0*x[0][1] + w1*x[1][1] + w2*x[2][1] + w3*x[3][1];
    y[2] = w0*x[0][2] + w1*x[1][2] + w2*x[2][2] + w3*x[3][2];
    
    // Evaluate function at physical points
    double values[1];
    f.evaluate(values, y, c);
    
    // Map function values using appropriate mapping
    // Affine map: Do nothing
    
    // Note that we do not map the weights (yet).
    
    // Take directional components
    for(int k = 0; k < 1; k++)
      result += values[k]*D[i][0][k];
    // Multiply by weights 
    result *= W[i][0];
    
    return result;
  }

  /// Evaluate linear functionals for all dofs on the function f
  virtual void evaluate_dofs(double* values,
                             const ufc::function& f,
                             const ufc::cell& c) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Interpolate vertex values from dof values
  virtual void interpolate_vertex_values(double* vertex_values,
                                         const double* dof_values,
                                         const ufc::cell& c) const
  {
    // Evaluate at vertices and use affine mapping
    vertex_values[0] = dof_values[0];
    vertex_values[1] = dof_values[1];
    vertex_values[2] = dof_values[2];
    vertex_values[3] = dof_values[3];
  }

  /// Return the number of sub elements (for a mixed element)
  virtual unsigned int num_sub_elements() const
  {
    return 1;
  }

  /// Create a new finite element for sub element i (for a mixed element)
  virtual ufc::finite_element* create_sub_element(unsigned int i) const
  {
    return new poisson3d_5_0_finite_element_1();
  }

};

/// This class defines the interface for a local-to-global mapping of
/// degrees of freedom (dofs).

class poisson3d_5_0_dof_map_0: public ufc::dof_map
{
private:

  unsigned int __global_dimension;

public:

  /// Constructor
  poisson3d_5_0_dof_map_0() : ufc::dof_map()
  {
    __global_dimension = 0;
  }

  /// Destructor
  virtual ~poisson3d_5_0_dof_map_0()
  {
    // Do nothing
  }

  /// Return a string identifying the dof map
  virtual const char* signature() const
  {
    return "FFC dof map for FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return true iff mesh entities of topological dimension d are needed
  virtual bool needs_mesh_entities(unsigned int d) const
  {
    switch ( d )
    {
    case 0:
      return true;
      break;
    case 1:
      return true;
      break;
    case 2:
      return true;
      break;
    case 3:
      return true;
      break;
    }
    return false;
  }

  /// Initialize dof map for mesh (return true iff init_cell() is needed)
  virtual bool init_mesh(const ufc::mesh& m)
  {
    __global_dimension = m.num_entities[0] + 4*m.num_entities[1] + 6*m.num_entities[2] + 4*m.num_entities[3];
    return false;
  }

  /// Initialize dof map for given cell
  virtual void init_cell(const ufc::mesh& m,
                         const ufc::cell& c)
  {
    // Do nothing
  }

  /// Finish initialization of dof map for cells
  virtual void init_cell_finalize()
  {
    // Do nothing
  }

  /// Return the dimension of the global finite element function space
  virtual unsigned int global_dimension() const
  {
    return __global_dimension;
  }

  /// Return the dimension of the local finite element function space for a cell
  virtual unsigned int local_dimension(const ufc::cell& c) const
  {
    return 56;
  }

  /// Return the maximum dimension of the local finite element function space
  virtual unsigned int max_local_dimension() const
  {
    return 56;
  }

  // Return the geometric dimension of the coordinates this dof map provides
  virtual unsigned int geometric_dimension() const
  {
    return 3;
  }

  /// Return the number of dofs on each cell facet
  virtual unsigned int num_facet_dofs() const
  {
    return 21;
  }

  /// Return the number of dofs associated with each cell entity of dimension d
  virtual unsigned int num_entity_dofs(unsigned int d) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the local-to-global mapping of dofs on a cell
  virtual void tabulate_dofs(unsigned int* dofs,
                             const ufc::mesh& m,
                             const ufc::cell& c) const
  {
    dofs[0] = c.entity_indices[0][0];
    dofs[1] = c.entity_indices[0][1];
    dofs[2] = c.entity_indices[0][2];
    dofs[3] = c.entity_indices[0][3];
    unsigned int offset = m.num_entities[0];
    dofs[4] = offset + 4*c.entity_indices[1][0];
    dofs[5] = offset + 4*c.entity_indices[1][0] + 1;
    dofs[6] = offset + 4*c.entity_indices[1][0] + 2;
    dofs[7] = offset + 4*c.entity_indices[1][0] + 3;
    dofs[8] = offset + 4*c.entity_indices[1][1];
    dofs[9] = offset + 4*c.entity_indices[1][1] + 1;
    dofs[10] = offset + 4*c.entity_indices[1][1] + 2;
    dofs[11] = offset + 4*c.entity_indices[1][1] + 3;
    dofs[12] = offset + 4*c.entity_indices[1][2];
    dofs[13] = offset + 4*c.entity_indices[1][2] + 1;
    dofs[14] = offset + 4*c.entity_indices[1][2] + 2;
    dofs[15] = offset + 4*c.entity_indices[1][2] + 3;
    dofs[16] = offset + 4*c.entity_indices[1][3];
    dofs[17] = offset + 4*c.entity_indices[1][3] + 1;
    dofs[18] = offset + 4*c.entity_indices[1][3] + 2;
    dofs[19] = offset + 4*c.entity_indices[1][3] + 3;
    dofs[20] = offset + 4*c.entity_indices[1][4];
    dofs[21] = offset + 4*c.entity_indices[1][4] + 1;
    dofs[22] = offset + 4*c.entity_indices[1][4] + 2;
    dofs[23] = offset + 4*c.entity_indices[1][4] + 3;
    dofs[24] = offset + 4*c.entity_indices[1][5];
    dofs[25] = offset + 4*c.entity_indices[1][5] + 1;
    dofs[26] = offset + 4*c.entity_indices[1][5] + 2;
    dofs[27] = offset + 4*c.entity_indices[1][5] + 3;
    offset = offset + 4*m.num_entities[1];
    dofs[28] = offset + 6*c.entity_indices[2][0];
    dofs[29] = offset + 6*c.entity_indices[2][0] + 1;
    dofs[30] = offset + 6*c.entity_indices[2][0] + 2;
    dofs[31] = offset + 6*c.entity_indices[2][0] + 3;
    dofs[32] = offset + 6*c.entity_indices[2][0] + 4;
    dofs[33] = offset + 6*c.entity_indices[2][0] + 5;
    dofs[34] = offset + 6*c.entity_indices[2][1];
    dofs[35] = offset + 6*c.entity_indices[2][1] + 1;
    dofs[36] = offset + 6*c.entity_indices[2][1] + 2;
    dofs[37] = offset + 6*c.entity_indices[2][1] + 3;
    dofs[38] = offset + 6*c.entity_indices[2][1] + 4;
    dofs[39] = offset + 6*c.entity_indices[2][1] + 5;
    dofs[40] = offset + 6*c.entity_indices[2][2];
    dofs[41] = offset + 6*c.entity_indices[2][2] + 1;
    dofs[42] = offset + 6*c.entity_indices[2][2] + 2;
    dofs[43] = offset + 6*c.entity_indices[2][2] + 3;
    dofs[44] = offset + 6*c.entity_indices[2][2] + 4;
    dofs[45] = offset + 6*c.entity_indices[2][2] + 5;
    dofs[46] = offset + 6*c.entity_indices[2][3];
    dofs[47] = offset + 6*c.entity_indices[2][3] + 1;
    dofs[48] = offset + 6*c.entity_indices[2][3] + 2;
    dofs[49] = offset + 6*c.entity_indices[2][3] + 3;
    dofs[50] = offset + 6*c.entity_indices[2][3] + 4;
    dofs[51] = offset + 6*c.entity_indices[2][3] + 5;
    offset = offset + 6*m.num_entities[2];
    dofs[52] = offset + 4*c.entity_indices[3][0];
    dofs[53] = offset + 4*c.entity_indices[3][0] + 1;
    dofs[54] = offset + 4*c.entity_indices[3][0] + 2;
    dofs[55] = offset + 4*c.entity_indices[3][0] + 3;
  }

  /// Tabulate the local-to-local mapping from facet dofs to cell dofs
  virtual void tabulate_facet_dofs(unsigned int* dofs,
                                   unsigned int facet) const
  {
    switch ( facet )
    {
    case 0:
      dofs[0] = 1;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 8;
      dofs[8] = 9;
      dofs[9] = 10;
      dofs[10] = 11;
      dofs[11] = 12;
      dofs[12] = 13;
      dofs[13] = 14;
      dofs[14] = 15;
      dofs[15] = 28;
      dofs[16] = 29;
      dofs[17] = 30;
      dofs[18] = 31;
      dofs[19] = 32;
      dofs[20] = 33;
      break;
    case 1:
      dofs[0] = 0;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 20;
      dofs[12] = 21;
      dofs[13] = 22;
      dofs[14] = 23;
      dofs[15] = 34;
      dofs[16] = 35;
      dofs[17] = 36;
      dofs[18] = 37;
      dofs[19] = 38;
      dofs[20] = 39;
      break;
    case 2:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 3;
      dofs[3] = 8;
      dofs[4] = 9;
      dofs[5] = 10;
      dofs[6] = 11;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 40;
      dofs[16] = 41;
      dofs[17] = 42;
      dofs[18] = 43;
      dofs[19] = 44;
      dofs[20] = 45;
      break;
    case 3:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 2;
      dofs[3] = 12;
      dofs[4] = 13;
      dofs[5] = 14;
      dofs[6] = 15;
      dofs[7] = 20;
      dofs[8] = 21;
      dofs[9] = 22;
      dofs[10] = 23;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 46;
      dofs[16] = 47;
      dofs[17] = 48;
      dofs[18] = 49;
      dofs[19] = 50;
      dofs[20] = 51;
      break;
    }
  }

  /// Tabulate the local-to-local mapping of dofs on entity (d, i)
  virtual void tabulate_entity_dofs(unsigned int* dofs,
                                    unsigned int d, unsigned int i) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the coordinates of all dofs on a cell
  virtual void tabulate_coordinates(double** coordinates,
                                    const ufc::cell& c) const
  {
    const double * const * x = c.coordinates;
    coordinates[0][0] = x[0][0];
    coordinates[0][1] = x[0][1];
    coordinates[0][2] = x[0][2];
    coordinates[1][0] = x[1][0];
    coordinates[1][1] = x[1][1];
    coordinates[1][2] = x[1][2];
    coordinates[2][0] = x[2][0];
    coordinates[2][1] = x[2][1];
    coordinates[2][2] = x[2][2];
    coordinates[3][0] = x[3][0];
    coordinates[3][1] = x[3][1];
    coordinates[3][2] = x[3][2];
    coordinates[4][0] = 0.8*x[2][0] + 0.2*x[3][0];
    coordinates[4][1] = 0.8*x[2][1] + 0.2*x[3][1];
    coordinates[4][2] = 0.8*x[2][2] + 0.2*x[3][2];
    coordinates[5][0] = 0.6*x[2][0] + 0.4*x[3][0];
    coordinates[5][1] = 0.6*x[2][1] + 0.4*x[3][1];
    coordinates[5][2] = 0.6*x[2][2] + 0.4*x[3][2];
    coordinates[6][0] = 0.4*x[2][0] + 0.6*x[3][0];
    coordinates[6][1] = 0.4*x[2][1] + 0.6*x[3][1];
    coordinates[6][2] = 0.4*x[2][2] + 0.6*x[3][2];
    coordinates[7][0] = 0.2*x[2][0] + 0.8*x[3][0];
    coordinates[7][1] = 0.2*x[2][1] + 0.8*x[3][1];
    coordinates[7][2] = 0.2*x[2][2] + 0.8*x[3][2];
    coordinates[8][0] = 0.8*x[1][0] + 0.2*x[3][0];
    coordinates[8][1] = 0.8*x[1][1] + 0.2*x[3][1];
    coordinates[8][2] = 0.8*x[1][2] + 0.2*x[3][2];
    coordinates[9][0] = 0.6*x[1][0] + 0.4*x[3][0];
    coordinates[9][1] = 0.6*x[1][1] + 0.4*x[3][1];
    coordinates[9][2] = 0.6*x[1][2] + 0.4*x[3][2];
    coordinates[10][0] = 0.4*x[1][0] + 0.6*x[3][0];
    coordinates[10][1] = 0.4*x[1][1] + 0.6*x[3][1];
    coordinates[10][2] = 0.4*x[1][2] + 0.6*x[3][2];
    coordinates[11][0] = 0.2*x[1][0] + 0.8*x[3][0];
    coordinates[11][1] = 0.2*x[1][1] + 0.8*x[3][1];
    coordinates[11][2] = 0.2*x[1][2] + 0.8*x[3][2];
    coordinates[12][0] = 0.8*x[1][0] + 0.2*x[2][0];
    coordinates[12][1] = 0.8*x[1][1] + 0.2*x[2][1];
    coordinates[12][2] = 0.8*x[1][2] + 0.2*x[2][2];
    coordinates[13][0] = 0.6*x[1][0] + 0.4*x[2][0];
    coordinates[13][1] = 0.6*x[1][1] + 0.4*x[2][1];
    coordinates[13][2] = 0.6*x[1][2] + 0.4*x[2][2];
    coordinates[14][0] = 0.4*x[1][0] + 0.6*x[2][0];
    coordinates[14][1] = 0.4*x[1][1] + 0.6*x[2][1];
    coordinates[14][2] = 0.4*x[1][2] + 0.6*x[2][2];
    coordinates[15][0] = 0.2*x[1][0] + 0.8*x[2][0];
    coordinates[15][1] = 0.2*x[1][1] + 0.8*x[2][1];
    coordinates[15][2] = 0.2*x[1][2] + 0.8*x[2][2];
    coordinates[16][0] = 0.8*x[0][0] + 0.2*x[3][0];
    coordinates[16][1] = 0.8*x[0][1] + 0.2*x[3][1];
    coordinates[16][2] = 0.8*x[0][2] + 0.2*x[3][2];
    coordinates[17][0] = 0.6*x[0][0] + 0.4*x[3][0];
    coordinates[17][1] = 0.6*x[0][1] + 0.4*x[3][1];
    coordinates[17][2] = 0.6*x[0][2] + 0.4*x[3][2];
    coordinates[18][0] = 0.4*x[0][0] + 0.6*x[3][0];
    coordinates[18][1] = 0.4*x[0][1] + 0.6*x[3][1];
    coordinates[18][2] = 0.4*x[0][2] + 0.6*x[3][2];
    coordinates[19][0] = 0.2*x[0][0] + 0.8*x[3][0];
    coordinates[19][1] = 0.2*x[0][1] + 0.8*x[3][1];
    coordinates[19][2] = 0.2*x[0][2] + 0.8*x[3][2];
    coordinates[20][0] = 0.8*x[0][0] + 0.2*x[2][0];
    coordinates[20][1] = 0.8*x[0][1] + 0.2*x[2][1];
    coordinates[20][2] = 0.8*x[0][2] + 0.2*x[2][2];
    coordinates[21][0] = 0.6*x[0][0] + 0.4*x[2][0];
    coordinates[21][1] = 0.6*x[0][1] + 0.4*x[2][1];
    coordinates[21][2] = 0.6*x[0][2] + 0.4*x[2][2];
    coordinates[22][0] = 0.4*x[0][0] + 0.6*x[2][0];
    coordinates[22][1] = 0.4*x[0][1] + 0.6*x[2][1];
    coordinates[22][2] = 0.4*x[0][2] + 0.6*x[2][2];
    coordinates[23][0] = 0.2*x[0][0] + 0.8*x[2][0];
    coordinates[23][1] = 0.2*x[0][1] + 0.8*x[2][1];
    coordinates[23][2] = 0.2*x[0][2] + 0.8*x[2][2];
    coordinates[24][0] = 0.8*x[0][0] + 0.2*x[1][0];
    coordinates[24][1] = 0.8*x[0][1] + 0.2*x[1][1];
    coordinates[24][2] = 0.8*x[0][2] + 0.2*x[1][2];
    coordinates[25][0] = 0.6*x[0][0] + 0.4*x[1][0];
    coordinates[25][1] = 0.6*x[0][1] + 0.4*x[1][1];
    coordinates[25][2] = 0.6*x[0][2] + 0.4*x[1][2];
    coordinates[26][0] = 0.4*x[0][0] + 0.6*x[1][0];
    coordinates[26][1] = 0.4*x[0][1] + 0.6*x[1][1];
    coordinates[26][2] = 0.4*x[0][2] + 0.6*x[1][2];
    coordinates[27][0] = 0.2*x[0][0] + 0.8*x[1][0];
    coordinates[27][1] = 0.2*x[0][1] + 0.8*x[1][1];
    coordinates[27][2] = 0.2*x[0][2] + 0.8*x[1][2];
    coordinates[28][0] = 0.6*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[28][1] = 0.6*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[28][2] = 0.6*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[29][0] = 0.4*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[29][1] = 0.4*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[29][2] = 0.4*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[30][0] = 0.2*x[1][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[30][1] = 0.2*x[1][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[30][2] = 0.2*x[1][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[31][0] = 0.4*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[31][1] = 0.4*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[31][2] = 0.4*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[32][0] = 0.2*x[1][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[32][1] = 0.2*x[1][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[32][2] = 0.2*x[1][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[33][0] = 0.2*x[1][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[33][1] = 0.2*x[1][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[33][2] = 0.2*x[1][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[34][0] = 0.6*x[0][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[34][1] = 0.6*x[0][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[34][2] = 0.6*x[0][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[35][0] = 0.4*x[0][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[35][1] = 0.4*x[0][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[35][2] = 0.4*x[0][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[36][0] = 0.2*x[0][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[36][1] = 0.2*x[0][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[36][2] = 0.2*x[0][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[37][0] = 0.4*x[0][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[37][1] = 0.4*x[0][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[37][2] = 0.4*x[0][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[38][0] = 0.2*x[0][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[38][1] = 0.2*x[0][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[38][2] = 0.2*x[0][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[39][0] = 0.2*x[0][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[39][1] = 0.2*x[0][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[39][2] = 0.2*x[0][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[40][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[3][0];
    coordinates[40][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[3][1];
    coordinates[40][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[3][2];
    coordinates[41][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[3][0];
    coordinates[41][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[3][1];
    coordinates[41][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[3][2];
    coordinates[42][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[3][0];
    coordinates[42][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[3][1];
    coordinates[42][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[3][2];
    coordinates[43][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[3][0];
    coordinates[43][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[3][1];
    coordinates[43][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[3][2];
    coordinates[44][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[3][0];
    coordinates[44][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[3][1];
    coordinates[44][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[3][2];
    coordinates[45][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[3][0];
    coordinates[45][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[3][1];
    coordinates[45][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[3][2];
    coordinates[46][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0];
    coordinates[46][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1];
    coordinates[46][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2];
    coordinates[47][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0];
    coordinates[47][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1];
    coordinates[47][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2];
    coordinates[48][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[2][0];
    coordinates[48][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[2][1];
    coordinates[48][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[2][2];
    coordinates[49][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0];
    coordinates[49][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1];
    coordinates[49][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2];
    coordinates[50][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[2][0];
    coordinates[50][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[2][1];
    coordinates[50][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[2][2];
    coordinates[51][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[2][0];
    coordinates[51][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[2][1];
    coordinates[51][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[2][2];
    coordinates[52][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[52][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[52][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[53][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[53][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[53][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[54][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[54][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[54][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[55][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[55][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[55][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
  }

  /// Return the number of sub dof maps (for a mixed element)
  virtual unsigned int num_sub_dof_maps() const
  {
    return 1;
  }

  /// Create a new dof_map for sub dof map i (for a mixed element)
  virtual ufc::dof_map* create_sub_dof_map(unsigned int i) const
  {
    return new poisson3d_5_0_dof_map_0();
  }

};

/// This class defines the interface for a local-to-global mapping of
/// degrees of freedom (dofs).

class poisson3d_5_0_dof_map_1: public ufc::dof_map
{
private:

  unsigned int __global_dimension;

public:

  /// Constructor
  poisson3d_5_0_dof_map_1() : ufc::dof_map()
  {
    __global_dimension = 0;
  }

  /// Destructor
  virtual ~poisson3d_5_0_dof_map_1()
  {
    // Do nothing
  }

  /// Return a string identifying the dof map
  virtual const char* signature() const
  {
    return "FFC dof map for FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return true iff mesh entities of topological dimension d are needed
  virtual bool needs_mesh_entities(unsigned int d) const
  {
    switch ( d )
    {
    case 0:
      return true;
      break;
    case 1:
      return true;
      break;
    case 2:
      return true;
      break;
    case 3:
      return true;
      break;
    }
    return false;
  }

  /// Initialize dof map for mesh (return true iff init_cell() is needed)
  virtual bool init_mesh(const ufc::mesh& m)
  {
    __global_dimension = m.num_entities[0] + 4*m.num_entities[1] + 6*m.num_entities[2] + 4*m.num_entities[3];
    return false;
  }

  /// Initialize dof map for given cell
  virtual void init_cell(const ufc::mesh& m,
                         const ufc::cell& c)
  {
    // Do nothing
  }

  /// Finish initialization of dof map for cells
  virtual void init_cell_finalize()
  {
    // Do nothing
  }

  /// Return the dimension of the global finite element function space
  virtual unsigned int global_dimension() const
  {
    return __global_dimension;
  }

  /// Return the dimension of the local finite element function space for a cell
  virtual unsigned int local_dimension(const ufc::cell& c) const
  {
    return 56;
  }

  /// Return the maximum dimension of the local finite element function space
  virtual unsigned int max_local_dimension() const
  {
    return 56;
  }

  // Return the geometric dimension of the coordinates this dof map provides
  virtual unsigned int geometric_dimension() const
  {
    return 3;
  }

  /// Return the number of dofs on each cell facet
  virtual unsigned int num_facet_dofs() const
  {
    return 21;
  }

  /// Return the number of dofs associated with each cell entity of dimension d
  virtual unsigned int num_entity_dofs(unsigned int d) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the local-to-global mapping of dofs on a cell
  virtual void tabulate_dofs(unsigned int* dofs,
                             const ufc::mesh& m,
                             const ufc::cell& c) const
  {
    dofs[0] = c.entity_indices[0][0];
    dofs[1] = c.entity_indices[0][1];
    dofs[2] = c.entity_indices[0][2];
    dofs[3] = c.entity_indices[0][3];
    unsigned int offset = m.num_entities[0];
    dofs[4] = offset + 4*c.entity_indices[1][0];
    dofs[5] = offset + 4*c.entity_indices[1][0] + 1;
    dofs[6] = offset + 4*c.entity_indices[1][0] + 2;
    dofs[7] = offset + 4*c.entity_indices[1][0] + 3;
    dofs[8] = offset + 4*c.entity_indices[1][1];
    dofs[9] = offset + 4*c.entity_indices[1][1] + 1;
    dofs[10] = offset + 4*c.entity_indices[1][1] + 2;
    dofs[11] = offset + 4*c.entity_indices[1][1] + 3;
    dofs[12] = offset + 4*c.entity_indices[1][2];
    dofs[13] = offset + 4*c.entity_indices[1][2] + 1;
    dofs[14] = offset + 4*c.entity_indices[1][2] + 2;
    dofs[15] = offset + 4*c.entity_indices[1][2] + 3;
    dofs[16] = offset + 4*c.entity_indices[1][3];
    dofs[17] = offset + 4*c.entity_indices[1][3] + 1;
    dofs[18] = offset + 4*c.entity_indices[1][3] + 2;
    dofs[19] = offset + 4*c.entity_indices[1][3] + 3;
    dofs[20] = offset + 4*c.entity_indices[1][4];
    dofs[21] = offset + 4*c.entity_indices[1][4] + 1;
    dofs[22] = offset + 4*c.entity_indices[1][4] + 2;
    dofs[23] = offset + 4*c.entity_indices[1][4] + 3;
    dofs[24] = offset + 4*c.entity_indices[1][5];
    dofs[25] = offset + 4*c.entity_indices[1][5] + 1;
    dofs[26] = offset + 4*c.entity_indices[1][5] + 2;
    dofs[27] = offset + 4*c.entity_indices[1][5] + 3;
    offset = offset + 4*m.num_entities[1];
    dofs[28] = offset + 6*c.entity_indices[2][0];
    dofs[29] = offset + 6*c.entity_indices[2][0] + 1;
    dofs[30] = offset + 6*c.entity_indices[2][0] + 2;
    dofs[31] = offset + 6*c.entity_indices[2][0] + 3;
    dofs[32] = offset + 6*c.entity_indices[2][0] + 4;
    dofs[33] = offset + 6*c.entity_indices[2][0] + 5;
    dofs[34] = offset + 6*c.entity_indices[2][1];
    dofs[35] = offset + 6*c.entity_indices[2][1] + 1;
    dofs[36] = offset + 6*c.entity_indices[2][1] + 2;
    dofs[37] = offset + 6*c.entity_indices[2][1] + 3;
    dofs[38] = offset + 6*c.entity_indices[2][1] + 4;
    dofs[39] = offset + 6*c.entity_indices[2][1] + 5;
    dofs[40] = offset + 6*c.entity_indices[2][2];
    dofs[41] = offset + 6*c.entity_indices[2][2] + 1;
    dofs[42] = offset + 6*c.entity_indices[2][2] + 2;
    dofs[43] = offset + 6*c.entity_indices[2][2] + 3;
    dofs[44] = offset + 6*c.entity_indices[2][2] + 4;
    dofs[45] = offset + 6*c.entity_indices[2][2] + 5;
    dofs[46] = offset + 6*c.entity_indices[2][3];
    dofs[47] = offset + 6*c.entity_indices[2][3] + 1;
    dofs[48] = offset + 6*c.entity_indices[2][3] + 2;
    dofs[49] = offset + 6*c.entity_indices[2][3] + 3;
    dofs[50] = offset + 6*c.entity_indices[2][3] + 4;
    dofs[51] = offset + 6*c.entity_indices[2][3] + 5;
    offset = offset + 6*m.num_entities[2];
    dofs[52] = offset + 4*c.entity_indices[3][0];
    dofs[53] = offset + 4*c.entity_indices[3][0] + 1;
    dofs[54] = offset + 4*c.entity_indices[3][0] + 2;
    dofs[55] = offset + 4*c.entity_indices[3][0] + 3;
  }

  /// Tabulate the local-to-local mapping from facet dofs to cell dofs
  virtual void tabulate_facet_dofs(unsigned int* dofs,
                                   unsigned int facet) const
  {
    switch ( facet )
    {
    case 0:
      dofs[0] = 1;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 8;
      dofs[8] = 9;
      dofs[9] = 10;
      dofs[10] = 11;
      dofs[11] = 12;
      dofs[12] = 13;
      dofs[13] = 14;
      dofs[14] = 15;
      dofs[15] = 28;
      dofs[16] = 29;
      dofs[17] = 30;
      dofs[18] = 31;
      dofs[19] = 32;
      dofs[20] = 33;
      break;
    case 1:
      dofs[0] = 0;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 20;
      dofs[12] = 21;
      dofs[13] = 22;
      dofs[14] = 23;
      dofs[15] = 34;
      dofs[16] = 35;
      dofs[17] = 36;
      dofs[18] = 37;
      dofs[19] = 38;
      dofs[20] = 39;
      break;
    case 2:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 3;
      dofs[3] = 8;
      dofs[4] = 9;
      dofs[5] = 10;
      dofs[6] = 11;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 40;
      dofs[16] = 41;
      dofs[17] = 42;
      dofs[18] = 43;
      dofs[19] = 44;
      dofs[20] = 45;
      break;
    case 3:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 2;
      dofs[3] = 12;
      dofs[4] = 13;
      dofs[5] = 14;
      dofs[6] = 15;
      dofs[7] = 20;
      dofs[8] = 21;
      dofs[9] = 22;
      dofs[10] = 23;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 46;
      dofs[16] = 47;
      dofs[17] = 48;
      dofs[18] = 49;
      dofs[19] = 50;
      dofs[20] = 51;
      break;
    }
  }

  /// Tabulate the local-to-local mapping of dofs on entity (d, i)
  virtual void tabulate_entity_dofs(unsigned int* dofs,
                                    unsigned int d, unsigned int i) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the coordinates of all dofs on a cell
  virtual void tabulate_coordinates(double** coordinates,
                                    const ufc::cell& c) const
  {
    const double * const * x = c.coordinates;
    coordinates[0][0] = x[0][0];
    coordinates[0][1] = x[0][1];
    coordinates[0][2] = x[0][2];
    coordinates[1][0] = x[1][0];
    coordinates[1][1] = x[1][1];
    coordinates[1][2] = x[1][2];
    coordinates[2][0] = x[2][0];
    coordinates[2][1] = x[2][1];
    coordinates[2][2] = x[2][2];
    coordinates[3][0] = x[3][0];
    coordinates[3][1] = x[3][1];
    coordinates[3][2] = x[3][2];
    coordinates[4][0] = 0.8*x[2][0] + 0.2*x[3][0];
    coordinates[4][1] = 0.8*x[2][1] + 0.2*x[3][1];
    coordinates[4][2] = 0.8*x[2][2] + 0.2*x[3][2];
    coordinates[5][0] = 0.6*x[2][0] + 0.4*x[3][0];
    coordinates[5][1] = 0.6*x[2][1] + 0.4*x[3][1];
    coordinates[5][2] = 0.6*x[2][2] + 0.4*x[3][2];
    coordinates[6][0] = 0.4*x[2][0] + 0.6*x[3][0];
    coordinates[6][1] = 0.4*x[2][1] + 0.6*x[3][1];
    coordinates[6][2] = 0.4*x[2][2] + 0.6*x[3][2];
    coordinates[7][0] = 0.2*x[2][0] + 0.8*x[3][0];
    coordinates[7][1] = 0.2*x[2][1] + 0.8*x[3][1];
    coordinates[7][2] = 0.2*x[2][2] + 0.8*x[3][2];
    coordinates[8][0] = 0.8*x[1][0] + 0.2*x[3][0];
    coordinates[8][1] = 0.8*x[1][1] + 0.2*x[3][1];
    coordinates[8][2] = 0.8*x[1][2] + 0.2*x[3][2];
    coordinates[9][0] = 0.6*x[1][0] + 0.4*x[3][0];
    coordinates[9][1] = 0.6*x[1][1] + 0.4*x[3][1];
    coordinates[9][2] = 0.6*x[1][2] + 0.4*x[3][2];
    coordinates[10][0] = 0.4*x[1][0] + 0.6*x[3][0];
    coordinates[10][1] = 0.4*x[1][1] + 0.6*x[3][1];
    coordinates[10][2] = 0.4*x[1][2] + 0.6*x[3][2];
    coordinates[11][0] = 0.2*x[1][0] + 0.8*x[3][0];
    coordinates[11][1] = 0.2*x[1][1] + 0.8*x[3][1];
    coordinates[11][2] = 0.2*x[1][2] + 0.8*x[3][2];
    coordinates[12][0] = 0.8*x[1][0] + 0.2*x[2][0];
    coordinates[12][1] = 0.8*x[1][1] + 0.2*x[2][1];
    coordinates[12][2] = 0.8*x[1][2] + 0.2*x[2][2];
    coordinates[13][0] = 0.6*x[1][0] + 0.4*x[2][0];
    coordinates[13][1] = 0.6*x[1][1] + 0.4*x[2][1];
    coordinates[13][2] = 0.6*x[1][2] + 0.4*x[2][2];
    coordinates[14][0] = 0.4*x[1][0] + 0.6*x[2][0];
    coordinates[14][1] = 0.4*x[1][1] + 0.6*x[2][1];
    coordinates[14][2] = 0.4*x[1][2] + 0.6*x[2][2];
    coordinates[15][0] = 0.2*x[1][0] + 0.8*x[2][0];
    coordinates[15][1] = 0.2*x[1][1] + 0.8*x[2][1];
    coordinates[15][2] = 0.2*x[1][2] + 0.8*x[2][2];
    coordinates[16][0] = 0.8*x[0][0] + 0.2*x[3][0];
    coordinates[16][1] = 0.8*x[0][1] + 0.2*x[3][1];
    coordinates[16][2] = 0.8*x[0][2] + 0.2*x[3][2];
    coordinates[17][0] = 0.6*x[0][0] + 0.4*x[3][0];
    coordinates[17][1] = 0.6*x[0][1] + 0.4*x[3][1];
    coordinates[17][2] = 0.6*x[0][2] + 0.4*x[3][2];
    coordinates[18][0] = 0.4*x[0][0] + 0.6*x[3][0];
    coordinates[18][1] = 0.4*x[0][1] + 0.6*x[3][1];
    coordinates[18][2] = 0.4*x[0][2] + 0.6*x[3][2];
    coordinates[19][0] = 0.2*x[0][0] + 0.8*x[3][0];
    coordinates[19][1] = 0.2*x[0][1] + 0.8*x[3][1];
    coordinates[19][2] = 0.2*x[0][2] + 0.8*x[3][2];
    coordinates[20][0] = 0.8*x[0][0] + 0.2*x[2][0];
    coordinates[20][1] = 0.8*x[0][1] + 0.2*x[2][1];
    coordinates[20][2] = 0.8*x[0][2] + 0.2*x[2][2];
    coordinates[21][0] = 0.6*x[0][0] + 0.4*x[2][0];
    coordinates[21][1] = 0.6*x[0][1] + 0.4*x[2][1];
    coordinates[21][2] = 0.6*x[0][2] + 0.4*x[2][2];
    coordinates[22][0] = 0.4*x[0][0] + 0.6*x[2][0];
    coordinates[22][1] = 0.4*x[0][1] + 0.6*x[2][1];
    coordinates[22][2] = 0.4*x[0][2] + 0.6*x[2][2];
    coordinates[23][0] = 0.2*x[0][0] + 0.8*x[2][0];
    coordinates[23][1] = 0.2*x[0][1] + 0.8*x[2][1];
    coordinates[23][2] = 0.2*x[0][2] + 0.8*x[2][2];
    coordinates[24][0] = 0.8*x[0][0] + 0.2*x[1][0];
    coordinates[24][1] = 0.8*x[0][1] + 0.2*x[1][1];
    coordinates[24][2] = 0.8*x[0][2] + 0.2*x[1][2];
    coordinates[25][0] = 0.6*x[0][0] + 0.4*x[1][0];
    coordinates[25][1] = 0.6*x[0][1] + 0.4*x[1][1];
    coordinates[25][2] = 0.6*x[0][2] + 0.4*x[1][2];
    coordinates[26][0] = 0.4*x[0][0] + 0.6*x[1][0];
    coordinates[26][1] = 0.4*x[0][1] + 0.6*x[1][1];
    coordinates[26][2] = 0.4*x[0][2] + 0.6*x[1][2];
    coordinates[27][0] = 0.2*x[0][0] + 0.8*x[1][0];
    coordinates[27][1] = 0.2*x[0][1] + 0.8*x[1][1];
    coordinates[27][2] = 0.2*x[0][2] + 0.8*x[1][2];
    coordinates[28][0] = 0.6*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[28][1] = 0.6*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[28][2] = 0.6*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[29][0] = 0.4*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[29][1] = 0.4*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[29][2] = 0.4*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[30][0] = 0.2*x[1][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[30][1] = 0.2*x[1][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[30][2] = 0.2*x[1][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[31][0] = 0.4*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[31][1] = 0.4*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[31][2] = 0.4*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[32][0] = 0.2*x[1][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[32][1] = 0.2*x[1][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[32][2] = 0.2*x[1][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[33][0] = 0.2*x[1][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[33][1] = 0.2*x[1][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[33][2] = 0.2*x[1][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[34][0] = 0.6*x[0][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[34][1] = 0.6*x[0][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[34][2] = 0.6*x[0][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[35][0] = 0.4*x[0][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[35][1] = 0.4*x[0][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[35][2] = 0.4*x[0][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[36][0] = 0.2*x[0][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[36][1] = 0.2*x[0][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[36][2] = 0.2*x[0][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[37][0] = 0.4*x[0][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[37][1] = 0.4*x[0][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[37][2] = 0.4*x[0][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[38][0] = 0.2*x[0][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[38][1] = 0.2*x[0][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[38][2] = 0.2*x[0][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[39][0] = 0.2*x[0][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[39][1] = 0.2*x[0][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[39][2] = 0.2*x[0][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[40][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[3][0];
    coordinates[40][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[3][1];
    coordinates[40][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[3][2];
    coordinates[41][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[3][0];
    coordinates[41][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[3][1];
    coordinates[41][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[3][2];
    coordinates[42][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[3][0];
    coordinates[42][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[3][1];
    coordinates[42][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[3][2];
    coordinates[43][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[3][0];
    coordinates[43][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[3][1];
    coordinates[43][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[3][2];
    coordinates[44][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[3][0];
    coordinates[44][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[3][1];
    coordinates[44][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[3][2];
    coordinates[45][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[3][0];
    coordinates[45][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[3][1];
    coordinates[45][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[3][2];
    coordinates[46][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0];
    coordinates[46][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1];
    coordinates[46][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2];
    coordinates[47][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0];
    coordinates[47][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1];
    coordinates[47][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2];
    coordinates[48][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[2][0];
    coordinates[48][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[2][1];
    coordinates[48][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[2][2];
    coordinates[49][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0];
    coordinates[49][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1];
    coordinates[49][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2];
    coordinates[50][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[2][0];
    coordinates[50][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[2][1];
    coordinates[50][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[2][2];
    coordinates[51][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[2][0];
    coordinates[51][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[2][1];
    coordinates[51][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[2][2];
    coordinates[52][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[52][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[52][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[53][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[53][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[53][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[54][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[54][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[54][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[55][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[55][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[55][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
  }

  /// Return the number of sub dof maps (for a mixed element)
  virtual unsigned int num_sub_dof_maps() const
  {
    return 1;
  }

  /// Create a new dof_map for sub dof map i (for a mixed element)
  virtual ufc::dof_map* create_sub_dof_map(unsigned int i) const
  {
    return new poisson3d_5_0_dof_map_1();
  }

};

/// This class defines the interface for the tabulation of the cell
/// tensor corresponding to the local contribution to a form from
/// the integral over a cell.

class poisson3d_5_0_cell_integral_0_quadrature: public ufc::cell_integral
{
public:

  /// Constructor
  poisson3d_5_0_cell_integral_0_quadrature() : ufc::cell_integral()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_0_cell_integral_0_quadrature()
  {
    // Do nothing
  }

  /// Tabulate the tensor for the contribution from a local cell
  virtual void tabulate_tensor(double* A,
                               const double * const * w,
                               const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * x = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = x[1][0] - x[0][0];
    const double J_01 = x[2][0] - x[0][0];
    const double J_02 = x[3][0] - x[0][0];
    const double J_10 = x[1][1] - x[0][1];
    const double J_11 = x[2][1] - x[0][1];
    const double J_12 = x[3][1] - x[0][1];
    const double J_20 = x[1][2] - x[0][2];
    const double J_21 = x[2][2] - x[0][2];
    const double J_22 = x[3][2] - x[0][2];
      
    // Compute sub determinants
    const double d_00 = J_11*J_22 - J_12*J_21;
    const double d_01 = J_12*J_20 - J_10*J_22;
    const double d_02 = J_10*J_21 - J_11*J_20;
    
    const double d_10 = J_02*J_21 - J_01*J_22;
    const double d_11 = J_00*J_22 - J_02*J_20;
    const double d_12 = J_01*J_20 - J_00*J_21;
    
    const double d_20 = J_01*J_12 - J_02*J_11;
    const double d_21 = J_02*J_10 - J_00*J_12;
    const double d_22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d_00 + J_10*d_10 + J_20*d_20;
      
    // Compute inverse of Jacobian
    const double Jinv_00 = d_00 / detJ;
    const double Jinv_01 = d_10 / detJ;
    const double Jinv_02 = d_20 / detJ;
    const double Jinv_10 = d_01 / detJ;
    const double Jinv_11 = d_11 / detJ;
    const double Jinv_12 = d_21 / detJ;
    const double Jinv_20 = d_02 / detJ;
    const double Jinv_21 = d_12 / detJ;
    const double Jinv_22 = d_22 / detJ;
    
    // Set scale factor
    const double det = std::abs(detJ);
    
    
    // Array of quadrature weights
    const static double W125[125] = {0.000937439821766984, 0.00144688123847004, 0.00102268701578053, 0.000367520038007324, 4.71653365059364e-05, 0.00161927658526931, 0.00249925473264391, 0.00176652740822439, 0.000634831781565251, 8.1470536312884e-05, 0.00141792453255091, 0.00218848010941898, 0.00154686516950305, 0.000555892406098532, 7.13399262170554e-05, 0.000715891501943862, 0.00110493490770459, 0.000780991938624509, 0.000280662785913662, 3.60185932012982e-05, 0.000152536470498617, 0.000235430746830112, 0.000166407554052789, 5.9801395389292e-05, 7.67455552179798e-06, 0.00189377231486028, 0.00292292216383614, 0.00206598473020027, 0.000742446882427904, 9.52812185081393e-05, 0.00327118722298822, 0.00504887813656484, 0.00356865648488397, 0.00128245763045954, 0.000164582987156811, 0.00286442517370845, 0.00442106570107946, 0.00312490504969682, 0.00112298797668544, 0.000144117599953649, 0.00144621070637857, 0.0022321380949974, 0.00157772357985427, 0.000566981902660164, 7.27630862707133e-05, 0.000308147081155878, 0.000475606241660779, 0.000336168798819301, 0.000120807996789371, 1.55037800172006e-05, 0.00225090157446143, 0.00347412941301361, 0.00245558995953753, 0.00088245817276838, 0.000113249435042247, 0.00388807060532275, 0.00600100004508522, 0.00424163688396193, 0.00152430462570915, 0.00019562019257218, 0.0034046010087031, 0.0052547941847441, 0.00371420241029555, 0.00133476204345558, 0.000171295424533231, 0.00171893840164765, 0.00265307667295562, 0.00187525208922536, 0.000673903851785402, 8.64848134932762e-05, 0.000366257730507922, 0.000565296487744311, 0.00039956380849458, 0.000143590075769372, 1.8427496577589e-05, 0.00189377231486028, 0.00292292216383614, 0.00206598473020027, 0.000742446882427904, 9.52812185081393e-05, 0.00327118722298822, 0.00504887813656484, 0.00356865648488397, 0.00128245763045954, 0.000164582987156811, 0.00286442517370845, 0.00442106570107946, 0.00312490504969682, 0.00112298797668544, 0.000144117599953649, 0.00144621070637857, 0.0022321380949974, 0.00157772357985427, 0.000566981902660164, 7.27630862707133e-05, 0.000308147081155878, 0.000475606241660779, 0.000336168798819301, 0.000120807996789371, 1.55037800172006e-05, 0.000937439821766984, 0.00144688123847004, 0.00102268701578053, 0.000367520038007324, 4.71653365059364e-05, 0.00161927658526931, 0.00249925473264391, 0.00176652740822439, 0.000634831781565252, 8.1470536312884e-05, 0.00141792453255091, 0.00218848010941898, 0.00154686516950305, 0.000555892406098532, 7.13399262170554e-05, 0.000715891501943862, 0.00110493490770459, 0.000780991938624509, 0.000280662785913662, 3.60185932012982e-05, 0.000152536470498617, 0.000235430746830112, 0.000166407554052789, 5.9801395389292e-05, 7.67455552179798e-06};
    
    
    const static double FE0_D010[125][51] = \
    {{-3.62990990645796, 0.349323335271637, -0.0867591749077326, -0.0570689004231474, -0.0670256254939591, -0.153888727424818, 0, -0.17582849483076, -0.0778069667533932, -0.0679036256623779, -0.10910480966091, -3.05254952705569, 2.02813935973006, -0.852973082215375, 0.153888727424816, 7.38531978670071, -7.16081891567264, 5.10864194701881, -2.05255624686056, -3.83876213073826, 2.41318852918333, -0.990177230877914, 0.175828494830754, 0.0437002683219801, 0.0226398576078834, 0.030003979409515, 0.0304150432629712, 0.0239281275472776, 0.0473407328843811, 4.31602724927855, -1.74588576697716, 0.569167219662034, -2.42947806492689, 0.458407605619975, 0.919998707709337, -1.06629444649799, 0.288116507415982, -0.0437002683219799, 0.304511126233427, -0.0304150432629749, -0.0473407328843834, 5.4276603255462, -2.89072275534581, 1.06798419763132, -2.19555493120248, 0.545437851824837, 0.715761546055468, 1.27729830600255, -0.310756365023861, -0.241007838914068, -0.328439253780702},
    {-0.282631633534522, 0.425653570551385, -0.515016292023655, -0.0524324561977669, -0.0364185135341731, -0.0578765020203701, 0, -0.161086287535334, -0.076821991401671, -0.0690615677537144, -0.110521644691895, -6.52731890993827, 1.06473844170331, -0.356273456486928, 0.057876502020367, 1.81608845625925, -3.96890023631498, 4.10626582749042, -2.09647598445155, -1.40075184518968, 1.40242344845198, -0.751530849418162, 0.161086287535333, 0.198626300742617, 0.110210755392295, 0.147210409077319, 0.0217802683865339, 0.0179561870251814, 0.0202069040997955, 10.9095820348659, -6.67581251337118, 2.80856568046722, -1.3573672099876, 0.345061224482054, 0.392691970021103, -2.98938087073943, 1.07816500332459, -0.198626300742619, 0.175661008535875, -0.0217802683865256, -0.0202069040997926, 2.34117826575308, -1.78786031281182, 0.828352840819833, -1.43261832695309, 0.45449843211355, 0.602713551081579, 3.8109712330989, -1.18837575871688, -0.968800771436785, -0.193617195561065},
    {0.143241115565028, 0.555572946106275, -1.45661822356639, 1.01456732457268, 0.0295255943487216, 0.0204847751966079, 0, -0.131658137530839, -0.0696433278875364, -0.0649710303379907, -0.102669576732064, -0.878278855981289, -6.65596057481904, 0.178742789963477, -0.0204847751966062, -0.226551992163591, -0.865602057515817, 2.35911829376461, -1.96577830575651, -0.0619053894407265, 0.426235505482278, -0.421608540100333, 0.13165813753084, 0.358637701041751, 0.218670667099774, 0.293664290797276, -0.274215954779773, -0.240684254375343, -0.0107169476080468, 4.73065721449073, -8.03664327050678, 5.64088313556373, 10.2846225763129, -4.64322932606653, -0.208268384312204, -1.92655321577802, 1.32379401609845, -0.358637701041752, -1.45706042761479, 0.274215954779776, 0.0107169476080473, 0.333439858171691, -0.658608363621254, 0.491251867987868, -0.566461925012385, 0.297343888476968, 0.397597033013483, 2.97686148749422, -1.54246468319822, -1.34397256251348, 1.69774468199014},
    {-0.102291761943669, 0.719267259522415, -2.9685039649583, 4.53211724574025, -2.87309406907588, 0.288623553688339, 0, -0.0880875552963123, -0.0515926220049583, -0.0497249692031611, -0.0770776741593759, 0.558471148525222, -1.03193983204806, -7.88994374560002, -0.288623553688337, 0.114568117951404, 0.141162345470042, 0.613992989586026, -1.48669895058622, 0.0145007915507426, 0.0113221202333969, -0.141681015490771, 0.088087555296313, 0.383027020449086, 0.25599282152055, 0.343729201147272, -0.650646765379131, -0.605822457995312, 0.553837841226679, -1.04210594164294, -3.18777292613868, 6.63991168421469, 8.2274939117065, -11.7276713253987, 10.7630378146759, -0.0782653746293191, 0.702994372100141, -0.383027020449089, -1.66367859822355, 0.650646765379124, -0.553837841226679, -0.0270584453171137, -0.0902694831567567, 0.193273637495731, -0.0827710273577051, 0.128672332126518, 0.172406355283456, 0.623997517357419, -0.958987193620687, -0.889461343875378, 2.26950105621889},
    {0.290248257600283, 0.880270785828908, -4.75479662623643, 10.5319042888745, -12.244901566631, 8.1697622215787, 0, -0.0393989079388221, -0.0249878994264231, -0.0246488115605299, -0.0374823086891257, -1.683687613827, 4.01561825483131, -4.72603256077765, -8.16976222157871, -0.149952137540239, -0.120505154295872, -0.173596923941117, -0.726464827651963, -0.0132725968823333, -0.00939813114015284, -0.00964430997441759, 0.0393989079388222, 0.226065126168345, 0.162216159930339, 0.217055781839356, -0.56134242992681, -0.546385823335331, 0.873279986799679, 1.08790294413226, 1.14158185247199, 4.20899944345915, -3.94452348395903, -10.6029990597468, 16.9709341274087, 0.0827593126526502, 0.0626088212750494, -0.226065126168331, -0.210882641871732, 0.561342429926784, -0.873279986799679, 0.00857599539607353, 0.00923174132476624, 0.0346322094008466, 0.00899914901765878, 0.0248152013759099, 0.0331797611577229, -0.0812940950953645, -0.224824981205411, -0.218520999396618, 0.757268465207085},
    {-0.0804169334283828, -0.267111615790655, 0.0747872960979208, 0.0592354988079081, 0.0992497134834052, -0.153888727424809, 0, -0.158684622935267, 0.102658974459715, 0.0615636388130995, 0.0785536145829199, -1.11829004720866, 1.23357237757901, -0.694497732197728, 0.153888727424808, -3.7730589397251, 6.73378637280234, -4.22797584878612, 1.61477696492792, -1.17460758636495, 1.28205562258155, -0.718353962441777, 0.158684622935267, 0.0389380460040538, -0.0292826819147912, -0.0260118513062281, 0.0265666755156619, -0.0295942242317657, 0.0395407439246518, -0.435157361976349, 2.01350413283209, -0.534844019745, -0.683984241269894, -0.608823635117022, 0.595248018714324, -0.541693780027634, 0.204904935930984, -0.0389380460040503, 0.207084946583187, -0.0265666755156647, -0.0395407439246533, -0.457072062758504, -0.710866956990602, 0.615694987982062, 2.1149050154789, -0.63275230440405, -0.561778980938372, 0.300355306155597, -0.175622254016196, 0.267350325178266, -0.177490722351421},
    {0.296938442417927, -0.299846929362777, 0.386955294238904, 0.0431773246303414, 0.0345544018425532, -0.0578765020203726, 0, -0.143523611516616, 0.0642426662126431, 0.0492909235970515, 0.069358073767205, -1.80057222446278, 0.622114485944271, -0.28862988603762, 0.0578765020203716, -1.43720748845573, 2.90034530056824, -2.94925917988491, 1.48902985471725, -0.322735527919583, 0.710201427666701, -0.536613352828261, 0.143523611516617, 0.175062685486986, -0.0906317028154827, -0.101252068598982, 0.0188772281077639, -0.0142300079613511, 0.0168775591723757, -1.96650278130224, 5.56429304510754, -2.18417333358142, -0.354799752022249, -0.310492058552363, 0.254075484195067, -1.45887636963454, 0.757038659624984, -0.175062685486984, 0.118862007651415, -0.0188772281077644, -0.0168775591723763, -0.352477009617462, -0.405036847903528, 0.472370686615619, 0.997346859522858, -0.354455503360228, -0.391492395753016, 0.832015627142644, -0.666406956809504, 0.728112811090874, -0.104631999690066},
    {-0.100404462764304, -0.260145422130515, 0.651010728103406, -0.408482387606871, -0.00811565004606674, 0.020484775196603, 0, -0.115126938239244, 0.0166078053671588, 0.0224219502185277, 0.0383260478001775, 0.754231010240752, -3.33204574872113, 0.142867299242773, -0.0204847751966031, 0.0902863545719201, 0.519905220556767, -1.19498096482825, 0.945339274594386, 0.0444027916945013, 0.182898862155065, -0.292362569318101, 0.115126938239245, 0.311145847960948, -0.0515200597450687, -0.098753719891417, -0.235046552195556, 0.05525635095754, -0.00895119393395105, -2.56631544901888, 3.70987558278025, -2.54880187210553, 2.06452148094635, 1.67600665538165, -0.134751649196707, -0.805547368791975, 0.906955296349855, -0.311145847960945, -0.972728688706491, 0.235046552195554, 0.00895119393395129, -0.151083114798997, -0.113323362953441, 0.275754763950943, 0.218406337684435, -0.0919974494201561, -0.150052062380114, 0.499113749392281, -0.855435236604789, 0.405187339291106, 0.917472337748953},
    {0.0327513821297318, -0.0105569750572735, -0.135243708104241, 0.634253162364348, -0.92784377028209, 0.288623553688336, 0, -0.0755398622052371, -0.0142219521386633, -0.00589821387692258, -0.00293303939715404, -0.335749943545737, 1.50942741166772, -6.03594528816658, -0.288623553688338, 0.0734153358266378, -0.012134003337129, -0.23179616054043, 0.148320420978462, -0.00728143161568352, -0.0140368645108733, -0.0925187275588536, 0.0755398622052374, 0.326945989565535, 0.0700708340094202, 0.040177951708122, -0.551479996410739, -0.163410605106817, 0.462585999866338, -0.381363329437079, 1.03595011602072, -0.183593134933664, -0.812162016093041, -1.33151855793902, 6.96378905844867, 0.0956174998431678, 0.455835059655003, -0.326945989565532, -1.06304261937453, 0.551479996410735, -0.462585999866336, -0.00827065218446963, 0.00755267069661102, 0.106740679697519, 0.0224667198671675, 0.0123824076911808, -0.00398159666985722, -0.0514479204803968, -0.525905893664425, -0.0843475310708963, 1.22645322448135},
    {0.239734464658442, 0.475450897669483, -2.77864520754329, 6.81314195983392, -9.1776713616849, 8.1697622215787, 0, -0.0332504769431232, -0.015776557863154, -0.0133943891251008, -0.0182952076606388, -1.26639041080201, 2.55888156794631, -1.80268636101632, -8.16976222157871, -0.221548830513223, -0.126289880066032, -0.134043576195684, -0.233303075552983, -0.00833819138987338, -0.00503066803072973, -0.00309884550916264, 0.0332504769431244, 0.190431537011354, 0.102131030238311, 0.117279404520329, -0.471535356993048, -0.342047551053695, 0.729395981614862, 1.47589721749276, 1.01220714185208, 1.55693125900044, -4.59936445208094, -4.77265907569927, 10.9803577227012, 0.0440478281967477, 0.020060667678306, -0.19043153701134, -0.0671852838049795, 0.471535356993028, -0.729395981614861, 0.00971763001858503, 0.00904218311646755, 0.0188754033723205, 0.00666459316412279, 0.00938287403935737, 0.0102511758677995, -0.0791720952377649, -0.122191697916638, -0.0821551374792874, 0.409232834858687},
    {0.0232138437439114, 0.158558075149595, -0.0772323978522262, -0.162307063211106, 0.351454288722324, -0.153888727424809, 0, -0.124486375182813, 0.279788762204938, -0.126062544966411, -0.0568494855714351, 0.011149590245044, 0.389873654755783, -0.454124093010757, 0.153888727424809, -0.0709380867274253, -3.19169673587894, 4.18627333678429, -1.10541043307143, 0.00820702823413392, 0.302811622374952, -0.361523025747754, 0.124486375182814, 0.0299687006580568, -0.0774919973017114, 0.0499476789121407, 0.0198537994431189, -0.073440432248072, 0.0277098078727131, -1.64711011447787, 0.737126751174727, 0.97606617091032, 0.843502031359418, -1.0710686229041, 0.102669804288432, -0.119978044940128, 0.100129616053812, -0.0299687006580539, 0.0948944734924891, -0.0198537994431194, -0.0277098078727137, -1.21241040407344, 0.655141006520427, 0.0817342635428163, 0.542586761133696, -0.831890083928971, 0.718466100277051, -0.259575694307658, -0.0226376187521107, 0.32960606033565, -0.0214540412444175},
    {-0.138566640473884, 0.144369641593841, -0.258546391444691, -0.0463981325961401, 0.142205326424281, -0.0578765020203727, 0, -0.110575952246124, 0.200414170939772, -0.0391639985697967, -0.0324760640791474, 0.38208870515529, 0.16384919457081, -0.186028874620447, 0.0578765020203729, 0.703248296907836, -1.46180572737149, 1.4816501764658, -0.728895747122104, 0.0479942388799365, 0.138302756227033, -0.262175993089586, 0.110575952246124, 0.132704598354074, -0.275783272801988, 0.0762495624955158, 0.0139576891226322, -0.0410399011292788, 0.011827646007824, -4.05814755606083, 2.18404350464616, 1.75056173770407, 0.505600743224566, -0.623051805199234, 0.0438235481961647, -0.26926578080228, 0.360771661431503, -0.132704598354071, 0.0536872057719868, -0.013957689122633, -0.0118276460078239, -0.509744728351656, 0.426770339161938, 0.0617618221498169, 0.274338142614198, -0.525909096819179, 0.21988841093667, -0.830891962912569, -0.0849883886295214, 1.02390818121933, -0.0126473046427092},
    {-0.0867112697486254, -0.0683533897674908, 0.325725544285392, -0.509884452975203, -0.0652094687231992, 0.0204847751966017, 0, -0.0863518149033914, 0.0989135541327093, 0.020374579191884, 0.0134383636323564, 0.268333407534354, -0.158965367263467, 0.088451755997758, -0.0204847751966037, 0.291799362514225, -0.3027258524114, -0.00369930727230903, 0.1696904566856, 0.0110705530113288, 0.00635213026241181, -0.134168821282001, 0.0863518149033913, 0.23063234787197, -0.301356482486243, -0.0863854453341421, -0.171108157494921, 0.311141707254332, -0.00627291850182595, -1.06333489443118, 1.74010698392143, -1.27083104130999, -4.61390588340459, 5.28275570364326, -0.0232422872745566, -0.0269321685798124, 0.408767477777851, -0.230632347871966, -0.422040401641776, 0.17110815749492, 0.00627291850182803, -0.0438696971270338, 0.184368027416385, 0.0352552671492939, 0.0717910855301226, -0.211094736870684, -0.0524303050467731, -0.781695366748308, -0.107410995291613, 0.895012980662262, 0.110898694387444},
    {0.258324173993584, -0.301286830201028, 1.40654666417306, -2.52815393023257, 2.02269013545502, 0.288623553688335, 0, -0.0550682258188481, 0.0224439850584839, 0.0168400699068271, 0.0213768470827347, -1.34708568607265, 2.86625354516242, -3.2238211552292, -0.28862355368834, -0.348786799477787, -0.0612210877801288, -0.0690124100937657, 0.521982953559124, -0.0204731527591723, -0.0190921563335229, -0.0357718627143646, 0.0550682258188475, 0.23668038790238, -0.109414350988838, -0.11223216555983, -0.395013797789662, 0.249645313218055, 0.324176227066621, 2.16827434044311, 0.558218098997721, -2.78595341754125, -6.78385006662923, 6.44575045169939, 1.20113101977418, 0.127241398781273, 0.174387709328564, -0.236680387902373, -0.397891811478669, 0.395013797789662, -0.324176227066618, 0.0329536660174188, 0.0451873234431275, 0.0133278776558817, 0.00848385854876879, -0.0429352370164336, -0.0423412188897499, -0.301154994838854, -0.0649733583397352, 0.286145761617416, 0.14824649826061},
    {0.0664733009545234, 0.050920596106077, -0.53225801135685, 2.09010537178824, -4.5253308777861, 8.1697622215787, 0, -0.0236691033128983, -0.00552192775210005, -0.00290443700715162, -0.00245592517947499, -0.146914305631326, -0.484156194529887, 2.63141247240989, -8.16976222157871, -0.219299564551295, -0.0479301246209402, -0.0051931178249129, 0.155028909936552, -0.000677886541346005, 0.000672789605543126, 0.00321091870429606, 0.0236691033129015, 0.135175972111293, 0.0355953982494308, 0.0252133860930577, -0.333297894072589, -0.118193338717988, 0.511154331142265, 1.26435025729385, 0.207078150205733, -0.792256090511422, -3.01014678896072, 1.40419761170238, 1.89391840537622, -0.00584047925370031, -0.0206981936666245, -0.135175972111281, 0.0687276652377066, 0.333297894072574, -0.511154331142264, 0.00583391807412595, 0.00418293826180339, 0.00231100904780428, 0.000955492322049588, -0.00195129086019855, -0.00365559867536151, -0.0363120415895752, -0.0148972045828269, 0.0169391347502446, 0.0494656734802833},
    {0.0307253509165761, -0.277763665240073, 0.588308925193382, -0.933533835729221, 0.622081242620202, -0.153888727424811, 0, -0.0757063131817327, 0.295183781142472, -0.419128833660768, 0.234646956679987, -0.0176781856910539, -0.030831008372135, -0.19619227036681, 0.153888727424811, -0.231145906488424, 0.904707938978346, -4.39508691957179, 3.96856320140536, -0.00705094261601397, -0.0138422026979861, -0.0930951975884604, 0.0757063131817338, 0.0178628963919057, -0.0792873564973736, 0.155664801915642, 0.0114765791187455, -0.0704362054930726, 0.0150146766187828, 0.201785345580298, -2.38793509349719, 1.61551900841456, 0.980991861914702, -0.0166270178133474, -0.425888972253392, 0.00514100574332785, 0.0250056832080088, -0.0178628963919093, 0.0222142031055672, -0.0114765791187434, -0.0150146766187839, 0.080482065145384, 0.440436071172319, -0.20208858355401, -0.952427676078969, -0.00746503481356969, 0.644349596869615, -0.163578327877594, 0.0542816732893684, 0.00277252021862268, 0.0482220023875066},
    {0.148294415168219, -0.189231932784835, 0.633760217237781, -0.457019490504955, 0.257719653538468, -0.0578765020203722, 0, -0.0660640735715607, 0.213319323186303, -0.22073752392542, 0.0431352531615873, -0.251910113159575, -0.0422020538189004, -0.0759333334893328, 0.0578765020203722, -0.762835589501425, 1.59737491801092, -1.79350820569863, 0.999906394805751, -0.0171456115571042, -0.0203833251274638, -0.0628514243474519, 0.0660640735715601, 0.0779392221679451, -0.285992416229436, 0.406962173977091, 0.00798671967783541, -0.0403014293621362, 0.00640886002475385, 1.69100432584983, -6.93817873052023, 4.86532430059219, 0.54366236238487, -0.0444408180610142, -0.181786320049136, 0.0375796654743699, 0.0842634902647175, -0.0779392221679426, 0.0118742278046445, -0.00798671967783301, -0.0064088600247522, 0.115093844184133, 0.262585483152335, -0.150467898838849, -0.472229224683288, -0.0214646340994527, 0.33114573889467, -0.484115057458973, 0.201728925964712, 0.0395732180075203, 0.0284272015574909},
    {0.288245120659524, 0.157476470390114, -0.872076066213629, 2.13904455634208, -0.126473726995888, 0.0204847751966029, 0, -0.0502251134543607, 0.110191494450972, -0.0481705693270814, -0.0194953665925296, -0.87089576078296, 0.740818696194026, 0.0300614087998682, -0.0204847751966043, -0.997604215588487, 1.10518808917439, -0.210145730480013, -0.343159734155527, -0.0194689807209892, -0.0166829897292234, -0.0261913018588233, 0.0502251134543608, 0.13247161513959, -0.329393680842751, 0.196368175885009, -0.096430803446685, 0.326986899708115, -0.00339900742702502, 3.49448860824026, -5.27130984328823, 3.51979306204456, -4.01834167959564, 1.13847842705953, 0.0964123181960203, 0.068008502021081, 0.0782932418543253, -0.132471615139587, -0.0777211765464105, 0.0964308034466879, 0.00339900742702706, 0.0781197181191579, 0.0904917131730345, -0.0840001925921489, -0.117840773069151, -0.0256381541167301, 0.0786854022635096, -0.368891065576632, 0.251100438988418, 0.10451438767055, -0.249265723161706},
    {0.211629929169828, -0.106326707514485, 0.723274251164084, -2.23508757936844, 5.18874690712782, 0.288623553688337, 0, -0.0311077547329552, 0.0322822324989495, 0.0082542767391527, 0.00595627825506667, -0.795255349482025, 0.973470037069584, -0.206284350599033, -0.28862355368834, -0.507082554433031, 0.284085452518065, 0.0872485939133625, 0.0304452863462618, -0.00654905402442905, -0.00359506766419599, -0.00128341572370407, 0.0311077547329547, 0.132706663832992, -0.155615023567551, -0.0537639097383178, -0.219006179402854, 0.347007623924257, 0.175656260023992, 2.10718354009037, -1.60763757155524, -0.427564870217187, -2.81594291151992, 4.07756045381878, -4.98246255652879, 0.0234163330730931, 0.00618664672888715, -0.132706663832983, -0.013795670445171, 0.219006179402853, -0.175656260023987, 0.0173529909008808, 0.0103994010292329, -0.0309988167752469, -0.0132391505629953, -0.0150586101041873, -0.003521064568527, -0.0677360931718164, 0.149428376838648, 0.0980836698370539, -0.333211953479092},
    {-0.287383368069134, -0.201011180775918, 0.994395503589034, -1.74785530185878, 0.466841577692107, 8.16976222157871, 0, -0.0130409161051935, 0.000312915713609984, 0.00132815413491122, 0.00248619131476519, 1.81307241877916, -4.86684701705692, 7.38940173345124, -8.16976222157871, 0.0453882041920633, 0.0922397772807431, 0.108906774455681, 0.241859792916574, 0.00453305036514461, 0.00369820258157591, 0.00495298625307139, 0.0130409161051992, 0.0742535060640467, -0.00200799333803735, -0.0114248613268747, -0.182255982056143, 0.00660685321645534, 0.276971136705408, -0.476916665310362, -0.786243104764057, -1.54430815229379, 2.15726737803238, 4.45743494088333, -7.85624331114334, -0.0318121598565942, -0.0317835217805519, -0.0742535060640381, 0.104576573602558, 0.18225598205613, -0.276971136705405, -0.00119238880996115, -0.00163925674232922, -0.00526590196668524, -0.00196576791762356, -0.00338709997415891, -0.00386108495233487, 0.0141009845681336, 0.0337915151185684, 0.0291360366153639, -0.111183426819018},
    {0.136246592488553, 3.08041774684675, 2.82690544195191, -1.94822363815394, 0.838592338884256, -0.153888727424815, 0, -0.0267632969820078, 0.138467078595134, -0.297194184216797, 0.364815616315761, -0.0232954564071882, -0.00616373515139111, 0.01016227369352, 0.153888727424814, -0.789669027444732, 1.8588157723957, -2.04244724899486, -2.24336383529141, -0.00300630723630178, -0.000940254601252073, 0.00167797901910697, 0.0267632969820108, 0.00621587300782882, -0.0363154763493376, 0.105111883455635, 0.00389938824139921, -0.0307222052098702, 0.0048581244150128, 0.120081100044224, -0.118349344141983, -2.80534174144697, -0.0283091750005731, 1.98269654830591, -0.848754612577776, 0.000332550020546659, -0.000440080111461324, -0.00621587300783952, -0.000372299439585841, -0.00389938824139182, -0.00485812441501355, 0.0154966133179635, -0.00431845810993475, -0.140145057614247, -0.0152731280936747, 0.302452896927976, -0.362032794303729, 0.00152735581537334, 0.0367555564608066, -0.106971789291547, 0.031094504649446},
    {0.0508201537761873, 0.152389035168538, 5.95560097140644, -1.01996684985416, 0.350135184354869, -0.0578765020203686, 0, -0.0230500588646309, 0.0997625381024812, -0.166161970812507, 0.131155231768646, -0.011000482446071, 0.00590658279384121, 0.012146977657647, 0.0578765020203683, -0.255540141862249, 0.507468973892813, -0.472461497012003, 0.0173234760367127, -0.000242254447823632, 0.000962236603995799, 0.00346098700029843, 0.0230500588646311, 0.0268290407030147, -0.131052969298331, 0.293871878784499, 0.00269384482066819, -0.0177158222721325, 0.00207364035533096, -0.0551992442906888, 0.802639357357634, -6.69204060202732, -0.085720708401535, 1.09978097546186, -0.362282162012516, -0.00170179901734897, -0.00454652248950613, -0.0268290407030107, -0.000614601750817408, -0.00269384482066875, -0.00207364035533049, -0.00121560690737244, -0.0139646909597821, -0.103223525102782, 0.0176758569699797, 0.179164425168292, -0.147373227383423, 0.0246977689836499, 0.135599491787825, -0.316867848750783, 0.018330424022948},
    {-0.1275950926142, -0.118966191906673, 0.634469463727499, 6.31394635781804, -0.175487291718017, 0.0204847751966086, 0, -0.0171736078270692, 0.0517636670039573, -0.0474241264972715, 0.00458923622653097, 0.438855364505284, -0.406648411251723, -0.0166529258255925, -0.0204847751966069, 0.421065389531871, -0.400590600726757, -0.0551495321694295, 0.28123602788519, 0.00317432288255969, 0.00305434107327259, 0.00491213066563373, 0.0171736078270714, 0.0448491728896712, -0.152439361979685, 0.18754470734402, -0.0321626844245296, 0.146800778338201, -0.00109977733035593, -1.7866599991986, 2.76617861326413, -2.05284344229831, 2.24392444842931, -8.15122239499562, 0.192140217543604, -0.0120787781457088, -0.0144657847476982, -0.0448491728896702, 0.0139307094483687, 0.032162684424532, 0.00109977733035339, -0.0129232457377102, -0.01685414333001, -0.0566757976695953, 0.0200082869654345, 0.0612239287540108, -0.0148486003368158, 0.0666518418328899, 0.166905146727373, -0.242117771031199, -0.160731487786574},
    {-0.405296087049487, 0.0924967660603469, -0.480953409540754, 0.747335856394906, 7.72170385245788, 0.288623553688342, 0, -0.0104009318950457, 0.0159678061491253, -0.000909203888061618, -0.00128152661909551, 1.80583279730039, -3.03701648093234, 2.20785138931023, -0.288623553688341, 0.785199765675352, -0.222253028926932, -0.118257963364628, -0.131889452394647, 0.00481174008425106, 0.00369481427796357, 0.00456564298039176, 0.010400931895047, 0.0441086502404932, -0.0762892176099146, 0.00581654065195804, -0.0721468465368794, 0.16708686868145, 0.0568350546032071, -3.92260546598519, 1.48614072416041, 1.11158535406515, 8.09282165215099, -5.80314102761355, -9.92955524176811, -0.0236372036358169, -0.0218132239085926, -0.0441086502404852, 0.0477748152742846, 0.0721468465368723, -0.0568350546032028, -0.0104519964326653, -0.00984567360009547, -0.020533449129522, 0.00395990310062537, 0.0070600632102005, 0.00296187986687743, 0.0629867090222747, 0.0981024415184846, -0.0451660460384057, -0.214861683955738},
    {-0.7294203979467, -0.287417905294885, 1.65533088393824, -3.90144231251835, 4.4607553970921, 8.16976222157871, 0, -0.00427583515645391, 0.000977990931066612, 0.000966203266160789, 0.00133909953976563, 4.03187699731424, -9.20606324283965, 11.1959607479293, -8.16976222157871, 0.559465158668678, 0.164563918856158, 0.123382529296816, 0.169426696419947, 0.00326163468825044, 0.00227990770101606, 0.00245463987634235, 0.00427583515646203, 0.0242876523745508, -0.00625318760228773, -0.00825131754118976, -0.059399405834607, 0.0204261346086526, 0.0896163317835081, -3.3520074867803, -1.12801283727973, -1.20718755719246, 8.87209810346023, 4.23540745189778, -15.6567161450214, -0.0194702740770906, -0.0156947504877746, -0.0242876523745456, 0.0512671466943415, 0.0593994058345933, -0.0896163317835031, -0.00271164618895028, -0.00219720028601949, -0.00343263080741654, -0.000912519355472684, -0.00104891068115581, -0.000976568683605559, 0.0187639577478277, 0.0219479380900403, 0.00895763387048142, -0.0716932813029999},
    {0.113928564117327, 0.349323335271636, -0.0867591749077292, -0.0570689004231523, -0.0670256254939587, -0.153888727424812, 0, 0.0278488230036588, 0.0177636344219978, 0.0297013731176045, -0.536720692663427, -0.897392725924524, 1.11679585815058, -0.667429939275512, 0.153888727424811, 0.688914996163702, -2.46045115507583, 2.9332246233812, -1.62494036385804, -5.55156553714956, -0.581233740849928, 0.176887292825779, -0.0278488230036618, -0.00997694195012431, -0.00990278282758694, 0.147598961598275, -0.0133036865046642, 0.117709945429909, 0.232883875824241, 1.54388831955445, -1.01130865619547, 0.451572237473275, -1.42435274546479, 0.364625787737366, 0.734455564769472, -2.88840169966595, -0.0986102508193088, 0.0099769419501293, 1.17213589804524, 0.0133036865046676, -0.232883875824245, 9.5509991784434, 0.741300989338676, -0.194650927247772, -6.25628681954351, -0.189768621606355, 2.79357387091309, 3.68384504732798, 0.108513033646887, -0.943042309260294, -1.28984584347515},
    {0.26999054591072, 0.425653570551385, -0.515016292023658, -0.0524324561977649, -0.0364185135341737, -0.0578765020203695, 0, -0.0363474142259868, -0.0234013737801579, -0.0351920029423165, -0.543690547444175, -1.30154270918084, 0.55767696708066, -0.277076277497001, 0.0578765020203695, -0.174909704706167, -1.17668753447559, 2.31926020441892, -1.66330708169927, -1.3740079275861, 0.374305742846372, -0.17804036755202, 0.0363474142259865, 0.060505178549001, 0.0561605731551214, 0.724174057704709, 0.0110986659306179, 0.0883321016525771, 0.0994040830897176, 3.38168720858407, -3.79673023921942, 2.23160203183984, -0.779929820737547, 0.274685309854655, 0.313494791031173, -7.70238934861216, 0.427276158246284, -0.0605051785490023, 0.672040880702614, -0.0110986659306129, -0.0994040830897183, 3.56996739364428, -0.523479053559299, 0.201441741332178, -4.00811852795569, 0.184365313655245, 2.35584960934168, 10.7720481542588, -0.483436731401405, -3.79383286335139, -0.760372982355196},
    {-0.127458660661963, 0.555572946106276, -1.45661822356639, 1.01456732457268, 0.0295255943487218, 0.0204847751966066, 0, -0.140425692842852, -0.0914936594648404, -0.120072096778313, -0.505063768594209, 0.835345906031966, -2.86220224093332, 0.136739719441228, -0.0204847751966055, -0.0591907819839719, -0.0605330432107285, 1.25499365364475, -1.56338411389436, 0.289645525886159, 0.338736145102241, -0.423727874132203, 0.140425692842851, 0.471158927720348, 0.40412235062293, 1.44462652065549, -0.506774857797258, -1.18400114644807, -0.0527200181302925, 0.429171571301527, -4.29782015947263, 4.48992090570552, 5.54754735035445, -3.69991243399381, -0.166265313789954, -4.07544493557717, 1.87158220056295, -0.471158927720348, -5.48337766451798, 0.506774857797257, 0.0527200181302916, 0.148809762000871, -0.656541587927218, 0.515221533597045, -1.49021425886649, 0.43787753960329, 1.55682273957367, 7.89906577199249, -2.27570455118588, -5.2682473570708, 6.66737881096605},
    {0.0599574981188615, 0.719267259522416, -2.9685039649583, 4.53211724574025, -2.87309406907588, 0.288623553688339, 0, -0.207786421496731, -0.136837646941043, -0.158574389013705, -0.379169193294767, -0.485316152903597, 1.81264552367904, -5.71927997511735, -0.28862355368834, 0.0945023567458033, 0.0916757697803247, 0.219204547283424, -1.18460743145083, -0.0619897889177904, -0.0634227097028371, -0.272393731348953, 0.207786421496729, 1.01589169451495, 0.81636863561781, 1.69091147770453, -2.07493166787513, -2.98023020522086, 2.72450161170936, -0.690957544332375, -1.14795174546316, 5.29272940765743, 3.00850080875387, -9.35326357817315, 8.59237404419323, 0.676289459166004, 1.6250915137995, -1.01589169451495, -5.93254885644663, 2.07493166787512, -2.72450161170936, -0.088256514991417, -0.105264526870697, 0.409231378289998, -0.146628720192636, 0.327261625587239, 0.676044217396611, 1.12245740177763, -2.44146014941732, -3.48965833864816, 8.91277906166751},
    {0.226504621301662, 0.880270785828908, -4.75479662623642, 10.5319042888745, -12.2449015666311, 8.1697622215787, 0, -0.14932958878714, -0.0991011414889217, -0.104760298900418, -0.184387202954394, -1.17098067011928, 2.26640789781618, -1.30337508285042, -8.16976222157871, -0.191316311349827, -0.145361694694578, -0.190537467699469, -0.579559933386697, -0.0454096920330028, -0.0225438403438925, -0.0105485501697073, 0.14932958878714, 0.89656644089163, 0.689437434298019, 1.06776529776709, -2.38577022669893, -2.68784280430415, 4.29593746472691, 1.31378384172708, 1.2537035270972, 3.35828992753141, -4.33677010791272, -8.46154207877797, 13.5482766494815, 0.22977722143087, 0.0733852835124123, -0.896566440891621, -0.286100081628729, 2.38577022669891, -4.29593746472691, 0.0509474845940112, 0.043137624526957, 0.109649691658635, 0.0486176181374099, 0.0841665147173488, 0.130231792255971, -0.439678570808437, -0.762822717810445, -0.857863948389508, 2.9739428859329},
    {0.240503275451298, -0.267111615790656, 0.0747872960979256, 0.0592354988079019, 0.0992497134834087, -0.15388872742481, 0, -0.0462721460137383, 0.040049111844418, 0.0394640129859648, 0.386429805992916, -0.198934346621585, 0.639724604203331, -0.539525186253461, 0.15388872742481, -1.12628789153542, 2.3768576734873, -2.53086221513044, 1.30690077351792, -1.02790400216701, 0.426198826646042, -0.217708482662351, 0.0462721460137369, 0.0151904318899169, -0.0187710174646636, -0.127960434502694, 0.0170299814591386, -0.145583247685151, 0.194513289868927, -0.648679727349184, 1.20572221442139, -0.432895436548548, -0.206125491347603, -0.492834611663629, 0.440275472770053, -1.3819321177896, 0.102039958991739, -0.0151904318899147, 0.791396025902336, -0.0170299814591396, -0.194513289868928, -3.35176151926737, -0.137325408428821, 0.177659370817933, 6.23002870420838, -0.328337431203184, -2.23679298876691, 0.445271973153448, -0.083268941527079, 1.06462057913884, -0.645812778217185},
    {0.00303876266691716, -0.299846929362777, 0.386955294238903, 0.0431773246303433, 0.0345544018425523, -0.0578765020203713, 0, -0.1034560301836, 0.0589323903674599, 0.0675232169078057, 0.341194063853183, 0.112743231543427, 0.297246090911907, -0.222481451419092, 0.0578765020203711, -0.0973691697225825, 0.960002280146955, -1.78301880835979, 1.21719386463128, 0.0994102469069542, 0.464850762373005, -0.379441201277076, 0.1034560301836, 0.160592066427416, -0.124155598664817, -0.498090602613619, 0.0258597541924508, -0.0700018610853197, 0.0830259937909008, -2.09985897112538, 3.38749524490983, -1.78733479956678, -0.0857032101138503, -0.254720205428399, 0.187927049576539, -3.4290101532323, 0.799386368156974, -0.160592066427416, 0.450712928768469, -0.025859754192452, -0.0830259937909014, -1.85153020657341, -0.134027675307744, 0.320508810909616, 2.98689095640217, -0.398346303973067, -1.57596506058889, 0.988666248708005, -0.675230769492158, 2.93843450713791, -0.380711067683149},
    {-0.157996351774294, -0.260145422130515, 0.651010728103405, -0.408482387606869, -0.00811565004606834, 0.020484775196604, 0, -0.179040800534355, 0.0305979835068201, 0.0542547024805245, 0.188537819609357, 0.685081437210633, -1.02836080694758, 0.107784769793442, -0.0204847751966051, 0.257921546868495, 0.115897235305268, -0.750804511054162, 0.795127502785207, 0.198404964543104, 0.136587063032126, -0.406374916328886, 0.179040800534354, 0.57325066820396, -0.124663799803556, -0.485800443701226, -0.568745387183398, 0.2718232775636, -0.0440337233832862, -1.62685937719308, 2.45252236017476, -2.16175514829572, -0.0225965342211366, 1.45943972877558, -0.0996691197473732, -1.22301022383586, 1.65567254466686, -0.573250668203959, -3.61011246546788, 0.568745387183396, 0.0440337233832867, -0.471151252269836, 0.00300127564480895, 0.375776932822067, 0.710269736533581, -0.193843041157461, -0.626061268416204, -0.0268736344180054, -1.53100874486331, 1.73568430195508, 3.33828918790428},
    {0.188157374542531, -0.0105569750572729, -0.135243708104242, 0.63425316236435, -0.927843770282093, 0.288623553688337, 0, -0.206275655835315, -0.0427692121532596, -0.0206152809481789, -0.014428538409464, -1.09311974803885, 2.729017019739, -4.22292603253327, -0.288623553688341, -0.0756985794411081, -0.0770435263672226, -0.1846742136677, 0.15981591999077, -0.11661999283964, -0.0887018873734149, -0.194656929515232, 0.206275655835314, 0.983213995803715, 0.24490972343841, 0.197647914309175, -1.92751827935447, -0.803867890279693, 2.27560525549965, 0.577312226379426, 0.992114327298382, -0.341063097534714, -2.67220890933719, -0.691061272766156, 5.15076980281536, 0.85042464755704, 1.11466572267242, -0.983213995803713, -3.65867051038954, 1.92751827935447, -2.27560525549964, 0.0615908255498964, 0.0868554398890949, 0.237426141668493, 0.105844182170538, 0.0224617284324976, -0.0363864764713291, -0.832721930088664, -1.35957544611084, -0.215350631777552, 4.46253840066923},
    {0.143182682873862, 0.475450897669483, -2.77864520754329, 6.81314195983392, -9.1776713616849, 8.1697622215787, 0, -0.131948528310846, -0.0650083811815009, -0.0584471218103465, -0.0899998502224772, -0.617043178048847, 0.712046529486217, 1.05604468581899, -8.16976222157871, -0.223891097108815, -0.118863779164082, -0.1142802712793, -0.161598432991146, -0.0199859245989496, -0.00610835213604941, 0.00748030222208918, 0.131948528310848, 0.78468611812462, 0.44565412496262, 0.57693408223639, -2.05756934419685, -1.68263891478257, 3.58812702845017, 1.42125680067038, 0.877155003637368, 1.09727658128437, -4.09312077734973, -3.4320677119704, 8.12162667586592, 0.0602958096896669, -0.0512799654544954, -0.784686118124612, 0.1936157674513, 2.05756934419684, -3.58812702845017, 0.0460342683696367, 0.0351131871416433, 0.0575280789594154, 0.0284109028151191, 0.0294422868047478, 0.0355406036366659, -0.346603797937156, -0.394374159508137, -0.290626093988883, 1.48902314733128},
    {-0.161958917611737, 0.158558075149595, -0.0772323978522233, -0.162307063211108, 0.351454288722324, -0.153888727424811, 0, -0.159080911263008, 0.432664849446293, -0.265714169326553, -0.279660405148858, 0.0765730592183371, 0.151585061594863, -0.345520686816804, 0.15388872742481, 0.898837018621737, -2.23172205862127, 2.21888539595568, -0.882599513494009, 0.277272923798915, 0.248161096178579, -0.425360169840708, 0.159080911263008, 0.0463435459527727, -0.163337347329968, 0.245708258929771, 0.0418477655548958, -0.36127646240518, 0.136313214066665, -0.746529146484315, -0.0331171057744754, 0.780305590892676, 0.793954594363234, -0.783232592746989, -0.00593360190552115, -0.229476775855361, 0.160579723290484, -0.0463435459527718, 0.35517703276516, -0.0418477655548967, -0.136313214066665, -2.70320033259494, 1.29978930892136, -0.0073046796055854, -0.119917851520916, -1.28223623577339, 2.8255056654658, -1.20192675038753, 0.00275762403947858, 1.18569526731312, 0.00609942964002104},
    {-0.138647660917849, 0.144369641593842, -0.258546391444693, -0.0463981325961384, 0.14220532642428, -0.0578765020203715, 0, -0.18691086810133, 0.397478102435846, -0.100329151778503, -0.159759919491315, 0.241970447233903, 0.0410426412418466, -0.139672629582348, 0.057876502020371, 0.5807105873914, -0.850486150117399, 0.865665473759945, -0.601611891709939, 0.149517380433583, 0.0887486877626286, -0.39039896159007, 0.18691086810133, 0.263190829725001, -0.706493280700456, 0.375095452941702, 0.0357563875395927, -0.201888113176698, 0.0581838910459205, -1.33721875556561, -0.0979211474814907, 1.45171584725789, 0.467559084506109, -0.462203593151817, -0.00253269684193281, -0.33180016619494, 0.693910536116482, -0.263190829725001, 0.198292457517914, -0.0357563875395937, -0.0581838910459192, -0.826288696344617, 1.01102789552214, -0.00707914084577529, -0.0605070314488842, -0.999447431506264, 0.897038266851234, -3.7798781279922, 0.0125827445839717, 3.73658284124543, 0.00359565565878505},
    {0.0784651408728724, -0.0683533897674904, 0.32572554428539, -0.509884452975201, -0.0652094687232003, 0.0204847751966036, 0, -0.208140763677232, 0.267276533181229, 0.065871589837392, 0.0661075149614134, -0.358197104159232, 0.535979548866737, 0.0638662258776875, -0.0204847751966061, -0.145175181233359, -0.0695376468745341, 0.0875797716459684, 0.117021305356541, -0.0726977691427066, -0.0692427956925702, -0.261770932568323, 0.208140763677232, 0.623196840101039, -0.974294017178112, -0.424957031682421, -0.553197504703681, 1.53060340009786, -0.0308584486219002, 1.04317677449816, -0.0784457596626053, -0.932259454961707, -4.08938910669127, 4.06329401079973, 0.0013432428455157, 0.446705673804831, 0.954224639315861, -0.623196840101039, -1.49907466498073, 0.55319750470368, 0.0308584486219031, 0.211717580759078, 0.528305109813898, -0.00550560061290665, -0.0159209319672272, -0.524933903958722, -0.189206394610557, -3.40825190106056, 0.0200693778622512, 3.38650325893815, -0.0315287351171316},
    {0.301798607677329, -0.301286830201028, 1.40654666417306, -2.52815393023257, 2.02269013545502, 0.288623553688337, 0, -0.183558386739005, 0.0799279514730893, 0.0663981872654414, 0.105159398644885, -1.4000385651718, 2.49182453126872, -1.95327310133187, -0.288623553688341, -0.445702012696603, -0.00750135259921389, 0.0144911858225412, 0.438200401996973, -0.104672825540186, -0.0654440498583774, -0.077184891012398, 0.183558386739005, 0.842870751767021, -0.43140643754336, -0.552105134737886, -1.55748760326961, 1.22808339840383, 1.59472428096394, 2.36718295409855, -0.0276106047366291, -2.34608044836319, -5.43098296754976, 5.46731236651361, -0.0694170341231388, 0.544171421734892, 0.416600929338735, -0.842870751767018, -1.18593660306492, 1.55748760326961, -1.59472428096394, 0.176980645062198, 0.142636656653892, -0.00274306046069133, -0.00206428600222573, -0.143590794060957, -0.175402932164672, -1.18603283890329, 0.0148055082046234, 1.19396655190628, -0.0421467953389111},
    {-0.0586054310955141, 0.0509205961060772, -0.532258011356849, 2.09010537178824, -4.5253308777861, 8.1697622215787, 0, -0.100463988122249, -0.0240591474913983, -0.0131663105451285, -0.0120814643052654, 0.575471048921216, -2.18852029690417, 4.63478621313925, -8.16976222157871, -0.160269004707376, -0.0183398474773575, 0.0216392381118326, 0.164654449062342, 0.0130623359120987, 0.0137862608518712, 0.0246410722452093, 0.100463988122253, 0.588964361057188, 0.161360038511475, 0.124032534315479, -1.51089645482929, -0.581430010483414, 2.51452807187162, 0.860428183121186, -0.0125659819517168, -0.891075238733848, -1.76901935835187, 1.8674342834678, -0.109455335353145, -0.129872743494072, -0.165262895032893, -0.588964361057182, 0.595493206855284, 1.51089645482928, -2.51452807187162, 0.0195304385463759, 0.0111436765566036, -0.000581924753810997, -0.00028522907908742, -0.01176362686335, -0.0202260810741284, -0.104978417467041, 0.00390285652140707, 0.110818626645653, -0.0140631963718684},
    {0.186613680044605, -0.277763665240073, 0.588308925193383, -0.933533835729221, 0.622081242620198, -0.153888727424811, 0, -0.206357552845445, 0.886330083065447, -1.46329810777013, 1.15430179028823, -0.0592422377411523, -0.0565262386342826, -0.137345055287171, 0.153888727424811, -1.10023813827125, 2.82174955621817, -4.67926980054856, 3.04890836779712, -0.116237266097604, -0.088603899362991, -0.19568674623361, 0.206357552845446, 0.0536358142088592, -0.276814739084723, 0.765763861072021, 0.04006800572861, -0.34649773111116, 0.073861891698417, 0.440338302452296, -1.9748249391627, 1.00541994925817, 0.730625566558767, 0.259434507804736, -0.484736187333026, 0.0463676292082455, 0.0611160296101538, -0.0536358142088618, 0.0765008599775512, -0.0400680057286073, -0.0738618916984176, 0.863973448449889, 1.1452429125922, -0.690643336831837, -3.87473972459628, 0.406659094540924, 1.97270175195576, -0.599321238751768, 0.215698709474573, -0.212810251528501, 0.269996871133609},
    {0.26262833189321, -0.189231932784834, 0.633760217237778, -0.457019490504953, 0.257719653538468, -0.0578765020203716, 0, -0.198874814606376, 0.696999944491397, -0.818855703119532, 0.212195805364133, -0.371819690231106, -0.0477770585860796, -0.0508150060110061, 0.057876502020371, -1.24548839225751, 2.30045745660786, -1.95921130606192, 0.830845842603202, -0.124492791552473, -0.0856036070983833, -0.13742862014097, 0.198874814606376, 0.254658756240826, -1.06092755284112, 2.00197425378072, 0.0296278169706202, -0.198255339519809, 0.031527187503079, 2.09417343488009, -5.62642618267533, 3.27031222078857, 0.39128345699437, 0.113513092096663, -0.206904647527462, 0.209287444404248, 0.209184822479258, -0.254658756240824, 0.0390903298646112, -0.0296278169706189, -0.0315271875030767, 0.701171841494475, 0.701074455144476, -0.559571324350427, -1.88384187375822, 0.203384855073439, 1.09496701845208, -1.71401750495926, 0.851742730361863, -0.4972441932257, 0.159165009655198},
    {0.297257923557781, 0.157476470390114, -0.872076066213631, 2.13904455634208, -0.126473726995888, 0.0204847751966045, 0, -0.174529674546855, 0.406388232198368, -0.194647380835119, -0.0959038074837383, -0.80785783463157, 0.582773602692345, 0.0167396352982266, -0.0204847751966057, -1.00399696465103, 1.10343805136222, -0.287424187394771, -0.266751293264319, -0.0888416105525356, -0.0530308520444707, -0.0537881737027802, 0.174529674546856, 0.488557721821178, -1.33101223704312, 0.965996491865113, -0.389657078687915, 1.60855085901937, -0.0167207809286672, 3.03032836225611, -4.10055920747537, 2.75016474606446, -2.57873262678271, -0.143085532251721, 0.109734091697662, 0.263181640645725, 0.176168283759881, -0.488557721821178, -0.212902358285952, 0.389657078687916, 0.0167207809286694, 0.333250778373196, 0.23465782897747, -0.352600058495589, -0.450946031023232, 0.01302040390212, 0.302440670686308, -1.16456044056888, 1.15484395328324, -0.0646176919419501, -1.39564850073341},
    {0.105970427076992, -0.106326707514486, 0.723274251164083, -2.23508757936844, 5.18874690712782, 0.288623553688339, 0, -0.125371565743527, 0.134743224057091, 0.0363371457344551, 0.0293007961857373, -0.287413545533692, 0.0559394161257818, 0.48216748730357, -0.288623553688341, -0.321414156721487, 0.250240238067651, 0.0644294306757395, 0.00710076841559154, -0.0116435027310211, -0.000909440298816331, 0.0125210966997739, 0.125371565743527, 0.553906045354712, -0.685051636690258, -0.264481492289194, -0.964113478285581, 1.70703906501425, 0.864108097926592, 1.08267343025859, -1.30168684822267, -0.21684728766631, -0.538380849486131, 2.71752901272879, -5.67091439443139, 0.00661940068538665, -0.0636588433100189, -0.553906045354707, 0.158627651615904, 0.964113478285579, -0.864108097926588, 0.0438605321075279, 0.00875277710323065, -0.147264320756867, -0.0527330552360402, -0.0441804825388672, -0.00878477032620735, -0.0637074680233728, 0.748710480000268, 0.321569559627188, -1.86566671663016},
    {-0.397585858525551, -0.201011180775918, 0.994395503589035, -1.74785530185878, 0.466841577692106, 8.16976222157871, 0, -0.0593214248110993, 0.00144354837336478, 0.00625823945879545, 0.0122303528937875, 2.38339251504386, -6.02882067961084, 8.47493826989333, -8.16976222157871, 0.135326325796597, 0.112596325648861, 0.118558756518469, 0.232115631337551, 0.029314021873821, 0.0215863426605556, 0.026205856415926, 0.0593214248111057, 0.342547603810891, -0.00946163010062461, -0.056202467187301, -0.858787055312656, 0.0325011779561199, 1.36250767314749, -0.986107396037816, -0.892150076161718, -1.49953054643337, 3.34513536532596, 4.43154061614367, -8.94177984758543, -0.193857349669344, -0.171764330485647, -0.342547603810886, 0.590019162899959, 0.858787055312644, -1.36250767314749, -0.0121284151036357, -0.0119773405246714, -0.0276494047892949, -0.0109728073249754, -0.0158672415946811, -0.0184431523390067, 0.107563172081054, 0.181225960586258, 0.142496644775615, -0.622520340856083},
    {0.016723176927251, 3.08041774684675, 2.82690544195192, -1.94822363815395, 0.838592338884255, -0.153888727424815, 0, -0.111215180556962, 0.592811184964288, -1.33122411777889, 1.79464215090035, 0.00592046743460037, 0.0122940972627566, 0.0292027831626353, 0.153888727424814, -0.0590517234941539, -0.0369354053732363, 0.672036574969384, -3.673190369876, 0.00375856944258075, 0.00840057499662869, 0.0206438047286898, 0.111215180556966, 0.0266116616364414, -0.162668183067933, 0.517078239454573, 0.0174665587254971, -0.15113213901042, 0.0238986338841274, -0.0747350964839276, 0.459217284543321, -3.21730809744591, -0.167176941215267, 2.10310648210646, -0.86779512204689, -0.00326297763962865, -0.00566468766446, -0.0266116616364513, -0.0052629613696434, -0.0174665587254894, -0.0238986338841283, -0.0474450798075027, -0.114232253281345, -0.613454989692986, 0.291531044170466, 1.4370557960636, -2.04248668470588, 0.0443704494433212, 0.1683328707324, -0.558185711258257, 0.156395100380052},
    {-0.0748919790983802, 0.152389035168537, 5.95560097140644, -1.01996684985416, 0.350135184354868, -0.0578765020203684, 0, -0.0982464118371535, 0.436173238148095, -0.755014521756553, 0.645193617587331, 0.135886497249014, 0.0198848675421256, 0.0202742229580779, 0.057876502020368, 0.380511545357716, -0.780062924499115, 0.818769232853214, -0.496714909781973, 0.0147211173418592, 0.0147194624606224, 0.0252561692560355, 0.0982464118371536, 0.117299637543457, -0.595484601294155, 1.44564771090949, 0.0122404178827657, -0.0871496722331084, 0.0102008856557605, -0.855058167091066, 2.60738713258792, -7.84381643415232, -0.169132843110801, 1.16921482542284, -0.370409407312947, -0.0281837720981916, -0.0344809322633018, -0.117299637543454, -0.00504631343700494, -0.0122404178827672, -0.0102008856557602, -0.0926318057105816, -0.125197944102665, -0.461429407404134, 0.282468477085991, 0.865493003398594, -0.849751406304594, 0.239720053173965, 0.629965533557447, -1.65718399198525, 0.0921959856701116},
    {-0.250468856650955, -0.118966191906674, 0.634469463727498, 6.31394635781804, -0.175487291718017, 0.0204847751966096, 0, -0.0760925285239226, 0.233678626336278, -0.220216791197601, 0.0225758887620042, 0.74159770802542, -0.596171784672702, -0.0209632972537074, -0.0204847751966076, 0.864776154428892, -0.960584571721973, 0.201994090500994, 0.263249375349718, 0.026387759095896, 0.0207931822639915, 0.0279146966014816, 0.0760925285239246, 0.202464271172472, -0.707861369872462, 0.922591089649199, -0.149349364625149, 0.722158955944232, -0.00541014875847106, -2.94278434675719, 4.35460699960777, -2.7878898246035, 3.00880599945632, -8.72658057260165, 0.196450588971718, -0.0871123613139595, -0.0845594468167796, -0.202464271172472, 0.0862674026687297, 0.14934936462515, 0.00541014875846843, -0.10471106311826, -0.104940644881462, -0.261593322937763, 0.154946973567269, 0.304364253815073, -0.0991995583069101, 0.439645421146823, 0.792420816689234, -1.27512414948206, -0.808426358612965},
    {-0.502239635580975, 0.0924967660603466, -0.480953409540754, 0.747335856394906, 7.72170385245787, 0.288623553688343, 0, -0.0480952657120952, 0.0746638970428139, -0.00432325040203685, -0.00630423037076271, 2.17143575456293, -3.5188827636489, 2.43060574940823, -0.288623553688341, 0.995935126434355, -0.333171873528252, -0.12615363474249, -0.126866748642979, 0.0284626971354886, 0.0203563246598812, 0.0235023902616752, 0.0480952657120968, 0.206247726800621, -0.362754047829061, 0.0286133831984229, -0.343057137552251, 0.821952580939286, 0.279589414701215, -4.7539692378033, 1.97469838126244, 1.08878851151868, 9.22955364712538, -6.45800673987138, -10.1523096018661, -0.134728101274664, -0.114186206972159, -0.206247726800615, 0.258730806975472, 0.343057137552244, -0.279589414701211, -0.0623139719066883, -0.0533918868930551, -0.0981662873044943, 0.0258839073832412, 0.0373588126352176, 0.0142715977587146, 0.353373590997533, 0.4769402548012, -0.247258872921285, -1.08068338791476},
    {-0.778443022056047, -0.287417905294885, 1.65533088393824, -3.90144231251835, 4.4607553970921, 8.16976222157871, 0, -0.0205164010902964, 0.00471383992523653, 0.0046887080479677, 0.00658744957964596, 4.26837451395493, -9.64375602134093, 11.5471951890703, -8.16976222157871, 0.609933789752637, 0.168389984706707, 0.123358806511536, 0.164178346380067, 0.0169861519353288, 0.0115897539544466, 0.0122023345513382, 0.0205164010903048, 0.117064588039249, -0.0303449305791521, -0.0405908124477151, -0.288248324077205, 0.100482546550103, 0.440850772924441, -3.61066138287926, -1.13819595272799, -1.17484806228594, 9.38984729390296, 4.15535103995633, -16.0079505861624, -0.10033414839878, -0.0785514571420757, -0.117064588039245, 0.260111006953021, 0.288248324077192, -0.440850772924436, -0.0143687585604347, -0.0112846093954858, -0.0169161744765824, -0.00452949227441985, -0.00499385260692721, -0.00467535068013239, 0.0976924685509172, 0.108896387721208, 0.0432324922956046, -0.360593553503129},
    {-0.105791126909817, 0.349323335271634, -0.086759174907727, -0.0570689004231542, -0.0670256254939584, -0.153888727424811, 0, -0.137827978438842, -0.248651653930035, 1.21846090748446, -1.16291441591096, 0.0685178366798082, 0.250681372099602, -0.395723587573241, 0.153888727424812, -0.0616728150825705, 0.0234798980621433, 0.793407349269109, -0.998746640610501, 0.918408688265106, -5.3522224867339, -1.46805529712028, 0.137827978438839, 0.139655154915353, -0.406249020977916, 0.319803135154608, -0.545766751832532, 0.255042509647345, 0.50459022752652, 0.0231705192203608, -0.284297244909371, 0.279368063916934, -0.420905695196388, 0.22729322351994, 0.462749213067199, -1.4047701660255, -2.39852025019861, -0.139655154915353, 1.50578731876833, 0.545766751832536, -0.504590227526522, 0.31057615352105, 8.98663074865171, 1.71670695105032, -3.81070203653351, -4.85286916940227, 3.74463161065832, 2.35867451326691, 2.80476927117653, -1.27370748239603, -1.76082982841568},
    {-0.166507481624836, 0.425653570551386, -0.515016292023659, -0.0524324561977639, -0.0364185135341735, -0.0578765020203702, 0, 0.00659520248347668, 0.00871125236244255, 0.890030660034572, -1.17801602222524, 0.35537591884487, 0.0912942330174332, -0.161101220550595, 0.057876502020371, 0.0739985701518115, 0.117814001117102, 0.578022946722739, -1.0289816069182, 0.812864627383561, -1.5497016993325, 0.0385351639022019, -0.00659520248347611, -0.0225232879285928, -1.42034064031842, 1.56907021258008, -0.280693115987705, 0.191389442970318, 0.215379140036124, -0.249065371192065, -0.978000132593625, 1.38670587696448, -0.210489745356579, 0.171627968536914, 0.197519734084764, -2.73203034905887, -6.28302993581032, 0.0225232879285902, 0.846631832847529, 0.280693115987706, -0.215379140036126, -0.569696536575302, 3.57302214268966, -0.0472464162646438, -2.237016272644, -2.91335110339174, 3.17186420406098, 6.29902189298244, 7.70337057612873, -5.13606175650365, -1.03802127581785},
    {-0.00460700210468849, 0.555572946106276, -1.45661822356639, 1.01456732457268, 0.0295255943487214, 0.0204847751966054, 0, 0.116533764631271, 0.114924157681888, 0.372959141873574, -1.09432325878451, -0.0718887651732648, 0.271878352533969, 0.0752311081766655, -0.0204847751966061, 0.112055350153564, 0.0992514455241696, 0.211851884024746, -0.974124623704067, -0.0540083506450907, 0.0999436061059615, 0.292826340312171, -0.116533764631272, -0.591817435429701, -1.25525521036368, 3.1300768340807, 1.57410690042444, -2.56537901459856, -0.114228629394853, -0.522265034354518, -0.753698569186149, 2.80447059228032, 1.03208888873669, -2.31853456584334, -0.10475670252539, 0.838781333030829, -3.19838575998988, 0.591817435429703, -6.53657649976356, -1.57410690042444, 0.114228629394852, -0.392365525226447, 0.379400141279548, -0.407750497994058, -0.566236135885751, -0.852302889259085, 2.10693327054179, 3.18413321925917, 4.45364097035355, -7.15299138637069, 9.10195551436212},
    {0.290022490838601, 0.719267259522417, -2.9685039649583, 4.53211724574024, -2.87309406907589, 0.288623553688339, 0, -0.0532327497944617, -0.0428640277409205, -0.0705940464802375, -0.821547085810462, -1.41899947092762, 2.74129544088452, -2.54059536028731, -0.288623553688342, -0.0857969510501988, -0.0697237102610295, -0.111539550114655, -0.742229538935137, -0.392714611086449, -0.0426994994341207, -0.0379034404664841, 0.0532327497944591, 0.318225362310012, 0.363430474279349, 3.66370322652155, -0.923716771140346, -6.45727417585886, 5.90318622653941, 0.501980023649322, 0.565585753396183, 3.31993765884041, -1.39719307908959, -5.87621960753517, 5.41368942936319, 2.2160267281384, 0.321371230646193, -0.318225362310006, -5.70998387691732, 0.923716771140334, -5.9031862265394, 0.138925273616728, 0.0217632306974939, 0.0807674682074074, 0.156528451018951, 0.0915303152168645, 0.918807972261231, -1.12947227849089, -0.684801704925554, -4.75025767616905, 12.1672580527762},
    {0.00324591462100624, 0.880270785828909, -4.75479662623642, 10.5319042888745, -12.2449015666311, 8.1697622215787, 0, -0.207698228045339, -0.147879469090217, -0.174648000219722, -0.399512333614499, 0.223681572845235, -1.37517423910195, 3.70870869302661, -8.16976222157871, -0.206139781811669, -0.145023446147838, -0.167918669763815, -0.364434802726592, 0.0187943994619781, 0.0228041790188356, 0.0447894063950381, 0.20769822804534, 1.3378631899812, 1.14937500599562, 2.31353043502173, -3.9773655043959, -5.8237574730289, 9.30802124060394, 1.31281424654284, 1.10577601657157, 2.11252479027676, -3.83110263971933, -5.32562741005323, 8.53619287360445, -0.302082830260889, -0.348120158670753, -1.3378631899812, 1.76388677759243, 3.97736550439588, -9.30802124060394, 0.110306607089092, 0.0635302407153833, 0.103090062695185, 0.0929106314237944, 0.0883135804854988, 0.17750069563963, -0.841573595199363, -0.801254847324872, -1.16987400956146, 4.05987069543648},
    {-0.164081106760815, -0.267111615790656, 0.0747872960979266, 0.0592354988079009, 0.0992497134834083, -0.153888727424811, 0, 0.0258474166283123, -0.0442783824868053, -0.750189117397993, 0.837278678220517, 0.0665458915788041, 0.096898768058813, -0.312585918084556, 0.153888727424811, 0.393739939846182, -0.0156716242349997, -0.80292749435003, 0.856051901290317, 0.745012308897368, -1.22717631740947, 0.139454295182938, -0.0258474166283129, -0.0167945735219878, 0.356826687379339, -0.277252276618919, -0.323730553319049, -0.315435681467863, 0.421452558037833, -0.240753738827888, 0.383024145583484, -0.283603594432327, 0.166847911014204, -0.322982177880917, 0.213336204601147, -0.453535541804055, -1.12382186060609, 0.0167945735219879, 0.993461327268663, 0.323730553319051, -0.421452558037834, -2.6953504504096, -2.11304858779617, -0.0951759126961343, 4.28813404245509, 4.09041402260363, -3.17507457916337, -0.780933124709772, 0.766995173226753, 1.51172094313274, -0.6780256458008},
    {-0.0960766222659441, -0.299846929362777, 0.386955294238903, 0.0431773246303438, 0.034554401842552, -0.0578765020203712, 0, 0.104452923995495, -0.099037898280039, -0.40880692731083, 0.739266253196101, 0.139181614087523, 0.0141621012778624, -0.125614762862231, 0.0578765020203712, 0.235757381825313, -0.0807308548564224, -0.578224650628529, 0.819121675288359, 0.265902216333921, -0.134088092702238, 0.360030023483157, -0.104452923995495, -0.269880462004838, 0.751677291499641, -1.07921447808308, -0.156563136896518, -0.151673252977715, 0.179892682347762, -0.444678777621622, 1.12475279339252, -1.20621092409733, 0.1157093876278, -0.173048813536004, 0.0910603610196778, -0.353980819098922, -2.73255387695276, 0.269880462004839, 0.551374027313543, 0.156563136896519, -0.179892682347762, -0.84954520251427, -1.09554724898114, -0.26099212520312, 2.14880580708577, 1.63844226899421, -2.30442907410152, -2.89214877130877, 1.98087658545312, 4.32534406849076, -0.399700774335826},
    {0.134579466303349, -0.260145422130515, 0.651010728103405, -0.408482387606868, -0.00811565004606909, 0.0204847751966037, 0, 0.0785206721957281, -0.0183939829723469, -0.0602733003365504, 0.408505487798717, -0.527538352011229, 0.655871713874953, 0.0564104859792706, -0.0204847751966056, -0.0849430189981903, -0.103147735711714, -0.261503124058778, 0.575159834595847, -0.33102728191393, 0.0967766395614573, 0.127853408251256, -0.0785206721957282, -0.344609736372976, 0.138493039370227, -1.05258535204336, 0.631837609818955, 0.588960351966716, -0.0954080071974577, 0.489955712403519, 0.981542151457889, -1.59497023995358, -1.38969198064055, 1.14230265437246, -0.0482948359332008, 1.69006297404618, -0.962641268570258, 0.344609736372978, -4.09376198928806, -0.631837609818955, 0.0954080071974588, 0.307444391704979, -0.205054917092431, -0.109459425278909, 0.615912055004751, 0.168551577867522, -1.00083465259452, -3.58098529350099, 0.824148229200028, 2.94350767149817, 3.50480163732135},
    {0.299790343915579, -0.0105569750572726, -0.135243708104242, 0.63425316236435, -0.927843770282096, 0.288623553688338, 0, -0.117049123802541, -0.0284954840174734, -0.0180153481386409, -0.0312623596336963, -1.34163924975308, 2.25682373763315, -1.56797021089041, -0.288623553688341, -0.270192407039854, -0.104172465397177, -0.0915182376362797, 0.176649741215002, -0.310127615638405, -0.064102897287015, -0.048154734143141, 0.11704912380254, 0.655077736825815, 0.214022498231874, 0.428244358689191, -1.68442588453943, -1.74174309072225, 4.93056107714251, 1.40753902906185, 0.641003470710207, -0.571659541914732, -3.1378908276739, 0.246813927676395, 2.49581398117251, 1.52379537311955, 0.361678239846248, -0.655077736825814, -2.94338483346865, 1.68442588453943, -4.9305610771425, 0.325360727990989, 0.0891287565218545, 0.0766502181606152, 0.148171632593398, -0.00701051109619959, -0.132142385312286, -2.1186871818259, -0.575700738078122, 0.166647450017159, 4.6851279241909},
    {-0.103138285400148, 0.475450897669484, -2.77864520754328, 6.81314195983391, -9.1776713616849, 8.1697622215787, 0, -0.200550049418396, -0.104688629505173, -0.103018390649352, -0.195002959051497, 0.823425571056475, -2.74590631055142, 5.24232379549969, -8.16976222157871, -0.17201425500182, -0.0797670410881696, -0.0639359920172162, -0.056595324162127, 0.0577873067345085, 0.0415195882684573, 0.0597985776505827, 0.200550049418399, 1.26364805283861, 0.785506100520559, 1.25004489380432, -3.62665390395789, -3.64577903837316, 7.77440613813087, 1.01486465155501, 0.516189215215359, 0.42416576971643, -2.59830806090268, -1.46892758837981, 3.93534756618522, -0.503806640549349, -0.448684329606797, -1.26364805283861, 2.08248404772789, 3.62665390395787, -7.77440613813086, 0.0712223386968572, 0.0392878229198107, 0.0448900518545934, 0.0362257204065342, 0.0222109794610793, 0.0297675932135927, -0.476725972130164, -0.33682177091376, -0.269512281124802, 1.56329499064528},
    {0.0564307431585078, 0.158558075149595, -0.0772323978522224, -0.162307063211109, 0.351454288722323, -0.153888727424811, 0, 0.106547386759109, -0.418572933892423, 0.54883206817561, -0.605941080999178, -0.0254222755673757, -0.0368690228656234, -0.186483630465096, 0.15388872742481, -0.204315337434387, 0.188720968758324, 0.35692438801165, -0.55631883764369, -0.199455171238249, 0.124670495976095, 0.22209716265081, -0.106547386759109, -0.0448341343681107, 0.337372953699174, 0.532376858808736, -0.0864364733586957, -0.782778849414984, 0.295350270418371, 0.143646495895819, -0.534628813489927, 0.493636991013706, 0.560906291813921, -0.36173020573719, -0.164970658257226, 0.120932596476199, -0.17901199457624, 0.0448341343681114, 0.415346878312043, 0.0864364733586964, -0.29535027041837, 1.12700518727133, -1.89667260375809, 0.196475771241613, -4.19452937094158, 1.22317003960639, 3.87292043590767, -1.83980612928437, -0.158360959122937, 1.18649667399944, 0.367431971102941},
    {0.169880004840814, 0.144369641593842, -0.258546391444693, -0.0463981325961384, 0.14220532642428, -0.0578765020203714, 0, 0.0601843095813752, -0.171513359938569, 0.075571528982518, -0.346152320938611, -0.277936485181336, -0.0441822278518126, -0.071789300571367, 0.0578765020203705, -0.519775202991848, 0.391647589650999, 0.229097457168837, -0.415219490262644, -0.372112559302997, 0.071962346883186, 0.0865848309499942, -0.0601843095813753, -0.113567875147136, 0.532156172876649, 0.812720499751801, -0.0269329983295788, -0.437431610935616, 0.126067220056901, 1.09261087104033, -1.57021879486209, 1.0140908004478, 0.317240455840848, -0.226660095392897, -0.0704160258529126, 0.773906196019206, -0.268647598554563, 0.113567875147137, 0.2208279407424, 0.0269329983295797, -0.126067220056899, 1.46283143531814, -0.516709293274423, 0.0849285289885741, -2.10227215775785, 0.369175417408718, 1.35770560268132, -5.55685773081993, -0.263508574322089, 3.97023103504892, 0.216603670193218},
    {0.294232960746207, -0.0683533897674906, 0.32572554428539, -0.5098844529752, -0.0652094687232008, 0.0204847751966045, 0, -0.0624268174830956, 0.0974322990067761, 0.033712302805978, 0.143235360960613, -0.873832507491196, 0.724042594224888, 0.0278635766407037, -0.0204847751966066, -0.661320832677905, 0.273084803804748, 0.122462998537098, 0.0398934593573419, -0.384261280165229, -0.0478719110545667, -0.041632179863002, 0.0624268174830956, 0.227178570980758, -0.498632187415588, -0.920755739514808, -0.283119958636484, 3.31636320966726, -0.066861097858885, 2.26497186338524, -1.28040415305011, -0.436460747129319, -2.49169234248002, 2.27753420123033, 0.0373458920824993, 1.30748519668668, 0.213062250645694, -0.227178570980758, -1.41706016427169, 0.283119958636485, 0.0668610978588879, 0.996004360448219, 0.164744553906034, -0.0558001191437746, -0.563048106773329, -0.150584945657446, -0.191930334470275, -4.499529279735, 0.285569936769897, 4.11279982256313, -1.89930304539557},
    {0.197406415132327, -0.301286830201028, 1.40654666417306, -2.52815393023257, 2.02269013545501, 0.288623553688339, 0, -0.192304353920289, 0.0930541336911329, 0.09169219576941, 0.227849200383545, -0.723022422627704, 0.834525081479549, -0.0927032580218592, -0.288623553688342, -0.374848738444312, 0.0737241538906994, 0.0894943993640001, 0.315510600258313, -0.117123793366608, -0.0302669217370265, -0.00426482594360779, 0.19230435392029, 0.981291352696321, -0.595748244892208, -1.19624793502749, -2.1508035702318, 2.66089216880691, 3.45529412427395, 1.59672385676893, -0.578310450240701, -1.70193764807359, -2.34087474735752, 4.03450359611053, -1.92998687743315, 0.394872675081429, 0.0273041343774033, -0.981291352696322, -0.121953120237945, 2.1508035702318, -3.45529412427395, 0.258656369720962, 0.0848998722109544, -0.0887893077475261, -0.0936816225277979, -0.146325146243339, -0.275700154210102, -1.10763294481315, 0.568444110514811, 1.9090082047592, -2.53893904856897},
    {-0.304744182307483, 0.0509205961060774, -0.532258011356847, 2.09010537178824, -4.5253308777861, 8.1697622215787, 0, -0.172286458511462, -0.0429252705156645, -0.0249690209116749, -0.0261769467768742, 1.9038514267879, -5.0544025264641, 7.56849403744909, -8.16976222157871, -0.0263535680052577, 0.0372705104135244, 0.0641567122591937, 0.178749931533951, 0.0936331936893543, 0.0603813970734702, 0.0717913590691101, 0.172286458511467, 1.05080425362139, 0.306008441931422, 0.268741682907097, -2.86531333486939, -1.25978623570313, 5.44823589618146, 0.0379195220042552, -0.373728550109844, -1.03578438732547, 0.418506645988337, 2.54579050868752, -3.04316315966298, -0.649885244727968, -0.511790879101468, -1.05080425362139, 2.10695855637511, 2.86531333486938, -5.44823589618146, 0.00186491755528256, -0.00499960496556834, -0.028866088553446, -0.0183803196128271, -0.0304127711962314, -0.0509408448549413, 0.0538107704370404, 0.205782437170047, 0.327332791383839, -0.847172320671973},
    {0.299991988790641, -0.277763665240072, 0.588308925193385, -0.933533835729222, 0.622081242620195, -0.153888727424811, 0, -0.116259944551923, 0.586606245733343, -1.27147304705768, 2.50102932602933, -0.0732726949488136, -0.0470325451595032, -0.0511701535161591, 0.15388872742481, -1.53898861463403, 3.18911252263764, -3.3745330636102, 1.70218083205602, -0.311498178960916, -0.0640583246327792, -0.048252108553029, 0.116259944551924, 0.0354981786256079, -0.240526846789181, 1.65918297057853, 0.0348154549389279, -0.750757725754915, 0.160036793469428, 0.417292329309026, -1.04432939930525, 0.11200083975165, 0.316871878440241, 0.663694502448485, -0.570911089104035, 0.0835916117926707, 0.0197848686501448, -0.0354981786256094, 0.0617546157130715, -0.0348154549389243, -0.160036793469429, 1.77400054365301, 0.431579485806826, -0.538354137180316, -4.43967164502638, 0.903951885883636, 0.476139954304964, -0.563180898689719, 0.220741978139039, -1.17959368368148, 0.68900311004184},
    {0.272170305024623, -0.189231932784834, 0.633760217237777, -0.457019490504953, 0.257719653538468, -0.0578765020203713, 0, -0.157941208263556, 0.632653950000106, -0.926989625497546, 0.459765320075943, -0.309548329113105, -0.0281626337102479, -0.0140321370142741, 0.0578765020203703, -1.18360794422825, 1.95151688520918, -1.43412364111211, 0.583276327891389, -0.224563774662214, -0.0571233170980158, -0.034446293820188, 0.157941208263555, 0.231149039983691, -1.20102825338039, 4.33768392355258, 0.0335403158984841, -0.429560468806963, 0.0683100564998087, 1.45200103969364, -2.71081547883501, 0.934602551016698, 0.140363902831375, 0.344818221383825, -0.243687516524193, 0.267298454503272, 0.0653927350051022, -0.23114903998369, 0.0233884039166419, -0.0335403158984836, -0.0683100564998066, 1.05336325097049, 0.284705323125869, -0.598207656179918, -1.9665780722645, 0.699407619469694, 0.678013275880285, -1.33222818152909, 1.13563551837528, -3.27275419652676, 0.406172064890322},
    {0.148805352758509, 0.157476470390114, -0.872076066213632, 2.13904455634208, -0.126473726995889, 0.0204847751966065, 0, -0.201751253837805, 0.516115061727203, -0.287470671894172, -0.207795081851867, -0.299004451343537, 0.107758535600085, -0.0027685524956415, -0.0204847751966068, -0.527156928138635, 0.654649660726365, -0.278914536840163, -0.154860018896189, -0.0712456823987459, -0.0144818949841142, 0.011297932591398, 0.201751253837805, 0.620470719319343, -1.96574431384856, 2.09302764261745, -0.57547644226264, 3.48525221451189, -0.036228968722536, 1.10205620022749, -1.55410927798244, 1.62313359531212, -0.227016204197927, -2.01978688774424, 0.129242279491529, 0.105440343947137, -0.0430308053313962, -0.620470719319345, 0.0762933452315845, 0.57547644226264, 0.0362289687225379, 0.262593903449167, 0.0305091825030691, -0.527412994318602, -0.37030745038931, 0.271443384375218, 0.386754311190754, -0.222132441935149, 2.00877511917996, -1.97633554462944, -3.56154555974347},
    {-0.144387432414532, -0.106326707514486, 0.723274251164082, -2.23508757936844, 5.18874690712782, 0.288623553688342, 0, -0.196100657264722, 0.222368167659387, 0.0651892255343076, 0.0634861274175505, 0.782380615353437, -1.61328408499108, 1.49032512781454, -0.288623553688342, 0.117560315409556, 0.141496982482442, 0.0187414048532432, -0.0270845628162205, 0.0686742481920367, 0.0470535208723676, 0.063869152575862, 0.196100657264723, 0.914117004568585, -1.22898991498139, -0.573052882679938, -1.72962982387027, 3.69864692076087, 1.87226573843756, -0.97508143031845, -0.622297538923501, 0.0917241027244324, 3.12245050737735, 0.725921156982173, -6.67907203494237, -0.413629024660865, -0.352993619637022, -0.914117004568584, 1.06233480714808, 1.72962982387026, -1.87226573843756, -0.0855887567240946, -0.091070315196612, -0.286237320235252, -0.0546227945819298, -0.0211724312100614, 0.00805117569643428, 0.800563378721648, 1.58198353461841, 0.186118528619156, -4.76098172790895},
    {-0.581370126327104, -0.201011180775918, 0.994395503589036, -1.74785530185879, 0.466841577692106, 8.16976222157871, 0, -0.114067231912179, 0.00283446870569535, 0.0126860417796902, 0.0264995441507867, 3.30747149106532, -7.839041699661, 10.0645802651882, -8.16976222157871, 0.288503254143632, 0.144130385484699, 0.131901227394149, 0.217846440080553, 0.0881404697513846, 0.0568962490251328, 0.061107962874259, 0.114067231912186, 0.67260680772715, -0.0191796168156935, -0.121774062739297, -1.74084237832473, 0.070420404683289, 2.95214966844236, -1.82186652375427, -1.04604152001872, -1.43395895088138, 5.19327561210329, 4.3936213894165, -10.5314218428803, -0.5461504477717, -0.413491004488491, -0.672606807727151, 1.51818485993804, 1.74084237832472, -2.95214966844235, -0.0485507348020232, -0.0376931152815749, -0.0639424315799587, -0.027875853564575, -0.0318891755232504, -0.0382134255355815, 0.361818435163328, 0.43267062130418, 0.306106075347685, -1.58860526462133},
    {-0.23477560772866, 3.08041774684675, 2.82690544195192, -1.94822363815395, 0.838592338884254, -0.153888727424814, 0, -0.183808928740489, 1.02518120257737, -2.46945870260461, 3.88845680297295, 0.0623938398739496, 0.0442565832486221, 0.0570853946158793, 0.153888727424814, 1.38653809489941, -3.48823959814697, 5.02306438607807, -5.7670050219486, 0.0858237942879019, 0.0560971556399136, 0.0697870357124662, 0.183808928740493, 0.0460210197968399, -0.30175411859594, 1.12035505065331, 0.0324009645507016, -0.327458481785931, 0.0517812453373712, -0.419653713722649, 1.35093934054143, -3.82058490864465, -0.375465769976637, 2.27943282488197, -0.895677733500132, -0.0254504080518258, -0.0205412715312111, -0.046021019796849, -0.0222910415303121, -0.0324009645506936, -0.0517812453373727, -0.577240863384114, -0.475919291317898, -1.09496823828985, 1.85824017711212, 2.88928083828259, -5.25527991098885, 0.215917189126893, 0.322295390127158, -1.31082183172837, 0.34974952331623},
    {-0.319307309300148, 0.152389035168537, 5.95560097140644, -1.01996684985416, 0.350135184354868, -0.057876502020368, 0, -0.169696803710653, 0.782920000021125, -1.43794178384007, 1.39794304412362, 0.403549372775828, 0.043262558014752, 0.0321756283939297, 0.0578765020203675, 1.5635024241056, -3.03612507050114, 2.88900525684541, -1.24946433631826, 0.0947241162295673, 0.0609912369741314, 0.0719463341830898, 0.169696803710653, 0.210549901268391, -1.13411353710397, 3.13228945022165, 0.0233121454198658, -0.18882746942152, 0.0221022910916101, -2.22039967365901, 5.39170750294121, -9.53045817346448, -0.294188330771846, 1.27089262261126, -0.382310812748798, -0.132858096396542, -0.104219219766824, -0.210549901268389, -0.0173522763725336, -0.0233121454198685, -0.0221022910916101, -0.521188758929383, -0.414744550958162, -0.854866334204219, 1.26558176678948, 1.7916950978241, -2.23706016821328, 0.903444072703633, 1.23833275687079, -3.90287542652873, 0.206179745794052},
    {-0.467046932097559, -0.118966191906675, 0.634469463727498, 6.31394635781804, -0.175487291718017, 0.020484775196611, 0, -0.140239979255144, 0.442904859355278, -0.435651573811337, 0.0489152493134954, 1.25354229882125, -0.899206741227309, -0.0272753348567055, -0.0204847751966084, 1.62807841497893, -1.89512629921112, 0.616150993438201, 0.236910014798228, 0.0966434754978204, 0.0620437377508579, 0.0688390494280754, 0.140239979255146, 0.383742454130407, -1.40035152700259, 1.99898102087305, -0.295455607144353, 1.56470408524644, -0.0117221863614697, -4.8252683932684, 6.80153638654701, -3.86427975582735, 4.15438608531313, -9.56912570190385, 0.202762626574716, -0.284686804050647, -0.217651411917983, -0.383742454130409, 0.243196116704133, 0.295455607144353, 0.0117221863614668, -0.372010348732349, -0.286645583240597, -0.511743908783357, 0.524373302551416, 0.660253419301079, -0.297921678630382, 1.31526916246875, 1.61800293892057, -3.02956337929116, -1.80790020195057},
    {-0.658971363590877, 0.0924967660603462, -0.480953409540754, 0.747335856394907, 7.72170385245787, 0.288623553688345, 0, -0.0949022450750639, 0.149783565838486, -0.00889314599221364, -0.0136593958078877, 2.7497189701037, -4.25860765292945, 2.75680360047957, -0.288623553688342, 1.33400723179773, -0.510734702388036, -0.137286348673303, -0.119511583205853, 0.0780938424138092, 0.0506765723296676, 0.0534757459605022, 0.0949022450750658, 0.413754454158211, -0.746203528965416, 0.0619967075319916, -0.705685982583155, 1.78092724695623, 0.605787265772549, -6.05034993514167, 2.72617918739361, 1.05540518718511, 10.9282532024229, -7.41698140588832, -10.4785074529375, -0.353281126407797, -0.266409670022198, -0.413754454158207, 0.63582685122512, 0.705685982583147, -0.605787265772545, -0.171833950858447, -0.130044009447203, -0.203259311798994, 0.0774252969728163, 0.0882605831097559, 0.0299742072797034, 0.906574616791913, 1.0126131989876, -0.615290197916105, -2.41675409818135},
    {-0.852928776435765, -0.287417905294885, 1.65533088393824, -3.90144231251835, 4.4607553970921, 8.16976222157871, 0, -0.0428399680424282, 0.00990851802822205, 0.00995486939805093, 0.0142730477601971, 4.62479994033092, -10.2960803115461, 12.0615371748882, -8.16976222157871, 0.686806990944573, 0.173907889260906, 0.123139053325669, 0.156492748199516, 0.039877217944941, 0.0262713444420425, 0.0267918654817157, 0.042839968042437, 0.246070422298508, -0.0644270911558054, -0.0879482412253125, -0.61199682109661, 0.217715850213799, 0.955192758742367, -4.00072964471363, -1.15191054604721, -1.12749063350834, 10.1594048877718, 4.03811773629264, -16.5222925719803, -0.232099332087836, -0.174205865569752, -0.246070422298506, 0.58868680013878, 0.611996821096597, -0.955192758742362, -0.0344961879517598, -0.0259226052106022, -0.0367003835099455, -0.00993231890904149, -0.0103036086294903, -0.00972175884434868, 0.229018327121694, 0.238632956725541, 0.0910292461914781, -0.806402650352585},
    {0.218256695635769, 0.349323335271633, -0.0867591749077273, -0.0570689004231552, -0.0670256254939584, -0.153888727424811, 0, 1.68633541906575, -3.67280844988191, 3.65012267913837, -1.78910813915849, -0.0660288489812659, -0.0587187272009753, -0.124017235870966, 0.153888727424811, -0.0455399181484161, -0.0459795078401056, -0.103507687555919, -0.372552917362964, -1.36161681179277, 3.75564547866194, -6.79578218749924, -1.68633541906575, 2.06283217881599, -1.2169933033885, 0.492007308710949, -1.63494420391081, 0.392375073864779, 0.776296579228799, 0.0173080114119516, 0.0283161221164542, 0.107163890360595, 0.0258269683216171, 0.0899606593025101, 0.191042861364926, 0.506230937110604, -2.25179764377299, -2.062832178816, 0.726009965990636, 1.63494420391082, -0.776296579228801, 0.356917918164781, -1.65189099676162, 10.4685906373812, 0.583922156957063, -5.75387716103871, 2.20988487582943, -0.222661678810298, 3.46879094716151, -0.775576567011276, -1.11838503985542},
    {0.280175037546945, 0.425653570551386, -0.515016292023659, -0.0524324561977643, -0.0364185135341725, -0.0578765020203721, 0, 0.0719510337707424, -1.84314901856563, 2.85587895540873, -1.81234149700631, -0.383747306192838, -0.0469015469885916, -0.045126163604187, 0.0578765020203707, -0.109131920433172, -0.0794518769518529, -0.122588678576169, -0.394656132137137, -1.3504061485995, 2.55462266569428, -2.28384511302603, -0.0719510337707426, 4.76553477194971, -4.5575069785119, 2.41396636745545, -0.900671851963223, 0.294446784288056, 0.331354196982531, 0.17688902681516, 0.180064849312229, 0.541809722089106, 0.0307633759671831, 0.0685706272191752, 0.0815446771383588, 2.15932583026536, -5.64720483021854, -4.76553477194971, 0.364848876878041, 0.900671851963217, -0.33135419698253, 0.622472198699773, -1.675612481144, 4.12699413159167, 0.633647912920313, -3.73488913995902, 1.90662753398573, -1.4163317975048, 10.2047118087304, -3.15696040021602, -0.659295661166097},
    {0.288734078223699, 0.555572946106277, -1.45661822356639, 1.01456732457268, 0.0295255943487201, 0.0204847751966046, 0, -0.111229861949401, -0.225527686738773, 1.54782147144669, -1.6835827489748, -0.764302484300341, 0.528230785883265, 0.0137224969121033, -0.0204847751966068, -0.188039020221462, -0.121944075920714, -0.149458794674026, -0.384865133513774, -0.883393092814753, 0.805867617127966, -0.104817635449233, 0.111229861949399, 1.16138521157219, -5.20944722519986, 4.8155271475059, 6.53271681876414, -3.94675688274905, -0.175737240659418, 0.606291861760849, 0.49560856725077, 1.11902027885511, -0.605641412763089, -0.937156697692855, -0.043248091260823, 2.50718668733059, -2.42117474816067, -1.16138521157218, -1.83431901477316, -6.53271681876415, 0.175737240659421, 0.700761876234939, -0.923965083408197, 0.330345322188007, 0.572832345887159, -1.42972400516646, 1.29338161966746, -2.87460732686506, 7.63062197336052, -4.44810650797143, 5.7810758975222},
    {0.0751681159726949, 0.719267259522417, -2.96850396495829, 4.53211724574024, -2.87309406907589, 0.288623553688339, 0, 0.105639734313316, 0.109436381263989, 0.311379319648968, -1.26392497832616, -0.148269706050578, -0.176927006276895, 0.63808925454273, -0.288623553688341, -0.211189019346044, -0.135104085812631, -0.148290623916995, -0.299851646419441, -0.0631300436915664, -0.0121557779410535, -0.0243048703807531, -0.105639734313319, -0.812462895183729, -1.60303509237852, 5.63649497533857, 4.07437048996136, -9.93431814649686, 9.08187084136945, 1.00403191404936, 0.765595846936132, 1.34714591002338, -1.95601460256615, -2.39917563689719, 2.23500481453316, -0.220040243402516, 0.356020179816334, 0.81246289518374, 2.20632583134578, -4.07437048996137, -9.08187084136944, 0.427495139027528, -0.134388071434584, -0.0851315108832326, 0.325974203055822, -0.164835470273332, 0.573585679934372, -2.43265252888493, 1.24701491256217, -2.98380220305112, 7.72799231515107},
    {-0.424231227319638, 0.880270785828909, -4.75479662623641, 10.5319042888745, -12.2449015666311, 8.1697622215787, 0, -0.18315779211261, -0.140654718102906, -0.18817253629975, -0.614637464274605, 2.51931486939396, -6.30034913894454, 8.72079246890364, -8.1697622215787, -0.13177688330618, -0.0860162965477148, -0.0889367065888872, -0.149309672066486, 0.325663834808276, 0.112567741267965, 0.100173986672979, 0.183157792112612, 1.27250098343437, 1.23838125696052, 3.55929557227636, -4.28536801916839, -8.95967214175365, 14.320105016481, 0.781804918507113, 0.586917185313227, 0.866759653022107, -2.04184240860148, -2.18971274132848, 3.52410909772742, -2.12922603348466, -0.881972458542525, -1.27250098343437, 6.38105916266251, 4.28536801916838, -14.320105016481, 0.101061439729566, 0.0364814049019613, 0.0404807314299329, 0.0758689211920228, 0.0391233901298175, 0.112043268544736, -0.690048109523711, -0.356408798417978, -0.740021429267993, 2.57861297909114},
    {0.28628929987628, -0.267111615790656, 0.0747872960979274, 0.0592354988079009, 0.0992497134834068, -0.153888727424811, 0, -0.0264986033169903, 2.18799616918965, -2.43983545736058, 1.28812755044812, -0.0770893893180529, -0.0575512666200245, -0.0856466499156495, 0.153888727424811, -0.47245337639004, 0.0230586463899408, 0.0250140168517584, 0.405203029062714, -1.32777853203544, 2.37046405856914, -1.88811166644526, 0.0264986033169906, 0.829896226228096, 1.16050524302496, -0.426544118735146, -1.05286688956292, -0.485288115250573, 0.648391826206737, 0.148206917989049, -0.0115930724528164, -0.134311752316104, 0.151445511910329, -0.153129744098206, -0.0136030635677567, 0.414416267213997, -1.0014475889772, -0.829896226228098, 0.418775025703622, 1.05286688956292, -0.648391826206737, 2.55269844197491, -6.23784955395089, -0.299884502744396, -0.199677709985014, 6.30722095274233, -2.31336975040257, -1.09053175400229, -0.159057654047753, 1.10265960552343, 0.0665130895469497},
    {0.301946133397289, -0.299846929362777, 0.386955294238903, 0.0431773246303439, 0.0345544018425522, -0.0578765020203709, 0, -0.203731558094384, 0.57575865788657, -1.48295613960183, 1.13733844253902, -0.377044237587165, -0.0399716863386964, -0.0287480743053694, 0.0578765020203704, -0.459160981004959, 0.00726185199463562, 0.0287504390303695, 0.421049485945441, -1.10820787912762, 1.37285619648022, -0.479011407990876, 0.203731558094385, 1.56895506964764, 2.72672594312746, -1.66033835355253, -0.567936230002975, -0.233344644870111, 0.276759370904623, 0.653949888637554, -0.038773896661423, -0.625087048627867, 0.0881717833519627, -0.0913774216436102, -0.00580632753718268, 1.5370689233873, -2.26854223611181, -1.56895506964764, 0.194134721823643, 0.567936230002975, -0.276759370904623, 1.92208856918342, -3.0283230510661, -0.0967472498956951, -0.113964181125395, 3.13842299418771, -1.83725495146942, -3.39055267675164, -0.458183707015652, 3.51382210691688, 0.0392099230464676},
    {0.236643324868562, -0.260145422130515, 0.651010728103404, -0.408482387606867, -0.00811565004606961, 0.0204847751966044, 0, 0.0456413589580973, -0.0169906995074031, -0.36631021271669, 0.628473155988077, -0.56981887990348, 0.332539840484562, 0.00503620216509891, -0.0204847751966057, -0.355605588792676, -0.0123738337254011, 0.0362893533735429, 0.355192166406486, -0.550092117280208, 0.298208058414282, 0.0105436529618649, -0.0456413589580973, -0.318319337733484, 0.841689677323434, -1.6193702603855, 3.83998500103423, 0.906097426369832, -0.14678229101163, 0.996391741891085, -0.0493982584795609, -1.02818533161145, -0.749223032847038, 0.825165579969345, 0.00307944788097117, 1.31830684605258, -0.522314214044908, 0.318319337733488, -0.562282724682402, -3.83998500103423, 0.146782291011632, 0.961897301525393, -0.671872415705174, 0.00644704654553757, -0.0476881225865653, 0.739974570007579, -0.992590217646698, -2.97018802914949, -0.319375463278529, 3.2712514434824, -0.343814701687435},
    {-0.0291979345553113, -0.0105569750572729, -0.13524370810424, 0.634253162364348, -0.927843770282097, 0.288623553688339, 0, 0.0490770986832653, 0.0144672844878004, 0.0132869869789214, -0.0480961808579284, 0.305128780364223, -0.899029556149414, 1.08698561075244, -0.28862355368834, -0.171446305662548, -0.0126224878672655, 0.0303401407031635, 0.193483562439235, 0.10851173197681, -0.018833794949788, -0.0169486831388868, -0.0490770986832651, -0.332585892363576, -0.157849525044949, 0.658840803069203, 1.24232652195232, -2.67961829116481, 7.58551689878536, 0.683463097983021, -0.051092183948249, -0.802255986294754, -0.919912734333888, 1.18468912811895, -0.159141840470347, -0.93388159476952, 0.184923548428626, 0.332585892363579, 3.13922086680566, -1.24232652195233, -7.58551689878536, 0.243057257384394, -0.0192712772251273, 0.00248139865108689, -0.0181697097339842, 0.0248180851959922, -0.285303098769291, -0.955574336252129, -0.0270740233836783, 1.23061512795244, -0.459602575640859},
    {-0.50453951163875, 0.475450897669484, -2.77864520754328, 6.81314195983391, -9.1776713616849, 8.1697622215787, 0, -0.202507479822821, -0.112401311572458, -0.122153260624196, -0.300006067880517, 2.92484054429373, -7.09932077313887, 9.42860290518038, -8.16976222157871, -0.0305882458433286, -0.000575610963322131, 0.0118446861090279, 0.0484077846668938, 0.315790554507992, 0.127284178983565, 0.115474534996166, 0.202507479822826, 1.35674427276765, 0.931407788589716, 1.92315570537225, -4.30027684116911, -5.60891916196376, 11.9606852478116, 0.141476565796491, -0.0387268606954269, -0.248945041851518, -0.208033721905833, 0.494212535210786, -0.250931543495476, -2.00393582426727, -0.956873899197072, -1.35674427276766, 5.7622755731041, 4.3002768411691, -11.9606852478116, 0.015275008153858, 0.00372984998705329, -0.00307322342370464, -0.00418127984353254, -0.00886076834642814, -0.0268782149378036, -0.0587219878218261, 0.0254661106073722, 0.139502106716841, -0.153356411140347},
    {0.27076488372056, 0.158558075149595, -0.0772323978522219, -0.162307063211111, 0.351454288722322, -0.153888727424811, 0, -0.0374957547900431, 0.265135099080673, 2.57445587305492, -0.932221756849497, -0.0612235461982248, -0.0345884911148397, -0.0274465741133896, 0.15388872742481, -0.907720359589545, 1.002394615068, -0.293959052555239, -0.230038161793371, -0.73898937990598, 0.548630123230591, -0.0207055380471606, 0.0374957547900416, 0.0283991192343448, 1.58254561353879, 0.819045458687702, -0.405455328483567, -1.20428123642479, 0.454387326770081, 0.223165715310623, -0.291678162394914, 0.206968391134737, 0.137123373053339, 0.0597721812726109, -0.324007714608932, 0.174542906574692, -0.123587780441426, -0.0283991192343438, 0.0940474914363877, 0.405455328483568, -0.45438732677008, 2.69368737707081, -2.17500129757813, -0.244429561033511, -3.52065631191059, -0.948084698707377, 2.49818007159526, -0.6919617283272, -1.45895783309737, -0.30162663693519, 1.1102337449884},
    {0.21585406400914, 0.144369641593842, -0.258546391444693, -0.0463981325961387, 0.14220532642428, -0.0578765020203707, 0, 0.0758000408564925, -0.327343385724779, 0.566966782893935, -0.532544722385905, -0.223449718107214, -0.0169677308765817, -0.00390597156038669, 0.0578765020203703, -0.653174912253481, 0.613754281737721, -0.0919759862718723, -0.228827088815349, -0.460253834647199, 0.207338943397586, 0.00899118188658696, -0.0758000408564926, -0.216751002799709, 3.99244103427919, 1.2503455465619, -0.202061750267638, -0.672975108694535, 0.193950549067879, 0.726411390331473, -0.820881034417263, 0.576465753637697, 0.0544824611066964, 0.00888340236602259, -0.138299354863893, 0.457249582035072, -0.109660879297123, 0.216751002799711, 0.0184846918291027, 0.20206175026764, -0.193950549067878, 1.49623651693776, -0.665754071757144, 0.318352203838193, -1.69082175211527, -0.108551654534379, 1.18738379221061, -1.46820354179852, -3.88278015498206, -0.239391586798444, 0.654490416865433},
    {0.0617978275970904, -0.0683533897674909, 0.32572554428539, -0.5098844529752, -0.0652094687232015, 0.0204847751966063, 0, 0.100320494542055, -0.199566116235119, -0.115846086184705, 0.220363206959814, -0.0545443252607911, -0.0738260863498106, -0.00813907259628119, -0.0204847751966064, -0.245523522594399, 0.249366347937698, 0.0399471234689599, -0.0372343866418578, -0.0369008898651069, -0.0167733358255099, -0.0249087002179128, -0.100320494542055, -0.465319463510972, 1.7134571817969, -1.4165544473472, 0.972889313363567, 5.10212301923666, -0.102863747095871, 0.41541582725998, -0.745935006987648, 0.0593379607030687, 0.0919361476640752, 0.491774391660936, 0.0733485413194819, -0.205102686184763, 0.213863916794999, 0.465319463510973, 0.636817788303056, -0.972889313363564, 0.102863747095873, 0.28104140287096, 0.0208879537778328, 0.224474816453031, -0.504647649554213, 0.111731468232382, 0.0401439295885448, 0.255415826243774, -1.9273210985919, 1.36624130728819, -5.73894080753972},
    {-0.236409154506207, -0.301286830201029, 1.40654666417306, -2.52815393023257, 2.02269013545501, 0.288623553688341, 0, -0.0922286345676666, 0.0502164067882628, 0.0607991224851043, 0.350539002122206, 1.15104668812143, -2.14074232727352, 1.76786658528815, -0.288623553688341, 0.107051008856093, 0.129513646214306, 0.108310531117184, 0.192820798519654, 0.286863399364978, 0.0514823300149997, 0.0438900185639372, 0.0922286345676687, 0.529551174033436, -0.39502784514592, -1.8403907353171, -1.42615157823009, 4.09370093920999, 5.31586396758397, -0.735850415860869, -0.763948088649637, -1.05779484778398, 2.06720143179862, 2.60169482570746, -3.79055672074317, -1.55837122838992, -0.345261251563264, -0.52955117403344, 3.57796628051683, 1.42615157823009, -5.31586396758396, -0.183388348966531, -0.0497137581499046, -0.0941064253522016, -0.19039083984167, -0.0625676943502007, -0.263623212678983, 1.50483652028515, 0.740289096709195, 1.89392544342186, -7.67166721972682},
    {-0.636880676372843, 0.0509205961060772, -0.532258011356845, 2.09010537178824, -4.5253308777861, 8.16976222157871, 0, -0.204379670271957, -0.0530640494716995, -0.0329394822111655, -0.0402724292484829, 3.58097023983997, -8.36005347555908, 10.5022018617589, -8.16976222157871, 0.174022419043588, 0.108585811744015, 0.11050643547361, 0.192845414005561, 0.270948238537965, 0.131752129083815, 0.123148864515018, 0.204379670271964, 1.29900005822652, 0.403690623878339, 0.413450831498714, -3.77996149537444, -1.93814246092285, 8.3819437204913, -1.08636135282503, -0.781857339741, -1.1804935359171, 3.04580136986359, 3.22414673390725, -5.97687098397282, -1.65373052837354, -0.936868603902826, -1.29900005822652, 4.49796134496502, 3.77996149537444, -8.38194372049129, -0.082197749562071, -0.0480009866466865, -0.0700848150433195, -0.0591579529575505, -0.0508116602259685, -0.0893201067698655, 0.602500297806741, 0.533177980024502, 0.637779399068088, -2.55981888404217},
    {-0.02769794698315, -0.277763665240072, 0.588308925193387, -0.933533835729226, 0.622081242620194, -0.15388872742481, 0, 0.0500625320267799, -0.306082253789325, 0.965522610606369, 3.84775686177042, 0.0162868154822941, 0.0184619773736159, 0.0350047482548523, 0.153888727424809, 0.109881932370402, -0.135247886741856, -0.0246257297202447, 0.35545329631492, 0.106521766617379, -0.0190946015114806, -0.0172233649001302, -0.0500625320267798, -0.0185224119214175, 0.182649651575567, 2.55260208008505, -0.0264379249091081, -1.15501772039867, 0.246211695240445, -0.0962322175422218, 0.273054746621408, -0.781418269754868, -0.152882638736621, 1.06795449709223, -0.657085990875045, -0.0504813859366702, 0.0102777654013573, 0.0185224119214161, -0.0649932866680837, 0.0264379249091114, -0.246211695240445, -0.629394115089667, 0.158121365096614, 0.323305618689454, 1.7858785239509, -1.1045493741915, -5.11076303724903, 0.418033633824529, -0.192927416976921, -2.9201543279729, 1.22001100706674},
    {-0.119570063807635, -0.189231932784834, 0.633760217237777, -0.457019490504953, 0.257719653538467, -0.0578765020203707, 0, -0.0134898570388162, 0.0630462694728017, -0.122711418295396, 0.707334834787756, 0.186296385708589, 0.0244646644642496, 0.0227507319824575, 0.05787650202037, 0.418405228219932, -0.448686198224912, 0.00337615341787275, 0.335706813179577, 0.207923942877124, 0.00656885261329272, 0.00556553898616556, 0.0134898570388154, 0.023034843397702, -0.158987626540096, 6.67339359332445, 0.00443994152768612, -0.660865598094119, 0.105092925496536, -0.805886036576062, 1.38693655238487, -1.40110711875518, -0.143568524630285, 0.576123350670988, -0.280470385520924, -0.35723276247623, -0.0140349594230731, -0.0230348433977014, -0.0583392686286621, -0.00443994152768626, -0.105092925496535, -0.899443119077037, -0.0385486782204699, -0.0686118084589665, 1.547949067264, 0.154691243902575, -1.56376472585185, 2.09638602373871, 0.173022585963171, -8.41254685458694, 0.71920486672278},
    {-0.291832089112705, 0.157476470390113, -0.872076066213631, 2.13904455634208, -0.12647372699589, 0.0204847751966088, 0, -0.124807634069926, 0.354223087492422, -0.235690806650842, -0.319686356219995, 0.841280923622991, -0.656732008696605, -0.0222767402895102, -0.0204847751966074, 0.741033906523161, -0.437907813289338, -0.125801729983171, -0.0429687445280593, 0.308397447711335, 0.0723620723206562, 0.0623918968156407, 0.124807634069925, 0.425845068656627, -1.61167001818825, 3.22005879336979, -0.471820328632929, 5.36195357000441, -0.055737156516407, -2.44645432594537, 1.98114702397624, 0.496102444559773, 2.41417569559128, -3.89648824323676, 0.148750467285395, -0.988626287947556, -0.283875199065943, -0.425845068656629, 0.94444000315798, 0.471820328632928, 0.0557371565164077, -0.89682322382246, -0.266006154665517, -0.416614984308063, 0.726250493240688, 0.429334888995704, 0.18186163909043, 3.63423363682618, 1.8955452172542, -5.86566614224841, -6.30639357316239},
    {-0.53338096528945, -0.106326707514487, 0.723274251164083, -2.23508757936844, 5.18874690712782, 0.288623553688344, 0, -0.206188382357, 0.247436090352881, 0.0794567750924285, 0.0976714586493639, 2.28752304127763, -3.66947089586476, 2.49848276832552, -0.288623553688342, 0.791709824134515, -0.0492011060715578, -0.0415311512109848, -0.061269894048032, 0.308908704790785, 0.130448724413435, 0.119145300218687, 0.206188382357003, 1.01716689091037, -1.49797109054705, -0.881624273070683, -2.10818285969814, 5.69025477650749, 2.88042337894853, -3.74314165865803, 0.332048873101147, 0.400295493115174, 7.17024517399764, -1.26568669876444, -7.68722967545334, -1.44741290720916, -0.721302276671131, -1.01716689091038, 2.73996858219388, 2.10818285969813, -2.88042337894853, -0.505476456743651, -0.254900328473419, -0.366581390571571, 0.0448401111009614, 0.0449948289675574, 0.0540561822025387, 2.82828388811967, 2.21927336721819, -0.499246707839834, -8.43022335870138},
    {-0.793676417832494, -0.201011180775918, 0.994395503589037, -1.74785530185879, 0.466841577692105, 8.16976222157871, 0, -0.154769442476807, 0.00392899389341279, 0.0181729170402948, 0.0407687354077859, 4.34154822751179, -9.77838145744784, 11.6542222604831, -8.16976222157871, 0.46911220943354, 0.177695369141791, 0.144302771209539, 0.203577248823554, 0.177997014576984, 0.101668436068694, 0.0980833119458595, 0.154769442476816, 0.932332763072873, -0.0274750462996496, -0.187345658291294, -2.49377896360013, 0.108339631410458, 4.54179166373723, -2.76904596912684, -1.1985104066446, -1.36838735532939, 7.17053459661729, 4.35570216268934, -12.1210638381752, -1.04810581815352, -0.68588641520741, -0.93233276307288, 2.70458803244947, 2.49377896360013, -4.54179166373722, -0.113526762781904, -0.0745539577676528, -0.102012305839277, -0.049137142591297, -0.045287395341339, -0.0561018446115759, 0.76858108498729, 0.713361461507064, 0.466870391457531, -2.81292766385993},
    {-0.593196374839004, 3.08041774684675, 2.82690544195192, -1.94822363815395, 0.838592338884253, -0.153888727424814, 0, -0.208059837648134, 1.21685398004278, -3.16086198992807, 5.98227145504556, 0.136760509442213, 0.0820817973761752, 0.0849680060691232, 0.153888727424814, 3.33081466386314, -7.7781398565387, 9.82092349468902, -7.86081967402121, 0.28941133993101, 0.133172202775038, 0.123294301136931, 0.208059837648138, 0.05462532961453, -0.38623975479654, 1.72363186185205, 0.0414726422342152, -0.50378482456144, 0.0796638567906161, -0.837065927417695, 2.29726169586696, -4.4238617198434, -0.589617326879694, 2.45575916765748, -0.923560344953375, -0.0726193843791435, -0.0391346549544641, -0.0546253296145387, -0.0510445779743555, -0.0414726422342072, -0.0796638567906181, -1.77139126384231, -0.956614508025908, -1.34014828117972, 4.86144420114207, 3.98430429517894, -9.36173573227633, 0.521646073380408, 0.425374409751012, -2.17265855085331, 0.554829402535782},
    {-0.645727750172865, 0.152389035168537, 5.95560097140644, -1.01996684985416, 0.350135184354868, -0.0578765020203676, 0, -0.203105697019897, 0.975293412471046, -1.90768844364096, 2.1506924706599, 0.738792277826607, 0.0700963669874179, 0.0440770338297814, 0.0578765020203672, 3.07478343736792, -5.75165284262929, 5.17242188312024, -2.00221376285454, 0.266793392796454, 0.131104289577874, 0.122775552575936, 0.203105697019896, 0.262284692814012, -1.50460561952113, 4.81893118953381, 0.0309277544569272, -0.290505266609932, 0.0340036965274592, -3.82145806314358, 8.34416472668717, -11.2170999127766, -0.422699936932931, 1.37257041979968, -0.39421221818465, -0.331177007563507, -0.189408422105013, -0.262284692814011, -0.0365704763081419, -0.0309277544569312, -0.0340036965274597, -1.38000868809123, -0.790594110906625, -1.09806896504699, 3.01325295932209, 2.56717826496972, -4.05073013468721, 1.99708638588723, 1.69401404162614, -6.48484056785753, 0.327075742918072},
    {-0.731477026246279, -0.118966191906675, 0.634469463727498, 6.31394635781804, -0.175487291718017, 0.0204847751966124, 0, -0.181363947469798, 0.589524145791048, -0.606401112905337, 0.0752546098649868, 1.85165020848896, -1.23254689245621, -0.0335873724597036, -0.0204847751966092, 2.5359510590258, -2.97107163501473, 1.07499313989514, 0.210570654246739, 0.219624776309363, 0.118375698008267, 0.11283191429319, 0.1813639474698, 0.51077660968609, -1.94920614426792, 3.07537095209689, -0.411256654989259, 2.40724921454864, -0.0180342239644687, -6.93755129851629, 9.39210131335103, -4.9406696870512, 5.33027136584423, -10.4116708312061, 0.209074664177713, -0.600343857128845, -0.373068112951809, -0.510776609686093, 0.460735220088128, 0.411256654989257, 0.0180342239644655, -0.822865001762267, -0.511927454742014, -0.702356060084241, 1.11399990158124, 0.999952869639087, -0.586014285993325, 2.59624659386179, 2.32227425721973, -5.07127368882986, -2.86798443463677},
    {-0.834219465627166, 0.0924967660603458, -0.480953409540754, 0.747335856394907, 7.72170385245787, 0.288623553688346, 0, -0.132465689012754, 0.212613636329337, -0.0129525142247632, -0.0210145612450127, 3.38060476427582, -5.0388437404201, 3.0830014515509, -0.288623553688342, 1.70865814718408, -0.706870494602039, -0.147908535246489, -0.112156417768727, 0.147710619063581, 0.0873311439104344, 0.0848890558285627, 0.132465689012757, 0.587313024319987, -1.08681582782371, 0.09538003186556, -1.02780362940396, 2.73990191297317, 0.931985116843884, -7.44217039338946, 3.52049717580285, 1.02202186285154, 12.6674639559305, -8.37595607190527, -10.8047053040088, -0.643091151607829, -0.433926868832509, -0.587313024319985, 1.09394529189496, 1.02780362940396, -0.93198511684388, -0.32517483487002, -0.219547216525383, -0.297502692157905, 0.153823014966008, 0.145168586839719, 0.0446557620854378, 1.61670700720932, 1.5207426966562, -1.06899588746705, -3.83384720486813},
    {-0.930688141770982, -0.287417905294885, 1.65533088393825, -3.90144231251835, 4.4607553970921, 8.16976222157871, 0, -0.0634805252678703, 0.0147810504360844, 0.0150011531563003, 0.0219586459407483, 4.99337808590905, -10.961922045512, 12.5758791607061, -8.16976222157871, 0.767280516065688, 0.179318958433261, 0.122699422547968, 0.148807150018965, 0.0662392168845443, 0.0421488922094648, 0.0416711268844657, 0.0634805252678796, 0.367076016056144, -0.0970862221490659, -0.135305670002911, -0.922227874355331, 0.334949153877496, 1.4695347445603, -4.40437365533353, -1.16420210978303, -1.08013320473075, 10.9424799254014, 3.92088443262894, -17.0366345577982, -0.380169713679532, -0.273708035798547, -0.367076016056144, 0.944297480845922, 0.922227874355318, -1.46953474456029, -0.0584258305253087, -0.0420741367221135, -0.0564521773205579, -0.0154436204750981, -0.0150759086436511, -0.0143284118248972, 0.379495442761898, 0.370794257947601, 0.135979940920566, -1.27924663472342},
    {-0.284218581943476, 0.349323335271636, -0.0867591749077365, -0.0570689004231462, -0.0670256254939651, -0.153888727424802, 0, 10.7781211235609, -9.36250110289345, 6.02483510568529, -2.21672402216101, 0.07299241164692, 0.0498880353538267, 0.0615259070689036, 0.153888727424801, -0.0946999989222333, -0.0236501366188878, -0.00181758342659429, 0.0550629656395477, 1.86497892015752, -5.26674221029166, 8.59427075157848, -10.7781211235609, 5.25844699302783, -2.00875001258034, 0.609602290899738, -2.69861319781278, 0.486156891747386, 0.961839722168652, 0.0205186909472477, 0.00367916414172843, -0.0104310918281506, 0.0110020236494297, -0.00382115858012005, 0.00549971842506673, -0.532897259535407, 1.84392410645673, -5.25844699302787, -0.446265790466118, 2.69861319781279, -0.961839722168652, 0.524258963669997, -1.16149737992198, 0.768230351314956, 0.0940037931802883, 0.403404484528366, -0.266517654846794, -0.117522131519591, 0.164825906123698, 0.0408171001552133, -0.0398911012812681},
    {-0.365495227282886, 0.425653570551385, -0.515016292023655, -0.0524324561977709, -0.0364185135341666, -0.057876502020375, 0, 3.05411065485142, -5.24133428669362, 4.79626721973487, -2.24551039975859, 0.452267144066575, 0.0473046632961915, 0.0340710153857397, 0.0578765020203715, -0.0753057746212483, -0.0202897371294634, -0.00307560213293447, 0.0385127706151463, 1.97191931828046, -4.32720155341021, 4.90348352510902, -3.05411065485142, 13.5516773429902, -7.65404334919408, 2.99093001608284, -1.51262113932655, 0.364822698915449, 0.410551375972457, 0.0812421394763865, 0.0166609350189821, -0.035153926538288, 0.00693308030978683, -0.00180528740821124, 0.00234749814843191, -2.69842283984549, 7.16067196067347, -13.5516773429902, -0.34130662077009, 1.51262113932653, -0.41055137597245, 0.354221938059549, -0.634204617389309, 0.337850761584602, 0.0726429502022355, 0.165138951064649, -0.153273806783654, -0.395487060996766, 0.49337138852063, 0.102979884759418, -0.023516078145364},
    {-0.505828786742263, 0.555572946106277, -1.45661822356638, 1.01456732457267, 0.0295255943487242, 0.0204847751966022, 0, -0.171838342059685, -1.24929187044142, 2.74189559758475, -2.08597694083695, 1.34289336556039, -0.950264780748592, -0.0282805736101467, -0.0204847751966045, -0.0480006553658702, -0.0148643201310066, -0.00440824221550566, 0.01752905834837, 1.92311516445491, -2.56811623612245, 1.1966123453872, 0.171838342059681, 6.43339682257553, -9.22829969484468, 5.96648937736411, 11.5724118162643, -4.89007377482177, -0.217740311181671, 0.115539283892153, 0.0301275251169497, -0.0319419510031081, -0.0704627382039531, 0.00616019437986935, -0.00124502073857243, -5.58833759248822, 8.83916529280075, -6.43339682257551, 4.68387154935881, -11.5724118162643, 0.217740311181677, 0.165460158372694, -0.190427453157483, 0.0526795250542343, 0.0431446769384586, 0.0166480916951792, -0.0457430589291216, -0.414378788683103, 0.389134402043904, 0.0362270038072291, 0.206202225462947},
    {-0.685613082674017, 0.719267259522416, -2.96850396495829, 4.53211724574023, -2.87309406907589, 0.288623553688339, 0, 0.101751927918439, 0.131051222146624, 0.741151263335815, -1.56601649746155, 2.84662379487985, -4.38015391749967, 2.8087530250254, -0.288623553688339, -0.0227612235710124, -0.0086751232711253, -0.00445770272220812, 0.0022398727159496, 1.50171934330264, -0.716300226480568, -0.128116416583606, -0.101751927918443, -0.972932896106734, -3.81557608009215, 6.98367725189582, 9.69789785441527, -12.3087258937224, 11.2525346118521, 0.0894163108115531, 0.0325002258007788, -3.63665338946839e-05, -0.127195438568914, -0.0247678896716441, 0.0643410440504866, -6.74951233933679, 3.73012877389718, 0.972932896106749, 12.0330801070225, -9.69789785441527, -11.2525346118521, 0.0471710395290027, -0.0208006666364235, -0.00293480556301342, 0.0171452995771678, -0.00405037021882556, -1.91849472603955e-05, -0.195999318356904, 0.0854473061949423, -0.0381655942021114, 0.27564578669994},
    {-0.86509141302198, 0.880270785828908, -4.75479662623641, 10.5319042888745, -12.2449015666311, 8.1697622215787, -1.14200956516687e-14, -0.138221459026591, -0.112165339938182, -0.165021692646531, -0.761542358539873, 4.68268090500075, -10.4012155852295, 12.1434499468309, -8.1697622215787, -0.00677348275463463, -0.00338619289693686, -0.00261491935413594, -0.00240477780121577, 0.749992090304517, 0.162973965047236, 0.111236026185826, 0.138221459026595, 1.01475803516351, 1.08602336549169, 4.41000508820409, -3.75813972667071, -11.1011291227225, 17.7427624944082, 0.0366058900393385, 0.0194596941019578, 0.0160501370943542, -0.082432943285368, -0.0482557603596566, 0.101451619800189, -4.35528204551045, -1.07702543039437, -1.01475803516353, 11.0091539014451, 3.7581397266707, -17.7427624944082, 0.00586290813854949, 0.00129162053299638, 0.000929313752362904, 0.00311672244003617, 0.000756107066290451, 0.00257063765676816, -0.0345169961057656, -0.00899793509730759, -0.0202060465878858, 0.0919752212773527},
    {-0.377854821367116, -0.267111615790655, 0.074787296097928, 0.0592354988079029, 0.0992497134834032, -0.153888727424811, 0, 2.40929939068856, 6.36960726610732, -4.11080267791068, 1.59600374185812, 0.0927302983767208, 0.0601399658498413, 0.0693258960286203, 0.15388872742481, 0.353965859899714, 0.120413683820857, 0.0732600557844813, 0.0973268376527151, 1.97891768943057, -4.17357053861733, 4.44916882452415, -2.40929939068857, 2.41596082622727, 1.95529909460256, -0.528492701931615, -1.77394258946499, -0.601277138703959, 0.803364372151006, -0.100061621618974, -0.0350928037360224, -0.0323631691196494, -0.082234744012923, -0.0371407206448225, -0.168575609512021, -0.536562258876671, 1.36577584941787, -2.41596082622728, -0.419991906668325, 1.773942589465, -0.803364372151006, -2.135372327289, 5.70689557290479, -10.8187760906315, -0.748900535214502, 2.57747764362324, -0.690648568785199, 0.733689475579222, -3.32107494402043, 0.331365485229064, 1.02126904537228},
    {-0.451804425814345, -0.299846929362777, 0.386955294238903, 0.0431773246303422, 0.034554401842554, -0.0578765020203698, 0, 0.26145911536624, 2.09615129819622, -2.55998154197248, 1.409174432625, 0.542062083177417, 0.0546170488540182, 0.037400360313159, 0.0578765020203693, 0.367859795037028, 0.134844949406539, 0.0997331148740911, 0.149213495859463, 1.97402656038467, -3.23824225193072, 2.26879383358004, -0.261459115366241, 5.71205862214123, 4.70706307355659, -2.05717688756717, -0.980410834143363, -0.289116497994076, 0.342907805523151, -0.499058192222417, -0.201710670580675, -0.228248514613229, -0.0621888049647184, -0.0356055685196445, -0.0719547621557109, -2.60222076128038, 5.09474468028488, -5.71205862214123, -0.31292861750946, 0.980410834143359, -0.342907805523148, -1.81741936430954, 3.68717131480481, -4.36494513177626, -0.734569403757633, 2.11105247909839, -0.831212224942491, 2.96297589844055, -9.80180775384146, 1.696421750407, 0.602045115503529},
    {-0.576948661244747, -0.260145422130515, 0.651010728103404, -0.408482387606869, -0.00811565004606828, 0.0204847751966065, 0, -0.143420606214597, 0.0893280580886666, -0.685338813316577, 0.778684927797256, 1.50519714998454, -1.04181171702517, -0.0300463272842337, -0.0204847751966059, 0.351275326492787, 0.151233907999415, 0.129604454285755, 0.204980394597305, 1.80039173466613, -1.74791870471658, 0.330716585087007, 0.143420606214596, 1.67355371563219, 1.57473798057548, -2.00641698419531, 7.18432266532968, 1.1226643529759, -0.181864820460965, -1.01450983251178, -0.500559437774532, -0.641138607801632, 0.841695451268753, 0.608598653363282, 0.0381619773303023, -5.11725544795023, 5.83010510343556, -1.67355371563218, 4.15640649712278, -7.18432266532968, 0.181864820460968, -1.21347234627072, 1.41216997169938, -0.420044643175672, -0.598727598233652, 1.02108754633378, -0.766876717959018, 4.13430811262022, -7.40484308401104, 2.98936431952532, -5.27907085009869},
    {-0.73356085670795, -0.0105569750572735, -0.135243708104236, 0.634253162364344, -0.927843770282096, 0.28862355368834, 0, 0.111739981375583, 0.0384808976947857, 0.0511552733888991, -0.0595916798702377, 3.02009427869259, -4.59614374252044, 2.90000486638575, -0.288623553688339, 0.269193011113975, 0.13989831814258, 0.130047441057126, 0.204979061451545, 1.33072727712461, -0.370698963181924, -0.120273255209597, -0.111739981375583, -0.884630678933831, -0.607725108844575, 0.816310765670249, 4.78299203345092, -3.32007557633768, 9.39853615441868, -1.20548217579334, -0.719642445899196, -0.959725948895811, 2.13674416686427, 1.82514641329183, -1.97216109610366, -5.91543225989016, 1.89946392865065, 0.884630678933835, 10.3770005646753, -4.78299203345092, -9.39853615441867, -0.531164879432236, 0.172337701258941, 0.081792357514812, -0.317092032288908, 0.147205988534082, -0.42287868553323, 2.75008052051688, -1.29173881980608, 2.34904097370303, -7.05692498833761},
    {-0.886657647844937, 0.475450897669483, -2.77864520754328, 6.8131419598339, -9.1776713616849, 8.1697622215787, -1.22960257744215e-14, -0.177662099660994, -0.103065710691024, -0.120604248577168, -0.371710710442355, 4.78510003641369, -10.5867211358993, 12.2873339520157, -8.1697622215787, 0.132577055868026, 0.0803075313210171, 0.0782097357576833, 0.120112427228734, 0.640122362237704, 0.18740304473594, 0.137987377882091, 0.177662099660999, 1.24405855005195, 0.919596708984887, 2.38281038308831, -4.24574550407262, -6.94951052569263, 14.8194162946469, -0.768741936063561, -0.529113173239266, -0.708599719567592, 1.93877527712568, 1.83480389893966, -3.10966259033079, -3.70257205767899, -1.231182880621, -1.24405855005197, 9.30420727296097, 4.24574550407261, -14.8194162946469, -0.102837746404338, -0.0343196335605648, -0.0349216671910641, -0.0707816287575264, -0.0324791625982156, -0.0947922766334862, 0.678062175725148, 0.311586171636134, 0.641699498865522, -2.35469674726834},
    {-0.537207852379281, 0.158558075149594, -0.0772323978522207, -0.162307063211112, 0.351454288722322, -0.153888727424813, 0, -0.207274898435277, 3.23016842177172, 4.65360605107617, -1.15503267642692, 0.125473334825665, 0.0765656943091242, 0.0811568320805635, 0.153888727424812, 1.40979731134918, -0.9813751009011, -0.0425451910024447, -0.0072272422159455, 1.87648973454376, -2.19526230893808, 0.74590137212638, 0.207274898435274, 0.345989416244822, 2.86062150854784, 1.01480603870533, -0.732904140956693, -1.49211726658189, 0.562990732964044, -0.361447973783723, 0.301999225693184, 0.0112078111170934, -0.26186684252773, 0.347608211429717, -0.432611120802885, -0.478718100157488, 0.660566642277338, -0.345989416244817, -0.344555506460702, 0.732904140956695, -0.562990732964043, -5.40555818747606, 7.50814597253982, -3.97606979389809, 4.51648509733802, -9.96648971467792, 0.167616032021196, 1.63729198148449, -3.52118815082519, -2.17337992003232, 1.83667277304259},
    {-0.595832618747914, 0.144369641593842, -0.258546391444693, -0.0463981325961381, 0.142205326424279, -0.0578765020203687, 0, -0.0940416992472917, 0.626669039303185, 1.08381574406082, -0.65982857779807, 0.688772361232909, 0.0662246334629418, 0.0424502734777119, 0.0578765020203692, 1.32665918668831, -0.643706401528925, -0.129946574602129, -0.101543233403183, 1.75779551592058, -1.54694373190725, 0.187069449276909, 0.0940416992472916, 0.414950014620734, 7.63196465955174, 1.54919143700807, -0.386261969519158, -0.833823320741955, 0.240306794105973, -1.67523377960584, 0.967387946626113, 0.277619863191516, -0.189558115280247, 0.169731614413441, -0.184655599901991, -2.21118026393011, 2.27824790474838, -0.414950014620732, -0.248907891761946, 0.386261969519161, -0.240306794105973, -4.2753144458915, 4.4278952246524, -0.813738488580091, 2.468842088395, -3.96476723680597, 0.708505419373983, 6.32917302003641, -9.91021256430012, -5.66718419311437, 1.0827312125039},
    {-0.692328341357121, -0.0683533897674908, 0.32572554428539, -0.5098844529752, -0.0652094687232025, 0.0204847751966095, 0, 0.107893098474519, -0.264160904494422, -0.285434670419236, 0.273032358288873, 1.76462388414566, -1.18519576926095, -0.0327246027163535, -0.0204847751966071, 1.12305922694355, -0.18861456535522, -0.0838593924927985, -0.0899035379709166, 1.4791576191489, -0.663475738095752, -0.132566034075003, -0.107893098474518, -0.61593226685386, 4.22180931675051, -1.75512603369549, 2.39711456519616, 6.32158471208019, -0.127449277215948, -3.10506089455619, 0.616801919073787, 0.397909547051355, 2.42276752341874, -0.727687301182595, 0.097934071439552, -4.07968499042822, 2.11866520828912, 0.615932266853862, 3.17241272304678, -2.39711456519615, 0.127449277215948, -2.60274981052279, 1.35627169158478, 0.396726938569425, 0.517020803300175, -0.40736128306979, 0.333539029784836, 8.33965877785056, -6.34047452503962, -2.50484775372686, -9.49399743512698},
    {-0.809132783013122, -0.301286830201029, 1.40654666417306, -2.52815393023257, 2.02269013545501, 0.288623553688343, 0, -0.00868264811335277, 0.00516951492372794, 0.00741750939163084, 0.434321553684357, 3.29120129853803, -4.92980584650551, 3.03841463918548, -0.28862355368834, 0.77587462821162, 0.136632341463628, 0.0888743965814013, 0.109038246957505, 1.01627603113289, 0.0144638665898084, 0.00776546518244579, 0.00868264811335605, 0.0545145077501648, -0.048193503977691, -2.28026370449516, -0.173990878371733, 5.07213902439577, 6.58641202148129, -3.39887571944393, -0.680950364661232, -0.617921878605928, 5.83470303621639, 1.62325674052169, -5.0611047746405, -4.44642915431988, -0.0723946023331708, -0.0545145077501698, 7.61919049960717, 0.173990878371735, -6.58641202148129, -1.0495243569589, -0.0171188012134, -0.0129349801061757, -0.210267762808617, -0.00476257476804056, -0.190805465049728, 5.2625994805498, 0.120588106310875, 1.46409337826523, -12.6913295240029},
    {-0.919863564854666, 0.050920596106077, -0.532258011356843, 2.09010537178823, -4.5253308777861, 8.16976222157871, -1.20165177769495e-14, -0.208038376322079, -0.0556119987710111, -0.0361803346632901, -0.0498979683742732, 4.94227542033296, -10.8701129799616, 12.5055756024883, -8.16976222157871, 0.355163261239751, 0.166948941881289, 0.144359812496206, 0.202470953131352, 0.46332699059248, 0.188164831664134, 0.153681592311885, 0.208038376322087, 1.36137347904748, 0.443408969780318, 0.512269979721134, -4.15186465410289, -2.40137913268828, 10.3853174612207, -2.04315695857808, -1.08754776625851, -1.27931268413953, 5.09262420250069, 3.68738340567268, -7.98024472470217, -2.66418747636989, -1.2253434155785, -1.3613734790475, 6.63611769063909, 4.15186465410289, -10.3853174612206, -0.191541280971791, -0.088154812885447, -0.0980695935408743, -0.101955109906082, -0.0638296841154033, -0.119932631340337, 1.24816601696512, 0.781934445798206, 0.903751479683626, -4.23473855795081},
    {-0.73293351206251, -0.277763665240071, 0.588308925193388, -0.933533835729229, 0.622081242620195, -0.15388872742481, 0, 0.112109676444357, -0.801299944278726, 3.66828774344941, 4.76741169537866, 0.164508796215638, 0.0953652459991968, 0.0938519633344894, 0.15388872742481, 3.11854471061593, -4.98177179227541, 3.43812579625538, -0.564201537293325, 1.33311110113324, -0.37473431563051, -0.120890275800025, -0.112109676444357, -0.0484902586046423, 0.69393660061381, 3.16270113924143, -0.100444997186998, -1.43107924601675, 0.305058910320089, -0.756279625079269, 1.39497923258149, -1.39151732891125, -0.505847432980278, 1.34401602271031, -0.715933205954683, -0.323086063538463, 0.104692615586587, 0.0484902586046407, -0.215903627571549, 0.100444997187, -0.30505891032009, -6.12857662901218, 1.98770935496673, 0.92219022007875, 11.304333528568, -5.28126278278563, -11.2762796960677, 1.71375068726829, -0.798629216200394, -4.55336576297126, 1.64698287358829},
    {-0.768918916307803, -0.189231932784834, 0.633760217237778, -0.457019490504953, 0.257719653538466, -0.0578765020203697, 0, 0.0718509496285209, -0.378957450051657, 0.950790563068443, 0.876395386990305, 0.860731749519541, 0.0793721793555804, 0.0478690594607835, 0.0578765020203697, 2.78591037126002, -3.50369899675695, 1.50929321361254, 0.16664626097703, 1.19026299568438, -0.165127134989547, -0.0703878670507416, -0.071850949628522, -0.13845744703577, 1.23186527430632, 8.26840567312807, -0.0344014808380316, -0.818819508251791, 0.130211252974857, -3.3628499058864, 4.86447713768789, -2.9961191985588, -0.356429949679292, 0.734077260828665, -0.30558871299925, -1.43600304080496, 0.228807664661233, 0.13845744703577, -0.15208820588572, 0.0344014808380309, -0.130211252974857, -4.65031736688179, 0.741522494315501, 0.4493453171024, 6.72684275161746, -1.52718592239439, -4.14318376741035, 6.44853770841325, -1.46067293896755, -13.2809403407364, 0.970907714137509},
    {-0.826589347339829, 0.157476470390112, -0.87207606621363, 2.13904455634208, -0.126473726995891, 0.0204847751966111, 0, -0.0498108934157997, 0.152790022173939, -0.117241776514706, -0.396094797111201, 2.06115841063896, -1.34512191896954, -0.0355985137911528, -0.020484775196608, 2.19292758691862, -1.6191000610783, 0.0618456547462449, 0.0334396963631497, 0.936173063458539, 0.0737266004774331, 0.0430057517929101, 0.0498108934157994, 0.183683333413719, -0.801707367261885, 3.98968710934988, -0.234701787102894, 6.64351752931566, -0.0690589300180531, -5.87903533992085, 4.96347886691585, -0.273525871420329, 4.38412956517546, -5.178052202548, 0.162072240787037, -2.50888442912757, -0.225656280144808, -0.183683333413721, 1.86994845496094, 0.234701787102893, 0.0690589300180526, -2.67024334274654, -0.240295667132239, -0.195795773966849, 2.25439985217432, 0.283810843169516, -0.124234775775123, 8.17715795589205, 1.0273636474067, -9.65796063611438, -8.5134659842766},
    {-0.894125141570331, -0.106326707514487, 0.723274251164083, -2.23508757936844, 5.18874690712782, 0.288623553688346, 0, -0.188260025413348, 0.235287056522914, 0.0808194877088766, 0.121015976580035, 3.59296158151085, -5.29595271223312, 3.18693460622812, -0.288623553688342, 1.40933159450745, -0.233194862616463, -0.0910704708274628, -0.0846144119787013, 0.601163049702497, 0.191498619152118, 0.144513593792825, 0.188260025413351, 0.967224318059467, -1.52366184003683, -1.09234185562156, -2.1443389631563, 7.05028621759748, 3.56887521685113, -6.06899436840763, 1.14174546006665, 0.611013075666049, 10.156758431456, -2.62571813985443, -8.37568151335595, -2.58826135779401, -0.935834939170405, -0.967224318059472, 4.33029429510407, 2.1443389631563, -3.56887521685113, -1.01544508071389, -0.367262572075593, -0.379800650315743, 0.191033265228792, 0.0949444652145999, 0.102232789202567, 4.96385575873111, 2.45949677920724, -1.28325254531555, -11.3805805127016},
    {-0.956163846795189, -0.201011180775918, 0.994395503589037, -1.74785530185879, 0.466841577692105, 8.16976222157871, 0, -0.175290778787529, 0.00451660429035005, 0.021379140314779, 0.0505128969868082, 5.11339400277777, -11.1769121298321, 12.7397587969252, -8.16976222157871, 0.609338298546816, 0.201772750556845, 0.152230891222926, 0.193833087244532, 0.259748101819737, 0.13671198780317, 0.123254765620603, 0.175290778787538, 1.0717700948294, -0.0323224317093862, -0.232123264151721, -2.9337530270263, 0.134233956150123, 5.62732820017931, -3.48236863020844, -1.30181112668941, -1.32360974946896, 8.59495959374121, 4.32980783794968, -13.2066003746173, -1.48434559997852, -0.882055076891864, -1.07177009482941, 3.66314464140756, 2.9337530270263, -5.62732820017931, -0.176895940551768, -0.105130468728662, -0.127771369910958, -0.0661288703553372, -0.052960659389291, -0.0672361878994474, 1.14145036721816, 0.91437750860126, 0.575018496912081, -3.79737859755768},
    {-0.909191772905902, 3.08041774684675, 2.82690544195193, -1.94822363815396, 0.838592338884253, -0.153888727424814, 0, -0.203361938358276, 1.23021933768941, -3.37625725056366, 7.41209798963015, 0.198758544842854, 0.111280669107747, 0.104008515538238, 0.153888727424814, 4.97565184444246, -11.2102736013573, 13.3540419915798, -9.2906462086058, 0.521141524151656, 0.192848581941366, 0.152581035106713, 0.203361938358279, 0.0552253088058157, -0.412559857641062, 2.13559821785099, 0.0442987734008827, -0.624194758361988, 0.0987043662597324, -1.16469683937878, 2.97486092842633, -4.83582807584234, -0.73922613241181, 2.57616910145803, -0.94260085442249, -0.121983325719697, -0.0511687698232636, -0.0552253088058244, -0.077417318539261, -0.0442987734008749, -0.0987043662597347, -3.05381530403329, -1.28107345608767, -1.38280037279614, 7.80003475878298, 4.46448212470997, -12.6794589685315, 0.810322788436894, 0.463728627464334, -2.82393768056818, 0.701612076901234},
    {-0.921992874650234, 0.152389035168536, 5.95560097140644, -1.01996684985416, 0.350135184354868, -0.0578765020203674, 0, -0.208294305373908, 1.02887840822964, -2.1059751734363, 2.66473085647859, 1.00949188137988, 0.0904065681741668, 0.052204279130212, 0.0578765020203669, 4.31260418155547, -7.8809666275347, 6.85421843413415, -2.51625214867322, 0.45167971773004, 0.186666839336588, 0.153403194006995, 0.208294305373908, 0.276695252725794, -1.66099558399411, 5.9707070216588, 0.0341424110805616, -0.359939116570907, 0.0421309418278877, -5.05317127732498, 10.4569541694403, -12.3688757449016, -0.51244398808066, 1.44200426976066, -0.402339463485081, -0.52922419143207, -0.247650281877939, -0.276695252725793, -0.05366602087126, -0.0341424110805664, -0.0421309418278887, -2.2609542664809, -1.05806803116084, -1.18228160223664, 4.67878364817807, 2.97737636526056, -5.53423995590579, 2.99975721591095, 1.90864586587205, -8.44124004613768, 0.413605137442165},
    {-0.942112680825334, -0.118966191906676, 0.634469463727498, 6.31394635781804, -0.175487291718018, 0.0204847751966134, 0, -0.198009063873275, 0.65673761145991, -0.697326437699299, 0.0932412624004604, 2.31225141453112, -1.47759207750687, -0.0378977438878187, -0.0204847751966097, 3.24462035975901, -3.79012959121019, 1.41400410247193, 0.192584001711267, 0.339807119497162, 0.163188592583586, 0.141827214705652, 0.198009063873276, 0.569011825944322, -2.24147506987857, 3.81041733440207, -0.472921523560192, 2.98260739215467, -0.0223445953925848, -8.51468759087905, 11.2436827819768, -5.67571606935638, 6.15067472850092, -10.9870290088121, 0.213385035605828, -0.891715283316573, -0.484062676548006, -0.569011825944325, 0.644115536567854, 0.47292152356019, 0.0223445953925812, -1.25131352304159, -0.679294351711097, -0.798564826165566, 1.65236506492012, 1.21343219682681, -0.834099923776155, 3.71188418075947, 2.72553774642657, -6.63058623184499, -3.62672292872253},
    {-0.965098624043566, 0.0924967660603455, -0.480953409540754, 0.747335856394907, 7.72170385245787, 0.288623553688347, 0, -0.153213077878956, 0.248794090236753, -0.0154312292192871, -0.0260372649966798, 3.84258032344356, -5.59493014084544, 3.30575581164891, -0.288623553688343, 1.98642110683365, -0.851816659728464, -0.1548688751049, -0.107133714017059, 0.20802489423665, 0.115525902752577, 0.10651179136355, 0.153213077878958, 0.687256057948917, -1.29479913067598, 0.118176874412024, -1.22449380271056, 3.39476762523101, 1.15473947694189, -8.44838829447963, 4.08753636027175, 0.999225020305076, 13.8784160686136, -9.0308217841631, -11.0274596641068, -0.884731210125889, -0.554319335853267, -0.687256057948915, 1.45334151901369, 1.22449380271055, -1.15473947694189, -0.457368469490908, -0.28656596324546, -0.355305881600308, 0.22128602331256, 0.186471289712177, 0.0540948169383721, 2.19460610479753, 1.84911846652924, -1.42805176908367, -4.8481091442447},
    {-0.985708641666331, -0.287417905294885, 1.65533088393825, -3.90144231251836, 4.4607553970921, 8.16976222157871, 0, -0.0766373383161904, 0.017926699868952, 0.0183208226365493, 0.0272069959806285, 5.25214046484747, -11.4243799830647, 12.927113601847, -8.16976222157871, 0.824345590157423, 0.182949292363593, 0.12227286446113, 0.143558799979085, 0.0863241095199892, 0.0536478621586466, 0.0519509511468675, 0.0766373383161999, 0.445195799674887, -0.118570848381696, -0.167645164909435, -1.12631163354642, 0.415005565818945, 1.82076918570123, -4.68789953047444, -1.17177810848706, -1.04779370982422, 11.4849942748956, 3.8408280206875, -17.3878689989391, -0.490906160550731, -0.343614184247021, -0.445195799674889, 1.20267165920761, 1.12631163354641, -1.82076918570122, -0.0770502531674065, -0.053932501428161, -0.0698776510158275, -0.0192593291149142, -0.0180361833670346, -0.0172215232183082, 0.493510759602965, 0.462185032628707, 0.165040565857221, -1.61767722502656}};
    // Array of non-zero columns
    static const unsigned int nzc2[51] = {0, 2, 4, 5, 6, 7, 9, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55};
    
    const static double FE0_D100[125][50] = \
    {{-3.62990990645797, 0.284218581943474, -0.0729924116469152, -0.0498880353538527, -0.0615259070688796, -0.153888727424817, -0.0811284959085353, -0.0541568301344951, -0.0660860422357879, -0.16416777530046, -3.05254952705569, 2.02813935973006, -0.852973082215373, 0.153888727424817, -3.39280133686022, 2.20168218722083, -0.916193158666482, 0.16416777530046, 6.93935899282269, -6.1810822223952, 4.27656497941377, -1.68915042532677, 0.0231815773747676, 0.0189606934661044, 0.040435071237669, 0.019413019613542, 0.0277492861274139, 0.0418410144593047, -0.942419743749331, 0.262864245603229, -0.0404350712376693, 0.26913513288588, -0.0277492861274132, -0.0418410144593046, 4.19215254652989, -1.5558075990407, 0.489196991213411, -2.39410207157934, 0.415850747203131, 0.914498989284253, 4.65942997423122, -1.7292253754238, 0.543725233961326, -2.59895941573086, 0.45143405864452, 0.98227920090227, 1.11247239987881, -0.193234233504242, -0.281824939069335, -0.288548152499424},
    {-0.282631633534523, 0.365495227282887, -0.452267144066579, -0.0473046632961848, -0.0340710153857426, -0.0578765020203689, -0.0857805129140868, -0.0565322542722008, -0.065985965620789, -0.14903441530704, -6.52731890993827, 1.06473844170331, -0.356273456486931, 0.0578765020203696, -1.23802219859217, 1.27243405037863, -0.690001392244448, 0.149034415307041, 1.65335880966174, -3.50106007665703, 3.57567070399204, -1.81083303074512, 0.117384161266234, 0.0935498203733102, 0.182364335615602, 0.0148471880767256, 0.019761474433403, 0.0178594059513645, -2.64209530812438, 0.978230835822909, -0.182364335615604, 0.155253929338967, -0.0197614744334004, -0.0178594059513649, 10.5622964722508, -6.08250695734887, 2.49979653910288, -1.33696013079069, 0.319526352383562, 0.390344471872671, 2.00332750416848, -1.15365569542249, 0.474130902760279, -1.59775727801775, 0.381855481911312, 0.755987357865236, 3.31759984457827, -0.792888697720121, -1.07178065619622, -0.170101117415698},
    {0.143241115565026, 0.505828786742264, -1.3428933655604, 0.950264780748607, 0.02828057361014, 0.0204847751966083, -0.0836574821649622, -0.0547790077565434, -0.0605627881224762, -0.120198635080439, -0.878278855981289, -6.65596057481904, 0.178742789963475, -0.020484775196604, -0.0547136501039044, 0.383689812925605, -0.382777303820131, 0.12019863508044, -0.233743731500411, -0.770376839904911, 2.14650769602211, -1.79145702692408, 0.243098417149601, 0.188543141982828, 0.325606241800378, -0.203753216575829, -0.246844448755214, -0.00947192686946643, -1.70273960808481, 1.19165642433789, -0.32560624180038, -1.28778923995138, 0.246844448755215, 0.00947192686946296, 4.50684360679751, -7.51537127670233, 5.22969989144651, 10.1153513886495, -4.40965559457904, -0.20702336357362, 0.280760333117455, -0.468180910463761, 0.325791709615175, -0.583110016707575, 0.254199211538511, 0.443340091942608, 2.58772708545035, -1.12808589451515, -1.38019956632071, 1.49154245652721},
    {-0.10229176194367, 0.685613082674017, -2.84662379487985, 4.38015391749969, -2.80875302502541, 0.288623553688339, -0.0653263317252849, -0.0429174987338566, -0.045267266480939, -0.0793175468753275, 0.558471148525223, -1.03193983204806, -7.88994374560002, -0.288623553688335, 0.0128161900329652, 0.0101111233234095, -0.127158273749781, 0.0793175468753288, 0.116252719469185, 0.139438536817006, 0.574619210989785, -1.41363178800632, 0.293610709637526, 0.223492595719791, 0.343765567681143, -0.523451326810223, -0.581054568323658, 0.489496797176207, -0.0691730455362174, 0.627803153953462, -0.343765567681145, -1.47040394270875, 0.581054568323661, -0.489496797176213, -1.05119827073605, -3.02713440179707, 6.36648531888774, 8.0342192561917, -11.3824333416433, 10.6986967706254, -0.0241236397540955, -0.0694688165203008, 0.146102597966719, -0.0787206571389025, 0.111527032549349, 0.172425540230721, 0.538550211162511, -0.762987875263825, -0.851295749673256, 1.99385526951899},
    {0.290248257600285, 0.865091413021983, -4.68268090500075, 10.4012155852295, -12.1434499468309, 8.16976222157871, -0.0326254251841688, -0.0216017065295155, -0.0220338922063745, -0.0350775308879081, -1.683687613827, 4.01561825483131, -4.72603256077765, -8.1697622215787, -0.0117306785136394, -0.0083398143577047, -0.00857523129457315, 0.0350775308879091, -0.151494055908935, -0.120634157325967, -0.17261827502168, -0.710593182365686, 0.189459236128992, 0.142756465828413, 0.201005644744963, -0.478909486641472, -0.498130062975649, 0.771828366999505, 0.0731449089687587, 0.0555584869802832, -0.201005644744964, -0.186383757288307, 0.498130062975651, -0.771828366999513, 1.09751734781617, 1.1396342516694, 4.12921691934219, -3.96902236854247, -10.4478114715183, 16.8694825076085, 0.00764668164372126, 0.0079401207918119, 0.028769301262276, 0.00824304195133353, 0.021698478935888, 0.0306091235009463, -0.0722961599980102, -0.190307985099746, -0.198314952808702, 0.665293243929796},
    {-0.0804169334283797, 0.377854821367114, -0.0927302983767196, -0.0601399658498353, -0.0693258960286239, -0.153888727424807, -0.512650482834975, -0.0177547093611623, -0.0116964169713668, -0.0187732230698002, -1.11829004720866, 1.23357237757901, -0.694497732197729, 0.153888727424808, -6.18235833041367, 0.364179106695018, -0.117173170875443, 0.0187732230698, 1.23469180432362, -3.1671132019426, 3.45521657617556, -1.8202330664953, 0.138999667623029, 0.00581012182124211, 0.0063513178134045, 0.108801419528572, 0.00754649641306796, 0.20811635343668, -2.85111818820363, 0.0582050382295172, -0.00635131781340397, 1.0899583481951, -0.0075464964130681, -0.208116353436681, 1.87426704619966, -1.16087091348691, 0.497624212872634, -1.56685764288181, 0.393425231152634, 0.763823628226351, 10.361704027873, -6.4177625298954, 2.75106731527106, -0.462572628144321, 0.116148230810464, 0.128869587846809, 3.62143025017604, -0.90931172959544, -0.0640151600507617, -1.19875976772367},
    {0.296938442417928, 0.451804425814346, -0.542062083177416, -0.0546170488540234, -0.0374003603131568, -0.0578765020203697, -0.511383406553644, -0.0706022831938997, -0.0504421912770389, -0.079855422092258, -1.80057222446278, 0.622114485944271, -0.288629886037622, 0.0578765020203724, -1.69866660382198, 0.804194002372015, -0.389277637912433, 0.0798554220922582, -0.0612764125533424, -1.55859240591333, 2.70162889910246, -1.83050294886806, 0.674120877709402, 0.11107896776519, 0.126996446014248, 0.0810660330724892, 0.021375560558289, 0.0888323213280824, -7.67856140344348, 0.857229971550942, -0.126996446014249, 0.62561108212112, -0.0213755605582867, -0.0888323213280862, 4.25318225250671, -4.33770602065992, 2.4271580757934, -0.861548826491952, 0.294051389401707, 0.326030246350774, 4.01246812215881, -4.09220816270835, 2.28979005092517, -1.11370561957553, 0.380113900397409, 0.439719829189472, 10.6338233809841, -3.62938285525006, -0.968308939316134, -0.706677115193616},
    {-0.100404462764304, 0.57694866124475, -1.50519714998455, 1.04181171702517, 0.030046327284236, 0.0204847751966058, -0.466402264732031, -0.13462610263226, -0.107182504067224, -0.16665434679713, 0.754231010240751, -3.33204574872113, 0.142867299242771, -0.0204847751966021, 0.233706960786517, 0.430577162468101, -0.509642151511677, 0.166654346797131, -0.0990178145200987, -0.147817722931935, 1.45555613539848, -1.68526479642689, 1.32565568047274, 0.449039378029455, 0.54238488791022, -1.07674200346431, -0.553342302405746, -0.0471131712642577, -4.23986916465107, 2.13513760220476, -0.542384887910223, -5.11980118438332, 0.553342302405748, 0.0471131712642533, 0.868006346840215, -4.92314980708573, 4.80610959998931, 6.21159397662318, -3.92135994492722, -0.172913626527012, 0.268961528376674, -1.52549333465282, 1.48922711022167, -0.80268120864934, 0.506730148813495, 0.616824655578903, 7.90395683340335, -4.98974334922502, -2.58417698023422, 6.19654318784763},
    {0.0327513821297318, 0.733560856707952, -3.02009427869259, 4.59614374252045, -2.90000486638575, 0.288623553688339, -0.344732873319206, -0.154120270281252, -0.135945654934045, -0.207912100848699, -0.335749943545738, 1.50942741166772, -6.03594528816658, -0.288623553688337, -0.0383246455489452, -0.0506149010319183, -0.282951433929326, 0.207912100848701, 0.104458549759898, 0.106236390698728, 0.278180235623065, -1.25518741491938, 1.53242816535888, 0.789713279908626, 0.999903900603922, -2.68822416327502, -1.98855701839864, 2.43474709597, 0.50326734949675, 1.64367522486529, -0.999903900603925, -5.59515404954395, 1.98855701839864, -2.43474709597, -0.78901317909066, -1.44362886899566, 5.58848627032465, 3.71994941407637, -9.82552056826455, 8.93595015455234, -0.0900630096992786, -0.164785030562317, 0.637905559129748, -0.124739268666924, 0.329474439980093, 0.418897088863371, 1.2402908993257, -3.27598641418133, -2.43338850477391, 8.28337821281898},
    {0.239734464658444, 0.88665764784494, -4.78510003641368, 10.5867211358993, -12.2873339520157, 8.16976222157871, -0.165827532811134, -0.0960840891841905, -0.0916041248827719, -0.138407634889369, -1.26639041080201, 2.55888156794631, -1.80268636101631, -8.1697622215787, -0.0438867308522203, -0.0232241693750206, -0.0134393276185051, 0.13840763488937, -0.186000291050881, -0.143018045912808, -0.190501890245126, -0.606871885294569, 0.959173473074895, 0.631244203477602, 0.82587912408789, -2.41031063411875, -2.17685144999333, 3.83905857194565, 0.231838667440827, 0.0926104328671758, -0.82587912408789, -0.353618948008305, 2.17685144999334, -3.83905857194566, 1.28810637824869, 1.25124354829929, 3.5121405206677, -4.31293078787763, -8.83267191596794, 14.090020313032, 0.0446392972096551, 0.0433618166770612, 0.12171314977664, 0.0391437557623123, 0.0801645027968986, 0.105043452501276, -0.390758266873856, -0.80025387364187, -0.723854636344783, 2.76392958212706},
    {0.0232138437439115, 0.53720785237928, -0.12547333482566, -0.0765656943091245, -0.0811568320805669, -0.153888727424808, -1.53428368653199, 1.26116386310603, -0.0835173539639617, -0.0496222433554894, 0.0111495902450432, 0.389873654755786, -0.454124093010758, 0.153888727424808, 0.13633681170785, -6.42186515765066, -0.467332714291883, 0.049622243355489, -0.199067870201143, -0.443089749751426, 1.83373928319032, -1.75200335936095, 0.391416674441764, -0.379491222994871, 0.0387398677950253, 0.281720641970843, -0.421048643677778, 0.460320928675603, -1.99309953072271, -2.1234947573731, -0.0387398677950264, 1.57640617231611, 0.421048643677777, -0.460320928675604, 0.226011371304713, -0.560437026223538, 0.448749399499441, -0.638009667464206, 0.324701707017546, 0.535280925091324, 2.76365938982466, -6.85300496601942, 5.48729245101889, 10.5090764758116, -5.34837518126701, 0.550850068255845, 3.26161245651752, -1.65992960023658, 2.50298598036797, -1.85812681428695},
    {-0.138566640473884, 0.595832618747915, -0.688772361232908, -0.066224633462947, -0.0424502734777086, -0.0578765020203713, -1.43723513893444, 0.844120572468694, 0.0907825760323355, 0.0690671693240334, 0.38208870515529, 0.163849194570811, -0.186028874620448, 0.0578765020203724, 0.797289996155128, -2.08847476667468, 0.397834432404979, -0.069067169324034, -0.0460474603673563, -0.0487666930498727, 1.28476773881766, -1.64721956367447, 1.80793837795993, -1.24317121942811, -0.201370300695994, 0.203515804402884, -0.210771515542723, 0.19648324590981, -4.47309757068157, -5.44792115490559, 0.201370300695995, 0.891862712743735, 0.210771515542724, -0.196483245909814, 0.145684233818455, -1.91747624331689, 2.07847566557606, -0.332574763747181, 0.23495020263932, 0.228479148098153, 0.303993760228442, -4.00112488549047, 4.33707626804134, 4.23910537942018, -2.99475118521419, -0.488617008437313, 9.07932060138759, -6.41416140866595, 6.69109237433371, -1.09537851714662},
    {-0.0867112697486256, 0.692328341357126, -1.76462388414566, 1.18519576926095, 0.0327246027163578, 0.0204847751966039, -1.20941104184695, 0.287528119487931, 0.104233971684684, 0.103341901603272, 0.268333407534353, -0.158965367263467, 0.0884517559977574, -0.0204847751966033, 0.183906264039707, -0.038564947916983, 0.281735363146929, -0.103341901603272, 0.118963651485845, 0.138918164337418, 0.529306916813755, -1.39280580424552, 3.33569324242818, -0.918158401560049, -0.484294992385491, -2.59387568091367, 1.03882900843693, -0.104206989941387, -0.447402627577323, -2.48170233282908, 0.48429499238549, -7.01102044860074, -1.03882900843693, 0.104206989941383, -0.642864435433672, -1.7098977305113, 3.84905264255628, 1.97507416355437, -3.00130456555185, -0.121176358714117, -0.440596635696454, -1.17190366416841, 2.6380050776721, 0.479152368599922, -0.728115540170873, -0.385969334831611, 5.55877915829135, -8.44706977314221, 3.39986073438913, 9.60489612951441},
    {0.258324173993585, 0.809132783013127, -3.29120129853804, 4.92980584650552, -3.03841463918547, 0.288623553688338, -0.830942854030471, -0.114188356405141, -0.0720343266745783, -0.0876613998747674, -1.34708568607265, 2.86625354516242, -3.2238211552292, -0.288623553688338, -0.340104151364433, -0.0663906027038586, -0.0764299194853943, 0.0876613998747682, -0.0291558008725298, -0.0268576215159651, -0.0502357293041718, -0.961207805314046, 3.63555610734632, 0.571536013672395, 0.505689713046096, -6.22971683400606, -1.37361142730363, 5.38528100170711, 2.11375983269295, 0.606411602975405, -0.505689713046097, -6.60985918825748, 1.37361142730363, -5.38528100170711, 0.181755906531438, 0.246782311661728, 4.20974876641753, -0.571882689850421, -7.22417670181752, 6.26223579441467, 0.0458886461235967, 0.0623061246565235, 1.06285223461479, 0.0132464333168121, 0.167332525792185, 0.148464246159973, -0.421743101149711, -5.32757283888956, -1.1779476166478, 12.8395760222636},
    {0.0664733009545256, 0.919863564854673, -4.94227542033296, 10.8701129799616, -12.5055756024883, 8.16976222157871, -0.378832364552641, -0.172470869633397, -0.147264249503354, -0.204926878310822, -0.14691430563133, -0.484156194529885, 2.63141247240989, -8.1697622215787, -0.0112611882292042, 0.00768187415006124, 0.030987216838388, 0.204926878310823, -0.208716262863443, -0.153008802706328, -0.184953912959857, -0.439657887279568, 2.17833293068936, 1.12314316450796, 1.30452607023257, -5.4259220965733, -3.80557674439065, 8.49139905584445, -0.0970232217536013, -0.236330819574602, -1.30452607023257, 1.14171786514219, 3.80557674439065, -8.49139905584445, 1.35553299979376, 1.20464522191188, 2.52901150425865, -4.08313698886522, -6.30281979656652, 9.87416313007839, 0.103903511615001, 0.0923377511472639, 0.193852290019582, 0.0647851764374369, 0.100003819045897, 0.116277032664967, -0.818246487387744, -1.26306322154801, -0.886812344933365, 4.28420423143111},
    {0.0307253509165754, 0.732933512062506, -0.164508796215631, -0.0953652459992034, -0.093851963334491, -0.153888727424811, -3.19425102379765, 5.27695557341787, -3.85725462991615, 0.798848493973309, -0.0176781856910549, -0.0308310083721326, -0.196192270366811, 0.153888727424811, -0.343255582932782, 1.70600788325705, -8.06337466302119, -0.79884849397331, 0.105058733828347, 0.107048073102035, 0.28163911804204, -1.2574047879515, 0.774142521471153, -1.47426658907884, 1.54718213082688, 0.517324012099031, -1.41445222820338, 0.730947882573474, 0.250275604184912, -3.08187169411101, -1.54718213082688, 1.08143685910169, 1.41445222820338, -0.730947882573472, -0.0433492528612944, -0.0796869323785759, 0.305223167146556, -0.0782307940814289, 0.204427048452765, 0.290044233701302, -0.841708154933354, -1.54727328379439, 5.92648804545818, 4.32883510670665, -11.3117985633816, 11.9206292929373, 0.635050888322835, -1.6594690139789, 4.55613828318986, -1.59876087120073},
    {0.148294415168219, 0.768918916307804, -0.860731749519541, -0.079372179355585, -0.047869059460781, -0.0578765020203732, -2.85197444483158, 3.71701831994325, -1.73003073753795, -0.123511007815444, -0.251910113159573, -0.042202053818901, -0.0759333334893335, 0.0578765020203713, -0.834686539129947, 1.97633236806257, -2.74429876876707, 0.123511007815443, 0.0547053380714208, 0.0500045419232791, 0.102275710642093, -1.12419892211282, 3.44078912805436, -5.15046955391734, 3.4030813725359, 0.364416669357123, -0.774378690190798, 0.311997573024001, 1.82946177288559, -8.17004400482656, -3.4030813725359, 0.578063843222914, 0.774378690190798, -0.311997573024002, -0.100877781561396, -0.144544174396519, 1.35806381863703, -0.0225272530333986, 0.144101486207885, 0.123802392950114, -0.334251472918266, -0.478937011163161, 4.49984946804296, 1.05495669771111, -6.74830738571693, 4.47432950630503, 0.976557881508616, -6.24680878244856, 13.3205135587439, -0.942480512580042},
    {0.288245120659524, 0.826589347339836, -2.06115841063897, 1.34512191896954, 0.0355985137911572, 0.0204847751966025, -2.243152700373, 1.72929155552928, -0.11001622407333, -0.0529350629556766, -0.870895760782958, 0.740818696194024, 0.0300614087998687, -0.0204847751966042, -0.947793322172685, 0.952398067000443, -0.0929039539653039, 0.0529350629556751, -0.0692798741367886, -0.0596887415221322, -0.0999179023362539, -0.885947950004186, 6.01150695506046, -5.29287254775862, 0.469894047305343, -4.48056036862216, 5.50503910225613, -0.165471248214072, 3.31080527482654, -4.46960247602634, -0.469894047305342, -3.78363989249273, -5.50503910225613, 0.165471248214069, 0.251691835434796, 0.303949521999126, 2.376412813988, -0.312422963649317, -1.77351765151425, -0.0656599225910269, 0.273915492086006, 0.330787380305268, 2.58624315015441, -0.401651616238655, -2.28003800629107, 0.202920178038634, -1.39625471298331, -7.92605751690369, 9.76247502378497, 8.26420026111489},
    {0.211629929169828, 0.894125141570338, -3.59296158151086, 5.29595271223312, -3.18693460622811, 0.288623553688339, -1.44043934924041, 0.265477095115421, 0.0993247475666086, 0.0905706902337725, -0.795255349482026, 0.973470037069584, -0.206284350599031, -0.288623553688339, -0.318822529019678, 0.0487983959951488, 0.00642910620449009, -0.0905706902337734, -0.194809079437784, -0.148108661457017, -0.19278203487582, -0.570055294969546, 6.20170103224063, -1.2973604836342, -0.664776985404366, -10.3757646108589, 2.97272576377869, 8.55133777337992, 1.1399592220309, -0.0839757315184119, 0.664776985404368, -0.671603948363598, -2.97272576377869, -8.55133777337993, 0.990640651132554, 0.942021585899293, 2.45555469396104, -2.15813463360149, -4.11128811570121, 3.39321895682714, 0.397153641216623, 0.377661973104815, 0.984446263938655, -0.108183615777587, -0.206091875332984, -0.105753853771098, -2.52723287237905, -4.81442738189248, 1.38133621515261, 11.0473685592225},
    {-0.287383368069133, 0.956163846795196, -5.11339400277776, 11.1769121298321, -12.7397587969251, 8.16976222157871, -0.622379214652005, -0.201459834843232, -0.150902737088019, -0.19134689592976, 1.81307241877916, -4.86684701705692, 7.38940173345125, -8.16976222157871, 0.220678982979607, 0.0877231729903849, 0.0875276341409139, 0.19134689592976, -0.170757728422407, -0.119556563039011, -0.131759001550116, -0.246707185714526, 3.55662213627245, 1.29980313335139, 1.31218488814208, -8.77721557579735, -4.32320098473321, 13.4835715113227, -1.54868676013972, -0.753920673054691, -1.31218488814207, 5.09102040505871, 4.32320098473321, -13.4835715113227, 1.03995793497277, 0.850271555111316, 1.41009209391451, -2.82917645342377, -3.4808886593514, 5.35035706347389, 0.126578981100993, 0.103491211986334, 0.171630038585074, 0.0509948914716579, 0.0627417703811865, 0.0633751029471067, -0.90027652403309, -1.10765885209964, -0.545882460296707, 3.68619517073864},
    {0.136246592488556, 0.9091917729059, -0.198758544842835, -0.111280669107761, -0.104008515538231, -0.153888727424814, -5.00241514142445, 11.3487406799524, -13.6512361757966, 9.65546182492156, -0.0232954564071926, -0.00616373515138709, 0.0101622736935181, 0.153888727424814, -0.586307089086447, 0.628596434706267, 1.33381000156881, -9.65546182492156, -0.206368245594597, -0.153521289707953, -0.191170602922272, -0.494378227169631, 1.17091271238659, -3.01117640477567, 4.94093995929796, 0.743125520653222, -2.60689130666788, 0.947458978837498, 0.0648557912384477, 0.294210513499034, -4.94093995929796, -0.0726079484014586, 2.60689130666788, -0.947458978837496, 0.0555578588263402, 0.0507286897117971, 0.115767452711893, 0.0439264739612906, 0.0735179302978557, 0.0938462418447137, 1.39829698611411, 1.27675499797773, 2.91367024641904, -4.47975525280365, -7.49758186185501, 12.3174261742278, -0.462201271648912, -0.773567231976131, 2.71696589127664, -0.670517572251766},
    {0.0508201537761879, 0.921992874650236, -1.00949188137987, -0.0904065681741713, -0.052204279130212, -0.0578765020203685, -4.33565424042011, 7.98072916563719, -7.02038040494667, 2.64740738044187, -0.0110004824460673, 0.00590658279383861, 0.0121469776576461, 0.0578765020203669, -0.0472458364883375, -0.521409434336837, 1.6335136764243, -2.64740738044187, -0.208536559821733, -0.152440957402996, -0.183205852336291, -0.428629658865401, 5.08000031802799, -10.5880071387386, 12.6627476236861, 0.515137832901325, -1.45972009203278, 0.404413103840409, -0.331894497016479, 2.46363494135172, -12.6627476236861, -0.119863119482095, 1.45972009203279, -0.404413103840407, 0.27499345370843, 0.243103759388443, 0.502395150729069, 0.033527809329745, 0.050972176050587, 0.0400573014725643, 1.18106599532927, 1.04410334020107, 2.15773074137811, -2.95970050829058, -4.49961922300977, 5.38686672852237, -1.88394809688837, -2.86415772412314, 8.12437219738692, -0.395274713419241},
    {-0.127595092614201, 0.94211268082534, -2.31225141453112, 1.47759207750688, 0.0378977438878161, 0.0204847751966082, -3.26179396758609, 3.84189325821416, -1.46142822896921, -0.187994765484731, 0.438855364505288, -0.406648411251724, -0.0166529258255924, -0.0204847751966075, 0.619074453405154, -1.05732821218668, 0.642176905529876, 0.187994765484729, -0.19483474099072, -0.138772873632375, -0.158276461917954, -0.322633511670089, 8.55953676376873, -11.3961221439565, 5.86326077670041, -6.18283741292547, 11.1338297871503, -0.214484812936191, -2.35567182514291, 5.0076536831427, -5.86326077670041, 2.71684597198951, -11.1338297871503, 0.214484812936186, 0.55693304779859, 0.469596891800311, 0.846866110426928, -0.458990814111838, -0.611952852143316, -0.02124481806223, 0.785641580427851, 0.662440208381087, 1.194637725372, -1.19342390986138, -1.59114113616611, 0.819251323439337, -2.65888590459367, -3.54497903403215, 6.38846846081382, 3.46599144093595},
    {-0.405296087049488, 0.965098624043575, -3.84258032344357, 5.59493014084544, -3.30575581164891, 0.288623553688344, -1.99682203872871, 0.867784465877598, 0.153959671216833, 0.105852187397968, 1.80583279730039, -3.03701648093234, 2.20785138931023, -0.28862355368834, 0.938412843554319, -0.471047119163687, -0.102826734145331, -0.10585218739797, -0.148401337794717, -0.102816977085576, -0.110960259772187, -0.197623962341603, 8.49249694472013, -4.16382557788167, -0.993408479653116, -13.9505629151505, 9.19790865284456, 11.08429471871, -4.6098615239341, 2.78093985483639, 0.993408479653118, 9.31731545486157, -9.19790865284456, -11.08429471871, 0.663618854313082, 0.532506111944666, 0.840622559885424, -1.1767189874363, -1.3811946724768, 1.09790442233867, 0.34485388516764, 0.276720289645354, 0.436835020361395, -0.182511386611546, -0.214225960102364, -0.051132937071501, -1.78613175750695, -2.09650366327908, 1.38288572304528, 4.63324746028895},
    {-0.729420397946699, 0.985708641666342, -5.25214046484746, 11.4243799830647, -12.927113601847, 8.16976222157871, -0.828621425313877, -0.181971301432517, -0.121306661194978, -0.142219700439312, 4.03187699731423, -9.20606324283965, 11.1959607479293, -8.16976222157871, 0.636102496984887, 0.146637218987198, 0.105061706660281, 0.142219700439311, -0.0733757036279665, -0.0496710434458343, -0.0511932222823217, -0.0820482743635141, 4.71218718284896, 1.16552492088478, 1.03954239228303, -11.5443936807302, -3.82040188607883, 17.4774853307226, -3.79720328645515, -1.00944198889806, -1.03954239228302, 9.99840973700668, 3.82040188607883, -17.4774853307227, 0.425725525597762, 0.327919433759249, 0.466618508176213, -1.0750444868521, -1.14327225337298, 1.73115285391771, 0.0671660048268726, 0.0517353011421367, 0.0736176223599847, 0.0171236640115543, 0.0182104184337617, 0.0162449545346992, -0.443421074880846, -0.471562821512963, -0.156082931986733, 1.54598394372352},
    {0.113928564117325, -0.218256695635769, 0.0660288489812618, 0.0587187272009724, 0.124017235870969, -0.153888727424812, 0.0733887411520707, 0.0637431422621104, 0.133209060673519, -0.164167775300463, -0.897392725924522, 1.11679585815058, -0.667429939275512, 0.153888727424811, -0.997420422902051, 1.2123572948061, -0.716898055757182, 0.164167775300463, -3.86523011808381, 6.21454844664931, -3.57875818583616, 1.33376798878911, -0.027284953362061, -0.0382189049440483, 0.0404350712376756, -0.0391306548262898, 0.0277492861274074, 0.0418410144593153, -0.51894385926155, 0.205684647193066, -0.0404350712376759, 0.210591458446025, -0.0277492861274074, -0.0418410144593151, -0.825569520849963, 2.1531873929537, -0.496253995160481, -0.462808305865572, -0.712706279485977, 0.543412703404544, -0.917591458937763, 2.39319198610029, -0.551568845412548, -0.50240965850478, -0.77369077856343, 0.583688995083663, 0.215054100166431, 0.33117471245718, -0.167465742249018, -0.171460803619737},
    {0.269990545910719, -0.280175037546945, 0.383747306192837, 0.0469015469885933, 0.045126163604186, -0.057876502020371, 0.0727845062071856, 0.0560505031716976, 0.0873966756338503, -0.149034415307041, -1.30154270918084, 0.557676967080659, -0.277076277497001, 0.0578765020203703, -0.246860738476909, 0.666461484090048, -0.536618750989811, 0.149034415307041, -1.30205689381536, 2.6581508558724, -2.7326630332463, 1.38675356282549, -0.116383848266156, -0.123904276157109, 0.182364335615601, -0.0196647100365752, 0.0197614744334056, 0.0178594059513608, -1.38384756336564, 0.760776739292482, -0.182364335615601, 0.120742031225668, -0.0197614744334059, -0.0178594059513596, -2.93685457666246, 6.07448098846483, -2.21983100881438, -0.228630971260604, -0.375947542808648, 0.231950113892816, -0.557026737947385, 1.1521334275847, -0.421030457367597, -0.273229387996673, -0.449282599265072, 0.44922207535596, 0.56733634552841, 0.932895066103386, -0.636872463135374, -0.101077321189096},
    {-0.127458660661965, -0.288734078223701, 0.764302484300342, -0.528230785883265, -0.0137224969121036, 0.0204847751966052, 0.0476133273786156, 0.0304504164558667, 0.0293866978957181, -0.12019863508044, 0.835345906031967, -2.86220224093332, 0.136739719441228, -0.0204847751966055, 0.0520390799654305, 0.164994643528039, -0.292827817801937, 0.12019863508044, 0.178415663936761, 0.443553780551471, -1.22959549126017, 1.02381878565761, -0.135132934040505, -0.0914862166278396, 0.325606241800377, 0.0988665549658368, -0.246844448755217, -0.00947192686946453, -0.732213640270674, 0.911627065727216, -0.325606241800377, -0.985169468409701, 0.246844448755216, 0.00947192686946598, -2.91405972400498, 4.29275694872362, -2.97834561505095, 1.04933915424617, 2.34109387257041, -0.123017222529124, -0.181535560187137, 0.26742349548099, -0.185540342637899, -0.0604902537000339, -0.134954806283873, 0.263441119906219, 0.268443798631998, 0.598902775679182, -0.820140849099378, 0.886302913443861},
    {0.0599574981188607, -0.0751681159726966, 0.148269706050578, 0.176927006276899, -0.638089254542732, 0.288623553688339, 0.00340259784932194, -0.00173356112842579, -0.0102837650967014, -0.0793175468753273, -0.485316152903596, 1.81264552367903, -5.71927997511735, -0.28862355368834, -0.0111373775675126, -0.0177606114836698, -0.0921747723655413, 0.0793175468753281, 0.0436499453955299, -0.0391178393220858, -0.260237953407905, 0.270916465188297, 0.0118597804655851, 0.0507727886816861, 0.343765567681145, -0.118917065308977, -0.581054568323668, 0.489496797176208, 0.121505350851338, 0.455083346915352, -0.343765567681145, -1.06586968120749, 0.581054568323669, -0.489496797176208, -0.13617343601772, 1.26907133398317, -0.795851451112426, -1.85817836648528, -0.13139416347066, 6.35736922966008, -0.00312500410818067, 0.0291235445639072, -0.0182637607375357, 0.0182067500806835, 0.00128742253141226, 0.102458537462242, -0.124557510784524, -0.00880762053240027, -0.50585613559704, 1.18478674651647},
    {0.226504621301664, 0.42423122731964, -2.51931486939396, 6.30034913894456, -8.72079246890365, 8.16976222157871, -0.0175527054809475, -0.0130848449412267, -0.0158235923115167, -0.0350775308879066, -1.17098067011928, 2.26640789781618, -1.30337508285042, -8.16976222157871, -0.00815851923720928, -0.00470697659168063, -0.00236493139971214, 0.0350775308879074, -0.228567484145621, -0.122717827016862, -0.123116291437693, -0.176334246021128, 0.114761522384505, 0.102520248984808, 0.201005644744965, -0.343927818097475, -0.49813006297566, 0.771828366999503, 0.0412828582927278, 0.0153222701366798, -0.201005644744966, -0.0514020887443139, 0.498130062975661, -0.771828366999507, 1.50227820486522, 0.955357742054932, 1.23265959259308, -4.57146810079714, -3.9952889359636, 10.0241675517541, 0.0104667531640829, 0.00665621962502162, 0.00858825192905253, 0.00949422800756961, 0.00829759352533823, 0.0181885237112276, -0.0832697723904236, -0.0727746082868107, -0.117842519121492, 0.395329906841798},
    {0.240503275451299, -0.28628929987628, 0.0770893893180499, 0.0575512666200279, 0.085646649915649, -0.15388872742481, 0.426181230376303, 0.0169904654544728, 0.0144499961342095, -0.0187732230697999, -0.198934346621586, 0.639724604203333, -0.539525186253461, 0.15388872742481, -1.09978928821843, 0.188861504297646, -0.091026757769863, 0.0187732230698, -1.054402605484, 2.3143104930913, -2.58817254123149, 1.37405067804918, -0.133016486099124, -0.00717794501184874, 0.00635131781340734, -0.134415530451198, 0.00754649641306006, 0.208116353436686, -1.47857595357729, 0.0452169713964343, -0.00635131781340765, 0.846741398215317, -0.00754649641306005, -0.208116353436687, -0.552035891561493, 1.10348754796893, -0.429606699103903, -0.261470863660587, -0.435805007162773, 0.453878536337812, -3.05187701652297, 6.10052414552206, -2.37503907115697, -0.0771922485339491, -0.128659721218169, 0.0765767616356522, 0.604329627201206, 1.0072628124752, -0.0380390263845858, -0.712325867764121},
    {0.00303876266691748, -0.301946133397289, 0.377044237587166, 0.039971686338694, 0.0287480743053704, -0.0578765020203709, 0.35570495082136, 0.0516705383728245, 0.0387727778774345, -0.0798554220922581, 0.112743231543427, 0.297246090911907, -0.222481451419092, 0.0578765020203713, 0.106362388371802, 0.384243622260384, -0.30006266875796, 0.0798554220922583, -0.10432131118743, 0.943862170363879, -1.7522973977573, 1.21166390931122, -0.493357822210139, -0.0853817020033917, 0.126996446014248, -0.0623120291595097, 0.0213755605582898, 0.0888323213280831, -3.66881404077302, 0.66076930178236, -0.126996446014248, 0.482233019889125, -0.0213755605582894, -0.0888323213280833, -1.86005508358466, 3.06792860426878, -1.69766098981472, -0.117223301234508, -0.219994476016092, 0.193733377113721, -1.75478295667771, 2.89429537575835, -1.6015797582738, -0.151532037785542, -0.284382122847667, 0.261289890880525, 1.44684995572366, 2.71532190725949, -0.57538759977897, -0.419920990729618},
    {-0.157996351774294, -0.236643324868563, 0.569818879903481, -0.332539840484563, -0.00503620216509752, 0.0204847751966048, 0.176564788258324, 0.0429718172322192, 0.0179653491069811, -0.16665434679713, 0.685081437210633, -1.02836080694758, 0.107784769793441, -0.0204847751966052, 0.212280187910397, 0.132887934812672, -0.384494298337473, 0.166654346797131, 0.244046323501201, 0.126043410070261, -0.704582974743168, 0.729132917814563, -0.423141073687126, -0.0752655413239927, 0.542384887910221, 0.180477645663641, -0.553342302405745, -0.047113171264257, -1.30854003945959, 1.61083268285132, -0.542384887910222, -3.86258153525536, 0.553342302405745, 0.0471131712642581, -1.54132956156934, 2.17798675871177, -1.89155751425654, 0.229872535566345, 1.13102811186579, -0.102748567628344, -0.477598298815375, 0.674873691349984, -0.58612036870333, -0.029704833474, -0.146154918570893, 0.366528949230492, 0.292501828860529, 1.43917928428619, -1.53556714152733, 3.68210388959172},
    {0.188157374542531, 0.0291979345553117, -0.305128780364225, 0.899029556149418, -1.08698561075244, 0.288623553688339, -0.0348293501727623, -0.0301467242860004, -0.0509554216513402, -0.207912100848699, -1.09311974803885, 2.729017019739, -4.22292603253327, -0.28862355368834, -0.124775678124373, -0.0915108108550249, -0.19796120064662, 0.2079121008487, -0.0675428941563744, -0.0717532042345271, -0.175823134565446, 0.0977639238585042, 0.299750897820694, 0.296001907386665, 0.999903900603923, -1.00760554502059, -1.98855701839864, 2.43474709597, 0.909898118742999, 1.14996385234333, -0.999903900603924, -3.91453543128951, 1.98855701839864, -2.43474709596999, 0.517838755193467, 0.929742174243796, -0.0493324010341839, -2.41634398843722, -1.2117025874512, 5.30991164328572, 0.059109426898811, 0.10612671711423, -0.00563111571590529, 0.0810260969745397, 0.0406314381664842, 0.24891662229796, -0.805647906704975, -0.404001109858718, -1.44596575972999, 4.92214097631011},
    {0.143182682873864, 0.504539511638753, -2.92484054429372, 7.09932077313887, -9.42860290518039, 8.16976222157871, -0.101360282467508, -0.0644327702181918, -0.0702918079193658, -0.138407634889368, -0.617043178048848, 0.712046529486216, 1.05604468581899, -8.1697622215787, -0.0213836172859851, -0.00646246759163136, 0.00787298934490316, 0.138407634889369, -0.222493404421782, -0.121582887132205, -0.119803876761495, -0.183842026197134, 0.643209552328112, 0.484380985658062, 0.825879124087891, -1.84953562229103, -2.17685144999334, 3.83905857194565, 0.064512527902758, -0.0542527849523605, -0.825879124087891, 0.207156063819399, 2.17685144999334, -3.83905857194565, 1.4170400824573, 0.905593933742575, 1.2192497061427, -4.10666107371783, -3.70470622890726, 8.37255821936139, 0.0491074917933431, 0.0313833371546078, 0.0422530708055426, 0.0372716711615292, 0.0336235666482932, 0.0624188185744622, -0.372069908544494, -0.335652171686378, -0.430128200705707, 1.64237955847164},
    {-0.161958917611737, -0.27076488372056, 0.061223546198224, 0.0345884911148389, 0.02744657411339, -0.15388872742481, 0.748639448326537, -0.569729765621708, 0.0282448832286858, -0.0496222433554887, 0.0765730592183364, 0.151585061594865, -0.345520686816804, 0.15388872742481, 0.93633277341178, -2.49685715770195, -0.355570477099234, 0.0496222433554887, 0.239777169008873, 0.268866634225737, -0.973990293071298, 0.898070291168985, -0.176822169357849, 0.128340815064948, 0.0387398677950284, -0.0952756074984443, -0.421048643677785, 0.4603209286756, -0.774928265718669, -1.61566271931327, -0.0387398677950279, 1.1994099228468, 0.421048643677785, -0.4603209286756, -0.201077656621006, 0.28416750373191, -0.220886452527464, -0.0502782957184065, -0.135895256991297, 0.318074112703414, -2.45877077156142, 3.47479060649949, -2.70099205667639, 0.828166847186466, 2.23842007613719, 0.327325593870547, 0.257031082709832, 0.694719352366685, 1.48732190424832, -1.10413431534835},
    {-0.138647660917849, -0.21585406400914, 0.223449718107214, 0.0169677308765796, 0.00390597156038776, -0.0578765020203714, 0.46626404415215, -0.216276179301875, -0.00835316550663156, 0.0690671693240333, 0.241970447233903, 0.0410426412418469, -0.139672629582348, 0.057876502020371, 0.504910546534908, -0.523142764392621, 0.29869869086601, -0.0690671693240335, 0.225317421290075, 0.0797575058760414, -0.597737904987654, 0.647164702748526, -0.463220560606469, 0.114387753716803, -0.201370300695994, -0.0187260735671016, -0.210771515542721, 0.196483245909812, -1.1204677527659, -4.09036218176068, 0.201370300695996, 0.669620834773752, 0.210771515542721, -0.196483245909813, -0.548551168994651, 0.803571415413603, -0.720440411760069, -0.00376929274972976, -0.0542410793686958, 0.13576665802196, -1.14464090018281, 1.67678196727928, -1.50331565778353, 0.0480446230854954, 0.691374320609001, -0.290345525359379, 0.102902026989879, 1.48078628638249, 3.97597442804388, -0.650894761206651},
    {0.0784651408728721, -0.061797827597089, 0.0545443252607886, 0.0738260863498102, 0.00813907259628298, 0.0204847751966043, 0.0373827589171648, 0.017910185243533, 0.0259244663684304, 0.103341901603272, -0.358197104159233, 0.535979548866736, 0.0638662258776871, -0.0204847751966059, -0.245495675775414, 0.130028469360583, 0.203425857830674, -0.103341901603272, 0.027622725399348, -0.0443340954746575, -0.24499759674281, 0.245041653542336, 0.207781012841066, -0.228359010190467, -0.48429499238549, -0.645133652367759, 1.03882900843693, -0.104206989941385, 1.50849623800913, -1.7919029414595, 0.484294992385491, -5.06227842005482, -1.03882900843693, 0.104206989941385, -0.018613789706141, 0.740360722520855, -0.41809415391627, -0.526185351617172, -0.0836202835993773, -0.0720052984739693, -0.0127572356939521, 0.507417156036062, -0.286547003483861, -0.127652400199607, -0.0202862544045108, -0.229350324199104, -1.48093080246866, -0.235346448381532, 2.02026195164997, 5.70741207242258},
    {0.30179860767733, 0.23640915450621, -1.15104668812143, 2.14074232727352, -1.76786658528815, 0.288623553688339, -0.290609395595099, -0.0495856947412152, -0.0419123438517455, -0.0876613998747676, -1.4000385651718, 2.49182453126872, -1.95327310133187, -0.28862355368834, -0.353473378128936, -0.0577177593874778, -0.0463079366625621, 0.0876613998747681, -0.196901460107855, -0.109334068422313, -0.128667221027397, -0.103305012625975, 1.5787211676279, 0.332541651106278, 0.505689713046096, -3.62468903506824, -1.37361142730363, 5.38528100170711, 1.83763178006512, 0.36741724040929, -0.505689713046096, -4.00483138931966, 1.37361142730363, -5.38528100170711, 1.07372259576833, 0.761862180901998, 0.715500476622906, -2.61208818129502, -2.02047867724722, 3.72113968662003, 0.2710870704144, 0.192350414803794, 0.180645288505841, 0.0605034083479767, 0.0468000457807142, 0.0882202805143077, -1.92632193561248, -1.49003101208054, -0.699958891515569, 7.62952042438791},
    {-0.0586054310955124, 0.636880676372848, -3.58097023983996, 8.36005347555908, -10.5022018617589, 8.16976222157871, -0.274486407165831, -0.132644959235417, -0.123672746018737, -0.204926878310821, 0.575471048921213, -2.18852029690417, 4.63478621313926, -8.1697622215787, 0.0441106655645927, 0.0347242019943345, 0.0545787203230065, 0.204926878310822, -0.191317334359874, -0.109362603663135, -0.107111056838623, -0.170484250415702, 1.67532571388219, 0.943217378252488, 1.30452607023257, -4.55669782469289, -3.80557674439066, 8.49139905584445, -0.438571875105297, -0.416256605830071, -1.30452607023257, 2.01094213702259, 3.80557674439065, -8.49139905584445, 1.16912731473242, 0.771605708869936, 1.0647661673164, -3.18446828851918, -2.98706489013573, 5.86741564861967, 0.089615253589694, 0.0591446632032978, 0.0816158248082483, 0.0505264311468687, 0.0473943260942116, 0.0690940256957309, -0.63815639749151, -0.598597441285388, -0.526960772422423, 2.5457556876703},
    {0.186613680044605, 0.0276979469831479, -0.016286815482291, -0.0184619773736188, -0.0350047482548525, -0.153888727424811, -0.316239485215842, 1.0215779698073, -1.43867237804989, 0.79884849397331, -0.0592422377411533, -0.0565262386342809, -0.137345055287173, 0.15388872742481, -1.15030067029803, 3.12783181000749, -5.64479241115493, -0.79884849397331, -0.0661747340708229, -0.0713805344628641, -0.176592144722135, 0.0998357862280682, 0.149868031751073, -0.549869485706119, 1.54718213082688, 0.192950644465232, -1.41445222820338, 0.730947882573468, 0.4588607143737, -2.15747459073827, -1.54718213082688, 0.757063491467872, 1.41445222820338, -0.730947882573466, 0.0278452172868373, 0.0508382642088003, -0.00315442827219281, 0.0500629350684436, 0.0249252809394559, 0.172349803542025, 0.54066782976044, 0.987121547495601, -0.0612492217421674, -2.77019035040479, -1.37921942940999, 7.08346478920481, -0.406393821774826, -0.202334924349947, 2.7073440764444, -0.950014135933104},
    {0.26262833189321, 0.119570063807635, -0.18629638570859, -0.0244646644642523, -0.0227507319824558, -0.0578765020203725, -0.61728004282631, 1.14568614271631, -0.822231856537404, -0.123511007815445, -0.371819690231104, -0.0477770585860801, -0.0508150060110062, 0.0578765020203707, -1.2319985352187, 2.23741118713505, -1.83649988776653, 0.123511007815444, -0.137982648591287, -0.0911691460845481, -0.143997472754263, -0.00904912827074755, 1.06054479281689, -2.447864105226, 3.4030813725359, 0.173196341600901, -0.774378690190793, 0.311997573024002, 2.07113859148238, -5.46743855613523, -3.4030813725359, 0.38684351546669, 0.774378690190794, -0.311997573024002, 0.232322287801951, 0.223219781902331, 0.102574006235411, 0.043530271392291, 0.0287114516580414, 0.0735657379934624, 0.76978364995344, 0.73962313336495, 0.339871794726614, -2.03853311766079, -1.34456421219057, 2.65873174430393, -1.88704009092242, -1.24464329337685, 7.91530266136124, -0.560039857067593},
    {0.297257923557781, 0.291832089112708, -0.841280923622996, 0.656732008696605, 0.0222767402895126, 0.0204847751966039, -0.915563581070026, 0.844296045487713, -0.0688456508519504, -0.0529350629556774, -0.807857834631569, 0.582773602692343, 0.0167396352982269, -0.0204847751966055, -0.8791893305811, 0.749214963869796, -0.0517333807439275, 0.0529350629556764, -0.213649244622461, -0.11542274886011, -0.126150246023435, -0.133867773164484, 2.93501204776657, -3.31215926101938, 0.469894047305341, -2.80383277427921, 5.50503910225613, -0.165471248214069, 2.60448329359948, -2.4888891892871, -0.46989404730534, -2.10691229814977, -5.50503910225613, 0.165471248214067, 0.68902670930235, 0.46004348282582, 0.500068566126393, -0.684722686918888, -0.554782924470062, -0.0390163755877404, 0.749865762681257, 0.500663983642982, 0.544223165326885, -0.880280920018928, -0.71323008933858, 0.120579031595878, -3.06010565782308, -2.47938968354297, 5.80104845030648, 4.91074507242897},
    {0.105970427076992, 0.533380965289456, -2.28752304127764, 3.66947089586476, -2.49848276832551, 0.288623553688341, -0.917081389878049, 0.183944330128656, 0.0778682969454349, 0.0905706902337719, -0.287413545533693, 0.0559394161257819, 0.482167487303572, -0.28862355368834, -0.115225774364482, 0.00280414771476864, -0.0150273444166856, -0.0905706902337728, -0.217831885088027, -0.120054740517499, -0.11792762771366, -0.18353713904726, 4.29704770401275, -1.01710050979141, -0.664776985404366, -8.13435865228323, 2.97272576377869, 8.55133777337993, 0.0655065393482127, 0.196284242324381, 0.664776985404369, 1.56980201021202, -2.97272576377869, -8.55133777337993, 1.02378629159576, 0.65764343336111, 0.89350686185446, -1.94955520808225, -1.7758551039083, 2.01631528102194, 0.410441922679098, 0.263653105576641, 0.358212135986793, -0.0977278842035911, -0.0890205936398339, -0.0628409525287492, -2.28298083524155, -2.07957340811942, 0.820816267467028, 6.56455664207121},
    {-0.397585858525549, 0.793676417832501, -4.34154822751178, 9.77838145744783, -11.6542222604831, 8.16976222157871, -0.528433634244636, -0.176251820768422, -0.138044531750748, -0.19134689592976, 2.38339251504385, -6.02882067961084, 8.47493826989333, -8.16976222157871, 0.290095768273419, 0.108667331755441, 0.100385839478185, 0.19134689592976, -0.125455420603007, -0.0764969692852894, -0.0754625796527843, -0.118675589765866, 3.1115935729377, 1.18904877654399, 1.31218488814208, -8.02932165192994, -4.32320098473321, 13.4835715113227, -1.91844015911065, -0.864675029862088, -1.31218488814207, 5.83891432892612, 4.32320098473321, -13.4835715113227, 0.738475413403498, 0.514122084721766, 0.705558214342659, -1.9037598007002, -1.8458009771368, 3.17928399058972, 0.0898838907356377, 0.0625766172429808, 0.0858773579926013, 0.034314588016355, 0.0332699009966228, 0.037658692272565, -0.605798289425976, -0.587355124401074, -0.32437374668191, 2.19040732300382},
    {0.0167231769272537, 0.593196374839002, -0.136760509442194, -0.0820817973761881, -0.0849680060691155, -0.153888727424814, -3.4420298444201, 8.37095104150298, -11.1521476124679, 9.65546182492156, 0.00592046743459575, 0.0122940972627608, 0.0292027831626337, 0.153888727424813, 0.149008114153989, -1.25378938541603, 3.83289856489746, -9.65546182492156, -0.204301268205573, -0.114893726140292, -0.112528398046357, -0.178196159374032, 0.863677589054118, -2.45992987893488, 4.94093995929796, 0.607083885605202, -2.60689130666788, 0.947458978837497, -0.129360426098413, 0.845457039339825, -4.94093995929796, -0.208649583449486, 2.60689130666788, -0.947458978837495, 0.0513623519748769, 0.0334699672899995, 0.0460077227427246, 0.0362096808645664, 0.0335780192488592, 0.0557652229064821, 1.29270320137223, 0.842382254744555, 1.15793627414932, -3.69277325100848, -3.42438840507847, 7.31924904757045, -0.381003960307661, -0.353313202648048, 1.61447283959507, -0.398434302155718},
    {-0.0748919790983797, 0.645727750172867, -0.7387922778266, -0.0700963669874204, -0.0440770338297821, -0.0578765020203679, -3.17302984920507, 6.18782608077738, -5.92743640487679, 2.64740738044187, 0.135886497249017, 0.0198848675421233, 0.0202742229580772, 0.0578765020203668, 0.583617242377616, -1.75535633697017, 2.72645767649418, -2.64740738044187, -0.18838457967804, -0.108056090115312, -0.105848120321838, -0.168546980959294, 3.93875770068702, -8.93964932798132, 12.6627476236861, 0.434940354815695, -1.45972009203278, 0.404413103840409, -1.11734285990507, 4.11199275210903, -12.6627476236861, -0.200060597567729, 1.45972009203278, -0.404413103840407, 0.234100920715805, 0.154927489841716, 0.213877370020062, 0.0258814410199254, 0.0243300584253712, 0.0238028108717031, 1.00543715933641, 0.66539616680396, 0.918579280687085, -2.28470978788373, -2.14775995592348, 3.20097872838262, -1.45429398845215, -1.3671208523298, 4.8276565758723, -0.234879757247976},
    {-0.250468856650956, 0.731477026246285, -1.85165020848896, 1.23254689245622, 0.0335873724596993, 0.0204847751966094, -2.61204358754974, 3.20475026135101, -1.29520993109275, -0.187994765484732, 0.741597708025423, -0.596171784672703, -0.0209632972537075, -0.0204847751966081, 1.0461401018987, -1.55010871751303, 0.808395203406338, 0.18799476548473, -0.154976188373908, -0.0920387320291934, -0.0904610014067879, -0.143532247785438, 7.14001556968877, -10.0999626832235, 5.8632607767004, -5.4796207304694, 11.1338297871503, -0.21448481293619, -3.45356095644328, 6.3038131438757, -5.86326077670041, 3.42006265444559, -11.1338297871503, 0.214484812936185, 0.42366424837211, 0.288508666135027, 0.397879585956399, -0.324989252320542, -0.311385855462972, -0.0126240752059987, 0.59764499696598, 0.406986809860549, 0.561271678824508, -0.845005896071814, -0.809635647766169, 0.486814727686412, -1.88262883607289, -1.80382577717261, 3.79614953934782, 2.0595580760238},
    {-0.502239635580976, 0.834219465627175, -3.38060476427582, 5.03884374042011, -3.0830014515509, 0.288623553688344, -1.75675341289619, 0.781534391644862, 0.143585284844447, 0.105852187397967, 2.17143575456293, -3.5188827636489, 2.43060574940824, -0.28862355368834, 1.12840081544712, -0.545785509857592, -0.113201120517718, -0.10585218739797, -0.104002991877278, -0.0645327311686711, -0.0638287536487619, -0.099615353351484, 7.64841812019008, -3.88325122363192, -0.993408479653116, -13.0105210934827, 9.19790865284456, 11.08429471871, -5.34128226212328, 3.06151420908614, 0.993408479653119, 10.2573572765294, -9.19790865284456, -11.08429471871, 0.452584923045308, 0.319740661860338, 0.436843424807237, -0.769072822428517, -0.750888154342689, 0.652395702142658, 0.235188720251215, 0.166155329632317, 0.227008547565535, -0.119284679456472, -0.116464202330796, -0.0303841643267291, -1.16736910565866, -1.13976675240815, 0.82173701454578, 2.75316381695335},
    {-0.778443022056047, 0.930688141770992, -4.99337808590903, 10.9619220455119, -12.5758791607061, 8.16976222157871, -0.787796917155983, -0.174605118508015, -0.118010714500009, -0.142219700439312, 4.26837451395492, -9.64375602134093, 11.5471951890703, -8.16976222157871, 0.673414315020526, 0.153608934270615, 0.108357653355249, 0.142219700439311, -0.0464943733325675, -0.030081372930002, -0.0299465576581434, -0.045722815794226, 4.52143824337274, 1.13385717920389, 1.03954239228303, -11.2307282494786, -3.82040188607883, 17.4774853307226, -3.97773739893536, -1.04110973057895, -1.03954239228302, 10.3120751682583, 3.82040188607883, -17.4774853307227, 0.266741867657327, 0.195156578656471, 0.263105125640312, -0.662116867402329, -0.656049156768686, 1.02868397163584, 0.0420834187601185, 0.0307895273266221, 0.0415096560487208, 0.0105464163692236, 0.0104497678681736, 0.00965306114476197, -0.273101789396648, -0.270599055040725, -0.0927474486249556, 0.918653081220253},
    {-0.105791126909818, 0.105791126909818, -0.0685178366798126, -0.250681372099604, 0.395723587573243, -0.153888727424811, -0.0761551633562721, -0.27213155199218, 0.425053558215353, -0.164167775300464, 0.0685178366798076, 0.250681372099603, -0.395723587573241, 0.153888727424812, 0.0761551633562681, 0.272131551992178, -0.425053558215352, 0.164167775300464, 0.780580709826271, -3.88416718961363, 3.88416718961363, -0.780580709826274, 0.116484635695005, -0.121951776068555, 0.0404350712376785, -0.124861056636142, 0.0277492861274035, 0.0418410144593193, -0.116484635695003, 0.121951776068552, -0.0404350712376789, 0.124861056636151, -0.0277492861274031, -0.0418410144593198, -1.26511501111013, -1.37300671609703e-14, 1.26511501111015, 0.960020566935795, -0.960020566935794, 0, -1.40613079752927, 0, 1.40613079752928, 1.04216713286877, -1.04216713286877, 0, -0.446094757909608, 0.446094757909605, 0, 0},
    {-0.166507481624836, 0.166507481624834, -0.355375918844868, -0.091294233017432, 0.161101220550592, -0.0578765020203709, -0.0674033676683325, -0.109102748754661, 0.312007713311831, -0.14903441530704, 0.35537591884487, 0.0912942330174324, -0.161101220550594, 0.0578765020203712, 0.0674033676683355, 0.10910274875466, -0.312007713311829, 0.14903441530704, 0.819459829867039, -1.5882368632347, 1.58823686323469, -0.819459829867034, 0.226542083263471, -0.44234050772479, 0.182364335615602, -0.0702033706311282, 0.0197614744334065, 0.0178594059513594, -0.226542083263477, 0.442340507724791, -0.182364335615601, 0.0702033706311226, -0.0197614744334056, -0.0178594059513604, -2.75455363698746, 0, 2.75455363698745, 0.565938716859826, -0.565938716859825, 0, -0.522450120310661, 0, 0.522450120310651, 0.676334830747744, -0.676334830747742, 0, -1.40434868314629, 1.4043486831463, 0, 0},
    {-0.00460700210468895, 0.00460700210468629, 0.07188876517327, -0.271878352533974, -0.0752311081766656, 0.0204847751966056, 0.00447841447771119, 0.0156727121577176, 0.161107257848827, -0.12019863508044, -0.071888765173264, 0.271878352533968, 0.0752311081766659, -0.0204847751966069, -0.00447841447770822, -0.0156727121577182, -0.161107257848828, 0.12019863508044, 0.062525413986183, -0.192882734206211, 0.192882734206206, -0.0625254139861753, -0.0695524010751923, -0.50155664117753, 0.325606241800379, 0.542018011687759, -0.246844448755223, -0.00947192686946359, 0.0695524010751771, 0.501556641177526, -0.32560624180038, -0.542018011687764, 0.246844448755223, 0.00947192686946459, 0.246963897601127, 1.91729853799448e-14, -0.246963897601152, -4.96246959933911, 4.96246959933911, 0, 0.0153849727676087, 1.10124859458403e-14, -0.0153849727676235, 0.286066753373333, -0.286066753373332, 0, -1.26950775109438, 1.2695077510944, 0, 0},
    {0.290022490838601, -0.290022490838603, 1.41899947092762, -2.74129544088452, 2.54059536028731, 0.28862355368834, 0.0325642012557386, 0.026859682520107, 0.0409455036344191, -0.0793175468753269, -1.41899947092762, 2.74129544088452, -2.54059536028731, -0.288623553688343, -0.0325642012557387, -0.0268596825201065, -0.0409455036344198, 0.0793175468753274, -0.445947360880906, -0.00479605896763817, 0.00479605896763629, 0.445947360880909, -0.183754661339312, -0.202155279116841, 0.343765567681149, 0.473476307949252, -0.581054568323686, 0.48949679717621, 0.183754661339306, 0.202155279116828, -0.343765567681149, -0.473476307949253, 0.581054568323686, -0.489496797176205, 2.53425209044841, 1.22386155053122e-14, -2.53425209044842, -6.63370064805765, 6.63370064805766, 0, 0.058157805409318, 0, -0.0581578054093258, 0.0649981358020863, -0.0649981358020867, 0, -0.444670573565341, 0.44467057356535, 1.24955074734735e-14, 0},
    {0.00324591462100695, -0.00324591462100568, -0.223681572845232, 1.37517423910195, -3.70870869302661, 8.16976222157871, -0.00155844623366582, -0.00285602294238379, -0.0067293304559017, -0.0350775308879046, 0.223681572845238, -1.37517423910195, 3.70870869302661, -8.16976222157871, 0.00155844623367736, 0.00285602294237948, 0.00672933045590628, 0.0350775308879051, -0.188903828583366, -0.0219852273761949, 0.0219852273761913, 0.188903828583369, 0.0250489434383465, 0.0435989894240516, 0.201005644744969, -0.146262864676571, -0.498130062975679, 0.771828366999502, -0.0250489434383236, -0.0435989894240685, -0.201005644744969, 0.146262864676578, 0.498130062975677, -0.771828366999501, 1.03578035972028, 0, -1.03578035972029, -2.21347872680348, 2.21347872680347, 0, 0.00721654439390435, 0, -0.00721654439392061, 0.0045970509382863, -0.00459705093828269, 0, -0.0403187478744644, 0.040318747874443, 1.40096784142745e-14, 0},
    {-0.164081106760815, 0.164081106760815, -0.0665458915788057, -0.0968987680588124, 0.312585918084556, -0.15388872742481, -0.367892523217869, -0.0286067582518043, 0.0527383769520353, -0.0187732230697996, 0.0665458915788042, 0.0968987680588138, -0.312585918084556, 0.153888727424811, 0.367892523217868, 0.028606758251806, -0.0527383769520364, 0.0187732230697991, 0.770859725525681, -1.3666306125924, 1.3666306125924, -0.770859725525681, 0.223959165305902, -0.026197458204145, 0.00635131781340835, -0.490578464333257, 0.00754649641305751, 0.208116353436686, -0.223959165305902, 0.0261974582041456, -0.00635131781340802, 0.490578464333253, -0.00754649641305743, -0.208116353436686, -0.470330115326039, 0, 0.470330115326042, 0.669730773949613, -0.669730773949613, 0, -2.60017453771347, 0, 2.60017453771347, 0.197720019851455, -0.197720019851457, 0, -1.54792829793653, 1.54792829793653, 0, 0},
    {-0.0960766222659435, 0.0960766222659431, -0.139181614087521, -0.0141621012778632, 0.125614762862231, -0.0578765020203715, -0.131304457829816, -0.0183070434236165, 0.169417723317697, -0.0798554220922586, 0.139181614087523, 0.0141621012778626, -0.125614762862231, 0.0578765020203712, 0.131304457829817, 0.0183070434236171, -0.169417723317698, 0.0798554220922583, 0.370355140329414, -0.494118116185394, 0.494118116185392, -0.370355140329412, 0.17479831561678, -0.373075501892878, 0.12699644601425, -0.272272524524317, 0.0213755605582891, 0.0888323213280838, -0.174798315616783, 0.373075501892878, -0.126996446014249, 0.272272524524317, -0.0213755605582883, -0.0888323213280834, -0.62386128110376, 0, 0.623861281103754, 0.394810890417024, -0.394810890417022, 0, -0.58855307731115, 0, 0.588553077311145, 0.510363538091554, -0.510363538091554, 0, -4.87302535676189, 4.87302535676189, 0, 0},
    {0.134579466303349, -0.13457946630335, 0.527538352011231, -0.655871713874954, -0.0564104859792686, 0.0204847751966041, 0.16346369119392, 0.0847537527393661, 0.201229823722227, -0.166654346797131, -0.52753835201123, 0.655871713874953, 0.0564104859792705, -0.0204847751966061, -0.163463691193919, -0.0847537527393661, -0.201229823722228, 0.166654346797131, -0.252506609718202, -0.0310767686897985, 0.0310767686897976, 0.252506609718203, -0.834565448776498, -0.843049112087659, 0.542384887910223, 2.0215295904595, -0.553342302405746, -0.0471131712642571, 0.834565448776496, 0.843049112087657, -0.542384887910223, -2.0215295904595, 0.553342302405747, 0.0471131712642596, 1.34545323767321, 0, -1.34545323767321, -3.46192437946911, 3.46192437946911, 0, 0.416903816983887, 0, -0.416903816983893, 0.447360477137226, -0.447360477137226, 0, -4.40513352270102, 4.40513352270102, 0, 0},
    {0.29979034391558, -0.299790343915581, 1.34163924975309, -2.25682373763315, 1.56797021089042, 0.288623553688339, 0.153143283237314, 0.0756769813797018, 0.0735028894976396, -0.207912100848699, -1.34163924975308, 2.25682373763315, -1.56797021089041, -0.288623553688342, -0.153143283237314, -0.0756769813797022, -0.0735028894976398, 0.207912100848699, -0.427176739440945, -0.0159481631438741, 0.0159481631438736, 0.427176739440947, -0.752461292236038, -0.426980972478335, 0.999903900603925, 1.45346494313446, -1.98855701839864, 2.43474709597, 0.752461292236037, 0.42698097247833, -0.999903900603924, -1.45346494313446, 1.98855701839864, -2.43474709596999, 2.17887310994537, 0, -2.17887310994537, -4.62781071800808, 4.62781071800808, 0, 0.248710509830373, 0, -0.248710509830377, 0.155182143689596, -0.155182143689597, 0, -1.54298644374778, 1.54298644374778, 0, 0},
    {-0.103138285400147, 0.103138285400149, -0.823425571056468, 2.74590631055142, -5.24232379549969, 8.16976222157871, -0.0285357944165715, -0.0249215884170057, -0.0390823986321337, -0.138407634889366, 0.823425571056477, -2.74590631055142, 5.24232379549969, -8.16976222157871, 0.0285357944165846, 0.0249215884170014, 0.0390823986321377, 0.138407634889367, -0.142762742683896, -0.0182789893821167, 0.0182789893821134, 0.142762742683899, 0.248783401283581, 0.269316885305201, 0.825879124087893, -1.02834584305521, -2.17685144999335, 3.83905857194565, -0.248783401283562, -0.269316885305214, -0.825879124087892, 1.02834584305522, 2.17685144999335, -3.83905857194565, 0.759841412289223, 0, -0.759841412289235, -1.54416985623, 1.54416985623001, 0, 0.0263322868422603, 0, -0.0263322868422757, 0.0140147409454458, -0.0140147409454431, 0, -0.139904201216376, 0.139904201216359, 0, -1.19561797459575e-14},
    {0.0564307431585077, -0.056430743158508, 0.0254222755673752, 0.0368690228656226, 0.186483630465097, -0.15388872742481, 0.310862724193498, -0.60729390265075, 0.191907680163959, -0.0496222433554887, -0.0254222755673764, -0.0368690228656224, -0.186483630465097, 0.15388872742481, -0.310862724193497, 0.607293902650749, -0.19190768016396, 0.0496222433554883, -0.0929077844791388, -0.0974266666747165, 0.0974266666747144, 0.0929077844791412, -0.18848063026393, 0.872001767189101, 0.0387398677950302, -0.647342765172617, -0.421048643677792, 0.460320928675597, 0.188480630263925, -0.872001767189108, -0.0387398677950282, 0.647342765172615, 0.421048643677791, -0.460320928675596, 0.0760984621080932, 0, -0.0760984621080936, 0.328910404953348, -0.328910404953349, 0, 0.930529416029717, 0, -0.930529416029727, -5.41769941054797, 5.41769941054797, 0, -1.68144517016144, 1.68144517016144, 0, 0},
    {0.169880004840814, -0.169880004840815, 0.277936485181337, 0.0441822278518113, 0.0717893005713681, -0.0578765020203718, 0.579959512573225, -0.563160949589568, -0.153525928186321, 0.0690671693240331, -0.277936485181337, -0.0441822278518123, -0.0717893005713673, 0.0578765020203708, -0.579959512573224, 0.563160949589568, 0.15352592818632, -0.0690671693240332, -0.311928249721622, -0.0146224840668091, 0.0146224840668077, 0.311928249721623, -1.20617874618746, 2.10237496773874, -0.201370300695994, -0.344173454170424, -0.210771515542721, 0.196483245909814, 1.20617874618746, -2.10237496773874, 0.201370300695996, 0.344173454170427, 0.210771515542721, -0.196483245909813, 0.66033832087207, 0, -0.660338320872073, 0.193894942412819, -0.193894942412818, 0, 1.37790290632956, 0, -1.37790290632957, -2.47144757516657, 2.47144757516657, 0, -5.29334915649784, 5.29334915649785, 0, 0},
    {0.294232960746207, -0.294232960746207, 0.873832507491196, -0.724042594224889, -0.0278635766407018, 0.0204847751966044, 0.598894015194809, -0.175652504797971, -0.0887506957311214, 0.103341901603271, -0.873832507491197, 0.724042594224887, 0.0278635766407032, -0.0204847751966064, -0.598894015194809, 0.175652504797972, 0.0887506957311206, -0.103341901603271, -0.446688097648324, -0.00623973119156523, 0.00623973119156526, 0.446688097648324, -2.03779329240448, 0.78177196563452, -0.484294992385489, 2.20857238384354, 1.03882900843693, -0.104206989941384, 2.03779329240448, -0.781771965634517, 0.484294992385491, -2.20857238384353, -1.03882900843693, 0.104206989941386, 1.53466376766744, 0, -1.53466376766744, -1.70018012290817, 1.70018012290817, 0, 1.05180447959199, 0, -1.05180447959199, -0.412463161115885, 0.412463161115885, 0, -4.7850992165049, 4.7850992165049, 0, 0},
    {0.197406415132327, -0.197406415132326, 0.723022422627702, -0.834525081479548, 0.0927032580218592, 0.28862355368834, 0.182544384524022, 0.0193299798004343, 0.00219779640540858, -0.0876613998747681, -0.723022422627704, 0.834525081479549, -0.0927032580218596, -0.288623553688342, -0.182544384524023, -0.0193299798004343, -0.00219779640540932, 0.0876613998747683, -0.309428147286897, -0.0260020957934183, 0.026002095793419, 0.309428147286897, -0.615432504072605, -0.0174377946515076, 0.505689713046096, 0.190071177125714, -1.37361142730362, 5.38528100170711, 0.615432504072607, 0.0174377946515093, -0.505689713046094, -0.190071177125715, 1.37361142730362, -5.3852810017071, 1.37616402777775, 0, -1.37616402777775, -2.27275669046975, 2.27275669046975, 0, 0.347445677468488, 0, -0.347445677468486, 0.0526435237155407, -0.0526435237155421, 0, -1.67607705532796, 1.67607705532796, 0, 0},
    {-0.304744182307482, 0.304744182307487, -1.90385142678789, 5.0544025264641, -7.56849403744909, 8.16976222157871, -0.1459328905062, -0.0801957809291877, -0.0891257331708705, -0.204926878310821, 1.9038514267879, -5.0544025264641, 7.56849403744909, -8.16976222157871, 0.145932890506215, 0.0801957809291844, 0.0891257331708739, 0.204926878310821, -0.0786532648221211, -0.0114099619956296, 0.0114099619956266, 0.0786532648221223, 1.01288473161711, 0.679736992041272, 1.30452607023257, -3.28381998085773, -3.80557674439066, 8.49139905584444, -1.0128847316171, -0.67973699204128, -1.30452607023257, 3.28381998085775, 3.80557674439066, -8.49139905584444, 0.40091900889339, 0, -0.4009190088934, -0.758354778494299, 0.7583547784943, 0, 0.0307310061087251, 0, -0.0307310061087383, 0.012032451583396, -0.0120324515833953, 0, -0.151971666732978, 0.151971666732966, 0, -1.89925771123295e-14},
    {0.299991988790641, -0.299991988790642, 0.0732726949488155, 0.0470325451595016, 0.05117015351616, -0.15388872742481, 1.42272867008211, -2.6025062769043, 2.10306001655252, 0.79884849397331, -0.0732726949488144, -0.0470325451595017, -0.05117015351616, 0.15388872742481, -1.42272867008211, 2.6025062769043, -2.10306001655252, -0.79884849397331, -0.427758123512838, -0.0158062160797523, 0.0158062160797495, 0.427758123512841, -0.381794150683424, 0.803802552516071, 1.54718213082688, -0.282056423501314, -1.4144522282034, 0.730947882573464, 0.381794150683417, -0.803802552516075, -1.54718213082688, 0.282056423501311, 1.41445222820339, -0.730947882573463, 0.119089790418281, 0, -0.119089790418287, 0.0965700706520006, -0.0965700706520013, 0, 2.31235468083332, 0, -2.31235468083333, -5.34362353091002, 5.34362353091002, 0, -0.783922876828754, 0.783922876828763, 0, 0},
    {0.272170305024624, -0.272170305024623, 0.309548329113102, 0.0281626337102477, 0.0140321370142744, -0.0578765020203716, 1.02566673596469, -1.31886293520906, 0.507134015614559, -0.123511007815445, -0.309548329113104, -0.0281626337102483, -0.0140321370142741, 0.0578765020203706, -1.02566673596469, 1.31886293520907, -0.507134015614563, 0.123511007815446, -0.382504982925768, -0.0226770232778288, 0.0226770232778284, 0.382504982925767, -1.22085199970994, 1.50978722545461, 3.40308137253589, -0.106823586932891, -0.774378690190789, 0.311997573024002, 1.22085199970995, -1.50978722545462, -3.40308137253589, 0.106823586932891, 0.774378690190789, -0.311997573024001, 0.498447494486963, 0, -0.498447494486961, 0.0569287198151249, -0.0569287198151247, 0, 1.6515709071504, 0, -1.6515709071504, -2.6659856917342, 2.66598569173419, 0, -2.46786369990438, 2.46786369990437, 0, 0},
    {0.148805352758509, -0.148805352758507, 0.299004451343533, -0.107758535600083, 0.00276855249564118, 0.020484775196606, 0.325405674300824, -0.138534598999157, -0.00855613505400994, -0.0529350629556783, -0.299004451343537, 0.107758535600085, -0.00276855249564152, -0.0204847751966064, -0.325405674300828, 0.138534598999159, 0.00855613505400967, 0.052935062955678, -0.272996936236552, -0.0257798275755112, 0.0257798275755134, 0.272996936236547, -0.481585480908131, -0.411635035866138, 0.469894047305338, -0.348460238064719, 5.50503910225613, -0.165471248214067, 0.481585480908144, 0.411635035866138, -0.469894047305338, 0.348460238064718, -5.50503910225613, 0.165471248214065, 0.725911063266481, 0, -0.725911063266472, -0.49918309703106, 0.49918309703106, 0, 0.790006897767768, 0, -0.790006897767759, -0.641750834764522, 0.64175083476452, 0, -2.23090756111511, 2.2309075611151, 0, 0},
    {-0.144387432414532, 0.144387432414537, -0.78238061535344, 1.61328408499108, -1.49032512781454, 0.288623553688342, -0.313660972674283, 0.0808711851769495, 0.046447820681062, 0.0905706902337709, 0.782380615353437, -1.61328408499108, 1.49032512781454, -0.288623553688341, 0.313660972674282, -0.0808711851769469, -0.0464478206810614, -0.0905706902337719, -0.12742640907269, -0.0168156317034907, 0.0168156317034947, 0.127426409072684, 1.88919843488704, -0.606692376057898, -0.664776985404367, -4.85208033124762, 2.9727257637787, 8.55133777337993, -1.88919843488704, 0.606692376057897, 0.66477698540437, 4.85208033124763, -2.9727257637787, -8.55133777337993, 0.500487979907721, 0, -0.500487979907709, -0.667295016722201, 0.6672950167222, 0, 0.200648563511158, 0, -0.200648563511149, -0.0334503633718643, 0.0334503633718616, 0, -0.781420155896762, 0.781420155896759, 0, -1.57629714985092e-14},
    {-0.581370126327103, 0.581370126327111, -3.30747149106531, 7.839041699661, -10.0645802651882, 8.16976222157871, -0.402570486055809, -0.141295916778997, -0.119215185614465, -0.19134689592976, 3.30747149106532, -7.839041699661, 10.0645802651882, -8.16976222157871, 0.402570486055826, 0.141295916778997, 0.119215185614468, 0.19134689592976, -0.0259267621608142, -0.004211713849113, 0.00421171384911126, 0.0259267621608129, 2.49447333148139, 1.02686190320303, 1.31218488814208, -6.93411799042801, -4.32320098473321, 13.4835715113227, -2.49447333148139, -1.02686190320304, -1.31218488814207, 6.93411799042804, 4.32320098473321, -13.4835715113227, 0.126456359955415, 0, -0.126456359955424, -0.22265751838671, 0.222657518386714, 0, 0.0153916967779317, 0, -0.0153916967779425, 0.00401332195866779, -0.0040133219586702, 0, -0.070852186140821, 0.070852186140815, 0, -2.888320379761e-14},
    {-0.234775607728658, 0.23477560772866, -0.0623938398739288, -0.0442565832486351, -0.0570853946158705, -0.153888727424814, -1.5703470236399, 4.51342080072434, -7.49252308868269, 9.65546182492156, 0.0623938398739447, 0.0442565832486266, 0.0570853946158781, 0.153888727424813, 1.57034702363991, -4.51342080072435, 7.49252308868268, -9.65546182492156, -0.097985134452605, -0.0136898800725447, 0.0136898800725492, 0.0979851344526013, 0.465674733519465, -1.65269345913737, 4.94093995929797, 0.40786673452735, -2.60689130666789, 0.947458978837496, -0.465674733519437, 1.65269345913735, -4.94093995929797, -0.407866734527345, 2.60689130666789, -0.947458978837494, 0.0205706117449871, 0, -0.0205706117449966, 0.010109923020387, -0.0101099230203802, 0, 0.51772737490574, -1.652683399223e-14, -0.517727374905739, -1.03104066117047, 1.03104066117047, 0, -0.106378201000259, 0.106378201000228, 2.70429843393178e-14, 0},
    {-0.319307309300148, 0.319307309300151, -0.403549372775823, -0.0432625580147516, -0.032175628393932, -0.0578765020203669, -1.73319922781625, 3.81904507052227, -4.32694704068548, 2.64740738044187, 0.403549372775829, 0.0432625580147501, 0.032175628393929, 0.0578765020203667, 1.73319922781625, -3.81904507052228, 4.32694704068548, -2.64740738044187, -0.0749726874810888, -0.0109550972089597, 0.0109550972089609, 0.0749726874810868, 2.43094957492739, -6.52582104004519, 12.6627476236861, 0.317500476191713, -1.45972009203278, 0.404413103840408, -2.43094957492739, 6.52582104004517, -12.6627476236861, -0.317500476191717, 1.45972009203278, -0.404413103840406, 0.0776918048718339, 0, -0.077691804871838, 0.00595986904733829, -0.00595986904733699, 0, 0.333677575274844, 0, -0.333677575274839, -0.52611333103462, 0.526113331034622, 0, -0.334888684167133, 0.334888684167132, 2.66636250294358e-14, 0},
    {-0.46704693209756, 0.467046932097564, -1.25354229882125, 0.899206741227319, 0.0272753348566985, 0.0204847751966111, -1.76831839423408, 2.33803115856641, -1.05180256724954, -0.187994765484733, 1.25354229882125, -0.899206741227309, -0.0272753348567059, -0.0204847751966089, 1.76831839423408, -2.33803115856641, 1.05180256724954, 0.187994765484732, -0.0435965037573304, -0.00679531167721291, 0.00679531167721643, 0.0435965037573244, 5.20901084739882, -8.20188791354961, 5.8632607767004, -4.4498416924575, 11.1338297871503, -0.214484812936188, -5.2090108473988, 8.2018879135496, -5.86326077670041, 4.44984169245749, -11.1338297871503, 0.214484812936183, 0.0990556500797409, -1.17915929086549e-14, -0.0990556500797345, -0.0522594904402321, 0.0522594904402264, 0, 0.139733560051009, 0, -0.139733560051001, -0.135880116749659, 0.135880116749665, 0, -0.302733776451799, 0.302733776451778, 1.41128769769213e-14, 0},
    {-0.658971363590878, 0.658971363590886, -2.7497189701037, 4.25860765292946, -2.75680360047957, 0.288623553688346, -1.4289094768728, 0.66051826822653, 0.128393202681086, 0.105852187397967, 2.7497189701037, -4.25860765292945, 2.75680360047957, -0.288623553688341, 1.4289094768728, -0.660518268226526, -0.128393202681081, -0.105852187397969, -0.0168084026612667, -0.00279917363082418, 0.00279917363083174, 0.0168084026612563, 6.46410438929988, -3.47238271635904, -0.993408479653116, -11.633939185006, 9.19790865284456, 11.08429471871, -6.46410438929987, 3.47238271635902, 0.993408479653119, 11.6339391850061, -9.19790865284456, -11.08429471871, 0.0604733277504018, -1.8946785313922e-14, -0.0604733277503847, -0.0698591313580596, 0.0698591313580557, -1.05104585969976e-14, 0.0314253609405461, -1.09899149261945e-14, -0.0314253609405367, -0.0108352861369356, 0.0108352861369334, 0, -0.106038582195671, 0.106038582195655, 0, -1.79587091565873e-14},
    {-0.852928776435764, 0.852928776435775, -4.62479994033091, 10.2960803115461, -12.0615371748882, 8.16976222157871, -0.729646958987001, -0.163999371232674, -0.113184183927627, -0.142219700439312, 4.62479994033091, -10.2960803115461, 12.0615371748882, -8.1697622215787, 0.72964695898702, 0.163999371232676, 0.113184183927631, 0.142219700439311, -0.00296275009751288, -0.000520521039656733, 0.000520521039656559, 0.00296275009750895, 4.2468000670121, 1.08748345489141, 1.03954239228303, -10.7714017088684, -3.82040188607883, 17.4774853307226, -4.2468000670121, -1.08748345489142, -1.03954239228302, 10.7714017088685, 3.82040188607883, -17.4774853307227, 0.0139710902106364, 0, -0.0139710902106442, -0.0233100209578517, 0.0233100209578591, -1.29738082029283e-14, 0.0022041955581814, 0, -0.00220419555819058, 0.000371289720441304, -0.00037128972044676, 0, -0.00961462960381431, 0.00961462960381151, 0, -3.65430574118192e-14},
    {0.218256695635769, -0.113928564117328, 0.897392725924522, -1.11679585815058, 0.667429939275518, -0.153888727424811, 0.997420422902056, -1.2123572948061, 0.716898055757191, -0.164167775300466, -0.0660288489812678, -0.0587187272009733, -0.124017235870967, 0.153888727424811, -0.0733887411520768, -0.0637431422621092, -0.13320906067352, 0.164167775300466, -1.33376798878911, 3.57875818583616, -6.2145484466493, 3.86523011808381, 0.518943859261572, -0.205684647193048, 0.0404350712376801, -0.210591458446008, 0.0277492861274017, 0.0418410144593223, 0.0272849533620645, 0.0382189049440547, -0.0404350712376801, 0.039130654826282, -0.0277492861274012, -0.0418410144593225, 0.496253995160498, -2.15318739295372, 0.825569520849967, 0.71270627948597, 0.462808305865586, -0.543412703404551, 0.551568845412555, -2.39319198610029, 0.917591458937758, 0.773690778563426, 0.502409658504786, -0.583688995083671, -0.33117471245718, -0.215054100166457, 0.167465742248993, 0.171460803619726},
    {0.280175037546944, -0.269990545910721, 1.30154270918084, -0.557676967080656, 0.277076277497, -0.0578765020203713, 0.246860738476914, -0.666461484090052, 0.536618750989811, -0.149034415307039, -0.383747306192838, -0.0469015469885917, -0.0451261636041873, 0.0578765020203716, -0.0727845062071855, -0.0560505031716959, -0.0873966756338471, 0.149034415307039, -1.38675356282549, 2.7326630332463, -2.6581508558724, 1.30205689381536, 1.38384756336563, -0.760776739292474, 0.182364335615604, -0.120742031225677, 0.0197614744334072, 0.0178594059513572, 0.116383848266153, 0.123904276157105, -0.182364335615604, 0.0196647100365739, -0.0197614744334052, -0.0178594059513585, 2.21983100881438, -6.07448098846483, 2.93685457666245, 0.37594754280865, 0.228630971260599, -0.231950113892814, 0.421030457367595, -1.15213342758469, 0.55702673794737, 0.449282599265064, 0.273229387996684, -0.449222075355964, -0.932895066103392, -0.567336345528395, 0.63687246313537, 0.101077321189104},
    {0.288734078223699, 0.127458660661966, -0.835345906031967, 2.86220224093332, -0.136739719441231, 0.0204847751966068, -0.0520390799654302, -0.164994643528042, 0.292827817801936, -0.120198635080438, -0.76430248430034, 0.528230785883264, 0.0137224969121024, -0.0204847751966068, -0.0476133273786123, -0.0304504164558691, -0.029386697895716, 0.120198635080438, -1.0238187856576, 1.22959549126017, -0.443553780551473, -0.178415663936758, 0.732213640270659, -0.911627065727229, 0.325606241800383, 0.985169468409691, -0.246844448755228, -0.00947192686946907, 0.135132934040503, 0.0914862166278321, -0.325606241800384, -0.0988665549658296, 0.246844448755231, 0.00947192686946721, 2.97834561505094, -4.29275694872361, 2.91405972400498, -2.34109387257041, -1.04933915424617, 0.123017222529128, 0.18554034263789, -0.267423495480975, 0.181535560187127, 0.134954806283871, 0.0604902537000413, -0.26344111990622, -0.598902775679179, -0.268443798631984, 0.820140849099397, -0.88630291344386},
    {0.0751681159726951, -0.0599574981188604, 0.485316152903595, -1.81264552367904, 5.71927997511735, 0.28862355368834, 0.0111373775675076, 0.017760611483673, 0.09217477236554, -0.0793175468753261, -0.148269706050576, -0.176927006276897, 0.638089254542732, -0.288623553688343, -0.00340259784931679, 0.00173356112842206, 0.0102837650967023, 0.0793175468753263, -0.270916465188292, 0.260237953407899, 0.0391178393220894, -0.0436499453955303, -0.121505350851351, -0.455083346915378, 0.343765567681156, 1.06586968120749, -0.581054568323708, 0.489496797176211, -0.0118597804655818, -0.0507727886816949, -0.343765567681156, 0.118917065308982, 0.581054568323707, -0.489496797176207, 0.795851451112421, -1.26907133398316, 0.136173436017721, 0.131394163470661, 1.85817836648527, -6.35736922966008, 0.0182637607375227, -0.0291235445638939, 0.0031250041081796, -0.00128742253140913, -0.0182067500806864, -0.102458537462243, 0.00880762053239964, 0.124557510784535, 0.505856135597072, -1.18478674651648},
    {-0.424231227319638, -0.226504621301663, 1.17098067011929, -2.26640789781619, 1.30337508285043, 8.1697622215787, 0.00815851923721439, 0.00470697659168284, 0.00236493139971345, -0.0350775308879029, 2.51931486939396, -6.30034913894455, 8.72079246890365, -8.1697622215787, 0.0175527054809658, 0.0130848449412164, 0.0158235923115238, 0.035077530887903, 0.176334246021135, 0.123116291437678, 0.12271782701687, 0.22856748414562, -0.0412828582927222, -0.0153222701367084, 0.201005644744974, 0.0514020887443366, -0.498130062975702, 0.771828366999503, -0.114761522384467, -0.102520248984814, -0.201005644744973, 0.343927818097466, 0.498130062975697, -0.771828366999499, -1.23265959259309, -0.955357742054927, -1.50227820486524, 3.99528893596359, 4.57146810079715, -10.0241675517541, -0.00858825192907831, -0.00665621962501086, -0.0104667531640911, -0.00829759352532621, -0.00949422800757501, -0.0181885237112372, 0.0727746082867639, 0.0832697723904287, 0.117842519121521, -0.39532990684181},
    {0.286289299876281, -0.240503275451298, 0.198934346621585, -0.639724604203333, 0.539525186253462, -0.153888727424811, 1.09978928821842, -0.188861504297645, 0.0910267577698613, -0.0187732230697988, -0.0770893893180525, -0.0575512666200238, -0.0856466499156503, 0.153888727424811, -0.426181230376304, -0.0169904654544722, -0.0144499961342086, 0.0187732230697982, -1.37405067804918, 2.58817254123149, -2.31431049309129, 1.054402605484, 1.47857595357728, -0.0452169713964418, 0.00635131781340957, -0.846741398215315, 0.00754649641305609, 0.208116353436682, 0.133016486099135, 0.00717794501185254, -0.00635131781340871, 0.134415530451186, -0.00754649641305611, -0.208116353436681, 0.429606699103909, -1.10348754796894, 0.552035891561495, 0.435805007162765, 0.261470863660591, -0.453878536337812, 2.37503907115697, -6.10052414552207, 3.05187701652298, 0.128659721218169, 0.0771922485339469, -0.0765767616356522, -1.00726281247522, -0.604329627201199, 0.0380390263845897, 0.712325867764129},
    {0.30194613339729, -0.00303876266691668, -0.112743231543429, -0.297246090911906, 0.222481451419091, -0.057876502020371, -0.106362388371803, -0.384243622260384, 0.30006266875796, -0.0798554220922588, -0.377044237587166, -0.0399716863386961, -0.0287480743053696, 0.0578765020203705, -0.35570495082136, -0.0516705383728235, -0.0387727778774355, 0.0798554220922583, -1.21166390931122, 1.7522973977573, -0.943862170363881, 0.104321311187429, 3.66881404077302, -0.660769301782364, 0.12699644601425, -0.482233019889127, 0.0213755605582893, 0.0888323213280837, 0.493357822210138, 0.085381702003396, -0.12699644601425, 0.0623120291595094, -0.0213755605582877, -0.0888323213280841, 1.69766098981472, -3.06792860426879, 1.86005508358467, 0.219994476016095, 0.117223301234506, -0.193733377113722, 1.60157975827381, -2.89429537575836, 1.75478295667772, 0.284382122847668, 0.151532037785539, -0.261289890880524, -2.71532190725949, -1.44684995572367, 0.575387599778969, 0.419920990729616},
    {0.236643324868562, 0.157996351774294, -0.685081437210633, 1.02836080694758, -0.107784769793441, 0.0204847751966051, -0.212280187910397, -0.132887934812672, 0.384494298337473, -0.166654346797131, -0.569818879903481, 0.332539840484562, 0.00503620216509844, -0.0204847751966059, -0.176564788258322, -0.0429718172322192, -0.0179653491069811, 0.166654346797131, -0.729132917814563, 0.704582974743169, -0.126043410070262, -0.244046323501201, 1.30854003945959, -1.61083268285132, 0.542384887910223, 3.86258153525536, -0.553342302405747, -0.0471131712642592, 0.423141073687127, 0.0752655413239952, -0.542384887910223, -0.180477645663644, 0.553342302405749, 0.0471131712642589, 1.89155751425654, -2.17798675871177, 1.54132956156934, -1.1310281118658, -0.229872535566343, 0.102748567628343, 0.586120368703328, -0.674873691349983, 0.477598298815374, 0.146154918570894, 0.0297048334739978, -0.366528949230492, -1.43917928428619, -0.292501828860533, 1.53556714152733, -3.68210388959172},
    {-0.0291979345553113, -0.188157374542532, 1.09311974803885, -2.729017019739, 4.22292603253327, 0.288623553688339, 0.124775678124372, 0.0915108108550262, 0.197961200646619, -0.207912100848699, 0.305128780364223, -0.899029556149414, 1.08698561075244, -0.288623553688341, 0.0348293501727647, 0.0301467242859985, 0.0509554216513402, 0.207912100848699, -0.0977639238585026, 0.175823134565443, 0.0717532042345301, 0.067542894156374, -0.909898118743003, -1.14996385234334, 0.999903900603927, 3.91453543128952, -1.98855701839865, 2.43474709597, -0.29975089782069, -0.296001907386664, -0.999903900603925, 1.00760554502058, 1.98855701839865, -2.43474709596999, 0.0493324010341879, -0.929742174243794, -0.517838755193467, 1.21170258745119, 2.41634398843722, -5.30991164328572, 0.00563111571589936, -0.106126717114225, -0.0591094268988115, -0.0406314381664814, -0.0810260969745444, -0.24891662229796, 0.404001109858712, 0.805647906704984, 1.44596575973, -4.92214097631011},
    {-0.50453951163875, -0.143182682873862, 0.617043178048858, -0.712046529486228, -1.05604468581899, 8.16976222157871, 0.0213836172859939, 0.00646246759163201, -0.00787298934490139, -0.138407634889365, 2.92484054429373, -7.09932077313887, 9.42860290518039, -8.16976222157871, 0.101360282467525, 0.0644327702181831, 0.0702918079193717, 0.138407634889365, 0.18384202619714, 0.119803876761482, 0.12158288713221, 0.222493404421782, -0.0645125279027523, 0.0542527849523376, 0.825879124087896, -0.207156063819372, -2.17685144999337, 3.83905857194565, -0.643209552328083, -0.484380985658065, -0.825879124087895, 1.84953562229103, 2.17685144999336, -3.83905857194565, -1.21924970614271, -0.90559393374257, -1.41704008245731, 3.70470622890725, 4.10666107371784, -8.3725582193614, -0.0422530708055645, -0.0313833371546013, -0.0491074917933528, -0.0336235666482836, -0.0372716711615341, -0.0624188185744697, 0.33565217168634, 0.372069908544499, 0.430128200705724, -1.64237955847167},
    {0.27076488372056, 0.161958917611738, -0.0765730592183368, -0.151585061594868, 0.345520686816806, -0.153888727424811, -0.936332773411782, 2.49685715770194, 0.355570477099233, -0.0496222433554894, -0.0612235461982256, -0.0345884911148387, -0.0274465741133897, 0.15388872742481, -0.74863944832654, 0.569729765621712, -0.028244883228688, 0.0496222433554888, -0.898070291168986, 0.973990293071299, -0.268866634225738, -0.239777169008873, 0.77492826571866, 1.61566271931326, 0.0387398677950289, -1.1994099228468, -0.421048643677798, 0.460320928675597, 0.176822169357851, -0.128340815064946, -0.0387398677950288, 0.0952756074984327, 0.421048643677797, -0.460320928675596, 0.220886452527465, -0.284167503731906, 0.201077656621004, 0.135895256991292, 0.0502782957184129, -0.318074112703417, 2.70099205667639, -3.4747906064995, 2.45877077156143, -2.2384200761372, -0.828166847186458, -0.327325593870544, -0.694719352366689, -0.257031082709822, -1.48732190424832, 1.10413431534837},
    {0.21585406400914, 0.13864766091785, -0.241970447233904, -0.0410426412418452, 0.139672629582347, -0.0578765020203709, -0.504910546534907, 0.523142764392619, -0.29869869086601, 0.0690671693240333, -0.223449718107215, -0.0169677308765817, -0.00390597156038689, 0.0578765020203706, -0.466264044152152, 0.216276179301877, 0.00835316550663101, -0.0690671693240332, -0.647164702748529, 0.597737904987656, -0.0797575058760418, -0.225317421290076, 1.1204677527659, 4.09036218176068, -0.201370300695995, -0.669620834773747, -0.210771515542721, 0.196483245909813, 0.463220560606473, -0.114387753716803, 0.201370300695995, 0.0187260735671017, 0.210771515542721, -0.196483245909812, 0.720440411760073, -0.803571415413608, 0.548551168994654, 0.0542410793686968, 0.0037692927497284, -0.135766658021959, 1.50331565778353, -1.67678196727929, 1.14464090018281, -0.691374320609004, -0.0480446230854911, 0.290345525359379, -1.4807862863825, -0.102902026989873, -3.97597442804388, 0.650894761206647},
    {0.0617978275970905, -0.0784651408728727, 0.358197104159231, -0.535979548866735, -0.0638662258776882, 0.0204847751966059, 0.245495675775414, -0.130028469360585, -0.203425857830673, 0.103341901603271, -0.0545443252607913, -0.0738260863498106, -0.00813907259628168, -0.0204847751966062, -0.0373827589171674, -0.017910185243531, -0.0259244663684316, -0.103341901603271, -0.245041653542339, 0.244997596742813, 0.0443340954746576, -0.0276227253993491, -1.50849623800913, 1.7919029414595, -0.48429499238549, 5.06227842005483, 1.03882900843693, -0.104206989941385, -0.207781012841061, 0.228359010190469, 0.484294992385491, 0.645133652367756, -1.03882900843693, 0.104206989941385, 0.418094153916278, -0.740360722520863, 0.0186137897061453, 0.0836202835993748, 0.526185351617172, 0.0720052984739695, 0.286547003483867, -0.507417156036069, 0.0127572356939543, 0.0202862544045087, 0.127652400199608, 0.229350324199104, 0.235346448381517, 1.48093080246867, -2.02026195164998, -5.70741207242259},
    {-0.236409154506207, -0.30179860767733, 1.4000385651718, -2.49182453126872, 1.95327310133187, 0.288623553688341, 0.353473378128936, 0.0577177593874777, 0.0463079366625627, -0.0876613998747689, 1.15104668812143, -2.14074232727352, 1.76786658528815, -0.288623553688342, 0.290609395595098, 0.0495856947412162, 0.0419123438517433, 0.0876613998747687, 0.103305012625973, 0.128667221027397, 0.109334068422315, 0.196901460107853, -1.83763178006512, -0.367417240409295, 0.505689713046096, 4.00483138931968, -1.37361142730362, 5.38528100170711, -1.5787211676279, -0.332541651106272, -0.505689713046093, 3.62468903506824, 1.37361142730362, -5.38528100170711, -0.715500476622894, -0.761862180902006, -1.07372259576833, 2.02047867724721, 2.61208818129503, -3.72113968662003, -0.180645288505837, -0.192350414803799, -0.271087070414398, -0.0468000457807149, -0.06050340834798, -0.088220280514306, 1.49003101208053, 1.92632193561249, 0.699958891515562, -7.62952042438793},
    {-0.636880676372843, 0.0586054310955159, -0.575471048921201, 2.18852029690416, -4.63478621313925, 8.16976222157871, -0.0441106655645795, -0.0347242019943348, -0.054578720323004, -0.20492687831082, 3.58097023983997, -8.36005347555909, 10.5022018617589, -8.16976222157871, 0.274486407165848, 0.132644959235411, 0.123672746018741, 0.20492687831082, 0.170484250415705, 0.107111056838614, 0.109362603663138, 0.191317334359874, 0.438571875105301, 0.416256605830054, 1.30452607023257, -2.01094213702256, -3.80557674439067, 8.49139905584444, -1.67532571388218, -0.94321737825249, -1.30452607023257, 4.5566978246929, 3.80557674439066, -8.49139905584444, -1.0647661673164, -0.771605708869932, -1.16912731473244, 2.98706489013573, 3.1844682885192, -5.86741564861968, -0.0816158248082648, -0.0591446632032976, -0.0896152535897047, -0.0473943260942064, -0.0505264311468732, -0.0690940256957357, 0.598597441285363, 0.638156397491516, 0.52696077242243, -2.54575568767035},
    {-0.0276979469831494, -0.186613680044607, 0.0592422377411566, 0.0565262386342767, 0.137345055287174, -0.15388872742481, 1.15030067029803, -3.12783181000749, 5.64479241115492, 0.798848493973309, 0.0162868154822932, 0.0184619773736181, 0.0350047482548514, 0.15388872742481, 0.316239485215845, -1.02157796980729, 1.43867237804988, -0.798848493973309, -0.0998357862280643, 0.176592144722129, 0.0713805344628649, 0.0661747340708267, -0.458860714373722, 2.15747459073826, 1.54718213082688, -0.757063491467867, -1.41445222820341, 0.730947882573466, -0.149868031751074, 0.549869485706125, -1.54718213082688, -0.192950644465244, 1.41445222820341, -0.730947882573465, 0.00315442827218581, -0.0508382642087878, -0.0278452172868482, -0.0249252809394622, -0.0500629350684332, -0.172349803542025, 0.0612492217421621, -0.987121547495591, -0.540667829760449, 1.37921942940999, 2.77019035040479, -7.0834647892048, 0.202334924349945, 0.406393821774853, -2.70734407644439, 0.950014135933111},
    {-0.119570063807635, -0.262628331893209, 0.371819690231102, 0.047777058586084, 0.050815006011003, -0.0578765020203701, 1.23199853521869, -2.23741118713505, 1.83649988776653, -0.123511007815445, 0.186296385708589, 0.0244646644642494, 0.0227507319824573, 0.0578765020203706, 0.617280042826308, -1.14568614271631, 0.822231856537402, 0.123511007815447, 0.00904912827074745, 0.14399747275426, 0.0911691460845524, 0.137982648591284, -2.07113859148238, 5.46743855613523, 3.40308137253589, -0.386843515466681, -0.774378690190786, 0.311997573024, -1.06054479281689, 2.447864105226, -3.40308137253589, -0.173196341600908, 0.774378690190786, -0.311997573023999, -0.102574006235407, -0.223219781902339, -0.232322287801946, -0.0287114516580399, -0.0435302713922939, -0.0735657379934613, -0.339871794726609, -0.739623133364955, -0.769783649953437, 1.34456421219057, 2.03853311766079, -2.65873174430393, 1.24464329337685, 1.88704009092242, -7.91530266136123, 0.560039857067589},
    {-0.291832089112704, -0.297257923557779, 0.807857834631564, -0.582773602692337, -0.0167396352982316, 0.0204847751966087, 0.879189330581097, -0.749214963869796, 0.0517333807439303, -0.0529350629556789, 0.84128092362299, -0.656732008696605, -0.0222767402895107, -0.020484775196607, 0.915563581070018, -0.844296045487709, 0.0688456508519471, 0.0529350629556792, 0.133867773164477, 0.126150246023438, 0.115422748860114, 0.213649244622456, -2.60448329359947, 2.4888891892871, 0.469894047305336, 2.10691229814977, 5.50503910225613, -0.165471248214066, -2.93501204776655, 3.31215926101937, -0.469894047305337, 2.8038327742792, -5.50503910225613, 0.165471248214064, -0.500068566126376, -0.46004348282584, -0.68902670930234, 0.554782924470059, 0.684722686918886, 0.0390163755877379, -0.544223165326869, -0.500663983642999, -0.749865762681248, 0.713230089338577, 0.88028092001893, -0.120579031595879, 2.47938968354294, 3.06010565782308, -5.80104845030647, -4.91074507242898},
    {-0.53338096528945, -0.105970427076989, 0.28741354553369, -0.0559394161257791, -0.482167487303574, 0.288623553688344, 0.115225774364483, -0.00280414771476711, 0.015027344416689, 0.0905706902337699, 2.28752304127763, -3.66947089586476, 2.49848276832552, -0.288623553688342, 0.917081389878046, -0.183944330128652, -0.0778682969454374, -0.0905706902337709, 0.183537139047253, 0.117927627713664, 0.120054740517504, 0.217831885088022, -0.0655065393482075, -0.196284242324386, -0.664776985404367, -1.56980201021201, 2.9727257637787, 8.55133777337993, -4.29704770401275, 1.01710050979141, 0.664776985404372, 8.13435865228323, -2.9727257637787, -8.55133777337993, -0.893506861854441, -0.657643433361132, -1.02378629159575, 1.77585510390829, 1.94955520808225, -2.01631528102195, -0.358212135986781, -0.263653105576657, -0.41044192267909, 0.0890205936398308, 0.0977278842035882, 0.0628409525287484, 2.0795734081194, 2.28298083524155, -0.820816267467032, -6.56455664207124},
    {-0.793676417832493, 0.397585858525556, -2.38339251504384, 6.02882067961082, -8.47493826989332, 8.16976222157871, -0.290095768273402, -0.10866733175544, -0.100385839478181, -0.19134689592976, 4.34154822751178, -9.77838145744785, 11.6542222604831, -8.16976222157871, 0.528433634244654, 0.17625182076842, 0.138044531750752, 0.191346895929759, 0.118675589765866, 0.0754625796527799, 0.076496969285291, 0.125455420603006, 1.91844015911065, 0.864675029862073, 1.31218488814208, -5.83891432892608, -4.32320098473321, 13.4835715113227, -3.1115935729377, -1.18904877654399, -1.31218488814207, 8.02932165192996, 4.32320098473321, -13.4835715113227, -0.705558214342668, -0.514122084721766, -0.738475413403514, 1.84580097713681, 1.90375980070021, -3.17928399058975, -0.0858773579926133, -0.0625766172429876, -0.089883890735648, -0.033269900996623, -0.0343145880163601, -0.0376586922725683, 0.587355124401063, 0.605798289425981, 0.324373746681913, -2.19040732300389},
    {-0.593196374839002, -0.0167231769272513, -0.00592046743457692, -0.0122940972627709, -0.0292027831626255, -0.153888727424813, -0.149008114153978, 1.25378938541601, -3.83289856489746, 9.65546182492156, 0.136760509442208, 0.0820817973761803, 0.0849680060691222, 0.153888727424813, 3.44202984442011, -8.37095104150298, 11.1521476124679, -9.65546182492156, 0.178196159374032, 0.112528398046353, 0.114893726140305, 0.204301268205567, 0.129360426098424, -0.845457039339852, 4.94093995929797, 0.208649583449497, -2.6068913066679, 0.947458978837496, -0.863677589054078, 2.45992987893487, -4.94093995929797, -0.607083885605204, 2.6068913066679, -0.947458978837494, -0.0460077227427312, -0.0334699672900063, -0.051362351974891, -0.0335780192488557, -0.0362096808645552, -0.0557652229064964, -1.15793627414932, -0.84238225474459, -1.29270320137223, 3.42438840507847, 3.6927732510085, -7.31924904757045, 0.353313202647993, 0.381003960307659, -1.61447283959501, 0.398434302155705},
    {-0.645727750172865, 0.0748919790983828, -0.13588649724901, -0.0198848675421217, -0.0202742229580824, -0.0578765020203659, -0.583617242377614, 1.75535633697016, -2.72645767649417, 2.64740738044187, 0.738792277826607, 0.0700963669874164, 0.0440770338297807, 0.0578765020203666, 3.17302984920508, -6.18782608077739, 5.92743640487679, -2.64740738044187, 0.168546980959296, 0.105848120321834, 0.10805609011532, 0.188384579678035, 1.11734285990506, -4.11199275210905, 12.6627476236861, 0.200060597567732, -1.45972009203278, 0.404413103840408, -3.93875770068702, 8.93964932798131, -12.6627476236861, -0.434940354815704, 1.45972009203278, -0.404413103840406, -0.213877370020066, -0.154927489841722, -0.234100920715809, -0.0243300584253674, -0.0258814410199271, -0.0238028108717017, -0.918579280687083, -0.665396166803975, -1.0054371593364, 2.14775995592349, 2.28470978788374, -3.20097872838261, 1.36712085232981, 1.45429398845215, -4.82765657587225, 0.234879757247963},
    {-0.731477026246279, 0.250468856650961, -0.741597708025424, 0.596171784672717, 0.0209632972536974, 0.0204847751966129, -1.0461401018987, 1.55010871751303, -0.808395203406331, -0.187994765484734, 1.85165020848896, -1.23254689245621, -0.0335873724597043, -0.0204847751966096, 2.61204358754973, -3.20475026135102, 1.29520993109275, 0.187994765484733, 0.143532247785432, 0.0904610014067898, 0.0920387320291981, 0.154976188373901, 3.4535609564433, -6.30381314387572, 5.8632607767004, -3.4200626544456, 11.1338297871503, -0.214484812936187, -7.14001556968875, 10.0999626832235, -5.86326077670041, 5.47962073046939, -11.1338297871503, 0.214484812936181, -0.39787958595639, -0.28850866613505, -0.423664248372102, 0.311385855462966, 0.324989252320533, 0.0126240752059977, -0.561271678824498, -0.406986809860563, -0.597644996965971, 0.809635647766173, 0.845005896071818, -0.486814727686419, 1.80382577717258, 1.88262883607286, -3.79614953934777, -2.0595580760238},
    {-0.834219465627167, 0.502239635580983, -2.17143575456293, 3.51888276364891, -2.43060574940824, 0.288623553688347, -1.12840081544712, 0.545785509857595, 0.113201120517725, 0.105852187397966, 3.38060476427582, -5.0388437404201, 3.08300145155091, -0.288623553688342, 1.75675341289619, -0.781534391644857, -0.143585284844444, -0.105852187397968, 0.0996153533514733, 0.0638287536487696, 0.0645327311686786, 0.104002991877268, 5.34128226212329, -3.06151420908615, -0.993408479653117, -10.2573572765294, 9.19790865284456, 11.08429471871, -7.64841812019007, 3.88325122363191, 0.99340847965312, 13.0105210934827, -9.19790865284456, -11.08429471871, -0.436843424807217, -0.319740661860376, -0.452584923045293, 0.750888154342683, 0.769072822428515, -0.652395702142679, -0.227008547565525, -0.166155329632339, -0.235188720251206, 0.116464202330794, 0.11928467945647, 0.0303841643267188, 1.13976675240814, 1.16736910565864, -0.821737014545765, -2.75316381695339},
    {-0.930688141770982, 0.778443022056056, -4.26837451395491, 9.64375602134091, -11.5471951890703, 8.16976222157871, -0.673414315020506, -0.153608934270612, -0.108357653355245, -0.142219700439312, 4.99337808590904, -10.961922045512, 12.5758791607061, -8.1697622215787, 0.787796917156003, 0.174605118508017, 0.118010714500013, 0.142219700439311, 0.045722815794223, 0.0299465576581428, 0.0300813729300032, 0.046494373332564, 3.97773739893536, 1.04110973057893, 1.03954239228303, -10.3120751682583, -3.82040188607883, 17.4774853307226, -4.52143824337274, -1.1338571792039, -1.03954239228302, 11.2307282494786, 3.82040188607883, -17.4774853307227, -0.263105125640322, -0.195156578656476, -0.26674186765734, 0.656049156768701, 0.662116867402348, -1.02868397163588, -0.0415096560487307, -0.0307895273266344, -0.0420834187601281, -0.0104497678681785, -0.01054641636923, -0.00965306114476577, 0.270599055040724, 0.273101789396652, 0.0927474486249634, -0.918653081220339},
    {-0.284218581943474, 3.62990990645796, 3.05254952705567, -2.02813935973005, 0.852973082215366, -0.153888727424802, 3.39280133686021, -2.20168218722082, 0.916193158666494, -0.164167775300464, 0.0729924116469215, 0.0498880353538249, 0.0615259070689035, 0.153888727424801, 0.0811284959085262, 0.0541568301345113, 0.0660860422357802, 0.164167775300464, 1.68915042532676, -4.27656497941375, 6.18108222239517, -6.93935899282266, 0.94241974374932, -0.262864245603166, 0.0404350712376781, -0.269135132885898, 0.0277492861274057, 0.0418410144593229, -0.0231815773747179, -0.0189606934660814, -0.0404350712376774, -0.0194130196135651, -0.0277492861274062, -0.0418410144593209, -0.489196991213422, 1.55580759904072, -4.1921525465299, -0.415850747203113, 2.39410207157934, -0.914498989284269, -0.543725233961309, 1.72922537542378, -4.65942997423121, -0.451434058644537, 2.59895941573085, -0.982279200902275, 0.193234233504183, -1.11247239987878, 0.281824939069245, 0.288548152499459},
    {-0.365495227282886, 0.282631633534524, 6.52731890993826, -1.0647384417033, 0.35627345648693, -0.057876502020376, 1.23802219859217, -1.27243405037863, 0.690001392244447, -0.149034415307039, 0.452267144066574, 0.0473046632961914, 0.0340710153857401, 0.0578765020203728, 0.0857805129140862, 0.0565322542722092, 0.0659859656207882, 0.149034415307039, 1.81083303074512, -3.57567070399205, 3.50106007665704, -1.65335880966175, 2.64209530812437, -0.978230835822891, 0.18236433561561, -0.155253929338965, 0.019761474433403, 0.0178594059513579, -0.117384161266223, -0.0935498203733095, -0.182364335615608, -0.0148471880767361, -0.0197614744334042, -0.0178594059513541, -2.49979653910288, 6.08250695734888, -10.5622964722508, -0.319526352383568, 1.33696013079067, -0.390344471872667, -0.474130902760283, 1.1536556954225, -2.00332750416848, -0.381855481911323, 1.59775727801774, -0.755987357865235, 0.792888697720108, -3.31759984457825, 1.0717806561962, 0.170101117415693},
    {-0.505828786742262, -0.14324111556502, 0.878278855981276, 6.65596057481905, -0.178742789963479, 0.0204847751966033, 0.0547136501038985, -0.383689812925603, 0.382777303820129, -0.120198635080436, 1.34289336556039, -0.950264780748592, -0.028280573610149, -0.0204847751966036, 0.0836574821649667, 0.054779007756535, 0.0605627881224823, 0.120198635080436, 1.79145702692407, -2.14650769602211, 0.770376839904921, 0.233743731500401, 1.70273960808482, -1.19165642433791, 0.32560624180039, 1.28778923995139, -0.246844448755237, -0.00947192686947259, -0.243098417149591, -0.18854314198284, -0.325606241800389, 0.203753216575841, 0.246844448755237, 0.00947192686947121, -5.22969989144648, 7.51537127670229, -4.50684360679747, 4.40965559457903, -10.1153513886495, 0.207023363573631, -0.325791709615184, 0.468180910463772, -0.280760333117453, -0.254199211538504, 0.583110016707572, -0.443340091942611, 1.12808589451516, -2.58772708545038, 1.38019956632075, -1.49154245652723},
    {-0.685613082674017, 0.102291761943673, -0.558471148525231, 1.03193983204807, 7.88994374560003, 0.28862355368834, -0.0128161900329733, -0.0101111233234024, 0.127158273749779, -0.0793175468753251, 2.84662379487985, -4.38015391749968, 2.8087530250254, -0.28862355368834, 0.0653263317252941, 0.0429174987338469, 0.0452672664809428, 0.0793175468753251, 1.41363178800633, -0.574619210989799, -0.139438536816994, -0.116252719469191, 0.0691730455362102, -0.6278031539535, 0.343765567681163, 1.47040394270876, -0.581054568323726, 0.489496797176213, -0.293610709637516, -0.223492595719799, -0.343765567681161, 0.523451326810234, 0.581054568323725, -0.489496797176211, -6.36648531888773, 3.02713440179705, 1.05119827073607, 11.3824333416433, -8.03421925619172, -10.6986967706254, -0.146102597966737, 0.0694688165203167, 0.0241236397540997, -0.111527032549339, 0.0787206571388934, -0.17242554023072, 0.762987875263824, -0.538550211162517, 0.851295749673297, -1.993855269519},
    {-0.865091413021981, -0.290248257600283, 1.683687613827, -4.01561825483132, 4.72603256077766, 8.1697622215787, 0.0117306785136405, 0.00833981435771211, 0.00857523129457171, -0.0350775308879018, 4.68268090500076, -10.4012155852295, 12.1434499468309, -8.1697622215787, 0.0326254251841919, 0.0216017065295013, 0.0220338922063833, 0.0350775308879018, 0.710593182365696, 0.172618275021657, 0.120634157325983, 0.151494055908931, -0.0731449089687665, -0.0555584869803205, 0.201005644744978, 0.186383757288342, -0.498130062975718, 0.771828366999505, -0.189459236128947, -0.142756465828413, -0.201005644744977, 0.478909486641455, 0.498130062975712, -0.7718283669995, -4.12921691934218, -1.1396342516694, -1.09751734781617, 10.4478114715183, 3.96902236854248, -16.8694825076085, -0.0287693012623093, -0.00794012079179784, -0.00764668164372487, -0.0216984789358703, -0.00824304195134603, -0.0306091235009541, 0.190307985099684, 0.0722961599980332, 0.198314952808732, -0.665293243929808},
    {-0.377854821367117, 0.0804169334283815, 1.11829004720866, -1.23357237757902, 0.694497732197732, -0.153888727424811, 6.18235833041366, -0.364179106695016, 0.11717317087544, -0.0187732230697973, 0.092730298376723, 0.0601399658498409, 0.0693258960286183, 0.15388872742481, 0.512650482834983, 0.0177547093611451, 0.0116964169713749, 0.0187732230697978, 1.82023306649531, -3.45521657617557, 3.16711320194261, -1.23469180432362, 2.85111818820362, -0.0582050382295413, 0.00635131781340625, -1.08995834819509, 0.00754649641305548, 0.208116353436676, -0.138999667623016, -0.00581012182124337, -0.00635131781340645, -0.108801419528598, -0.00754649641305565, -0.208116353436675, -0.49762421287264, 1.16087091348691, -1.87426704619965, -0.393425231152646, 1.56685764288182, -0.76382362822635, -2.75106731527106, 6.41776252989539, -10.361704027873, -0.116148230810443, 0.462572628144317, -0.128869587846818, 0.909311729595415, -3.62143025017602, 0.0640151600507863, 1.19875976772368},
    {-0.451804425814345, -0.296938442417926, 1.80057222446277, -0.622114485944265, 0.288629886037618, -0.0578765020203712, 1.69866660382197, -0.804194002372015, 0.389277637912434, -0.079855422092259, 0.542062083177417, 0.0546170488540189, 0.0374003603131588, 0.0578765020203692, 0.511383406553645, 0.0706022831938982, 0.0504421912770383, 0.0798554220922586, 1.83050294886805, -2.70162889910245, 1.55859240591333, 0.061276412553339, 7.67856140344348, -0.857229971550946, 0.126996446014249, -0.625611082121124, 0.0213755605582896, 0.0888323213280851, -0.674120877709398, -0.111078967765185, -0.126996446014249, -0.081066033072484, -0.0213755605582891, -0.0888323213280844, -2.42715807579339, 4.33770602065989, -4.25318225250668, -0.294051389401697, 0.861548826491939, -0.326030246350775, -2.28979005092516, 4.09220816270834, -4.01246812215879, -0.380113900397407, 1.11370561957552, -0.439719829189473, 3.62938285525005, -10.6338233809841, 0.968308939316133, 0.706677115193598},
    {-0.576948661244747, 0.100404462764307, -0.754231010240758, 3.33204574872114, -0.142867299242777, 0.0204847751966061, -0.233706960786518, -0.430577162468102, 0.509642151511678, -0.166654346797131, 1.50519714998454, -1.04181171702516, -0.0300463272842345, -0.020484775196606, 0.466402264732032, 0.13462610263226, 0.107182504067226, 0.16665434679713, 1.68526479642688, -1.45555613539847, 0.14781772293194, 0.0990178145200919, 4.23986916465108, -2.13513760220477, 0.542384887910222, 5.11980118438332, -0.553342302405748, -0.0471131712642592, -1.32565568047273, -0.449039378029453, -0.542384887910221, 1.07674200346431, 0.553342302405749, 0.047113171264257, -4.80610959998928, 4.92314980708569, -0.868006346840189, 3.92135994492722, -6.21159397662319, 0.172913626527013, -1.48922711022166, 1.52549333465282, -0.268961528376667, -0.506730148813495, 0.802681208649337, -0.616824655578904, 4.98974334922501, -7.90395683340336, 2.58417698023422, -6.19654318784764},
    {-0.73356085670795, -0.0327513821297313, 0.335749943545735, -1.50942741166772, 6.03594528816658, 0.28862355368834, 0.0383246455489426, 0.0506149010319216, 0.282951433929324, -0.207912100848699, 3.02009427869259, -4.59614374252044, 2.90000486638575, -0.28862355368834, 0.34473287331921, 0.154120270281249, 0.135945654934046, 0.207912100848699, 1.25518741491938, -0.278180235623072, -0.106236390698721, -0.104458549759902, -0.503267349496753, -1.64367522486531, 0.999903900603929, 5.59515404954396, -1.98855701839866, 2.43474709597, -1.53242816535887, -0.789713279908622, -0.999903900603926, 2.68822416327501, 1.98855701839866, -2.43474709597, -5.58848627032463, 1.44362886899564, 0.789013179090673, 9.82552056826454, -3.71994941407638, -8.93595015455233, -0.637905559129755, 0.164785030562322, 0.0900630096992815, -0.329474439980088, 0.124739268666916, -0.418897088863369, 3.27598641418132, -1.2402908993257, 2.43338850477392, -8.28337821281898},
    {-0.886657647844938, -0.239734464658443, 1.26639041080202, -2.55888156794632, 1.80268636101633, 8.1697622215787, 0.0438867308522263, 0.0232241693750251, 0.013439327618505, -0.138407634889365, 4.78510003641369, -10.5867211358993, 12.2873339520157, -8.1697622215787, 0.165827532811155, 0.0960840891841791, 0.0916041248827788, 0.138407634889365, 0.606871885294578, 0.190501890245107, 0.14301804591282, 0.186000291050878, -0.231838667440831, -0.0926104328672063, 0.825879124087899, 0.353618948008345, -2.17685144999338, 3.83905857194565, -0.959173473074861, -0.631244203477599, -0.825879124087896, 2.41031063411873, 2.17685144999337, -3.83905857194565, -3.51214052066771, -1.2512435482993, -1.28810637824871, 8.83267191596794, 4.31293078787765, -14.090020313032, -0.121713149776667, -0.0433618166770526, -0.0446392972096614, -0.0801645027968846, -0.0391437557623229, -0.105043452501282, 0.80025387364182, 0.390758266873876, 0.723854636344801, -2.76392958212709},
    {-0.53720785237928, -0.0232138437439102, -0.0111495902450428, -0.389873654755798, 0.454124093010768, -0.153888727424812, -0.136336811707862, 6.42186515765066, 0.467332714291884, -0.0496222433554905, 0.125473334825664, 0.0765656943091255, 0.0811568320805634, 0.153888727424812, 1.53428368653199, -1.26116386310603, 0.0835173539639612, 0.0496222433554908, 1.75200335936094, -1.83373928319032, 0.44308974975143, 0.19906787020114, 1.9930995307227, 2.12349475737309, 0.0387398677950238, -1.5764061723161, -0.421048643677801, 0.460320928675598, -0.391416674441762, 0.379491222994889, -0.038739867795028, -0.281720641970876, 0.4210486436778, -0.460320928675597, -0.448749399499447, 0.560437026223538, -0.226011371304714, -0.324701707017559, 0.63800966746423, -0.535280925091331, -5.48729245101887, 6.85300496601937, -2.76365938982462, 5.34837518126701, -10.5090764758116, -0.550850068255849, 1.65992960023658, -3.26161245651752, -2.50298598036797, 1.85812681428697},
    {-0.595832618747913, 0.138566640473886, -0.382088705155295, -0.163849194570803, 0.186028874620441, -0.0578765020203689, -0.79728999615513, 2.08847476667467, -0.397834432404976, 0.0690671693240335, 0.688772361232909, 0.0662246334629416, 0.042450273477712, 0.0578765020203691, 1.43723513893443, -0.844120572468692, -0.0907825760323359, -0.069067169324033, 1.64721956367446, -1.28476773881766, 0.0487666930498762, 0.0460474603673518, 4.47309757068156, 5.44792115490559, -0.201370300695997, -0.891862712743733, -0.21077151554272, 0.196483245909811, -1.80793837795991, 1.24317121942811, 0.201370300695994, -0.20351580440288, 0.21077151554272, -0.196483245909811, -2.07847566557605, 1.91747624331687, -0.145684233818439, -0.234950202639313, 0.332574763747172, -0.228479148098153, -4.33707626804132, 4.00112488549044, -0.303993760228428, 2.99475118521419, -4.23910537942017, 0.48861700843731, 6.41416140866592, -9.07932060138757, -6.6910923743337, 1.09537851714661},
    {-0.69232834135712, 0.0867112697486259, -0.268333407534357, 0.158965367263474, -0.0884517559977655, 0.0204847751966089, -0.183906264039707, 0.0385649479169776, -0.281735363146926, 0.103341901603271, 1.76462388414566, -1.18519576926095, -0.0327246027163539, -0.0204847751966072, 1.20941104184694, -0.287528119487926, -0.104233971684685, -0.103341901603271, 1.39280580424551, -0.529306916813747, -0.138918164337415, -0.118963651485849, 0.447402627577318, 2.48170233282908, -0.484294992385491, 7.01102044860074, 1.03882900843693, -0.104206989941387, -3.33569324242816, 0.918158401560046, 0.484294992385491, 2.59387568091367, -1.03882900843693, 0.104206989941384, -3.84905264255625, 1.70989773051126, 0.64286443543369, 3.00130456555185, -1.97507416355438, 0.121176358714117, -2.63800507767208, 1.17190366416838, 0.440596635696462, 0.728115540170864, -0.479152368599915, 0.385969334831611, 8.44706977314216, -5.55877915829132, -3.39986073438913, -9.60489612951442},
    {-0.809132783013122, -0.258324173993585, 1.34708568607265, -2.86625354516242, 3.22382115522919, 0.288623553688343, 0.340104151364434, 0.0663906027038585, 0.0764299194853955, -0.0876613998747695, 3.29120129853803, -4.92980584650551, 3.03841463918548, -0.288623553688341, 0.830942854030468, 0.114188356405143, 0.0720343266745749, 0.087661399874769, 0.961207805314041, 0.0502357293041726, 0.0268576215159697, 0.0291558008725267, -2.11375983269295, -0.606411602975414, 0.505689713046096, 6.6098591882575, -1.37361142730363, 5.38528100170711, -3.63555610734632, -0.571536013672387, -0.505689713046091, 6.22971683400606, 1.37361142730362, -5.38528100170711, -4.2097487664175, -0.24678231166175, -0.181755906531433, 7.2241767018175, 0.571882689850429, -6.26223579441467, -1.06285223461478, -0.0623061246565316, -0.0458886461235933, -0.167332525792186, -0.0132464333168163, -0.14846424615997, 5.32757283888954, 0.421743101149734, 1.17794761664779, -12.8395760222636},
    {-0.919863564854666, -0.0664733009545219, 0.14691430563134, 0.484156194529876, -2.63141247240989, 8.16976222157871, 0.0112611882292159, -0.00768187415005943, -0.0309872168383865, -0.20492687831082, 4.94227542033296, -10.8701129799616, 12.5055756024883, -8.1697622215787, 0.378832364552659, 0.172470869633389, 0.147264249503359, 0.20492687831082, 0.439657887279571, 0.184953912959844, 0.153008802706335, 0.208716262863442, 0.0970232217536009, 0.23633081957458, 1.30452607023257, -1.14171786514215, -3.80557674439067, 8.49139905584445, -2.17833293068933, -1.12314316450796, -1.30452607023257, 5.42592209657329, 3.80557674439066, -8.49139905584444, -2.52901150425865, -1.20464522191188, -1.35553299979378, 6.3028197965665, 4.08313698886524, -9.87416313007839, -0.1938522900196, -0.0923377511472629, -0.10390351161501, -0.100003819045888, -0.0647851764374451, -0.116277032664971, 1.26306322154798, 0.81824648738776, 0.88681234493337, -4.28420423143115},
    {-0.732933512062509, -0.0307253509165775, 0.0176781856910605, 0.0308310083721223, 0.196192270366814, -0.153888727424809, 0.343255582932779, -1.70600788325706, 8.06337466302119, 0.798848493973308, 0.164508796215637, 0.0953652459991999, 0.0938519633344883, 0.15388872742481, 3.19425102379766, -5.27695557341787, 3.85725462991614, -0.798848493973308, 1.25740478795151, -0.281639118042049, -0.10704807310203, -0.105058733828342, -0.250275604184952, 3.08187169411099, 1.54718213082688, -1.08143685910168, -1.41445222820341, 0.730947882573471, -0.774142521471156, 1.47426658907886, -1.54718213082689, -0.517324012099056, 1.41445222820341, -0.730947882573469, -0.305223167146568, 0.0796869323785905, 0.0433492528612787, -0.204427048452776, 0.0782307940814541, -0.290044233701303, -5.92648804545817, 1.54727328379438, 0.841708154933352, 11.3117985633816, -4.32883510670664, -11.9206292929373, 1.6594690139789, -0.635050888322795, -4.55613828318985, 1.59876087120073},
    {-0.768918916307803, -0.148294415168217, 0.251910113159569, 0.0422020538189104, 0.075933333489325, -0.0578765020203683, 0.834686539129944, -1.97633236806258, 2.74429876876708, -0.123511007815445, 0.860731749519541, 0.0793721793555802, 0.0478690594607831, 0.0578765020203701, 2.85197444483158, -3.71701831994325, 1.73003073753795, 0.123511007815447, 1.12419892211281, -0.102275710642097, -0.0500045419232705, -0.0547053380714261, -1.8294617728856, 8.17004400482655, 3.40308137253589, -0.578063843222897, -0.774378690190784, 0.311997573023997, -3.44078912805434, 5.15046955391733, -3.40308137253589, -0.364416669357131, 0.774378690190784, -0.311997573023997, -1.35806381863702, 0.1445441743965, 0.100877781561408, -0.144101486207882, 0.0225272530333914, -0.123802392950111, -4.49984946804294, 0.478937011163143, 0.334251472918275, 6.74830738571693, -1.05495669771111, -4.47432950630503, 6.24680878244855, -0.976557881508611, -13.3205135587439, 0.942480512580027},
    {-0.826589347339829, -0.288245120659522, 0.870895760782952, -0.740818696194012, -0.0300614087998787, 0.0204847751966113, 0.947793322172683, -0.952398067000447, 0.0929039539653095, -0.0529350629556791, 2.06115841063896, -1.34512191896954, -0.0355985137911537, -0.0204847751966078, 2.24315270037299, -1.72929155552928, 0.110016224073325, 0.0529350629556798, 0.885947950004173, 0.099917902336259, 0.0596887415221381, 0.0692798741367818, -3.31080527482653, 4.46960247602633, 0.469894047305335, 3.78363989249273, 5.50503910225613, -0.165471248214068, -6.01150695506044, 5.29287254775861, -0.469894047305337, 4.48056036862216, -5.50503910225613, 0.165471248214064, -2.37641281398797, -0.30394952199916, -0.251691835434779, 1.77351765151424, 0.312422963649311, 0.0656599225910258, -2.58624315015438, -0.330787380305294, -0.273915492085994, 2.28003800629106, 0.401651616238661, -0.202920178038636, 7.92605751690364, 1.39625471298332, -9.76247502378494, -8.26420026111489},
    {-0.894125141570331, -0.211629929169826, 0.795255349482024, -0.973470037069579, 0.206284350599025, 0.288623553688346, 0.31882252901968, -0.0487983959951481, -0.0064291062044848, 0.0905706902337692, 3.59296158151085, -5.29595271223312, 3.18693460622812, -0.288623553688342, 1.44043934924041, -0.265477095115417, -0.0993247475666133, -0.0905706902337702, 0.570055294969537, 0.192782034875825, 0.148108661457022, 0.194809079437778, -1.1399592220309, 0.0839757315184023, -0.664776985404368, 0.671603948363619, 2.9727257637787, 8.55133777337993, -6.20170103224063, 1.2973604836342, 0.664776985404372, 10.3757646108589, -2.9727257637787, -8.55133777337993, -2.45555469396101, -0.942021585899321, -0.990640651132545, 4.1112881157012, 2.1581346336015, -3.39321895682715, -0.98444626393864, -0.377661973104833, -0.397153641216615, 0.206091875332981, 0.108183615777584, 0.105753853771098, 4.81442738189246, 2.52723287237906, -1.38133621515261, -11.0473685592225},
    {-0.956163846795188, 0.287383368069139, -1.81307241877914, 4.86684701705691, -7.38940173345124, 8.16976222157871, -0.220678982979591, -0.0877231729903833, -0.0875276341409106, -0.19134689592976, 5.11339400277777, -11.1769121298321, 12.7397587969252, -8.1697622215787, 0.622379214652023, 0.20145983484323, 0.150902737088022, 0.191346895929759, 0.246707185714527, 0.13175900155011, 0.119556563039015, 0.170757728422404, 1.54868676013972, 0.753920673054673, 1.31218488814208, -5.09102040505867, -4.32320098473321, 13.4835715113227, -3.55662213627244, -1.29980313335139, -1.31218488814207, 8.77721557579737, 4.32320098473321, -13.4835715113227, -1.41009209391451, -0.850271555111317, -1.03995793497279, 3.48088865935141, 2.82917645342379, -5.35035706347392, -0.171630038585086, -0.10349121198634, -0.126578981101003, -0.0627417703811851, -0.0509948914716648, -0.0633751029471096, 1.10765885209962, 0.900276524033101, 0.54588246029671, -3.68619517073871},
    {-0.9091917729059, -0.136246592488554, 0.0232954564072138, 0.00616373515137534, -0.0101622736935097, -0.153888727424813, 0.586307089086458, -0.628596434706286, -1.3338100015688, 9.65546182492156, 0.198758544842849, 0.111280669107753, 0.104008515538237, 0.153888727424813, 5.00241514142447, -11.3487406799524, 13.6512361757966, -9.65546182492156, 0.494378227169635, 0.191170602922261, 0.153521289707972, 0.20636824559459, -0.06485579123845, -0.294210513499068, 4.94093995929798, 0.0726079484014747, -2.60689130666791, 0.947458978837497, -1.17091271238654, 3.01117640477566, -4.94093995929798, -0.743125520653228, 2.60689130666791, -0.947458978837495, -0.115767452711899, -0.0507286897118034, -0.055557858826358, -0.073517930297854, -0.0439264739612756, -0.0938462418447273, -2.91367024641904, -1.27675499797777, -1.39829698611412, 7.49758186185501, 4.47975525280367, -12.3174261742278, 0.77356723197606, 0.462201271648931, -2.71696589127658, 0.670517572251751},
    {-0.921992874650234, -0.0508201537761838, 0.0110004824460726, -0.00590658279383472, -0.0121469776576534, -0.0578765020203651, 0.0472458364883371, 0.521409434336825, -1.6335136764243, 2.64740738044187, 1.00949188137988, 0.0904065681741656, 0.0522042791302113, 0.0578765020203665, 4.33565424042011, -7.98072916563719, 7.02038040494666, -2.64740738044187, 0.428629658865404, 0.183205852336283, 0.152440957403008, 0.208536559821726, 0.33189449701647, -2.46363494135175, 12.6627476236861, 0.119863119482104, -1.45972009203277, 0.404413103840407, -5.08000031802799, 10.5880071387386, -12.6627476236861, -0.515137832901338, 1.45972009203278, -0.404413103840405, -0.502395150729072, -0.24310375938845, -0.274993453708433, -0.0509721760505815, -0.0335278093297489, -0.0400573014725619, -2.1577307413781, -1.04410334020108, -1.18106599532926, 4.49961922300977, 2.95970050829059, -5.38686672852236, 2.86415772412315, 1.88394809688836, -8.12437219738686, 0.395274713419225},
    {-0.942112680825334, 0.127595092614206, -0.43885536450529, 0.406648411251741, 0.01665292582558, 0.0204847751966143, -0.619074453405155, 1.05732821218667, -0.642176905529868, -0.187994765484734, 2.31225141453112, -1.47759207750687, -0.0378977438878197, -0.0204847751966101, 3.26179396758608, -3.84189325821416, 1.46142822896921, 0.187994765484734, 0.322633511670083, 0.158276461917956, 0.138772873632381, 0.194834740990712, 2.35567182514294, -5.00765368314272, 5.8632607767004, -2.71684597198952, 11.1338297871503, -0.214484812936186, -8.55953676376871, 11.3961221439565, -5.86326077670041, 6.18283741292546, -11.1338297871503, 0.214484812936181, -0.846866110426917, -0.469596891800337, -0.556933047798582, 0.611952852143312, 0.458990814111828, 0.0212448180622294, -1.19463772537198, -0.662440208381103, -0.785641580427842, 1.59114113616611, 1.19342390986138, -0.819251323439343, 3.54497903403213, 2.65888590459363, -6.38846846081377, -3.46599144093595},
    {-0.965098624043567, 0.405296087049495, -1.80583279730039, 3.03701648093235, -2.20785138931023, 0.288623553688348, -0.938412843554314, 0.47104711916369, 0.10282673414534, 0.105852187397966, 3.84258032344356, -5.59493014084544, 3.30575581164891, -0.288623553688342, 1.99682203872871, -0.867784465877594, -0.15395967121683, -0.105852187397968, 0.197623962341592, 0.110960259772195, 0.102816977085583, 0.148401337794706, 4.60986152393412, -2.7809398548364, -0.993408479653117, -9.31731545486156, 9.19790865284456, 11.08429471871, -8.49249694472012, 4.16382557788166, 0.99340847965312, 13.9505629151505, -9.19790865284456, -11.08429471871, -0.840622559885403, -0.532506111944705, -0.663618854313068, 1.38119467247679, 1.1767189874363, -1.09790442233869, -0.436835020361384, -0.276720289645376, -0.344853885167632, 0.214225960102362, 0.182511386611544, 0.0511329370714908, 2.09650366327906, 1.78613175750694, -1.38288572304526, -4.63324746028898},
    {-0.985708641666331, 0.729420397946709, -4.03187699731422, 9.20606324283964, -11.1959607479293, 8.16976222157871, -0.636102496984868, -0.146637218987195, -0.105061706660276, -0.142219700439312, 5.25214046484746, -11.4243799830647, 12.9271136018471, -8.1697622215787, 0.828621425313896, 0.181971301432519, 0.121306661194982, 0.142219700439311, 0.0820482743635104, 0.05119322228232, 0.0496710434458357, 0.0733757036279623, 3.79720328645515, 1.00944198889804, 1.03954239228303, -9.99840973700664, -3.82040188607883, 17.4774853307226, -4.71218718284896, -1.16552492088479, -1.03954239228302, 11.5443936807302, 3.82040188607883, -17.4774853307227, -0.466618508176217, -0.327919433759251, -0.425725525597772, 1.14327225337298, 1.07504448685211, -1.73115285391773, -0.073617622359994, -0.0517353011421485, -0.0671660048268817, -0.0182104184337659, -0.017123664011561, -0.0162449545347028, 0.471562821512956, 0.443421074880847, 0.15608293198674, -1.5459839437236}};
    // Array of non-zero columns
    static const unsigned int nzc1[50] = {0, 1, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55};
    
    const static double FE0_D001[125][50] = \
    {{-3.62990990645796, 0.401957822762741, -0.164167775300458, -0.0765004719955939, -0.0680662120055019, -0.108642456439209, -0.175828494830761, -0.0826780082397543, -0.0746050465367258, -0.1229227727065, 7.72557159650524, -7.92049346364188, 5.76645406988604, -2.34358011905419, -3.39280133686021, 2.20168218722083, -0.91619315866648, 0.164167775300462, -3.83876213073826, 2.41318852918333, -0.990177230877914, 0.175828494830753, 0.0485713098083451, 0.0330175826697734, 0.050849500997477, 0.0267387390754311, 0.0276017787947505, 0.0366395230945368, 4.90215896975702, -2.66666255408092, 0.992693630662066, -2.10329332423926, 0.53304657886559, 0.702578147781675, 5.54651461832333, -2.92283760302113, 1.07285523911769, -2.37975700940866, 0.584254120374492, 0.794927294530099, -1.18514873927513, 0.320231355091316, -0.0485713098083388, 0.330567383953291, -0.0330175826697824, -0.0508495009974795, 1.43544412648885, -0.346970094166738, -0.358169162748024, -0.286934910308267},
    {-0.282631633534523, -0.292253144230846, -0.14903441530704, 0.0772432851100529, 0.05425072991727, 0.0737033512859865, -0.161086287535333, 0.0841312964337312, 0.0597928794101206, 0.0833911584363395, -3.47320825508685, 6.80476470939691, -4.50883814356457, 1.75216646701988, -1.23802219859217, 1.27243405037863, -0.690001392244446, 0.149034415307042, -1.40075184518968, 1.40242344845198, -0.751530849418162, 0.161086287535333, 0.03767301290722, 0.0260288856266568, 0.0391350848847673, -0.0228923090116703, -0.0235005750094204, -0.0241738128012897, -0.0717785195213326, -0.829453162063555, 0.612758107134391, 1.7451053455173, -0.497231618232346, -0.509007978689778, -0.0812133205517719, -0.914188490573989, 0.667399552984434, 1.97448764292228, -0.548027837288121, -0.575913635617162, -0.566989284434582, 0.204493181086755, -0.0376730129072147, 0.209926719868722, -0.0260288856266574, -0.0391350848847674, 0.369599551890693, -0.181600872075084, -0.186426144859296, 0.221563545345168},
    {0.143241115565025, 0.165069823211548, -0.120198635080439, 0.242093133212239, -0.0757646835227003, -0.0476672211627494, -0.131658137530838, 0.266652519476156, -0.0841658993570021, -0.053932755062646, -1.05011719804097, -1.8726333714976, 3.7306967564191, -1.1162571256571, -0.0547136501039032, 0.383689812925604, -0.382777303820131, 0.12019863508044, -0.0619053894407258, 0.426235505482277, -0.421608540100333, 0.13165813753084, 0.0223418536780578, 0.0158074656855151, 0.0229503204656662, -0.0521578843465088, -0.0531230966917488, 0.0236990433705475, -1.30196185927214, 0.524552634438823, 0.140684170607889, 0.913368302496411, -0.832477763841724, 0.49097442804238, -1.47309594191112, 0.582717991878085, 0.154956020624176, 1.03342438973589, -0.924787598003361, 0.555509696678612, -0.120017415695208, 0.0824676605991121, -0.0223418536780551, 0.0839937731914839, -0.0158074656855161, -0.0229503204656639, -0.164079028060327, -0.030309776252605, -0.0308706764997387, 0.260397400384987},
    {-0.102291761943669, -0.298712767052989, -0.0793175468753281, 0.289572373956804, -0.369732996138584, 0.156600961026918, -0.0880875552963131, 0.322644424074261, -0.414015466198867, 0.177185098430691, 0.66022307644366, -1.85149395530342, -1.71903824819844, 3.31131365605486, 0.0128161900329635, 0.0101111233234137, -0.127158273749782, 0.0793175468753278, 0.0145007915507424, 0.0113221202333971, -0.141681015490769, 0.0880875552963119, 0.00878997436986548, 0.00637514851195158, 0.00892592724340214, -0.0367385953748234, -0.0371216237110968, 0.0656775082562624, -0.0915005962409434, 0.532781488795746, -0.162414100207027, -0.922814737293697, -0.173159615980573, 0.844898182474759, -0.103527730897077, 0.596592077984862, -0.180963408583488, -1.04411249451125, -0.193898732019399, 0.955954335426893, -0.00179608904935126, 0.0161328109585156, -0.00878997436986211, 0.016301008018802, -0.00637514851195256, -0.008925927243397, -0.0946406217314053, 0.0206057844163049, 0.0208206156922917, 0.0307592025244975},
    {0.290248257600285, 2.37732743172645, -0.0350775308879026, 0.177387214604188, -0.369081269115153, 0.431683257087081, -0.0393989079388218, 0.199502173687807, -0.415917431700295, 0.488425102223412, -1.8219090728536, 4.91114087352826, -7.51056431849917, 1.75375682849778, -0.0117306785136408, -0.00833981435769746, -0.0085752312945715, 0.0350775308879084, -0.0132725968823335, -0.00939813114014996, -0.0096443099744116, 0.0393989079388198, 0.00157505305409682, 0.00116582089219569, 0.00158453793438681, -0.00902347074885904, -0.00905985545377396, 0.0255178519105298, 0.0802149854971419, 0.0633635584939867, -0.168811983309643, -0.246795124906015, 0.314057524978897, -0.25337243916457, 0.0907587029333757, 0.0714043510671624, -0.18985786371339, -0.279234675265909, 0.35391121177328, -0.286676533008556, 0.000576605115335879, 0.000436211532642038, -0.00157505305409257, 0.000437970437622818, -0.00116582089220821, -0.00158453793438487, -0.00438088312113532, 0.0085872592162265, 0.00862188501617185, -0.0217135739047448},
    {-0.0804169334283813, 0.401957822762746, -0.0187732230697996, -0.0120162719057353, -0.0185107978054486, -0.540385364807991, -0.158684622935269, -0.0736681995781856, -0.065165386944685, -0.10266967961748, 1.29100934347991, -3.33726521147607, 3.65680528243622, -1.93209030377443, -6.18235833041366, 0.364179106695016, -0.117173170875441, 0.0187732230698009, -1.17460758636495, 1.28205562258155, -0.718353962441773, 0.158684622935263, 0.215265220041952, 0.00784309727827001, 0.00667117274778164, 0.116169922080394, 0.00626960940032307, 0.152217180438963, 10.505287493186, -0.465503857415089, 0.129189442781173, -6.66708194356735, 0.119835548525522, 2.88453814560296, 1.99593581073057, -1.63875913461505, 0.792022162019964, -1.26670189777028, 0.42186889897818, 0.548043353022137, -2.99470165351671, 1.13279711355543, -0.215265220041951, 0.0611362675002861, -0.00784309727827049, -0.00667117274777355, 3.82791089848768, -1.24896703563581, -0.0674058769006151, -0.985426425409928},
    {0.296938442417928, -0.292253144230848, -0.0798554220922586, 0.0537913438739449, 0.058681844140006, 0.366598967637807, -0.143523611516616, 0.0741505562562734, 0.0518232284292385, 0.0696514025113317, -1.53911310909654, 3.04154683397432, -2.98012962965793, 1.47301060659307, -1.69866660382198, 0.804194002372015, -0.389277637912433, 0.0798554220922587, -0.322735527919583, 0.7102014276667, -0.536613352828259, 0.143523611516616, 0.165154795443356, 0.0244021863638676, 0.0227629108632673, -0.0986889659037718, -0.0212317853742951, -0.100428971621053, -2.28978383113605, -0.410126006315281, 0.335486294038489, 5.75113750104839, -0.452749840196742, -2.12928603372817, -0.435043929103376, -0.362191305019976, 0.462462796571988, 1.09267845341914, -0.399833351075966, -0.40455039890751, -1.37630945014862, 0.714193116741431, -0.165154795443353, 0.153650358290698, -0.0244021863638689, -0.0227629108632673, 0.701895682607076, -0.615504150837662, -0.1324185729164, 0.774842739162597},
    {-0.100404462764304, 0.165069823211546, -0.166654346797131, 0.403271313827146, -0.169838959850658, -0.237095786874347, -0.115126938239244, 0.231341613116332, -0.0721435208691214, -0.0450466464533041, 0.610810404026152, -2.08773341497667, 2.34797231905812, -0.935714668554841, 0.233706960786517, 0.430577162468101, -0.509642151511677, 0.166654346797131, 0.044402791694501, 0.182898862155065, -0.2923625693181, 0.115126938239244, 0.0964120402117748, 0.0303734357582343, 0.0319310700158517, -0.222374576611212, -0.0994635029161292, 0.0984565642859314, -3.72129972467467, 1.20675741154256, 0.106370837684533, 1.67719581905213, -1.46749561416, 2.04749273171038, -0.707022571991248, 0.512601634984925, 0.0610209562017693, 0.318656219453766, -0.62335697627087, 0.389010207296285, -0.249607911599725, 0.281030298411491, -0.0964120402117702, 0.125698982012867, -0.0303734357582349, -0.0319310700158533, -0.699563803096414, -0.0586557218002875, -0.0262354790967368, 0.850715150410208},
    {0.0327513821297323, -0.29871276705299, -0.2079121008487, 0.842273262501719, -1.26534612149435, 0.778929989503397, -0.0755398622052382, 0.275404331483146, -0.350914290152962, 0.14799159576644, -0.224009962170158, 0.764255032997449, -2.99246181614667, 2.71817813024264, -0.0383246455489454, -0.0506149010319168, -0.282951433929326, 0.2079121008487, -0.00728143161568441, -0.0140368645108733, -0.0925187275588517, 0.075539862205236, 0.0373197059437268, 0.018492512606863, 0.0216849831681601, -0.154885598732143, -0.106110399883783, 0.272854128019672, 0.402289946927986, 1.48328946100658, -0.559321828572397, -4.25182955970992, -0.167328438480316, 3.10893426882748, 0.0764324547892105, 0.411355801751517, -0.182885603924288, -0.807819765508789, -0.0464046470876882, 0.590677146568824, 0.0109143928694911, 0.052031928600095, -0.037319705943721, 0.0356464951917747, -0.0184925126068622, -0.0216849831681587, -0.319850549670757, 0.10285367013204, 0.0704639046920058, 0.0360820287816012},
    {0.239734464658443, 2.37732743172645, -0.138407634889363, 0.728837230454806, -1.61290224291862, 2.14718372548066, -0.0332504769431215, 0.168055578568907, -0.349376359563627, 0.407950843104922, -1.44405251046301, 3.65676158658083, -4.94850159172541, 0.118730619222699, -0.0438867308522205, -0.023224169375015, -0.0134393276185045, 0.138407634889371, -0.00833819138987429, -0.00503066803072708, -0.0030988455091575, 0.0332504769431217, 0.00659940057927389, 0.00427961072299674, 0.00543776875029719, -0.0377019670391676, -0.0330687035042788, 0.106012719069892, 0.274951488167215, 0.131144421288119, -0.715397902836328, -0.693090749385035, 1.50498199100555, -1.68515773341063, 0.0522389817320626, 0.0284076488131163, -0.164956733059746, -0.131682702418263, 0.325999378781236, -0.320168931028857, 0.00152647648325601, 0.000695201981644499, -0.00659940057927318, 0.000609767341366122, -0.00427961072300577, -0.00543776875029792, -0.00861985080170279, 0.0370067650575321, 0.0324589361629307, -0.0989193447514591},
    {0.0232138437439104, 0.401957822762746, -0.0496222433554882, -0.0732932595554707, 1.03279003696237, -1.19524818143038, -0.124486375182813, -0.056698793281691, -0.0486993761139167, -0.071950014445202, -0.19612530819023, -0.264715365073916, 1.3436161590818, -1.30794715232431, 0.136336811707852, -6.42186515765066, -0.467332714291881, 0.0496222433554881, 0.00820702823413441, 0.302811622374952, -0.361523025747754, 0.124486375182812, 0.366456256144687, -0.327024976772811, 0.0285157733865363, 0.192023610061725, -0.245141063756188, 0.235942873780198, 2.23764732712355, 9.9486509475111, 0.540625973847353, -5.51215636599334, -4.55957582682282, 4.33342040859232, 0.134699019008029, -0.469110929597911, 0.418221819029449, -0.331813707244309, 0.214998683336873, 0.260857674447347, -1.4670874680216, 1.22438155217215, -0.366456256144685, -1.56306922907257, 0.327024976772811, -0.0285157733865344, 2.2727884766354, -1.41640516223388, 1.80821029282876, -1.041643882394},
    {-0.138566640473883, -0.292253144230849, 0.0690671693240335, -0.0852935608097439, -0.578626286337774, 0.810859764011252, -0.110575952246123, 0.0562091216546043, 0.038317729044601, 0.0488110943317464, 0.288047005907997, 0.339607805362624, -1.2464251449651, 1.04959011839921, 0.797289996155129, -2.08847476667468, 0.397834432404979, -0.069067169324034, 0.0479942388799365, 0.138302756227033, -0.262175993089586, 0.110575952246123, 0.276909647639241, -0.177909214690157, -0.025294163853915, -0.161398096603596, 0.146713338525789, -0.155669025708707, -3.60723712754945, -0.524501306672906, -0.312540871595234, 5.3583575689491, 3.19160235968536, -3.35927020156603, -0.217143826250265, 0.0347334703368379, 0.205966871434983, 0.322555524850988, -0.211353955608474, -0.202217031812404, -0.561866682903671, 0.752808530256606, -0.276909647639238, -0.684314468812517, 0.177909214690158, 0.0252941638539145, -0.141107670564856, -0.591410433653017, 0.537601130286725, 0.858643379177234},
    {-0.0867112697486246, 0.165069823211547, 0.103341901603272, -0.360080603668168, 0.318850804445174, -0.524418917575723, -0.0863518149033908, 0.171478616035411, -0.052518723698788, -0.0315682962594106, 0.376226506008869, -0.616920262429722, 0.824205091005289, -0.66186988804736, 0.183906264039707, -0.0385649479169827, 0.281735363146929, -0.103341901603272, 0.0110705530113283, 0.006352130262412, -0.134168821282001, 0.0863518149033906, 0.158067285969267, -0.0415107849939682, -0.0199804170326389, -0.358060552096524, 0.130858706913602, 0.152611713429167, -0.86954090375934, -1.9001630960178, 0.0783452405212382, -1.99482380889213, 1.61987723948961, 3.20487736618749, -0.0523435061924123, 0.312980676953425, -0.0373097947534092, -0.120081840822121, -0.26681408351705, 0.192923090262615, -0.0184583595144346, 0.280154828240814, -0.158067285969263, -0.102386868211362, 0.0415107849939715, 0.0199804170326381, -0.909475973826484, 0.0779057238557033, -0.0284718387022425, 0.775322619911756},
    {0.258324173993585, -0.29871276705299, -0.0876613998747672, 0.425969859867174, -0.874047802450552, 1.72287170239396, -0.0550682258188478, 0.19936872170246, -0.25135270064944, 0.103711217302285, -1.35576833418601, 2.91217407039357, -3.3345339389644, 1.81851679581624, -0.340104151364433, -0.0663906027038586, -0.0764299194853948, 0.0876613998747685, -0.0204731527591738, -0.0190921563335232, -0.0357718627143634, 0.0550682258188467, 0.059755651258404, 0.0091496455908021, 0.00768552650434477, -0.245385023813036, -0.0513656131766267, 0.422935091177579, 2.1275233301357, 0.610441727700265, -0.349539940381784, -6.71794340220495, 0.329996677454154, 3.20765252103972, 0.128069916117842, 0.175546665086716, -0.16359685898809, -0.404398126130011, 0.0948981918962411, 0.193090145469057, 0.0321251486808513, 0.0440283676849776, -0.059755651258399, 0.0092163085919534, -0.00914964559079963, -0.00768552650434442, -0.295381130230707, 0.201356656128051, 0.0421493045846689, -0.159679109627713},
    {0.0664733009545237, 2.37732743172645, -0.204926878310817, 1.15124252490879, -2.81967943501396, 4.74923565701962, -0.0236691033128943, 0.119292615909628, -0.246951587308051, 0.285888386558625, -0.35495268195342, 0.717254093179465, -0.444843288137044, -2.36125885576996, -0.0112611882292031, 0.00768187415006521, 0.0309872168383871, 0.204926878310825, -0.000677886541347938, 0.000672789605545484, 0.00321091870429992, 0.0236691033128985, 0.0103614284495418, 0.00528827784435492, 0.00601929582040999, -0.0589436233665733, -0.0405132923464584, 0.164324063305257, 0.00732797081348698, -0.170455174232805, -1.1822297417472, 0.407461961361492, 2.98245273509674, -5.15276440096542, 0.000441119772515904, -0.0149287097387633, -0.12250353461393, 0.0245278716682604, 0.261207507441269, -0.31017949145806, -0.00044768095210656, -0.00158654566607545, -0.0103614284495474, -0.00109046890435892, -0.00528827784435909, -0.00601929582041316, 0.00993371320631218, 0.0605301690326579, 0.0416037612508319, -0.173810095559476},
    {0.0307253509165747, 0.401957822762745, 0.798848493973309, -2.9271659390857, 3.46950926213077, -1.89794570036165, -0.0757063131817325, -0.0337954148060455, -0.0281508959837137, -0.0389864197028798, 0.0944314907533047, 0.0609093436761832, 0.0501892200265536, -0.638213228135363, -0.343255582932783, 1.70600788325706, -8.06337466302119, -0.798848493973307, -0.00705094261601494, -0.0138422026979853, -0.0930951975884613, 0.0757063131817312, 0.346842092340428, -0.635046840281547, 0.617093439996431, 0.176258125225858, -0.446225665713588, 0.203008875141374, -0.691254950746732, 2.47616763325851, 10.9905406021069, -0.461204611784964, -7.65168477864635, 3.39366084582613, -0.0141993291095899, -0.0200911230423593, 0.126890612394508, -0.00947377818050856, 0.0620842217240609, 0.0697104696089949, 0.099822399998301, 0.485532877422691, -0.34684209234042, -1.22920422066289, 0.635046840281543, -0.617093439996434, 0.1448861979924, -0.661791002648563, 1.67542988637648, -0.447717473132076},
    {0.148294415168219, -0.29225314423085, -0.123511007815443, 1.44142868628427, -2.12588434718252, 1.28757175841063, -0.0660640735715589, 0.033012384460215, 0.0219257613406904, 0.0264484979530291, -0.180059163531051, -0.100847885093374, -0.170374942691501, 0.595240720378557, -0.834686539129948, 1.97633236806258, -2.74429876876708, 0.123511007815444, -0.0171456115571043, -0.0203833251274631, -0.0628514243474522, 0.0660640735715595, 0.258246160894032, -0.374020010534921, 0.231621948713673, -0.146648971282788, 0.292074433552562, -0.133940022417969, 1.37069270707265, -6.55901435254365, 1.3028700824828, 1.20973015667891, 6.70856633166359, -3.03330808303223, 0.0281559167638188, 0.0676477925596476, 0.0298390398872364, 0.024849524202151, -0.0691902287728742, -0.0623083273618961, 0.124517592894681, 0.279201180857404, -0.258246160894026, -0.556072954571815, 0.374020010534924, -0.231621948713673, -0.41324662396795, -0.132552209574625, 0.263998521019251, 0.422669053491244},
    {0.288245120659524, 0.165069823211546, -0.0529350629556755, 0.349373284618034, 1.68967763895773, -0.832729675112351, -0.0502251134543585, 0.0984946363236171, -0.029597786548658, -0.0171054148739813, -0.920706654198761, 0.877390014541971, -0.041976292318127, -0.368022011896154, -0.947793322172687, 0.952398067000445, -0.0929039539653044, 0.0529350629556756, -0.0194689807209893, -0.0166829897292228, -0.0261913018588235, 0.0502251134543606, 0.144168473266942, -0.123971642824031, 0.0105045386139803, -0.320425624243827, 0.375752113893093, 0.131309463940475, 3.51070731206626, -4.77133558495939, -0.25646933065273, -4.56352001332119, 2.12925987900122, 2.83333569853996, 0.0721147652939444, 0.0835786477488943, -0.0723033344647955, -0.093740988758521, -0.0372978714710145, 0.0582006190595458, 0.0740134548462916, 0.0852063072784682, -0.144168473266941, -0.0999185073056075, 0.123971642824037, -0.0105045386139815, -0.370793519128068, 0.235219316965359, -0.275833606587491, 0.165470600341307},
    {0.211629929169828, -0.298712767052992, 0.090570690233772, -0.559977693850787, 1.89158620077828, 2.73576399498904, -0.0311077547329526, 0.111786017271075, -0.139356637565188, 0.056196361832883, -0.98351537489538, 1.78821551556098, -1.570756661473, 0.853139358690571, -0.318822529019678, 0.0487983959951486, 0.00642910620448957, -0.090570690233773, -0.00654905402443054, -0.00359506766419647, -0.00128341572370377, 0.0311077547329548, 0.0532028790608616, -0.0109784069985832, -0.00547454398696541, -0.21603188166748, 0.0602345814802053, 0.363899853138873, 1.52772511812189, -0.191467793818474, 0.553548587646299, -2.78682089067384, -1.74891680295495, -1.15784569341742, 0.0313815788483419, 0.0141057848368581, -0.11050260154737, -0.0572451408172001, 0.128845920392521, -0.0237837458395938, 0.00938774512563162, 0.00248026292126031, -0.0532028790608607, -0.000691553477522353, 0.0109784069985864, 0.00547454398696689, -0.0368342198852618, 0.213551618746216, -0.0595430280026884, -0.336453378379234},
    {-0.287383368069135, 2.37732743172645, -0.191346895929757, 1.15800142154502, -3.20320459390345, 7.5413554567869, -0.0130409161051867, 0.0655286205121274, -0.135039569302968, 0.154909831672689, 1.63778163999162, -3.92101133140204, 5.21568572840441, -5.02240010065129, 0.22067898297961, 0.0877231729903877, 0.0875276341409117, 0.191346895929764, 0.00453305036514177, 0.00369820258157798, 0.00495298625307394, 0.0130409161051959, 0.00903780126550157, 0.003285098748001, 0.00328072950902848, -0.0511813507042582, -0.0249381910695813, 0.141386949797586, -1.41823574667491, -0.701040826328685, -1.24552905568595, 4.26716024495865, 3.81652224724178, -10.6109589380503, -0.0291325163027229, -0.0295542318562664, -0.0704816067652104, 0.0876533507875001, 0.16089559857766, -0.21796371652261, -0.00387203236385003, -0.00386854666664111, -0.00903780126551499, -0.00188495525434559, -0.00328509874800034, -0.00328072950903248, 0.0309433947199594, 0.055049897370909, 0.0268231463239384, -0.168458312153712},
    {0.136246592488553, 0.401957822762748, 9.65546182492155, -9.34793058151144, 6.39444256476643, -2.46012846883513, -0.0267632969820077, -0.0117600193200734, -0.00956480773991207, -0.012614382728486, -0.226657394765486, -0.110646355323276, -0.0984981685262203, -0.102402496636316, -0.586307089086441, 0.62859643470626, 1.33381000156881, -9.65546182492156, -0.00300630723630432, -0.000940254601246542, 0.00167797901910664, 0.0267632969820057, 0.156442970923061, -0.397671458273193, 0.637634365012838, 0.0776259936883407, -0.266098137984381, 0.0851415746765813, 1.45478305790557, -4.22351296711152, 8.01412057994264, 0.809257639625007, -2.79952603236115, 0.782394860390986, 0.00745944389152426, 0.00631753106048553, 0.0100820403009724, 0.00414949289094024, 0.00418753128067978, 0.00401175318231894, 0.00836971944697734, -0.0110760692818977, -0.156442970923049, 0.0379682278069438, 0.39767145827319, -0.637634365012842, -0.0562357924157444, -0.0665499244064633, 0.228129910177438, -0.0372755017078106},
    {0.0508201537761871, -0.292253144230848, 2.64740738044187, 5.36350609164481, -4.00733663545901, 1.6689581466585, -0.0230500588646273, 0.0113638625296745, 0.00739535140953914, 0.00855763310187159, -0.219294787819981, 0.123105212793225, 0.105877368499588, 0.23174519698183, -0.0472458364883382, -0.521409434336836, 1.6335136764243, -2.64740738044188, -0.000242254447824311, 0.000962236603997911, 0.00346098700029738, 0.0230500588646294, 0.115227716275823, -0.23780181420748, 0.278861127094668, -0.0641146324922278, 0.178140384532275, -0.0561742160924731, 0.856480533939577, -0.550320143979465, -6.99701976806911, -0.932466771342675, 5.07906621377532, -1.54572607276707, 0.00439162970205596, 0.00101558995978512, -0.0148248495299731, -0.00478125142013211, -0.00937317797332251, -0.00792575693597817, -0.0073090356267814, -0.019526803409087, -0.115227716275814, 0.0542545770406088, 0.237801814207477, -0.278861127094666, -0.0077143014176528, 0.0836414359013039, -0.232394961572887, 0.0711975531369153},
    {-0.127595092614201, 0.165069823211545, -0.187994765484734, 4.35942248656922, 3.41733871056418, -1.07938914174274, -0.0171736078270662, 0.0333460339298098, -0.00987178613476264, -0.00553460029400182, 0.240846300632004, 0.0164204310898583, -0.161808102473479, -0.132933359845727, 0.619074453405153, -1.05732821218667, 0.642176905529878, 0.187994765484728, 0.00317432288256043, 0.00305434107327239, 0.00491213066563273, 0.0171736078270706, 0.0632668059638165, -0.083626328496019, 0.0424100611619912, -0.138528058270702, 0.245888519339779, 0.0550709643706238, -1.55299123008027, 3.77800847815761, -5.00159939209908, 0.679923322484418, -6.13801897653512, 1.33338259593344, -0.00796300924863291, -0.0109136655364116, -0.0382581645954466, 0.00348632728918146, 0.0177311105978974, 0.0068369593708909, -0.017039014634789, -0.0204062625413031, -0.063266805963817, 0.0362212951237127, 0.083626328496023, -0.0424100611619944, 0.0608832158338023, 0.158934320812011, -0.282109814463499, -0.0989151655696409},
    {-0.405296087049487, -0.298712767052994, 0.105852187397963, -0.836801817303566, 5.85275550665803, 3.54611350936128, -0.0104009318950417, 0.0371551073259643, -0.0459080285849659, 0.0181828036919214, 1.65261971942142, -2.45810344563656, 1.42868917785832, 0.0808034024593068, 0.93841284355432, -0.471047119163688, -0.10282673414533, -0.105852187397971, 0.00481174008425034, 0.00369481427796235, 0.00456564298039154, 0.0104009318950469, 0.022921349063647, -0.011190115177605, -0.00264699113269952, -0.0922471242722783, 0.0603021493600473, 0.152618975398245, -4.25272441104422, 2.59101850214635, 0.939628551448917, 7.75167485639766, -7.97272688964071, -7.98347679826905, -0.0218059723462323, -0.0203235128010156, -0.0417207503063598, 0.0397469460087128, 0.0625367271080141, -0.0409355174386496, -0.0122832277222497, -0.011335384707685, -0.0229213490636498, 0.0074099660784931, 0.0111901151776082, 0.00264699113270199, 0.0675645153099873, 0.103582508979962, -0.0677121154385464, -0.207900262985986},
    {-0.729420397946702, 2.37732743172644, -0.142219700439311, 0.917394780947759, -2.83066387967162, 9.77514965223254, -0.00427583515644463, 0.0214338209728062, -0.0440110118211848, 0.0501223738936737, 3.95523965899803, -8.81317854073087, 10.361438686271, -7.15140683831791, 0.63610249698489, 0.1466372189872, 0.105061706660278, 0.142219700439315, 0.00326163468824707, 0.00227990770101789, 0.00245463987634396, 0.00427583515645834, 0.00383182233277898, 0.000946133374428588, 0.000840950140280304, -0.0216215117239299, -0.00713052032935899, 0.0592974446861051, -3.72696548902015, -0.991501724824304, -1.02245648760805, 9.5884298752997, 3.67552838550875, -16.272716535497, -0.0191101276578984, -0.0154158162137965, -0.0238884608491666, 0.0491649626206262, 0.0571469203339701, -0.0834388435446465, -0.00307179260816012, -0.00247613456003402, -0.0038318223327991, -0.000816600062195864, -0.000946133374424163, -0.000840950140283872, 0.0207702225283237, 0.0240976462839738, 0.00794712039156438, -0.0769958746062914},
    {0.113928564117325, 0.401957822762744, -0.164167775300459, -0.0765004719955909, -0.0680662120055077, -0.108642456439205, 0.027848823003661, 0.0188757122195086, 0.0326326069046862, -0.604695575897982, 0.78894269314123, -2.78594575938159, 3.342923995223, -1.86180731586271, -0.997420422902051, 1.2123572948061, -0.716898055757182, 0.164167775300463, -5.55156553714956, -0.581233740849926, 0.176887292825778, -0.0278488230036618, -0.0110890197476351, -0.014442049783797, 0.250144603906783, -0.011695653335539, 0.135781785234779, 0.18024127694542, 1.77382148720469, -1.56915765522616, 0.793398527752766, -1.22673500179423, 0.424866572425574, 0.558976393930799, 9.87295428418144, 0.752292560813328, -0.195763005045284, -6.82791288688566, -0.203691426868087, 3.11121971575175, -3.21035680540399, -0.109601822293946, 0.0110890197476435, 1.27243264391445, 0.0144420497837918, -0.250144603906788, 4.1551743688009, 0.121297475629479, -1.40821442914922, -1.12505884034232},
    {0.269990545910719, -0.292253144230847, -0.14903441530704, 0.0772432851100512, 0.054250729917271, 0.0737033512859859, -0.0363474142259865, 0.0256279208405437, 0.0304689171788661, 0.410227197655725, -1.22959167541009, 2.57619423828383, -2.7496703923541, 1.4253304278005, -0.246860738476908, 0.666461484090048, -0.536618750989811, 0.149034415307041, -1.3740079275861, 0.374305742846373, -0.178040367552021, 0.0363474142259868, 0.0114758839283005, 0.0132636522649596, 0.192517726139402, -0.0116653333004056, -0.115606680734239, -0.118918548058064, -0.47997908118474, -0.315586701499798, 0.459375465879758, 1.06739971180867, -0.405125512507521, -0.414263243433008, -2.6715267348396, -0.177243422999302, 0.152412446711478, 5.94106488936635, -0.227531237025935, -2.30575742459638, -1.46089522012829, 0.0810405276862908, -0.0114758839283006, 0.803134052795607, -0.0132636522649608, -0.192517726139402, 0.691771564843816, -0.069375194385885, -0.687527372061365, 0.888042203342528},
    {-0.127458660661965, 0.165069823211547, -0.120198635080439, 0.242093133212239, -0.0757646835227007, -0.0476672211627499, -0.140425692842852, 0.350313742212196, -0.155545878839458, -0.265312095263558, 0.724116044082566, -1.99869488560365, 2.14184546442769, -0.904877785456186, 0.0520390799654304, 0.16499464352804, -0.292827817801938, 0.12019863508044, 0.289645525886159, 0.338736145102241, -0.423727874132204, 0.140425692842852, 0.0293515260433095, 0.029213567027303, 0.112899806483857, -0.096392292140484, -0.261329132431795, 0.11658300869441, -0.659863470766915, 0.53504176809634, 0.0507346845896961, 0.257401149245719, -0.62427172810168, 0.398090462718516, -3.67274944388542, 1.09844769574502, 0.0734141319200079, 1.43267504511034, -1.28163796200781, 2.21574096815247, -0.25388572969089, 0.116592916890711, -0.0293515260433103, 0.316095043930836, -0.0292135670273054, -0.112899806483855, -0.823296240433152, -0.0202006247502263, -0.054765911499042, 0.96059896142963},
    {0.0599574981188616, -0.298712767052989, -0.0793175468753274, 0.289572373956804, -0.369732996138588, 0.156600961026919, -0.20778642149673, 0.855740648046979, -1.32030749635023, 0.871628932353357, -0.37967641859028, 1.12826398163817, -3.12670211624596, 2.6168698221322, -0.0111373775675139, -0.0177606114836674, -0.092174772365541, 0.079317546875327, -0.0619897889177901, -0.063422709702837, -0.272393731348953, 0.20778642149673, 0.0233133995269242, 0.0203305360738609, 0.0439094286276389, -0.117160460994648, -0.182612880705682, 0.323088210622942, 0.102860378972483, 0.415161966608239, -0.197397601591266, -0.835811442539953, -0.0276683589859846, 0.587487480108067, 0.572512976403903, 1.48253324003278, -0.583346916698027, -4.65206235346523, -0.0988030339797152, 3.26991023362576, 0.0155199677706862, 0.0372937468960205, -0.023313399526924, 0.0581281303877888, -0.0203305360738628, -0.0439094286276355, -0.362785951784197, 0.0798667140986281, 0.124484750317896, 0.0241777733905685},
    {0.226504621301663, 2.37732743172645, -0.0350775308879007, 0.177387214604186, -0.369081269115156, 0.431683257087081, -0.149329588787138, 0.791218693679688, -1.76769717094974, 2.40271588387604, -1.3541384622319, 3.38938832614652, -4.47854796378789, -0.160533953154848, -0.00815851923721139, -0.00470697659167479, -0.00236493139971002, 0.0350775308879061, -0.0454096920330028, -0.0225438403438892, -0.0105485501697035, 0.149329588787139, 0.00624660572299828, 0.00495487357812849, 0.00779483782924384, -0.0383507939296759, -0.044568263395026, 0.125530296925171, 0.0501486952938266, 0.0242223127867147, -0.1750222832045, -0.120288548964484, 0.349565932920144, -0.353384884179214, 0.279123789861887, 0.116011614161877, -0.780670143509991, -0.669516833234548, 1.67422939713176, -1.96691314847039, 0.00160091616297958, 0.000511293877480618, -0.00624660572299619, 0.000594185357526877, -0.00495487357813821, -0.00779483782924532, -0.00823838642270611, 0.0378395000522046, 0.0439740780375215, -0.11889282666546},
    {0.240503275451298, 0.401957822762746, -0.0187732230697996, -0.0120162719057326, -0.0185107978054524, -0.54038536480799, -0.0462721460137373, -0.0287392892809513, -0.0417728341956488, -0.505064274719771, -0.225432949938576, -0.930383993866089, 2.04305155426276, -1.52969570867214, -1.09978928821843, 0.188861504297645, -0.0910267577698615, 0.0187732230697997, -1.02790400216701, 0.426198826646041, -0.21770848266235, 0.046272146013736, 0.0839788330152885, 0.00502764454485727, 0.0328175858533545, 0.0744681666312307, 0.0308421701162753, 0.748803932424146, 3.10942503990989, -0.265613694301756, 0.103043029675594, -3.75720178050126, 0.0952629878095629, 2.28795139361779, 2.90618437295318, -0.59940349026405, 0.246447771943303, -3.51162062451297, 0.214977497813657, 2.13840452844657, -7.63987801001015, 0.564118040826969, -0.0839788330152861, 0.233638417164242, -0.00502764454485891, -0.0328175858533501, 10.7446789106129, -0.638586207458198, -0.26448058728052, -3.85360483302688},
    {0.00303876266691805, -0.292253144230848, -0.0798554220922583, 0.0537913438739437, 0.0586818441400078, 0.366598967637806, -0.1034560301836, 0.0680212977586409, 0.0709921997545904, 0.342637039714788, -0.0909883265509572, 0.961801708985776, -1.7816239702605, 1.20002496938961, 0.106362388371801, 0.384243622260385, -0.30006266875796, 0.0798554220922582, 0.0994102469069543, 0.464850762373004, -0.379441201277076, 0.1034560301836, 0.151503159036236, 0.0334283475055566, 0.11197788001774, -0.135193174824708, -0.104445794717843, -0.494041531069539, -2.18865593131267, -0.073389635547197, 0.246271324884017, 3.45136804958275, -0.369535830853196, -1.73567347427969, -2.04559929366765, -0.088785411280743, 0.311419903518435, 3.2257770366762, -0.447057550846852, -1.62222502963029, -3.23494106613806, 0.754144104129974, -0.151503159036237, 0.582626899544015, -0.0334283475055583, -0.111977880017739, 0.61786619765842, -0.618950929305266, -0.478181104826171, 3.11111639954918},
    {-0.157996351774294, 0.165069823211547, -0.166654346797131, 0.403271313827145, -0.169838959850656, -0.237095786874348, -0.179040800534355, 0.426220485252836, -0.174566673393891, -0.221598546954275, 0.730722796168729, -1.26503601749588, 1.28640251794377, -0.759162768053871, 0.212280187910397, 0.132887934812672, -0.384494298337473, 0.166654346797131, 0.198404964543104, 0.136587063032126, -0.406374916328886, 0.179040800534354, 0.177628166457945, 0.073495021811822, 0.157078923190058, -0.538082832924361, -0.489292088458685, 0.484338642311347, -1.40717486615218, 1.11461805365543, -0.0187770154896718, -0.229620188568826, -1.07766702861745, 1.66161065368496, -1.3151980039829, 1.14564506225483, -0.0198455689239487, -0.214611574541328, -1.10766545189307, 1.5530031609354, -0.378963472122789, 0.513028758056843, -0.177628166457944, 0.466509795721887, -0.0734950218118227, -0.157078923190058, -3.17861458453287, 0.0250540748675148, 0.0227822927367974, 3.07323941434431},
    {0.188157374542532, -0.298712767052989, -0.207912100848699, 0.842273262501719, -1.26534612149435, 0.778929989503396, -0.206275655835315, 0.828214450891499, -1.22650633415315, 0.728016959426352, -1.04404264935559, 2.44886189237734, -3.43241661709402, 2.13815276658272, -0.124775678124374, -0.0915108108550242, -0.19796120064662, 0.207912100848699, -0.11661999283964, -0.0887018873734149, -0.194656929515231, 0.206275655835314, 0.112230332758955, 0.0646345403512638, 0.106675216450864, -0.541352043062352, -0.521990254154891, 1.34225481939734, 0.871934638228891, 1.10830551655858, -0.644312061855102, -3.56562252705772, 0.248551415790793, 2.03953357744981, 0.814942565694016, 1.07428608911419, -0.633557521376266, -3.33256352379708, 0.240922132412369, 1.90622399151635, 0.0970729074129221, 0.127235073447325, -0.112230332758954, 0.122684432759284, -0.0646345403512633, -0.106675216450863, -1.17566916726987, 0.414116969615026, 0.399305821395607, -0.263658559540386},
    {0.143182682873863, 2.37732743172645, -0.138407634889362, 0.728837230454805, -1.61290224291862, 2.14718372548066, -0.131948528310844, 0.692484457385784, -1.52452213044935, 2.00683782653019, -0.819550657871677, 1.90937154879999, -2.13017464132606, -1.48015636420257, -0.0213836172859861, -0.00646246759162648, 0.00787298934490417, 0.138407634889369, -0.0199859245989504, -0.0061083521360463, 0.00748030222209262, 0.131948528310846, 0.0271932795573126, 0.0186743065990317, 0.0267500857137022, -0.164514517194218, -0.162675298233856, 0.521509731671454, 0.111530469784142, -0.0152238752248443, -0.736710219799733, -0.136675831966633, 1.63458858573512, -2.10065474601219, 0.10424052814734, -0.0143896722776301, -0.699964759607883, -0.127742319536108, 1.54502015486304, -1.96335011054248, 0.0020895499119476, -0.00177710603523535, -0.0271932795573141, -0.00175723856599127, -0.0186743065990383, -0.0267500857137056, 0.00492243043139444, 0.166291623229463, 0.164432536799866, -0.528521712014811},
    {-0.161958917611738, 0.401957822762746, -0.0496222433554884, -0.0732932595554697, 1.03279003696237, -1.19524818143038, -0.159080911263008, -0.0876789141410982, -0.102648366128718, -0.353944630948838, 0.0390773044282951, 0.0978558122282061, 0.649020514013169, -1.02595253582068, 0.936332773411781, -2.49685715770195, -0.355570477099233, 0.0496222433554872, 0.277272923798915, 0.248161096178578, -0.425360169840708, 0.159080911263007, 0.566687309540166, -0.689302045071177, 0.140278010579186, 0.404746660098266, -1.20592558612574, 1.1606768119378, -0.427664798036984, 5.06285842519284, 0.428863736654705, -2.72210626437914, -3.59879130445328, 3.40868647043473, -0.126642869207189, -0.503194382873377, 0.513039083981809, -0.806087733173687, 0.357681652823515, 1.0094023095308, -2.80603423924311, 1.96356341508523, -0.566687309540165, -5.85035429731965, 0.689302045071175, -0.140278010579182, 5.68977446135004, -2.3683100751835, 7.05627988344539, -4.04441703404473},
    {-0.138647660917848, -0.292253144230848, 0.0690671693240336, -0.0852935608097451, -0.578626286337773, 0.810859764011252, -0.18691086810133, 0.111478619052203, 0.0981612040014767, 0.24011704379317, 0.317770488090396, -0.0507656580653103, -0.694388193814171, 0.858284168937784, 0.504910546534909, -0.523142764392622, 0.29869869086601, -0.0690671693240339, 0.149517380433583, 0.0887486877626283, -0.39039896159007, 0.18691086810133, 0.549190313108644, -0.455762466940976, -0.124429905392882, -0.413464781999866, 0.721728812150959, -0.765784639231638, -1.57275384198323, -1.5148178353298, -0.213405130056265, 3.00613811948018, 2.61658688606019, -2.7491545880431, -0.46573405157408, 0.256981658230577, 0.278920342537868, 0.890197085267533, -0.443891549994684, -0.814097457920206, -0.692354810965477, 1.44795677340804, -0.549190313108644, -2.52749972334539, 0.455762466940976, 0.124429905392883, -2.00479006384531, -1.03449199140818, 1.80577091119443, 3.46292951404242},
    {0.0784651408728726, 0.165069823211547, 0.103341901603272, -0.360080603668169, 0.318850804445175, -0.524418917575723, -0.208140763677232, 0.463356214530207, -0.169794516671451, -0.155294325586674, -0.257876609617179, 0.190007536035745, 0.362477968217109, -0.538143858720096, -0.245495675775414, 0.130028469360583, 0.203425857830674, -0.103341901603272, -0.0726977691427067, -0.0692427956925701, -0.261770932568323, 0.208140763677232, 0.427117158752062, -0.134205540011372, -0.0982899223488918, -1.15761987536158, 0.643734919056193, 0.750744763634327, 1.18958267109403, -1.55588030115278, 0.156654745837493, -3.02641239372522, 1.10700102734703, 2.60674431598232, 0.352266923342765, 0.828537799026609, -0.201585281961884, -0.896200834636838, -0.589500486662588, 0.771926006023453, 0.306156331221144, 0.653991950103151, -0.427117158752061, -0.363675040506329, 0.134205540011374, 0.0982899223488915, -3.66337162286536, 0.503627925258423, -0.280059878549866, 2.6064705280099},
    {0.301798607677329, -0.298712767052989, -0.0876613998747671, 0.425969859867174, -0.87404780245055, 1.72287170239396, -0.183558386739005, 0.709995728118776, -0.991050736709453, 0.510187924441153, -1.49226719973947, 2.93789419330861, -2.86075292287085, 1.41204008867737, -0.353473378128935, -0.0577177593874778, -0.0463079366625623, 0.0876613998747683, -0.104672825540186, -0.0654440498583776, -0.0771848910123975, 0.183558386739004, 0.212802975121334, 0.0360758526960717, 0.0378075093271767, -0.967520969534152, -0.252683521184084, 2.08055003069053, 1.97132969884693, 0.400450976376424, -0.379661923204615, -4.89076560463873, 0.53131458546161, 1.55003758152678, 0.583762915164502, 0.454056670631955, -0.632810837106376, -1.44828517950099, 0.602438115935873, 0.459007165435525, 0.137389151632589, 0.105180915360674, -0.212802975121333, 0.0274696723808449, -0.0360758526960695, -0.0378075093271768, -0.953218220850293, 0.862340054173475, 0.225213848803236, -1.26472096147281},
    {-0.0586054310955146, 2.37732743172645, -0.204926878310816, 1.15124252490879, -2.81967943501396, 4.74923565701962, -0.100463988122245, 0.519760266641384, -1.11947385331201, 1.40637441497817, 0.371091378649248, -1.04215447025364, 1.83408597516299, -3.48174488418952, 0.044110665564593, 0.0347242019943383, 0.0545787203230059, 0.204926878310824, 0.013062335912097, 0.0137862608518739, 0.0246410722452121, 0.100463988122251, 0.0451449469243819, 0.0239726694626533, 0.0296107993050263, -0.267201543013549, -0.199297559822249, 0.808361476937443, -0.339001693001049, -0.356281769552868, -1.20582124523182, 1.34245718501442, 3.14123700257253, -5.7968018145976, -0.10038737643314, -0.141451585053746, -0.544401338886605, 0.397537114296987, 1.24713917751389, -1.71658648875413, -0.00995492851457273, -0.0126676334225613, -0.0451449469243893, -0.00944840513033535, -0.0239726694626557, -0.0296107993050313, 0.102140851142542, 0.27986917643612, 0.2087459649526, -0.900547399565429},
    {0.186613680044604, 0.401957822762746, 0.798848493973309, -2.9271659390857, 3.46950926213077, -1.89794570036165, -0.206357552845446, -0.101475401854207, -0.0982827940163635, -0.191786395599154, -0.00917970571437208, -0.0214830642039521, -0.0724954806499317, -0.485413252239096, -1.15030067029803, 3.12783181000749, -5.64479241115493, -0.798848493973308, -0.116237266097605, -0.0886038993629917, -0.195686746233611, 0.206357552845444, 1.04144129912852, -2.21712935283644, 3.0356756918627, 0.615367305726544, -2.19512365339655, 0.998664169080523, 0.0992128742326471, -0.69455428117487, 8.57195835024063, 0.351027944540055, -5.9027867909634, 2.59800555188699, 0.0100254077566372, 0.0196750405295034, 0.29716214808782, 0.0354711856219746, 0.167211652849853, 0.26252706831815, 0.900315669901498, 1.18668390167285, -1.04144129912852, -4.23311065996821, 2.21712935283643, -3.0356756918627, -0.199920629024268, -1.8020512073994, 6.42823431336476, -1.69905920995776},
    {0.26262833189321, -0.292253144230849, -0.123511007815444, 1.44142868628427, -2.12588434718252, 1.28757175841063, -0.198874814606376, 0.107864725016982, 0.0813365774870578, 0.130108435965152, -0.38530954726992, -0.0380202880529171, -0.0386261347059571, 0.491580782366433, -1.2319985352187, 2.23741118713505, -1.83649988776653, 0.123511007815445, -0.124492791552473, -0.085603607098383, -0.13742862014097, 0.198874814606376, 0.84379397571524, -1.3874778209926, 1.13942082971422, -0.54401419548449, 1.43680551547464, -0.658892874025889, 2.14746293381973, -5.67536208969405, 0.395071201482251, 0.305319074412653, 5.56383524974152, -2.50835523142431, 0.216999978282623, 0.217140000577777, 0.029563895123988, 0.0308523287985039, -0.212872970966452, -0.253467951493807, 0.693459307616097, 0.693119277045956, -0.843793975715239, -1.83060958410197, 1.3874778209926, -1.13942082971422, -1.75901179354939, -0.149105081561468, 0.393804068627335, 1.72444535995918},
    {0.297257923557781, 0.165069823211546, -0.0529350629556764, 0.349373284618034, 1.68967763895773, -0.83272967511235, -0.174529674546854, 0.363250007053725, -0.119598578773171, -0.0841468872728111, -0.932665468701496, 0.89939580982212, -0.128077548392628, -0.300980539497324, -0.879189330581101, 0.749214963869797, -0.0517333807439277, 0.0529350629556767, -0.0888416105525355, -0.0530308520444703, -0.0537881737027804, 0.174529674546855, 0.531695946965819, -0.500943956250018, 0.0516751118353569, -1.29477416154296, 1.84844220401676, 0.645952333892768, 3.06792924261876, -3.09546239170508, -0.297639903874107, -3.67470306551298, 0.65656978887756, 2.31869282858767, 0.310012605356938, 0.21910268216728, -0.309461833350946, -0.371326774890149, -0.0464732513496389, 0.234302667358556, 0.286419813661982, 0.191723430570072, -0.53169594696582, -0.273707717600947, 0.500943956250023, -0.0516751118353585, -1.18337433738697, 1.10305073097289, -1.57473448641581, 0.251002189832225},
    {0.105970427076992, -0.298712767052991, 0.0905706902337713, -0.559977693850787, 1.89158620077829, 2.73576399498904, -0.125371565743525, 0.466585090485748, -0.613478637595956, 0.276447485146134, -0.493601927890698, 0.912754231227878, -0.859298198738498, 0.632888235377318, -0.115225774364482, 0.00280414771476834, -0.0150273444166858, -0.0905706902337726, -0.0116435027310222, -0.000909440298816768, 0.0125210966997741, 0.125371565743527, 0.222064178926051, -0.0483293676292872, -0.0269309946081405, -0.951019964016138, 0.296312750966937, 1.79013722533245, 0.473294705509374, 0.0906046239486374, 0.575005038267476, -0.509749860522943, -1.98499497244169, -2.584083065611, 0.047826176274978, -0.0293848629457392, -0.479106187185522, -0.0515099501467612, 0.643772940840509, -0.261120208543328, 0.00265375651793663, -0.0255212032610513, -0.222064178926052, 0.0079517341721545, 0.0483293676292901, 0.0269309946081415, 0.0857453443310972, 0.976541167277188, -0.304264485139095, -1.87853632618148},
    {-0.397585858525552, 2.37732743172645, -0.191346895929757, 1.15800142154502, -3.20320459390345, 7.5413554567869, -0.0593214248110924, 0.302297805548911, -0.636304129851136, 0.76204992625109, 2.22862307256703, -5.20603825409457, 6.62721380355634, -5.6295401952297, 0.29009576827342, 0.108667331755444, 0.100385839478183, 0.191346895929763, 0.0293140218738183, 0.0215863426605579, 0.0262058564159281, 0.0593214248111026, 0.0416933466353165, 0.0154793288449518, 0.0161389348462984, -0.241165644948257, -0.122678763899121, 0.695526639611801, -1.80496082766069, -0.81972555792328, -1.25838726102322, 5.13860823046484, 3.91426282007132, -11.1650986278645, -0.182390324058645, -0.162835292770213, -0.328503661964853, 0.519253607060104, 0.777553079960798, -1.12822723112637, -0.0235954407143524, -0.0209063782401332, -0.0416933466353309, -0.0106348839224518, -0.0154793288449502, -0.0161389348463034, 0.177990804518434, 0.262072023188401, 0.133313647821585, -0.849922003415902},
    {0.0167231769272507, 0.401957822762749, 9.65546182492155, -9.34793058151144, 6.39444256476643, -2.46012846883513, -0.111215180556962, -0.0503474981856448, -0.0428437143844053, -0.062054095109035, -0.202139370213555, -0.0910534020866288, -0.072525443134044, -0.0529627842557692, 0.149008114153994, -1.25378938541603, 3.83289856489746, -9.65546182492156, 0.00375856944257844, 0.0084005749966328, 0.0206438047286899, 0.111215180556961, 0.669770344786397, -1.78129271809509, 3.13672292834149, 0.34771069035814, -1.30901999077111, 0.418838042767304, 1.24546638290828, -3.38404899977595, 5.51503201661398, 0.616955579472583, -1.75660417957442, 0.448698392300264, 0.0314155501873419, 0.0226736306317072, 0.029703693456961, 0.0155620410444686, 0.0117695087560682, 0.0113179344346416, -0.0821236076344811, -0.142570571577526, -0.669770344786393, 0.53673278810734, 1.78129271809509, -3.1367229283415, -0.221656296907637, -0.205140118780627, 0.772287202663774, -0.115058138225182},
    {-0.0748919790983803, -0.292253144230847, 2.64740738044187, 5.36350609164481, -4.00733663545901, 1.6689581466585, -0.0982464118371504, 0.0496841080000025, 0.0336033430537147, 0.0420976745229769, -0.0672191997708853, 0.130979678041365, 0.105179489498026, 0.198205155560723, 0.583617242377615, -1.75535633697017, 2.72645767649418, -2.64740738044188, 0.0147211173418585, 0.0147194624606238, 0.0252561692560348, 0.0982464118371522, 0.50378876769155, -1.08053498733039, 1.37180512716454, -0.291327060891265, 0.876328283552688, -0.276338543320731, 0.00914043488074854, 1.38181465767428, -8.08996376813898, -0.936154078378064, 4.38087831475491, -1.3255617455388, 0.000230557640632578, -0.0115871453293, -0.074940277256038, -0.0236134799268842, -0.0367356601850401, -0.0334358695785896, -0.121046135449409, -0.148091731036679, -0.503788767691545, 0.445468306551032, 1.08053498733039, -1.37180512716454, 0.0952873901988158, 0.439418791927937, -1.32179659010372, 0.302097288571331},
    {-0.250468856650956, 0.165069823211546, -0.187994765484735, 4.35942248656922, 3.41733871056418, -1.07938914174274, -0.0760925285239202, 0.150535227766681, -0.0458402342130931, -0.0272264303713623, 0.560233760555616, -0.21640170063899, -0.147191496708848, -0.111241529768367, 1.0461401018987, -1.55010871751303, 0.80839520340634, 0.187994765484729, 0.0263877590958967, 0.0207931822639911, 0.0279146966014808, 0.0760925285239237, 0.285607669742067, -0.388323899272724, 0.208628359038452, -0.643263392209392, 1.20960255398634, 0.270911302943535, -2.73303028499986, 5.23450301813053, -5.16781768997554, 1.64873706748337, -7.10173301118168, 1.11754225736053, -0.0689377499547834, -0.0702157042843016, -0.178449924368165, 0.0415876195456565, 0.0952627562333995, 0.0281888016845907, -0.122885674477438, -0.119284387413947, -0.285607669742068, 0.224304229673362, 0.388323899272728, -0.208628359038456, 0.414967948163808, 0.762547779623345, -1.43390678365971, -0.56299357662991},
    {-0.502239635580975, -0.298712767052993, 0.105852187397962, -0.836801817303566, 5.85275550665803, 3.54611350936128, -0.0480952657120916, 0.173733641433925, -0.218291964694202, 0.0894468999342669, 2.03897006555017, -3.02415716371378, 1.77660019458062, 0.00953930621696029, 1.12840081544712, -0.545785509857593, -0.113201120517717, -0.10585218739797, 0.028462697135488, 0.02035632465988, 0.0235023902616751, 0.0480952657120966, 0.107177982409503, -0.0532088243073665, -0.0130213775050856, -0.438633646781775, 0.296645138506821, 0.750780487532153, -5.03608120140908, 2.90209988198704, 0.950002937821304, 8.94320518700363, -8.20906987878749, -8.58163831040296, -0.127029732718367, -0.10824048335133, -0.197236031695605, 0.225582733700331, 0.306176123385649, -0.216462598051716, -0.0700123404629844, -0.0593376105138963, -0.107177982409507, 0.0401296476426361, 0.0532088243073696, 0.0130213775050878, 0.372275924013287, 0.49797125729567, -0.336774786149463, -1.05304407108246},
    {-0.778443022056049, 2.37732743172644, -0.142219700439311, 0.917394780947759, -2.83066387967162, 9.77514965223254, -0.0205164010902871, 0.103309343513253, -0.213572850101013, 0.246567638198119, 4.20489398868704, -9.31981192455293, 10.8638856288179, -7.34785210262236, 0.673414315020529, 0.153608934270617, 0.108357653355247, 0.142219700439315, 0.0169861519353255, 0.0115897539544485, 0.0122023345513397, 0.0205164010903011, 0.0184690844511998, 0.00459131460489899, 0.00413689683524863, -0.104923011112228, -0.0350772603162161, 0.291702681889287, -3.91982442923119, -1.02642018009458, -1.02575243430301, 9.97638223467828, 3.70347512549561, -16.5051217727002, -0.0988733560151502, -0.0774431343962685, -0.115511678064611, 0.251643513693367, 0.279426230542841, -0.416323947811659, -0.0158295509440822, -0.0123929321413296, -0.0184690844512202, -0.00414313411514216, -0.00459131460489423, -0.00413689683525253, 0.105773603651352, 0.117315943253567, 0.0392203944313678, -0.38164673459658},
    {-0.105791126909817, 0.401957822762747, -0.16416777530046, -0.07650047199559, -0.068066212005509, -0.108642456439206, -0.137827978438842, -0.26421828725976, 1.33871103080744, -1.31019580959275, -0.0693101417590293, -0.0135369151601575, 0.942987443234203, -1.15630708216794, 0.0761551633562675, 0.27213155199218, -0.425053558215354, 0.164167775300464, 0.918408688265108, -5.3522224867339, -1.46805529712028, 0.137827978438839, 0.155221788245079, -0.592466651821692, 0.541989101448617, -0.479799244311742, 0.294198821893878, 0.390529342667778, 0.0387371525500867, -0.470514875753139, 0.501554030210936, -0.354938187675605, 0.266449535766477, 0.348688328208458, 0.467158573269901, 9.25398131864231, 1.73227358438004, -4.28044929578007, -5.24046986271585, 4.20507784383781, -1.56135258577435, -2.66587082018919, -0.155221788245073, 1.63463378469046, 0.592466651821695, -0.541989101448622, 2.69957530659132, 3.14567006450093, -1.92883260658433, -1.52875206348475},
    {-0.166507481624836, -0.292253144230849, -0.14903441530704, 0.077243285110051, 0.0542507299172694, 0.0737033512859882, 0.00659520248347681, -0.009540093161369, -0.77058047851643, 0.888840561717927, 0.361971121328349, 0.0817541398560618, -0.931681699067024, 0.946717063738298, 0.0674033676683355, 0.109102748754661, -0.31200771331183, 0.149034415307041, 0.812864627383563, -1.5497016993325, 0.0385351639022018, -0.00659520248347564, -0.00427194240478237, -0.335447152559144, 0.417128763817382, 0.295024534804027, -0.250485359404172, -0.257661192769863, -0.23081402566826, 0.106893355165645, 0.234764428201779, 0.36522790543516, -0.270246833837577, -0.275520598721223, -2.78354870772829, -1.51831934610621, -0.0289950707408342, 4.40454024081497, 3.83860152395514, -3.32269672218817, -0.518178177905879, -1.19168844701444, 0.00427194240478001, 1.01178198330689, 0.335447152559144, -0.417128763817383, -0.507684770935884, 0.896663912210414, -0.761296623902711, 1.28352414161162},
    {-0.00460700210468877, 0.165069823211547, -0.120198635080439, 0.242093133212239, -0.0757646835227034, -0.0476672211627486, 0.116533764631272, -0.440025155662253, 0.483145202344923, -0.574852552761569, 0.0446449994580089, -0.168146803128284, 0.558376310521588, -0.595337327958173, -0.00447841447770854, -0.0156727121577167, -0.161107257848828, 0.12019863508044, -0.0540083506450905, 0.0999436061059615, 0.292826340312171, -0.116533764631272, -0.0368681220855627, -0.0907410396079823, 0.244620366436967, 0.2994066691974, -0.56622265464435, 0.252600772271729, 0.032684278989615, 0.410815601569543, -0.0809858753634127, -0.242611342490345, -0.319378205889125, 0.262072699141188, 0.394162712951208, -2.61973755737124, 0.147198815350082, -2.92582085041873, 2.03664874892036, 3.16051904087418, 0.0522530948531736, -0.199248061339085, 0.0368681220855637, 0.376807792981308, 0.0907410396079799, -0.244620366436966, -1.36966635895271, -0.100158607858316, 0.189414861663045, 1.0648124918278},
    {0.290022490838601, -0.298712767052989, -0.0793175468753267, 0.289572373956805, -0.369732996138594, 0.156600961026921, -0.0532327497944598, 0.268058474381141, -0.587773658440496, 1.88856115408695, -1.47223222072208, 3.00935391526566, -3.12836901872781, 1.59993760039861, -0.0325642012557395, -0.0268596825201057, -0.0409455036344193, 0.0793175468753261, -0.392714611086449, -0.0426994994341204, -0.0379034404664845, 0.0532327497944599, 0.00730286018794285, 0.00905073522585888, 0.0951386973587611, -0.0521574201265808, -0.395667904007683, 0.700036243953607, 0.191057521527252, 0.211206014342687, -0.248626870322388, -0.525633728075823, 0.185386664316008, 0.210539446777392, 2.30409705653375, 0.335759407549103, -0.230155033914659, -6.33898689773213, 0.294713750325518, 2.53904329819788, 0.0508549452213776, 0.0073750537945814, -0.00730286018794138, 0.0559474005762211, -0.00905073522586072, -0.0951386973587591, -0.399888207233351, 0.0447823663319976, 0.339720503431467, -0.351002981941632},
    {0.00324591462100564, 2.37732743172645, -0.0350775308878984, 0.177387214604185, -0.36908126911516, 0.431683257087081, -0.207698228045336, 1.18066248882389, -2.94696348846714, 5.20597207614994, 0.0159833447998947, -0.194511750278059, 0.761745204559466, -2.96379014542876, 0.00155844623367404, 0.00285602294238367, 0.00672933045590861, 0.0350775308879031, 0.0187943994619776, 0.0228041790188396, 0.0447894063950396, 0.207698228045341, 0.00932123206706976, 0.00826036934647261, 0.0168890996848587, -0.0639353794992818, -0.0965661967252909, 0.271986889872726, -0.0157277113712771, -0.0353386200775957, -0.184116545060114, 0.0823274851772881, 0.401563866250393, -0.499841477126766, -0.189671535498668, -0.282164476542188, -1.22545189521895, 0.992845059187059, 3.20632378599051, -6.02793999930033, -0.00210468767314616, -0.0024254414131953, -0.00932123206706824, -0.00366331840819524, -0.00826036934647789, -0.0168890996848642, 0.0260420730380351, 0.0663608209124822, 0.100229515133509, -0.295924275237629},
    {-0.164081106760815, 0.401957822762747, -0.0187732230697992, -0.012016271905733, -0.0185107978054519, -0.540385364807992, 0.0258474166283128, 0.0317742188172514, 0.794078534982992, -1.09432435540836, 0.0923933082071172, 0.128672986876066, 0.481492616898435, -0.940435627983551, 0.367892523217867, 0.0286067582518055, -0.0527383769520354, 0.0187732230697984, 0.745012308897368, -1.22717631740947, 0.139454295182939, -0.0258474166283135, -0.0928471748260422, -0.095572749406886, 0.0711059666711795, -1.41559876891381, 0.066825827169445, 1.62243583973931, -0.31680634013194, -0.0693752912027441, 0.0647546488577717, -0.92502030458056, 0.0592793307563879, 1.41431948630263, -0.641558629326227, 2.97606997717111, -0.171228514000189, -1.87324142079503, -2.54297219474464, 2.86411209663225, -2.50732736288742, -6.21294042557338, 0.0928471748260429, 0.293292769258343, 0.0955727494068854, -0.0711059666711771, 6.08061089655065, 7.62853919448719, -0.36011859642779, -5.19571937340254},
    {-0.0960766222659436, -0.292253144230849, -0.0798554220922584, 0.0537913438739439, 0.0586818441400081, 0.366598967637806, 0.104452923995495, -0.114312118111811, -0.429809247452431, 0.742392753542015, 0.243634538083018, -0.100150016833949, -0.555424010314663, 0.800269255562387, 0.131304457829817, 0.018307043423617, -0.169417723317698, 0.0798554220922585, 0.265902216333921, -0.134088092702238, 0.360030023483158, -0.104452923995495, -0.254606242173065, -0.202385796391838, 0.242622825458004, 0.81850227113656, -0.226303032506377, -1.07044134201057, -0.42940455778985, 0.17068970550104, 0.115626379443754, 1.09077479566088, -0.247678593064665, -1.15927366333866, -0.869579186475107, -1.25019952839658, -0.245717905371347, 2.20890775896828, 1.81409686855125, -2.34762354236911, -0.333946835138085, -2.57790159753732, 0.254606242173064, 0.712749334483391, 0.202385796391837, -0.242622825458003, -3.11362603036113, 1.75939932640076, -0.486446301977015, 4.51801420750978},
    {0.134579466303349, 0.165069823211547, -0.166654346797131, 0.403271313827145, -0.169838959850655, -0.237095786874349, 0.0785206721957281, -0.256222516966144, 0.193931752514902, -0.480138269905771, -0.449017679815502, 0.39964919690881, 0.250342238494169, -0.500623045102375, -0.163463691193919, -0.0847537527393663, -0.201229823722227, 0.166654346797131, -0.33102728191393, 0.0967766395614574, 0.127853408251256, -0.0785206721957281, -0.106781202379179, -0.0816479921624412, 0.340343397805305, 0.597773588500172, -1.06015070974094, 1.04941806236602, 0.727784246397315, 0.761401119925217, -0.202041490104918, -1.42375600195933, -0.506808407335194, 1.09653123363028, 1.4738223463881, -0.86941096250086, 0.128369108714888, -2.8832218090446, 0.578702570424501, 2.22056501447621, 0.523685019363069, -0.298285223161826, 0.10678120237918, 0.529008469299667, 0.081647992162441, -0.340343397805305, -4.70462188803937, -0.299488365338349, 0.531142240441274, 3.13151880631028},
    {0.29979034391558, -0.298712767052989, -0.207912100848699, 0.842273262501719, -1.26534612149435, 0.778929989503395, -0.11704912380254, 0.551807490955153, -1.07182330716522, 1.57739663984871, -1.45868837355563, 2.8086312285883, -2.63979351805564, 1.28877308616037, -0.153143283237314, -0.0756769813797021, -0.0735028894976394, 0.207912100848699, -0.310127615638405, -0.0641028972870147, -0.0481547341431412, 0.11704912380254, 0.0747747618531864, 0.0564830403784479, 0.231133527599844, -0.47307846765942, -1.13099792838138, 2.90826774640857, 0.827236054089224, 0.483464012856778, -0.768770373004081, -1.92654341079388, 0.857559090017272, 0.473520650438573, 1.67522035313336, 0.409522729277868, -0.503652756812014, -3.90140724283371, 0.726403475174373, 0.958917865490045, 0.173935747977188, 0.0412842670902347, -0.0747747618531863, 0.0986991033111477, -0.0564830403784475, -0.231133527599844, -1.1111922431786, 0.431794200569186, 1.03229882507023, -1.97101125120716},
    {-0.103138285400149, 2.37732743172645, -0.13840763488936, 0.728837230454803, -1.61290224291862, 2.14718372548066, -0.200550049418393, 1.11516772883396, -2.68710950212105, 4.34822184195316, 0.622875521638076, -1.63073858171746, 2.55521429337863, -3.82154037962554, 0.0285357944165824, 0.0249215884170054, 0.039082398632139, 0.138407634889366, 0.0577873067345075, 0.0415195882684611, 0.0597985776505842, 0.200550049418399, 0.0437916944994516, 0.0329151710595495, 0.0579594950009334, -0.289971863025132, -0.352469081246052, 1.12995677880246, -0.204991706784136, -0.236401714245664, -0.767919629086963, 0.738373980030076, 1.82438236874731, -2.70910179314318, -0.415124894195335, -0.393847361460469, -1.17496630648456, 1.4952674190831, 3.03943727531309, -5.48615167357545, -0.0174594076571751, -0.0155491452265332, -0.0437916944994543, -0.0189004301141103, -0.0329151710595524, -0.0579594950009402, 0.165616807035313, 0.305521008251673, 0.371369511360181, -1.27811417818061},
    {0.0564307431585077, 0.401957822762747, -0.0496222433554889, -0.073293259555469, 1.03279003696237, -1.19524818143039, 0.10654738675911, 0.084823207569342, 0.212019988320744, -0.766892947097166, 0.0811251111917349, 0.04795418470372, 0.0255363578556469, -0.613004219672357, -0.310862724193497, 0.607293902650748, -0.191907680163961, 0.0496222433554875, -0.19945517123825, 0.124670495976095, 0.222097162650809, -0.10654738675911, -0.548230275829876, 1.4237519510266, 0.303940807514462, -0.836003390831256, -2.61288276712841, 2.51484210552406, -0.359749645565947, 0.551750183837494, 0.265200939719434, -0.188660625658637, -2.19183412345062, 2.05452117684847, -0.230821908112059, 0.113268005447903, -0.306920370220152, -0.121048084791395, -0.449958489744742, 1.31821811123887, 1.47875969185959, -2.18895260378223, 0.548230275829877, -6.84145136157457, -1.4237519510266, -0.303940807514456, 1.34351082445205, 3.02495599461348, 9.45433412870297, -5.3371126218357},
    {0.169880004840815, -0.292253144230849, 0.0690671693240334, -0.0852935608097448, -0.578626286337773, 0.810859764011252, 0.0601843095813754, -0.0481034612920377, -0.0739385526704499, 0.520262355355291, -0.217752175599961, -0.0922856891438499, -0.145727853241818, 0.578138857375663, -0.579959512573224, 0.563160949589567, 0.15352592818632, -0.0690671693240332, -0.372112559302997, 0.0719623468831859, 0.0865848309499942, -0.0601843095813752, -0.236977773793667, 0.343296697610014, -0.269602668072571, 0.311436558590027, 1.56377209133422, -1.65922799068246, 0.969200972393793, -1.75907827012873, -0.0682323673765759, 0.655610012760455, 1.77454360687694, -1.85571123659228, 0.621856951214112, -0.22478014635414, -0.038481369657957, 0.420651294554226, 0.226756352141404, -1.19065804182063, 1.61488068012323, -0.560576745474845, 0.236977773793668, -2.81474427277659, -0.343296697610014, 0.269602668072572, -5.04420896961302, 0.249140186884817, 1.25097218144237, 5.08855628017225},
    {0.294232960746207, 0.165069823211547, 0.103341901603272, -0.360080603668168, 0.318850804445175, -0.524418917575723, -0.0624268174830958, 0.168910681021681, -0.0868988311190471, -0.336476704555082, -0.936259324974293, 0.89295327524657, -0.0590352544783445, -0.356961479751688, -0.598894015194809, 0.175652504797971, 0.0887506957311207, -0.103341901603271, -0.384261280165229, -0.0478719110545667, -0.041632179863002, 0.0624268174830957, 0.155700188965853, -0.068684812591769, -0.212965084448443, -0.592456199535278, 1.39478247742007, 1.62664104483763, 2.19349348137033, -0.850456778226289, 0.271329907937046, -2.80102858337881, 0.355953468983144, 1.73084803477902, 1.40738526650876, 0.231781444220387, -0.127278501158679, -1.79719082495495, -0.0970107020467735, 1.1105435431665, 0.896104290626139, 0.146025360331341, -0.155700188965853, -0.34377834852411, 0.0686848125917715, 0.212965084448443, -4.33866837730096, 0.446430839203936, -1.05100412889596, 1.8159230418372},
    {0.197406415132327, -0.298712767052989, -0.0876613998747675, 0.425969859867174, -0.874047802450549, 1.72287170239395, -0.192304353920289, 0.826594904371368, -1.36858582907549, 1.10542578340343, -0.915326776547994, 1.66111998585092, -1.46128908709735, 0.816802229715091, -0.182544384524023, -0.0193299798004341, -0.00219779640540928, 0.0876613998747684, -0.117123793366608, -0.0302669217370265, -0.00426482594360776, 0.19230435392029, 0.247750582016085, 0.0498187418089059, 0.0819176495843294, -1.33609253208801, -0.547490181513051, 4.50793430696221, 0.863183086088694, 0.0672565364604129, -0.423772063461766, -1.52616370921373, 0.826121245790573, -0.8773466947449, 0.553833949349992, 0.105310421757657, -0.822330078427762, -0.979214361414885, 1.29354232905487, -0.56292157797193, 0.0996950954524003, 0.00689358483070213, -0.247750582016087, 0.00282478190663872, -0.049818741808904, -0.0819176495843299, -0.346878108070647, 1.32919894725731, 0.54466539960641, -4.26075129434396},
    {-0.304744182307484, 2.37732743172645, -0.204926878310815, 1.15124252490879, -2.81967943501396, 4.74923565701962, -0.172286458511457, 0.927333358625993, -2.12300674191135, 3.04719587618368, 1.73156496827643, -4.1270691678381, 5.44548729553773, -5.12256634539502, 0.145932890506214, 0.0801957809291881, 0.0891257331708736, 0.204926878310822, 0.0936331936893526, 0.0603813970734735, 0.0717913590691117, 0.172286458511465, 0.0805456244797083, 0.0454625525556167, 0.0641578121528911, -0.50672972449387, -0.4318186508202, 1.75147935909215, -0.932339107137422, -0.634274439485664, -1.24036825807968, 2.77709025636387, 3.37375809357047, -6.7399196967523, -0.598205708801732, -0.477560993114603, -0.999124717695124, 1.78183155945822, 2.5401863379525, -4.32445492052953, -0.0498146183709717, -0.0392294909524526, -0.0805456244797172, -0.0334301009722241, -0.0454625525556165, -0.0641578121528985, 0.393987548713368, 0.545959215446333, 0.465248751792439, -2.09565228943456},
    {0.299991988790641, 0.401957822762747, 0.79884849397331, -2.9271659390857, 3.46950926213077, -1.89794570036165, -0.116259944551924, -0.0671601987265352, -0.0853988144437311, -0.415544187631533, -0.189532639500736, -0.114192743886039, -0.136568967959891, -0.261655460206723, -1.42272867008211, 2.6025062769043, -2.10306001655252, -0.798848493973308, -0.311498178960916, -0.0640583246327806, -0.0482521085530296, 0.116259944551923, 0.689264623085488, -1.92648387844072, 6.5774080864651, 0.534698253976509, -4.75618133628168, 2.16380880177049, 1.07105877376891, -2.73028643095679, 5.03022595563822, 0.816754677477831, -3.34172910807828, 1.43286091919702, 0.234502097697847, 0.0672035168894006, 0.115412307279565, 0.178823692839114, 0.0822536221871109, 0.313716576055492, 1.62309005774784, 0.384160837567577, -0.68926462308549, -3.41713965246931, 1.92648387844072, -6.5774080864651, -1.70278196837284, -0.918859091544083, 8.17332098875099, -2.08411689114548},
    {0.272170305024623, -0.292253144230849, -0.123511007815445, 1.44142868628427, -2.12588434718252, 1.28757175841062, -0.157941208263555, 0.0979068146088083, 0.0920774725226199, 0.281906358155606, -0.467489537376659, 0.0697441808985603, 0.0780453355083463, 0.339782860175976, -1.02566673596469, 1.31886293520907, -0.507134015614563, 0.123511007815446, -0.224563774662214, -0.0571233170980159, -0.0344462938201878, 0.157941208263555, 0.765896175374987, -1.5707010902754, 2.46878670186618, -0.615853945226662, 3.11313103751268, -1.42762526621309, 1.98674817508493, -3.08048831573003, -0.934294670669712, -0.509030358293773, 3.88750972770347, -1.7396228392371, 0.434986973698342, 0.133423804838585, -0.0634605207886205, -0.111449240448065, -0.168377960263189, -0.38088031674367, 0.885674731775417, 0.216674253292386, -0.765896175374988, -1.09528460145879, 1.5707010902754, -2.46878670186618, -2.06868400797009, 0.399179691934279, -2.01784643605389, 2.61063454240777},
    {0.148805352758509, 0.165069823211547, -0.0529350629556777, 0.349373284618035, 1.68967763895773, -0.83272967511235, -0.201751253837805, 0.461329302767379, -0.176632655677167, -0.182321325786764, -0.500755705181343, 0.569087838367465, -0.179401208172807, -0.202806100983372, -0.325405674300828, 0.138534598999159, 0.00855613505400969, 0.052935062955678, -0.0712456823987457, -0.0144818949841141, 0.0112979325913981, 0.201751253837805, 0.675256478279167, -0.73983371914211, 0.111964627633294, -1.91222505318609, 4.00502554757522, 1.39958695713318, 1.15684195918731, -0.32819868327598, -0.357929419672045, -1.56376481512139, -1.50001355468091, 1.56505820534725, 0.253283827907705, 0.0343086773951389, -0.472627235358777, -0.342377223764925, 0.156805873266141, 0.342660404042729, 0.114750419488599, -0.0468303002234666, -0.675256478279169, 0.0980828843775971, 0.739833719142115, -0.111964627633297, -0.271852207705544, 1.95905535340956, -4.10310843195282, -1.24248516891624},
    {-0.144387432414533, -0.29871276705299, 0.0905706902337702, -0.559977693850787, 1.89158620077829, 2.73576399498904, -0.196100657264721, 0.770010309271972, -1.10058719413418, 0.598979637105895, 0.586279958088711, -0.843273775719103, 0.389737933680361, 0.310356083417555, 0.313660972674282, -0.0808711851769473, -0.0464478206810613, -0.0905706902337718, 0.0686742481920362, 0.0470535208723673, 0.0638691525758621, 0.196100657264723, 0.366474862955997, -0.0867033990325075, -0.0583514708725155, -1.70613992015067, 0.642021771151966, 3.8786959665507, -1.52272357193104, 0.519988977025384, 0.606425514531853, 3.14594041109695, -2.33070399262673, -4.67264180682924, -0.333391481940118, -0.302546724526545, -0.833879461847837, 0.688785381066153, 1.35608039778835, -1.02304778442397, -0.165826299444841, -0.141517210307092, -0.366474862955999, 0.0532530356606504, 0.0867033990325102, 0.0583514708725157, 1.06623697456099, 1.84765713045776, -0.695274806812619, -4.77910664166685},
    {-0.581370126327106, 2.37732743172645, -0.191346895929756, 1.15800142154501, -3.20320459390345, 7.54135545678689, -0.114067231912172, 0.593574614772201, -1.2898484995732, 1.65113597630005, 3.19340425915313, -7.24546708488879, 8.77473176561498, -6.51862624527865, 0.402570486055827, 0.141295916779, 0.119215185614467, 0.191346895929763, 0.088140469751382, 0.0568962490251355, 0.0611079628742604, 0.114067231912183, 0.0818666616606155, 0.0313780598748144, 0.0349682809825805, -0.488865513662304, -0.265808464280516, 1.50699976153499, -2.4126066698208, -0.995483843328229, -1.2772166071595, 6.44525247676573, 4.05739252045271, -11.9765717497877, -0.528226217691066, -0.400855862941178, -0.65468257764648, 1.41115059510257, 1.63380811348926, -2.62220082346294, -0.066474964882676, -0.0503282568289156, -0.081866661660631, -0.0273647379161458, -0.0313780598748113, -0.0349682809825868, 0.468341584350415, 0.539193770491231, 0.293173202196673, -1.90886638100275},
    {-0.23477560772866, 0.401957822762749, 9.65546182492156, -9.34793058151144, 6.39444256476643, -2.46012846883514, -0.183808928740489, -0.0870687160530466, -0.0794763120089828, -0.134452803394808, -0.121415088866557, -0.0428121328044274, -0.0223909173931028, 0.0194359240300021, 1.57034702363991, -4.51342080072435, 7.49252308868268, -9.65546182492156, 0.0858237942878999, 0.0560971556399159, 0.0697870357124671, 0.183808928740489, 1.15827093842728, -3.30434879134061, 6.79634745212671, 0.645013246699721, -2.83625773850671, 0.907497706952531, 0.692596204907801, -1.65165533220322, 1.85540749282876, 0.237146512172363, -0.229366431838827, -0.0399612718849619, 0.0378522920855774, 0.0205283686863819, 0.0172816803405864, 0.0129607107030454, 0.00285078768268284, -0.00218399368171565, -0.640543563521524, -0.516988931535503, -1.15827093842728, 2.27330813017014, 3.30434879134062, -6.79634745212672, -0.234402516164458, -0.128024315164222, 0.562949608336571, -0.0325516272665448},
    {-0.319307309300148, -0.292253144230846, 2.64740738044187, 5.36350609164481, -4.00733663545901, 1.6689581466585, -0.16969680371065, 0.0891817251364798, 0.0639983068686294, 0.0912131640316641, 0.233852569065172, 0.132444283151232, 0.0961739352625579, 0.149089666052033, 1.73319922781625, -3.81904507052228, 4.32694704068548, -2.64740738044188, 0.0947241162295667, 0.060991236974132, 0.0719463341830896, 0.169696803710651, 0.904288176153036, -2.05790267923408, 2.97229449135585, -0.55483880315872, 1.8987432531374, -0.598743592509556, -1.52666139877435, 4.4679183608111, -9.69045313233029, -0.872339279350433, 3.35846334517019, -1.00315669634997, -0.0834362544477361, -0.0713539281399591, -0.161128059319569, -0.0476757466554658, -0.0536356157028052, -0.0548252791580328, -0.570610600878192, -0.447609842585038, -0.904288176153036, 1.53178934819945, 2.05790267923408, -2.97229449135584, 0.667559961576612, 1.00244864574376, -3.43053260133686, 0.501794231811141},
    {-0.46704693209756, 0.165069823211547, -0.187994765484736, 4.35942248656922, 3.41733871056418, -1.07938914174275, -0.140239979255143, 0.285318280611889, -0.0906850475397886, -0.0589915924715624, 1.1133023195661, -0.613888460615419, -0.117960382396499, -0.0794763676681686, 1.76831839423408, -2.33803115856641, 1.05180256724955, 0.18799476548473, 0.0966434754978212, 0.0620437377508571, 0.0688390494280749, 0.140239979255145, 0.541329032873796, -0.768215343374563, 0.452035722881659, -1.27255831704393, 2.62084966497747, 0.586984373683946, -4.66768181452501, 7.43367257017504, -5.41122505381875, 3.17728337541355, -8.51298012217282, 0.801469186620127, -0.255101679960219, -0.197265476886328, -0.354157330039966, 0.17364729623502, 0.225906786675256, 0.043802500698939, -0.401595472822779, -0.307031518272259, -0.541329032873798, 0.632335226624903, 0.768215343374567, -0.452035722881663, 1.27685605886439, 1.5795898353162, -3.25318489160238, -1.46224495972556},
    {-0.658971363590877, -0.298712767052993, 0.105852187397961, -0.836801817303566, 5.85275550665803, 3.54611350936128, -0.0949022450750608, 0.348527807290236, -0.449037675456539, 0.193804879919781, 2.65481672502862, -3.91007984563921, 2.30776592502301, -0.0948186737685551, 1.42890947687281, -0.660518268226528, -0.12839320268108, -0.105852187397969, 0.0780938424138088, 0.0506765723296664, 0.0534757459605021, 0.0949022450750653, 0.215010212706457, -0.109453258227931, -0.0282134596684478, -0.90229172385631, 0.642741956281939, 1.6267184479196, -6.24909417659343, 3.36292945813109, 0.965195019984668, 10.7316474611497, -8.55516669656261, -9.45757627079041, -0.341530225500341, -0.258012149129706, -0.402003553250743, 0.586514120898521, 0.656373252256577, -0.516882617731767, -0.183584851765903, -0.138441530339708, -0.21501021270646, 0.0986179720910053, 0.109453258227934, 0.0282134596684495, 0.934694672000333, 1.04073325419602, -0.741359928372949, -2.37782826815404},
    {-0.852928776435767, 2.37732743172644, -0.142219700439311, 0.917394780947759, -2.83066387967162, 9.77514965223254, -0.042839968042419, 0.217156820960843, -0.453448968880601, 0.534238878577228, 4.58195997228847, -10.0789234905852, 11.6080882060076, -7.63552334300147, 0.729646958987023, 0.163999371232678, 0.113184183927629, 0.142219700439315, 0.0398772179449378, 0.0262713444420445, 0.026791865481717, 0.0428399680424334, 0.038822119365855, 0.00974808770127478, 0.0089634274076301, -0.22276816167499, -0.0760020104497307, 0.632033119955884, -4.20797794764628, -1.07773536719015, -1.0305789648754, 10.5486335471935, 3.74439987562912, -16.8454522107668, -0.229977596231946, -0.172644302450808, -0.243948686442579, 0.576511905931555, 0.599821926889375, -0.920650406221773, -0.0366179238076673, -0.0274841683295833, -0.0388221193658759, -0.00937679798082836, -0.00974808770126954, -0.00896342740763447, 0.240637700400766, 0.250252330004584, 0.0853788084305686, -0.836052896549008},
    {0.218256695635769, 0.401957822762747, -0.164167775300462, -0.076500471995588, -0.0680662120055107, -0.108642456439207, 1.68633541906574, -3.90274161753216, 4.0103539344985, -2.01569604328752, -0.0381800259776011, -0.039843014981468, -0.0913846289662699, -0.45080684847318, -0.0733887411520782, -0.0637431422621082, -0.133209060673522, 0.164167775300467, -1.36161681179277, 3.75564547866194, -6.79578218749924, -1.68633541906575, 2.29276534646625, -1.77484230241921, 0.833833598990455, -1.43732646024023, 0.45261585855298, 0.600817408390124, 0.016195933614441, 0.0237768551602508, 0.209709532669103, 0.0274350014907247, 0.108032499107373, 0.138400262486122, 0.300490990115211, -1.40089483214038, 10.6985238050314, 0.50901485261786, -6.36510458102006, 2.56780701234722, 0.562657865160177, -2.50279380839421, -2.29276534646625, 0.788132828347221, 1.77484230241922, -0.833833598990458, -0.209877236827697, 3.94012026863444, -1.2407486869002, -0.953598036722604},
    {0.280175037546944, -0.29225314423085, -0.149034415307039, 0.0772432851100513, 0.054250729917268, 0.0737033512859886, 0.0719510337707433, 2.01851727120317, -2.4725941148571, 1.36745392578013, -0.420094720418822, -0.0212736261480488, -0.0146572464253257, 0.4681036996761, -0.0727845062071863, -0.056050503171694, -0.0873966756338493, 0.14903441530704, -1.3504061485995, 2.55462266569428, -2.28384511302603, -0.0719510337707422, 0.903868482180903, -1.07636344079228, 0.641739801495365, 0.946657680582994, -0.385364038074109, -0.396403837481658, 0.127859732194452, 0.137167928422058, 0.0101533905237961, 0.00799937673617874, -0.135368155167632, -0.136777954009435, 2.37224345552585, -6.25172441146413, 0.265327841822856, 0.14841630578273, 6.16969586062695, -2.5377075384892, 0.409554573439293, -1.0710928998984, -0.903868482180907, 0.436018947000106, 1.07636344079228, -0.641739801495365, -1.00227026048928, 0.124435219315414, -0.0506549089259943, 0.989119524531642},
    {0.288734078223698, 0.165069823211548, -0.120198635080438, 0.24209313321224, -0.0757646835227046, -0.0476672211627498, -0.111229861949399, 0.863507355329661, 2.00510574498646, -0.884393010259583, -0.904728177143187, 0.878544528095456, -0.141823381927353, -0.285796870460163, -0.0476133273786133, -0.0304504164558671, -0.0293866978957171, 0.120198635080438, -0.883393092814752, 0.805867617127966, -0.104817635449233, 0.111229861949399, 0.0723501695037502, -0.376585297630882, 0.376340926390079, 1.2425706176554, -0.871116176856912, 0.388618535849047, 0.164484460083806, 0.120699783655139, -0.212706435316524, -0.195258847106305, -0.0144846836765686, 0.126054935563863, 3.05175974697095, -3.19430925297859, -0.758689719880427, -3.62273183457821, 0.383335890864163, 2.3387581906816, 0.156188816594587, -0.150830578590275, -0.0723501695037493, 0.105741239256558, 0.376585297630881, -0.376340926390078, -0.619103400429402, -1.09174003906513, 0.765374937600356, 0.0742960479857667},
    {0.0751681159726953, -0.298712767052989, -0.0793175468753258, 0.289572373956807, -0.3697329961386, 0.156600961026922, 0.105639734313318, -0.684381542040877, 2.5925778588714, 2.90549337582054, -0.356056127547302, 0.678813641770076, -0.682218241807497, 0.583005378665017, -0.00340259784931779, 0.00173356112842173, 0.0102837650967017, 0.0793175468753248, -0.0631300436915677, -0.0121557779410535, -0.0243048703807532, -0.105639734313318, -0.0186449718788731, -0.0399213803071121, 0.146367966089887, 0.230058238667534, -0.608722927309697, 1.07698427728428, 0.0114536190613369, -0.0304422526078252, -0.299856139053511, 0.0017566043143375, 0.398441687618, -0.166408586553278, 0.212504534414404, 0.213461906049628, 0.708686412421628, 0.0325911294909383, -2.79388398697997, -3.08745899603431, -0.005049638789388, 0.00817020233211562, 0.0186449718788783, -0.0216179586052803, 0.0399213803071108, -0.146367966089884, 0.0886743346310256, -0.238228440999659, 0.63034088591498, -1.16060897312591},
    {-0.42423122731964, 2.37732743172645, -0.0350775308878964, 0.177387214604184, -0.369081269115165, 0.43168325708708, -0.183157792112606, 1.12298042833033, -3.17517288093745, 8.00922826842385, 2.36998528060682, -5.50913044526487, 6.95309529795391, -5.76704633770267, 0.017552705480961, 0.0130848449412192, 0.0158235923115259, 0.0350775308879005, 0.325663834808275, 0.11256774126797, 0.100173986672979, 0.183157792112614, 0.00886583700110616, 0.00890004265004002, 0.0259833615404748, -0.0688864602201638, -0.148564130055563, 0.418443482820288, -0.108514916661504, -0.0975653754066794, -0.193210806915728, 0.305577024167777, 0.453561799580641, -0.646298070074316, -2.01332973610307, -0.839346127893039, -1.22315441500334, 5.66951833309536, 3.90195126756256, -11.9910807002244, -0.0148348576520396, -0.00614492574754349, -0.00886583700110266, -0.0132524671034698, -0.00890004265004063, -0.0259833615404835, 0.110614108338987, 0.0750313859677042, 0.161816597159052, -0.514222733507244},
    {0.28628929987628, 0.401957822762747, -0.0187732230697985, -0.0120162719057336, -0.0185107978054523, -0.540385364807994, -0.0264986033169902, -1.57010859806942, 2.58257674051622, -1.68358443609695, -0.123361535331789, -0.0862905559009789, -0.127419484111296, -0.351175547294965, -0.426181230376304, -0.0169904654544728, -0.0144499961342074, 0.0187732230697971, -1.32777853203544, 2.37046405856914, -1.88811166644526, 0.0264986033169909, 4.58800099348717, -0.310830665698193, 0.109394347489005, -4.60394317871658, 0.102809484222618, 2.49606774705447, 0.216995319114419, 0.0122055895567053, 0.0264662680399466, 0.208883697082413, 0.0232956737032166, 0.540687578987467, 0.676054471047215, -1.70289103823298, 3.45822026451468, 0.650782504976416, -3.25014976085238, 1.68452599210876, 2.29106023814169, -5.5364061046951, -4.58800099348717, 0.123632076673317, 0.310830665698197, -0.109394347489006, -1.64584901993342, 10.1403492834117, -0.226441560895933, -3.14127896526274},
    {0.301946133397289, -0.292253144230849, -0.0798554220922585, 0.0537913438739438, 0.0586818441400087, 0.366598967637805, -0.203731558094385, 0.664555618073867, -1.55914251884141, 1.14214846736924, -0.480500267770765, 0.0280496114199435, 0.0422441254492211, 0.400513541735158, -0.35570495082136, -0.0516705383728239, -0.0387727778774356, 0.0798554220922588, -1.10820787912762, 1.37285619648022, -0.479011407990876, 0.203731558094384, 1.48015810946035, -0.734158937329557, 0.373267770898266, 2.96913502969362, -0.34816027029491, -1.6468411529516, 0.644860981246373, 0.118810049508951, -0.0150185659965088, -0.072881145665197, -0.125821355276134, -0.582873852397622, 2.00908089333315, -3.15671401554952, -0.185544210082991, -0.227063074830754, 3.34300033791071, -1.81595840674401, 1.45007659923757, -2.14015127162839, -1.48015810946035, 0.250953775342113, 0.734158937329557, -0.373267770898266, -3.33427283656475, -0.828983758065236, 0.0972064949527964, 3.53103739027879},
    {0.236643324868562, 0.165069823211548, -0.166654346797131, 0.403271313827145, -0.169838959850655, -0.23709578687435, 0.0456413589580969, -0.236675210548304, 1.17861774815033, -0.738677992857268, -0.748859680437834, 0.758760325737396, -0.169530471228791, -0.242083322150882, -0.176564788258322, -0.0429718172322195, -0.0179653491069812, 0.166654346797131, -0.550092117280208, 0.298208058414283, 0.0105436529618649, -0.0456413589580974, -0.0986348266925839, -0.49621462919589, 0.523607872420551, 3.63296134668653, -1.6310093310232, 1.6144974824207, 0.600769240145068, 0.148760563135817, -0.385305964720165, -0.718560478588002, 0.0640502139470596, 0.531451813575606, 1.87171194533259, -1.03234169645694, 0.226131557586439, -2.23869356375886, -0.444484110107673, 1.65575172856375, 0.408492202245386, -0.16184493329314, 0.0986348266925852, 0.0726598967590726, 0.496214629195888, -0.52360787242055, -1.41412520941867, -3.47111641339339, 1.55834943426412, -0.608864475247417},
    {-0.0291979345553113, -0.298712767052988, -0.207912100848699, 0.84227326250172, -1.26534612149435, 0.778929989503395, 0.0490770986832658, -0.280155127361666, 0.790509415439255, 2.42677632027106, 0.0988531245289105, -0.0708151052579171, -0.139520723400706, 0.439393405738012, 0.0348293501727641, 0.0301467242859983, 0.0509554216513401, 0.207912100848699, 0.108511731976809, -0.0188337949497877, -0.0169486831388869, -0.0490770986832648, -0.037963480514114, -0.0416583357847465, 0.355591838748825, 0.348912904231793, -1.74000560260787, 4.47428067341981, -0.187520565061737, -0.231367367035398, -0.893228684153061, 0.466253501958233, 1.46656676424375, -1.09249227657266, -0.584225120342075, 0.144543914870401, 0.297103810500549, 1.45262471986356, -0.916219535359866, -3.40368765176936, -0.106599217043049, 0.0211083563330962, 0.0379634805141158, -0.105265978517746, 0.0416583357847462, -0.355591838748824, 0.818118079473735, -0.37002126056489, 1.84527158112561, -5.18579953585049},
    {-0.504539511638752, 2.37732743172645, -0.138407634889359, 0.728837230454803, -1.61290224291863, 2.14718372548065, -0.202507479822817, 1.19732501931376, -3.18621932714504, 6.68960585737613, 2.79289201598288, -6.40683631575309, 7.90408077473104, -6.16292439504852, 0.101360282467522, 0.0644327702181865, 0.0702918079193729, 0.138407634889364, 0.31579055450799, 0.127284178983569, 0.115474534996166, 0.202507479822826, 0.0470179418813998, 0.0390289097275186, 0.0891689042881653, -0.343831895786027, -0.542262864258254, 1.73840382593346, -0.616016272770804, -0.46570667905903, -0.799129038374193, 1.6850211050968, 2.01417615175949, -3.31754884027418, -1.91921446575058, -0.919983606020193, -1.31279955430996, 5.2497263837703, 3.9789187541817, -10.3359083299039, -0.069446350362848, -0.0331604431898447, -0.0470179418814018, -0.0522978732473264, -0.0390289097275177, -0.0891689042881749, 0.501943794915819, 0.376992338975875, 0.594560737505596, -2.17090127048645},
    {0.27076488372056, 0.401957822762747, -0.0496222433554896, -0.0732932595554683, 1.03279003696237, -1.19524818143039, -0.0374957547900419, -0.0537292493666606, 0.994541200829974, -1.17984126324549, -0.22030445746123, -0.12226740525594, -0.130094940242105, -0.200055903524032, -0.748639448326539, 0.569729765621711, -0.028244883228689, 0.049622243355489, -0.738989379905981, 0.548630123230591, -0.0207055380471621, 0.0374957547900425, 0.347263467681677, 6.67852114450611, 0.467603604449734, -3.92151618722594, -4.01983994813107, 3.86900739911033, 0.743509478898012, -0.817642860136121, 0.101538142784161, 0.500022267596709, -0.784876942447963, 0.700355883262203, 0.733925536509272, -0.787361886605281, 0.0744347874138205, 0.493576909814804, -0.755809437455284, 0.691328196827394, 2.13430474713624, -1.51122719141428, -0.347263467681673, -1.54911803106602, -6.67852114450611, -0.46760360444973, -3.06302942755019, 5.43274337864021, 5.56895797919709, -2.94028271869636},
    {0.21585406400914, -0.292253144230849, 0.0690671693240333, -0.0852935608097443, -0.578626286337773, 0.810859764011252, 0.0758000408564926, -0.0918082993071573, -0.554715564231823, 0.800407666917412, -0.410360586208544, 0.0945108881756204, 0.0942552324410909, 0.29799354581354, -0.466264044152152, 0.216276179301877, 0.00835316550663074, -0.0690671693240327, -0.460253834647198, 0.207338943397586, 0.00899118188658717, -0.0758000408564926, -0.452286089217332, 2.57554434643088, -0.41477543075226, 2.33651728470643, 2.40581537051747, -2.55267134213329, 1.01241087371511, -0.57015022065778, 0.0769403953031125, -0.394738708432765, 0.932500327693679, -0.962267885141451, 0.999360754297939, -0.546589757183027, 0.0828171174205701, -0.389650470625988, 0.893966378017264, -0.949864115942165, 0.954125344674892, -0.228825193871241, 0.452286089217334, -0.235611853668027, -2.57554434643088, 0.41477543075226, -2.51527827779067, -2.10769209083519, -2.17020351684944, 4.11382427524907},
    {0.0617978275970901, 0.165069823211548, 0.103341901603271, -0.360080603668167, 0.318850804445175, -0.524418917575722, 0.100320494542055, -0.345972012830993, 0.298611742339422, -0.517659083523491, -0.262685088938024, 0.389530128180398, -0.177933589267733, -0.17577910078328, -0.037382758917167, -0.0179101852435314, -0.0259244663684317, -0.103341901603271, -0.0369008898651071, -0.0167733358255098, -0.0249087002179127, -0.100320494542055, -0.318913566915097, 0.236022640306723, -0.327640246547996, 2.03586602632961, 2.14583003578395, 2.50253732604094, 0.219336145911, 0.0941534701790938, 0.386005070036599, -0.512486222993823, -0.395094089380736, 0.854951753575711, 0.216508871954392, 0.0881770765057482, 0.370880713048906, -0.505880203063215, -0.370015483019662, 0.843931304497421, -0.140570155268194, 0.146574794067085, 0.318913566915098, 0.154491794415886, -0.236022640306721, 0.327640246547995, 0.738974373639942, -2.1824408203967, -2.30032183019984, -3.10094154441269},
    {-0.236409154506207, -0.298712767052988, -0.0876613998747684, 0.425969859867174, -0.874047802450548, 1.72287170239395, -0.0922286345676668, 0.446069662039889, -0.907479821538976, 1.70066364236571, 0.967488301382424, -1.43074659915474, 0.7768158485787, 0.22156437075281, 0.290609395595097, 0.0495856947412165, 0.0419123438517434, 0.0876613998747688, 0.286863399364977, 0.051482330015, 0.0438900185639372, 0.0922286345676684, 0.13369791878181, 0.0330337359671332, 0.126027789841482, -0.88593421531906, -0.842296841842022, 6.93531858323389, -1.36591819250656, -0.296465798410204, -0.467882203718917, 2.65716806553408, 1.12092790611954, -3.30473097101658, -1.34831131372927, -0.307805510270048, -0.48995968060383, 2.62291679318309, 1.16380300179403, -3.26213252118449, -0.393448263627173, -0.0871694994431199, -0.133697918781811, -0.0828758984767818, -0.0330337359671321, -0.126027789841483, 2.352371066254, 0.973103714762183, 0.925172740318801, -8.89424138586073},
    {-0.636880676372845, 2.37732743172645, -0.204926878310815, 1.15124252490879, -2.81967943501396, 4.74923565701962, -0.204379670271952, 1.14636582665052, -2.80070023797626, 4.68801733738918, 3.48050625171772, -7.8402932089177, 9.38272800844692, -6.76338780660053, 0.274486407165846, 0.132644959235415, 0.123672746018741, 0.204926878310821, 0.270948238537963, 0.131752129083819, 0.123148864515019, 0.204379670271963, 0.0995701821042721, 0.0599748362772036, 0.0987048250007563, -0.668484952008171, -0.664339741818154, 2.69459724124685, -1.63018076695783, -0.919244708789836, -1.27491527092754, 4.28949628167934, 3.60627918456841, -7.68303757890699, -1.60916750620301, -0.913057293923675, -1.26951469116556, 4.23420406764964, 3.58200540281614, -7.58400213737379, -0.126760771732628, -0.0718122966258603, -0.0995701821042815, -0.0713669955568658, -0.0599748362772008, -0.0987048250007658, 0.878466617721494, 0.740297248634041, 0.735706737375033, -3.44630308723574},
    {-0.0276979469831499, 0.401957822762748, 0.798848493973309, -2.9271659390857, 3.46950926213077, -1.89794570036166, 0.0500625320267808, 0.0350431744303269, 0.0648495746372431, -0.639301979663909, -0.190070737363148, -0.0830134244805961, -0.0632780457615061, -0.0378976681743478, 0.316239485215844, -1.02157796980729, 1.43867237804988, -0.798848493973308, 0.106521766617378, -0.0190946015114821, -0.0172233649001309, -0.0500625320267803, -0.359647840141068, 1.4629203095634, 10.1191404810675, -0.406035546927826, -7.3172390191668, 3.32895343446046, 0.891573267377429, -1.6672598671303, 1.48849356103582, 0.422416661261316, -0.780671425193174, 0.267716286507062, 0.300316576360007, -0.0311632236792825, -0.0178198095301961, 0.142286371910387, -0.0145917494464781, 0.0901772647761384, -0.980192077386341, 0.199562354177258, 0.359647840141067, 3.59634878224641, -1.4629203095634, -10.1191404810675, -1.59971628304946, 0.206473192750568, 3.72089023692039, -0.749045074024652},
    {-0.119570063807635, -0.292253144230848, -0.123511007815445, 1.44142868628427, -2.12588434718251, 1.28757175841062, -0.0134898570388152, 0.00975677053316337, 0.0121888713050497, 0.433704280346059, -0.0125784288977869, 0.132329389481232, 0.104087309469517, 0.187984937985519, 0.617280042826308, -1.14568614271631, 0.822231856537402, 0.123511007815446, 0.207923942877124, 0.00656885261329251, 0.00556553898616608, 0.0134898570388152, 0.0763243423373376, -0.207923533558818, 3.79815257401814, -0.0815244410540327, 4.78945655955073, -2.1963576584003, -0.216750817101649, 1.0603862842334, -2.26366054282168, -0.717210537085401, 2.21118420566543, -0.970890447049884, -0.0730101111114225, -0.00607978132455333, -0.0153223095193295, -0.241584422624497, -0.0126779425937888, -0.327033689487264, -1.18366577044185, -0.0465038563189912, -0.0763243423373388, 2.73204203318317, 0.207923533558822, -3.79815257401814, 1.09553821181538, 0.128028297373027, -7.5214985927339, 2.28448521702676},
    {-0.291832089112705, 0.165069823211547, -0.0529350629556789, 0.349373284618036, 1.68967763895773, -0.832729675112349, -0.124807634069926, 0.316622207129775, -0.144817183690855, -0.280495764300718, 0.666751249076133, -0.293482001642876, -0.141875319062682, -0.104631662469419, 0.915563581070019, -0.84429604548771, 0.0688456508519473, 0.052935062955679, 0.308397447711335, 0.0723620723206561, 0.0623918968156411, 0.124807634069925, 0.463445949019275, -0.606573202417977, 0.172254143431232, -1.56779076736319, 6.16160889113368, 2.1532215803736, -2.40331610080073, 2.81121530476935, -0.418218935469982, 1.50905861273622, -3.65659689823937, 0.811423582106838, -0.809530399477325, -0.240940800658547, -0.379014103945416, 0.508309673120412, 0.313395912028746, 0.273319042946295, -1.07591911229269, -0.308940553072914, -0.463445949019276, 1.2141740455886, 0.606573202417982, -0.172254143431237, 3.58244041451583, 1.87673132043611, -7.37578293672228, -4.65974288259675},
    {-0.53338096528945, -0.29871276705299, 0.0905706902337689, -0.559977693850786, 1.89158620077829, 2.73576399498904, -0.206188382357, 0.85681481510209, -1.34146568604206, 0.921511789065655, 2.1621514755341, -3.20288580537901, 1.88500413072955, -0.0121760685422076, 0.917081389878046, -0.183944330128652, -0.077868296945437, -0.090570690233771, 0.308908704790784, 0.130448724413434, 0.119145300218687, 0.206188382357002, 0.407788166161163, -0.105679618375739, -0.0897719471368904, -2.07955187073495, 0.987730791336994, 5.96725470776894, -4.0749835250867, 0.96877114216212, 0.63784599079623, 7.18333868826709, -2.67641301281176, -6.76120054804748, -1.37261304903997, -0.687028296306859, -0.975960115320782, 2.4196280447488, 1.89804525793549, -2.27743548956527, -0.580276314912837, -0.289174308837695, -0.407788166161166, 0.137349961269124, 0.105679618375742, 0.0897719471368899, 3.05611457539659, 2.36872617957265, -1.12508075260612, -8.4430929682527},
    {-0.793676417832496, 2.37732743172645, -0.191346895929756, 1.15800142154501, -3.20320459390345, 7.54135545678689, -0.1547694424768, 0.822782425516261, -1.84772446633698, 2.54022202634901, 4.28222680270068, -9.47608365189893, 11.0179181306319, -7.40771229532762, 0.528433634244654, 0.176251820768424, 0.13804453175075, 0.191346895929762, 0.177997014576981, 0.101668436068697, 0.0980833119458604, 0.154769442476813, 0.113479331449996, 0.0449494719388092, 0.0537976271188627, -0.700306098461278, -0.408938164661912, 2.31847288345818, -3.06990022630242, -1.17356944769905, -1.29604595329578, 7.7881560069817, 4.2005222208341, -12.7880448717109, -1.03406187630752, -0.676957377491975, -0.920865737462146, 2.62335405709763, 2.42301340776027, -4.30751122171609, -0.12757070462792, -0.0834829954831167, -0.113479331450012, -0.0487492298415756, -0.0449494719388047, -0.0537976271188703, 0.849427147589467, 0.783789093944405, 0.457687394503499, -3.04032932641976},
    {-0.593196374839003, 0.401957822762749, 9.65546182492156, -9.34793058151144, 6.39444256476642, -2.46012846883514, -0.208059837648133, -0.103347499349385, -0.101728226296677, -0.206851511680582, 0.0255453288852376, 0.0317342991905251, 0.042124291684722, 0.0918346323157739, 3.44202984442011, -8.37095104150299, 11.1521476124679, -9.65546182492156, 0.289411339931008, 0.133172202775038, 0.123294301136933, 0.208059837648135, 1.37482680900671, -4.22950603911583, 10.4559719759119, 0.82560516292208, -4.36349548624232, 1.39615737113776, -0.193907244267736, 0.678637160839817, -1.80421703095647, -0.259373195247077, 1.29787131589677, -0.528620936070189, -0.0163040292857685, -0.01079633665829, -0.0199468017875398, -0.0218085104928158, -0.0206476398200774, -0.0444472884718411, -1.82770661893569, -0.984952826322092, -1.37482680900672, 5.20568112317356, 4.22950603911584, -10.455971975912, 0.148173083867404, 0.159347663400015, -0.842185636931251, 0.283376163930528},
    {-0.645727750172865, -0.292253144230846, 2.64740738044187, 5.36350609164481, -4.00733663545901, 1.6689581466585, -0.203105697019894, 0.111094810499241, 0.0849052665399499, 0.140328653540351, 0.640545865989451, 0.119780474987422, 0.0776803768834955, 0.0999741765433427, 3.17302984920507, -6.18782608077739, 5.92743640487679, -2.64740738044187, 0.266793392796453, 0.131104289577873, 0.122775552575937, 0.203105697019896, 1.12648329478582, -2.73017809443477, 4.57278385554715, -0.736093480810341, 2.92115822272212, -0.921148641698382, -3.43496893299548, 7.85911434065093, -11.2909424965216, -0.726267415706966, 2.33604837558547, -0.680751647161137, -0.28881764727611, -0.166514635171013, -0.233870363075177, -0.0610657186104105, -0.0494949209468144, -0.0572386804502862, -1.42236804837863, -0.813487897840635, -1.12648329478582, 3.22829494325387, 2.73017809443478, -4.57278385554715, 1.80653964425773, 1.54958137865098, -6.14945316597599, 0.536977045819282},
    {-0.731477026246279, 0.165069823211547, -0.187994765484737, 4.35942248656922, 3.41733871056418, -1.07938914174275, -0.181363947469797, 0.379770084033711, -0.126228199455135, -0.0907567545717627, 1.77555767996503, -1.08201166468953, -0.0794276066728022, -0.0477112055679702, 2.61204358754973, -3.20475026135102, 1.29520993109275, 0.187994765484732, 0.219624776309364, 0.118375698008266, 0.11283191429319, 0.181363947469799, 0.720530671443427, -1.06931012574518, 0.695443086724865, -1.77132558696221, 4.03209677596859, 0.903057444424356, -6.85440789994669, 9.71163878395078, -5.65463241766196, 4.83635733825998, -9.92422723316395, 0.485396115879722, -0.576329510324553, -0.358724370419335, -0.492601998326903, 0.406648611696359, 0.366576871866201, 0.0408128768905911, -0.84687934856656, -0.526271197274495, -0.72053067144343, 1.19795954703889, 1.06931012574518, -0.69544308672487, 2.56637355679592, 2.29759678423671, -5.23005632300749, -2.62255165265372},
    {-0.834219465627166, -0.298712767052992, 0.10585218739796, -0.836801817303565, 5.85275550665803, 3.54611350936128, -0.132465689012752, 0.49472559993511, -0.654005554827593, 0.298162859905295, 3.33250949856371, -4.86511009898616, 2.86470948685668, -0.19917665375407, 1.75675341289619, -0.78153439164486, -0.143585284844442, -0.105852187397969, 0.147710619063581, 0.0873311439104332, 0.0848890558285627, 0.132465689012756, 0.305201060714209, -0.159414327099098, -0.0434055418318099, -1.31415208952574, 0.988838774057057, 2.50265640830706, -7.54124013778058, 3.83004239932454, 0.980387102148031, 12.571887446701, -8.90126351433773, -10.3335142311779, -0.634079456502825, -0.427981145211686, -0.579614655763678, 1.05706427772834, 0.994655556128845, -0.868858300194383, -0.334186529975023, -0.225492940146221, -0.305201060714213, 0.169673026638169, 0.159414327099101, 0.0434055418318112, 1.63773800970379, 1.53964502967196, -1.15851180069523, -3.80620788803584},
    {-0.930688141770985, 2.37732743172644, -0.142219700439311, 0.917394780947759, -2.83066387967162, 9.77514965223254, -0.0634805252678612, 0.323944096787989, -0.683309560252382, 0.821910118956342, 4.97286168481874, -10.8586127019987, 12.3623063106051, -7.92319458338059, 0.787796917156006, 0.174605118508019, 0.118010714500011, 0.142219700439315, 0.066239216884541, 0.0421488922094669, 0.0416711268844668, 0.063480525267876, 0.0579129697042071, 0.0146895504843715, 0.0137899579800116, -0.335692933580037, -0.116926760583246, 0.972363558022487, -4.50296915892157, -1.12926586459901, -1.03540549544778, 11.1258052383664, 3.78532462576263, -17.1857826488334, -0.378616803704935, -0.272599713052741, -0.365615223672477, 0.935475387311569, 0.913760381095669, -1.44500791944752, -0.0599787404999236, -0.0431824594679572, -0.0579129697042282, -0.0150410824730729, -0.0146895504843658, -0.0137899579800165, 0.387914998294285, 0.378875393048005, 0.131967843056328, -1.30029981581688},
    {-0.284218581943478, 0.401957822762753, -0.164167775300461, -0.0765004719955932, -0.0680662120055055, -0.108642456439209, 10.7781211235609, -9.94863282337192, 6.61942715210139, -2.49746884647899, -0.102836083183828, -0.0327899728859481, -0.0130791394677893, 0.0309659547182797, 0.0811284959085221, 0.0541568301345102, 0.0660860422357746, 0.164167775300464, 1.86497892015752, -5.26674221029166, 8.59427075157848, -10.7781211235609, 5.84457871350631, -2.92952679968409, 1.03312870189976, -2.37242845712515, 0.560795864993026, 0.744419162240975, 0.0253897324335961, 0.014056889203665, 0.0104144297598112, 0.00732571946182968, -0.000147507332667325, -0.00520149136473287, 0.583658247904262, -1.36703000398038, 1.35436207179343, 0.168403373171353, 0.0143450621706727, -0.119571694754148, -0.592296543769654, 2.04945673051513, -5.84457871350636, -0.484451641314281, 2.92952679968409, -1.03312870189976, -0.153735860662492, 0.322971726610072, -0.0763442236787274, 0.00161324219114318},
    {-0.365495227282886, -0.29225314423085, -0.149034415307038, 0.0772432851100514, 0.0542507299172676, 0.0737033512859876, 3.05411065485142, 5.7400262676936, -4.15256468707763, 1.69428996499951, 0.29118085653124, 0.131435959729924, 0.0938638947958556, 0.141267660456715, 0.0857805129140837, 0.0565322542722111, 0.0659859656207843, 0.149034415307038, 1.97191931828046, -4.32720155341021, 4.90348352510902, -3.05411065485142, 2.57031678860303, -1.80768399788645, 0.795122442750004, 1.58985141617833, -0.477470143798936, -0.491148572738426, -0.0797111483590209, -0.0675209347466698, -0.14322925073084, -0.0377394970883975, -0.0432620494428049, -0.0420332187526604, -1.83239698611845, 5.1683184667749, -10.6435097928026, -0.867554189671689, 3.31144777371295, -0.966258107489825, -0.511803915667494, 1.35814887650926, -2.57031678860304, -0.407884367537965, 1.80768399788645, -0.79512244275, 0.611287825645025, -2.94800029268758, 0.885354511336897, 0.391664662760889},
    {-0.505828786742263, 0.165069823211549, -0.120198635080435, 0.242093133212241, -0.0757646835227066, -0.0476672211627503, -0.171838342059682, 4.78332720332143, 3.55195396645563, -1.0957723504605, 1.21123522802955, -0.68361226127244, -0.112446472967149, -0.0744175302592496, 0.0836574821649646, 0.0547790077565367, 0.0605627881224807, 0.120198635080435, 1.92311516445491, -2.56811623612245, 1.19661234538719, 0.171838342059683, 0.400777748812662, -0.667103789899068, 0.466290412408277, 2.2011575424478, -1.07932221259697, 0.481502501172913, -0.220756563471539, -0.172735676297314, -0.302655921334724, 0.151595332229323, 0.193721352063484, 0.0331709702400014, -5.0747438708223, 8.0980892685804, -5.97993954870862, 3.48486799657565, -9.08192699891358, 0.762533060252246, -0.348133563293233, 0.550648571062886, -0.400777748812659, -0.270006677224032, 0.667103789899069, -0.466290412408275, 1.09777611826255, -2.75180611351069, 1.349328889821, -1.23114505614223},
    {-0.685613082674016, -0.298712767052989, -0.0793175468753246, 0.289572373956809, -0.369732996138604, 0.156600961026924, 0.101751927918441, -0.81955412325537, 6.17090549740159, 3.5999372097432, 2.75853623958354, -4.05750949342543, 2.39473755882654, -0.111438455257646, 0.0653263317252925, 0.0429174987338455, 0.0452672664809414, 0.0793175468753237, 1.50171934330263, -0.716300226480569, -0.128116416583606, -0.10175192791844, -0.0223275507047495, -0.0950216651577118, 0.18135146747413, 0.547589205415066, -0.754214184304307, 1.33439497965097, -0.284820735267653, -0.217117447207829, -0.334839640437754, 0.486712731435398, 0.543932944612586, -0.423819288919962, -6.5474487274712, 3.62372647978193, 0.947670539838976, 11.1885346096239, -9.07833175070295, -9.74274243519853, -0.154892572336583, 0.0856016274788258, 0.0223275507047581, -0.117902181061305, 0.0950216651577108, -0.181351467474126, 0.783593659680124, -0.633190832893908, 0.872116365365609, -1.9630960669945},
    {-0.865091413021983, 2.37732743172645, -0.0350775308878952, 0.177387214604185, -0.369081269115168, 0.43168325708708, -0.138221459026588, 0.895522618696922, -2.7845317577215, 9.92351905007648, 4.64328199706194, -10.2017134115417, 11.7275325151306, -7.6813371193553, 0.032625425184186, 0.0216017065295033, 0.022033892206385, 0.0350775308878989, 0.749992090304514, 0.162973965047241, 0.111236026185825, 0.138221459026598, 0.00707007652837858, 0.00780507151371251, 0.0321936614353344, -0.0604113676177025, -0.184072537996827, 0.518455927834941, -0.187884183074891, -0.141590644936206, -0.199421106810585, 0.469886015892578, 0.489070207521885, -0.746310515088956, -4.31907478305556, -1.06822990060222, -1.00675864488279, 10.8017226832916, 3.68978769327652, -17.1561590406171, -0.0303443543163565, -0.00750390925917506, -0.00707007652837247, -0.022864299828085, -0.00780507151370989, -0.0321936614353446, 0.198895244315926, 0.0679152768768668, 0.206936837824929, -0.687006817834513},
    {-0.377854821367116, 0.401957822762748, -0.0187732230697969, -0.0120162719057354, -0.0185107978054515, -0.540385364807995, 2.40929939068856, -4.57083758905508, 4.35130301463395, -2.08597903119924, -0.0659543245585445, -0.0135282337283511, 0.00416050908393662, 0.0512190478073246, 0.51265048283498, 0.017754709361146, 0.0116964169713754, 0.0187732230697953, 1.97891768943057, -4.17357053861733, 4.44916882452415, -2.40929939068856, 13.3564056813897, -0.523708895644618, 0.135540760594577, -7.75704029176246, 0.127382044938574, 3.09265449903964, 0.0762655524189261, 0.0020329754570461, 0.000319854934364803, 0.00736850255179824, -0.00127688701274183, -0.0558991729977043, 0.294397949147326, -0.477888221128139, 0.121668764530921, 0.0284436678255324, 0.300155745111528, -0.2157802752042, -2.966332535313, 7.55055964345081, -13.3564056813897, -0.123991328088731, 0.523708895644624, -0.135540760594584, -0.339655306040403, 0.206480648311653, -0.00339071684983831, 0.213333342313759},
    {-0.451804425814345, -0.292253144230848, -0.0798554220922583, 0.0537913438739426, 0.0586818441400102, 0.366598967637805, 0.261459115366239, 2.41943234803004, -2.6914997436203, 1.4151341045727, 0.398538471660799, 0.128767605110292, 0.0892235887423979, 0.1275279045317, 0.511383406553645, 0.0706022831938985, 0.0504421912770377, 0.0798554220922588, 1.97402656038467, -3.23824225193071, 2.26879383358003, -0.261459115366242, 5.38877757230742, -1.26735597786622, 0.462482740052738, 5.12552641892727, -0.431374279638459, -2.04045371240008, -0.508966082266048, -0.0866767814013167, -0.104233535150982, -0.179754998976263, -0.0426073459325872, -0.189261292949139, -1.9646952792214, 3.97551471563992, -4.68822618161007, -0.69388474047767, 1.9542272799111, -0.73058064525829, -2.45494484636851, 4.80640127944977, -5.38877757230742, -0.404516086761276, 1.26735597786622, -0.462482740052738, 3.0138787044124, -9.93192769837703, 0.835890366399732, 1.48151985435619},
    {-0.576948661244748, 0.165069823211549, -0.166654346797131, 0.403271313827145, -0.169838959850655, -0.237095786874349, -0.143420606214597, 1.24431233374446, 2.20510501981535, -0.915229893358239, 1.3900702117453, -0.810470103908833, -0.102189848153355, -0.0655314216499119, 0.466402264732032, 0.134626102632259, 0.107182504067226, 0.166654346797131, 1.80039173466613, -1.74791870471658, 0.330716585087005, 0.143420606214597, 0.518569439976399, -0.92838019066221, 0.648755725594756, 6.79699700343545, -2.02083791656576, 2.00037956044612, -1.22924364026096, -0.418665942271219, -0.51045381789437, 0.854367426853088, 0.453878799489617, 0.145569735550185, -4.74508864378751, 5.43575144207063, -1.57502891883146, 3.29800296865633, -5.8929377571694, 0.561923833823297, -1.58563915043343, 1.80652363306431, -0.518569439976398, -0.537103584571727, 0.928380190662207, -0.648755725594754, 4.93108762742474, -8.60352063649975, 2.55794150113748, -5.34582803743744},
    {-0.73356085670795, -0.298712767052989, -0.207912100848699, 0.842273262501721, -1.26534612149435, 0.778929989503396, 0.111739981375583, -0.745172378670276, 3.04348347201991, 3.00680168393097, 2.94455441648735, -4.3207394110373, 2.54909057623279, -0.1406319579219, 0.344732873319209, 0.154120270281248, 0.135945654934045, 0.207912100848699, 1.33072727712461, -0.370698963181924, -0.120273255209597, -0.111739981375582, -0.100977402568772, -0.160385763858703, 0.440582072031531, 1.34332448983403, -2.15588545687899, 5.54368136479749, -1.49510845941514, -0.771220767301754, -0.978218917435766, 2.53333856454286, 1.88244661851486, -2.16189296795033, -5.77137187424892, 1.85498467074717, 0.86544563387987, 9.77911592117684, -4.52776917958516, -8.3452730079835, -0.675225265073469, 0.216816959162416, 0.100977402568776, -0.347966952586952, 0.160385763858702, -0.440582072031529, 3.37884008431336, -1.56014144899645, 2.50385240946593, -8.24729618403738},
    {-0.88665764784494, 2.37732743172645, -0.138407634889358, 0.728837230454802, -1.61290224291863, 2.14718372548065, -0.17766209966099, 1.0978800186345, -3.14581523070908, 8.2884928408014, 4.75184955947057, -10.4186655573304, 11.9379575924521, -7.76181137847379, 0.165827532811151, 0.096084089184182, 0.0916041248827799, 0.138407634889363, 0.640122362237701, 0.187403044735945, 0.137987377882091, 0.177662099661001, 0.0431128207263962, 0.0385339884209475, 0.110481221251572, -0.339471801376724, -0.671869458987839, 2.15390083853503, -0.952574072495624, -0.626964592754596, -0.820441355337597, 2.37260866707955, 2.14378274648906, -3.73304585287574, -3.67709725372745, -1.22283589948616, -1.23586739651663, 9.15867129474918, 4.18124808545934, -14.4101892440608, -0.128312550355902, -0.04266661469542, -0.0431128207263967, -0.0844441135198954, -0.038533988420944, -0.110481221251583, 0.837260638699365, 0.382138416072142, 0.756313572507748, -2.86284892687851},
    {-0.53720785237928, 0.401957822762747, -0.0496222433554907, -0.0732932595554681, 1.03279003696237, -1.19524818143039, -0.207274898435277, -0.654589019829707, 1.79774025209256, -1.46183587974912, 0.000986959642850257, 0.0198669010274295, 0.0324574559666504, 0.0819387129796017, 1.53428368653199, -1.26116386310603, 0.0835173539639602, 0.049622243355491, 1.87648973454376, -2.19526230893808, 0.745901372126379, 0.207274898435275, 4.23074685784624, 12.0721457048842, 0.579365841642379, -7.08856253830944, -4.98062447050062, 4.79374133726794, -0.0249604182970943, 0.0524662462220852, -0.0102240944084905, -0.0896970319091245, 0.17590757992158, -0.224378054895387, -0.0305275804699969, 0.0913260966256344, -0.0913123522966713, -0.109703023680693, 0.306195960219885, -0.274423250643949, -5.85374870716354, 8.07738651819153, -4.23074685784623, 5.67540015803982, -12.0721457048842, -0.579365841642381, 0.243524438002672, -0.988823979882103, -0.6947756875392, 0.816482931892953},
    {-0.595832618747914, -0.292253144230848, 0.0690671693240334, -0.0852935608097452, -0.578626286337771, 0.810859764011252, -0.0940416992472922, 0.175758610791812, -1.06039627034465, 0.991713616378836, 0.578196408986784, 0.122433755117546, 0.080768002522315, 0.106687596352114, 1.43723513893443, -0.844120572468692, -0.0907825760323366, -0.0690671693240324, 1.75779551592058, -1.54694373190725, 0.18706944927691, 0.0940416992472907, 0.865860443132105, 4.92341984823268, -0.513911172291228, 4.46649485620537, 2.98083084414263, -3.16278695565622, -1.53102873032068, 1.06526200473796, 0.176076136842079, -0.364913901006485, 0.357484854068512, -0.352152271618522, -1.87250879414106, 1.95220971365372, -0.362828060068719, -0.446304158247798, 0.655130288598176, -0.430696179910561, -4.61398591568055, 4.75393341574705, -0.865860443132104, 3.17266039990435, -4.92341984823268, 0.513911172291225, 5.82275097501291, -9.22042827195242, -6.15349124404698, 1.95402189632384},
    {-0.692328341357121, 0.165069823211548, 0.103341901603271, -0.360080603668168, 0.318850804445174, -0.52441891757572, 0.107893098474519, -0.457954895166256, 0.735753335007531, -0.641385112850755, 1.67827206924226, -1.01371715322553, -0.0852433264151441, -0.0520530714560167, 1.20941104184694, -0.287528119487927, -0.104233971684685, -0.103341901603271, 1.4791576191489, -0.663475738095752, -0.132566034075003, -0.107893098474518, -0.422138276182024, 0.581539236811277, -0.405949751864249, 5.01619663970861, 2.65870624792654, 3.1006703762461, -3.1776259564589, 0.876647616566075, 0.464314575352853, 2.23581512881713, -0.907970301523321, 0.256818703370545, -3.88636243730966, 2.0228784074647, 0.590520929241261, 2.73449048203479, -2.09515600437648, 0.314099448976725, -2.79607236364134, 1.4520584924092, 0.422138276182025, 0.769626325164839, -0.581539236811277, 0.405949751864248, 8.52497549699787, -6.46825513211781, -3.42833257309138, -8.82957350960264},
    {-0.809132783013122, -0.298712767052988, -0.0876613998747692, 0.425969859867175, -0.874047802450548, 1.72287170239395, -0.0086826481133533, 0.0459205252311485, -0.110712783735195, 2.10714034950458, 3.23613307271918, -4.73043712480305, 2.78706193853603, -0.184912336386057, 0.830942854030468, 0.114188356405143, 0.0720343266745753, 0.0876613998747692, 1.01627603113289, 0.014463866589809, 0.007765465182446, 0.0086826481133556, 0.013763497442745, 0.00403012472485673, 0.156149772664314, -0.108084213947459, -1.04361474984949, 8.59293352274685, -3.57580045608791, -0.562386368081589, -0.498004186541747, 5.98433181019301, 1.32224581412699, -4.96234591052952, -4.3733456254056, -0.0712356465750253, -0.0536859904136, 7.31907489371374, 0.167484563720415, -6.0691456489456, -1.12260788587318, -0.0182777569715459, -0.013763497442745, -0.176482171382983, -0.00403012472485674, -0.156149772664314, 5.52892949501758, 0.126361970919009, 1.22009692123246, -12.9992551318913},
    {-0.919863564854668, 2.37732743172645, -0.204926878310814, 1.15124252490879, -2.81967943501396, 4.74923565701962, -0.208038376322074, 1.20141028770933, -3.07625576054692, 5.80850336580873, 4.91860631702006, -10.750820364052, 12.2586240151802, -7.88387383502008, 0.378832364552657, 0.172470869633393, 0.147264249503359, 0.20492687831082, 0.463326990592477, 0.188164831664138, 0.153681592311885, 0.208038376322087, 0.104351192567109, 0.0658756453417974, 0.122296328485373, -0.734255903780697, -0.823124009293948, 3.33863465487904, -2.16797150223983, -1.1178548866636, -1.29850677441216, 5.36697847320671, 3.76506345204419, -8.32707499253917, -2.65151503887258, -1.21957393165063, -1.35509188002125, 6.56402730400779, 4.10766486053345, -10.1843426215364, -0.204213718469119, -0.0939242968133409, -0.104351192567118, -0.105292096890251, -0.0658756453417928, -0.122296328485384, 1.32359339058064, 0.828180200594046, 0.928416106184211, -4.45801432699059},
    {-0.732933512062509, 0.401957822762748, 0.798848493973309, -2.9271659390857, 3.46950926213076, -1.89794570036166, 0.112109676444359, 0.0917403520483107, 0.246381490393369, -0.792101955560179, 0.0888024830339097, 0.0615698311931432, 0.0657010673507867, 0.114902307721922, 3.19425102379766, -5.27695557341787, 3.85725462991614, -0.798848493973307, 1.33311110113324, -0.374734315630512, -0.120890275800025, -0.112109676444359, -0.941530554931676, 5.55803932736951, 12.5377227329338, -1.54264147088666, -9.06613700684976, 4.12460872839962, -0.427300429130754, 0.839219748797325, -0.93008869083044, -0.341065886873171, 0.968226562489774, -0.527939007432083, -0.178332554752059, 0.0595958093362416, 0.0291499237517161, -0.142342826728725, 0.0687570159009027, -0.220333764092278, -6.27333013779858, 2.03280616121708, 0.941530554931678, 11.9468454036631, -5.55803932736951, -12.5377227329338, 0.997678011330331, -0.490164690330418, -2.88070839681334, 1.15104339806864},
    {-0.768918916307803, -0.292253144230847, -0.123511007815445, 1.44142868628427, -2.12588434718251, 1.28757175841062, 0.0718509496285227, -0.058645831274472, -0.0944416092021658, 0.53736421835818, 0.79466767594798, 0.112384563815797, 0.0697948208014763, 0.0843249999733942, 2.85197444483158, -3.71701831994325, 1.73003073753795, 0.123511007815447, 1.19026299568438, -0.165127134989547, -0.0703878670507403, -0.071850949628523, -0.458769065812958, 1.61102965228291, 4.70595145501869, 0.631666313455997, 5.9341876414728, -2.72131051000822, -3.18254296716032, 4.77644954338242, -3.17145942382223, -0.511065640639927, 1.06645312374335, -0.445937595441961, -1.32822477874979, 0.212191966956167, 0.129033698325213, -0.213291714980768, 0.0473767772355469, -0.186110720312, -4.75809562893696, 0.758138192020564, 0.458769065812957, 7.12232739625185, -1.6110296522829, -4.70595145501869, 6.11425657287392, -1.38980450547656, -13.0565150377246, 1.36514956607126},
    {-0.826589347339829, 0.165069823211548, -0.0529350629556796, 0.349373284618037, 1.68967763895773, -0.832729675112348, -0.0498108934157999, 0.136571318347946, -0.0720377011179941, -0.34753723669955, 2.0109332971846, -1.24662728264591, -0.0651963003398137, -0.0375901900705895, 2.24315270037299, -1.72929155552928, 0.110016224073325, 0.0529350629556795, 0.936173063458539, 0.0737266004774331, 0.0430057517929108, 0.0498108934157987, 0.199902037239714, -0.301733108933051, 0.213424716652609, -0.779880120828443, 7.63429898125734, 2.66786445032589, -5.8673384817935, 5.16890090493458, -0.45938950869136, 4.16013474437831, -5.12928698836303, 0.296780712154545, -2.44871614845278, -0.220370874250243, -0.179577070140856, 1.73621978004322, 0.218681974890805, 0.123860541650571, -2.73041162342132, -0.245581073026806, -0.199902037239714, 2.40400964911509, 0.301733108933057, -0.213424716652616, 8.161276833869, 1.02546119385525, -10.0383086303724, -8.09872966077358},
    {-0.894125141570331, -0.298712767052989, 0.090570690233768, -0.559977693850785, 1.89158620077829, 2.73576399498904, -0.188260025413348, 0.814745478491386, -1.36447231087396, 1.14176291237891, 3.56185382677789, -5.18416669496203, 3.04757796866292, -0.23242719185546, 1.44043934924041, -0.265477095115417, -0.0993247475666125, -0.0905706902337704, 0.601163049702497, 0.191498619152118, 0.144513593792826, 0.18826002541335, 0.387765896090996, -0.10749206230006, -0.111228397758066, -2.11521694231023, 1.22380896082372, 7.39349207996252, -6.14849815317976, 1.28638207663562, 0.659302441417407, 10.1597327291914, -2.9124911822985, -8.18743792024105, -2.56605729550839, -0.927915801062447, -0.959259072284217, 4.24013403609373, 2.1008894927843, -3.41700270266673, -1.03764914299951, -0.375181710183555, -0.387765896090998, 0.217070282331569, 0.107492062300062, 0.111228397758064, 5.02797900063867, 2.49039865249379, -1.44087924315529, -11.3838219376017},
    {-0.956163846795191, 2.37732743172645, -0.191346895929756, 1.15800142154501, -3.20320459390345, 7.54135545678689, -0.175290778787522, 0.94583568565487, -2.17371600504682, 3.14736212092741, 5.10035308667257, -11.11138350932, 12.6047192276222, -8.01485238990602, 0.622379214652023, 0.201459834843233, 0.150902737088021, 0.191346895929762, 0.259748101819735, 0.136711987803173, 0.123254765620603, 0.175290778787536, 0.130451013464848, 0.0528798467260069, 0.0666558324561327, -0.823860160100058, -0.506678737491453, 2.8726125732724, -3.54758433500698, -1.29651803460339, -1.30890415863305, 8.72603422509311, 4.29826279366363, -13.3421845615251, -1.48057370067973, -0.879825786967578, -1.0690904512755, 3.64178425792909, 2.91682980421125, -5.56832077999651, -0.180667839850576, -0.107359758652977, -0.130451013464864, -0.066026869129188, -0.0528798467260014, -0.0666558324561412, 1.16270874947053, 0.931219918753046, 0.572705606620652, -3.85465348289238},
    {-0.909191772905901, 0.40195782276275, 9.65546182492156, -9.34793058151144, 6.39444256476642, -2.46012846883514, -0.203361938358274, -0.104482620171887, -0.108660442219736, -0.25629122406113, 0.171995247860836, 0.0995206497876668, 0.0944437077983329, 0.141274344696321, 5.00241514142447, -11.3487406799524, 13.6512361757966, -9.65546182492156, 0.521141524151654, 0.192848581941365, 0.152581035106715, 0.203361938358276, 1.38992726666713, -4.51772348061061, 12.9550605392406, 0.881865588026476, -5.40641733902905, 1.72985383922849, -1.01446974146355, 2.6135049465025, -4.30330559428512, -0.6654995269649, 2.3407931686835, -0.862317404160911, -0.105685412410927, -0.0444111586513047, -0.0480984149348204, -0.0693303990172052, -0.0397769810703331, -0.0898344886623901, -3.07011321734207, -1.28783106725964, -1.38992726666715, 7.8952533201282, 4.51772348061063, -12.9550605392406, 0.707017307569646, 0.405965479233168, -2.48883598109915, 0.633242070543944},
    {-0.921992874650234, -0.292253144230845, 2.64740738044187, 5.36350609164481, -4.00733663545901, 1.6689581466585, -0.208294305373905, 0.117198629999386, 0.0937303908419435, 0.173868694961456, 0.986441822515249, 0.101770430703843, 0.0595996305397512, 0.0664341351222355, 4.3356542404201, -7.98072916563719, 7.02038040494666, -2.64740738044187, 0.451679717730039, 0.186666839336587, 0.153403194006996, 0.208294305373907, 1.18837503095605, -3.01395508533121, 5.66572785561702, -0.812603651860586, 3.61934612174253, -1.14131296892664, -4.96477260175217, 10.3502053245311, -12.3838864965915, -0.579252465393565, 1.63786047656506, -0.460587319932875, -0.517220000259055, -0.242088169428651, -0.270601824006381, -0.0603453540239103, -0.0383090607498845, -0.0479830584085317, -2.27295845765392, -1.06363014361014, -1.18837503095605, 4.73742103721724, 3.01395508533122, -5.66572785561702, 2.94779916002444, 1.87623379547073, -8.35676715895977, 0.466472266556117},
    {-0.942112680825334, 0.165069823211548, -0.187994765484738, 4.35942248656922, 3.41733871056418, -1.07938914174275, -0.198009063873275, 0.423068842341581, -0.145155176647881, -0.112448584649124, 2.29507780670404, -1.44424604357706, -0.0477695300225872, -0.0260193754906107, 3.26179396758609, -3.84189325821416, 1.46142822896921, 0.187994765484733, 0.339807119497163, 0.163188592583584, 0.141827214705653, 0.198009063873275, 0.802680595062652, -1.22964520498509, 0.861661384601326, -2.03692264950509, 4.99581081061515, 1.11889778299727, -8.4962699578049, 11.3124958154605, -5.82085071553842, 6.04430935465475, -10.8879412678105, 0.269555777306814, -0.885124275022364, -0.480510557336726, -0.564896057047235, 0.6296839627412, 0.462477141401021, 0.0280817774331241, -1.2579045313358, -0.682846470922384, -0.802680595062654, 1.67476746466213, 1.22964520498509, -0.861661384601333, 3.70391335484413, 2.71976912042748, -6.67057827527728, -3.56490660650561},
    {-0.965098624043566, -0.298712767052992, 0.10585218739796, -0.836801817303565, 5.85275550665803, 3.54611350936128, -0.153213077878954, 0.578913035295764, -0.779162211451889, 0.36942695614764, 3.83217939154851, -5.55777503351946, 3.25984778306393, -0.270440749996417, 1.99682203872871, -0.867784465877596, -0.153959671216829, -0.105852187397968, 0.20802489423665, 0.115525902752575, 0.10651179136355, 0.153213077878957, 0.357137112889902, -0.189921352690028, -0.053779928204196, -1.56564059846391, 1.22518176320383, 3.10081792044096, -8.46957559565649, 4.15263546270405, 0.990761488520418, 13.8583157908783, -9.13760650348451, -10.9316757433118, -0.882343310191768, -0.552829624745697, -0.68542482665932, 1.44373139958481, 1.21646593344501, -1.13883993977733, -0.459756369425028, -0.288055674353043, -0.357137112889906, 0.225416075279975, 0.189921352690031, 0.053779928204197, 2.20008617225901, 1.85369627281695, -1.45059783848381, -4.84114772327496},
    {-0.985708641666334, 2.37732743172644, -0.142219700439311, 0.917394780947759, -2.83066387967162, 9.77514965223254, -0.0766373383161812, 0.392884702108768, -0.834522061658287, 1.01835538326078, 5.247864629691, -11.4029461620919, 12.8831025900258, -8.11963984768503, 0.828621425313898, 0.181971301432521, 0.121306661194979, 0.142219700439315, 0.086324109519986, 0.0536478621586489, 0.0519509511468685, 0.0766373383161963, 0.0702377974350387, 0.0179402640737562, 0.0170859046749799, -0.409979861706987, -0.144873500570103, 1.20476879522566, -4.70835536051622, -1.16457878751037, -1.03870144214274, 11.5227721690063, 3.81327136574949, -17.4181878860366, -0.490506969025389, -0.343335249973044, -0.444835653255659, 1.20041917370698, 1.1242094494727, -1.81459169746236, -0.0774494446927662, -0.0542114357021755, -0.0702377974350601, -0.0191565518081904, -0.0179402640737502, -0.0170859046749851, 0.495660467796926, 0.464191297409173, 0.164030052378302, -1.62297981832985}};
    // Array of non-zero columns
    static const unsigned int nzc0[50] = {0, 3, 4, 5, 6, 7, 8, 9, 10, 11, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55};
    
    // Number of operations to compute geometry constants: 36
    const double G0 = det*(Jinv_00*Jinv_20 + Jinv_01*Jinv_21 + Jinv_02*Jinv_22);
    const double G1 = det*(Jinv_00*Jinv_10 + Jinv_01*Jinv_11 + Jinv_02*Jinv_12);
    const double G2 = det*(Jinv_10*Jinv_20 + Jinv_11*Jinv_21 + Jinv_12*Jinv_22);
    const double G3 = det*(Jinv_10*Jinv_10 + Jinv_11*Jinv_11 + Jinv_12*Jinv_12);
    const double G4 = det*(Jinv_20*Jinv_20 + Jinv_21*Jinv_21 + Jinv_22*Jinv_22);
    const double G5 = det*(Jinv_00*Jinv_00 + Jinv_01*Jinv_01 + Jinv_02*Jinv_02);
    
    // Compute element tensor using UFL quadrature representation
    // Optimisations: ('simplify expressions', True), ('ignore zero tables', True), ('non zero columns', True), ('remove zero terms', True), ('ignore ones', True)
    // Total number of operations to compute element tensor: 8551161
    
    // Loop quadrature points for integral
    // Number of operations to compute element tensor for following IP loop = 8551125
    for (unsigned int ip = 0; ip < 125; ip++)
    {
      
      // Number of operations to compute ip constants: 6
      // Number of operations: 1
      const double Gip0 = W125[ip]*G0;
      
      // Number of operations: 1
      const double Gip1 = W125[ip]*G1;
      
      // Number of operations: 1
      const double Gip2 = W125[ip]*G2;
      
      // Number of operations: 1
      const double Gip3 = W125[ip]*G3;
      
      // Number of operations: 1
      const double Gip4 = W125[ip]*G4;
      
      // Number of operations: 1
      const double Gip5 = W125[ip]*G5;
      
      
      // Number of operations for primary indices = 7803
      for (unsigned int j = 0; j < 51; j++)
      {
        for (unsigned int k = 0; k < 51; k++)
        {
          // Number of operations to compute entry = 3
          A[nzc2[j]*56 + nzc2[k]] += FE0_D010[ip][j]*FE0_D010[ip][k]*Gip3;
        }// end loop over 'k'
      }// end loop over 'j'
      
      // Number of operations for primary indices = 15300
      for (unsigned int j = 0; j < 51; j++)
      {
        for (unsigned int k = 0; k < 50; k++)
        {
          // Number of operations to compute entry = 3
          A[nzc2[j]*56 + nzc0[k]] += FE0_D001[ip][k]*FE0_D010[ip][j]*Gip2;
          // Number of operations to compute entry = 3
          A[nzc2[j]*56 + nzc1[k]] += FE0_D010[ip][j]*FE0_D100[ip][k]*Gip1;
        }// end loop over 'k'
      }// end loop over 'j'
      
      // Number of operations for primary indices = 30000
      for (unsigned int j = 0; j < 50; j++)
      {
        for (unsigned int k = 0; k < 50; k++)
        {
          // Number of operations to compute entry = 3
          A[nzc1[j]*56 + nzc0[k]] += FE0_D001[ip][k]*FE0_D100[ip][j]*Gip0;
          // Number of operations to compute entry = 3
          A[nzc0[j]*56 + nzc0[k]] += FE0_D001[ip][j]*FE0_D001[ip][k]*Gip4;
          // Number of operations to compute entry = 3
          A[nzc1[j]*56 + nzc1[k]] += FE0_D100[ip][j]*FE0_D100[ip][k]*Gip5;
          // Number of operations to compute entry = 3
          A[nzc0[j]*56 + nzc1[k]] += FE0_D001[ip][j]*FE0_D100[ip][k]*Gip0;
        }// end loop over 'k'
      }// end loop over 'j'
      
      // Number of operations for primary indices = 15300
      for (unsigned int j = 0; j < 50; j++)
      {
        for (unsigned int k = 0; k < 51; k++)
        {
          // Number of operations to compute entry = 3
          A[nzc1[j]*56 + nzc2[k]] += FE0_D010[ip][k]*FE0_D100[ip][j]*Gip1;
          // Number of operations to compute entry = 3
          A[nzc0[j]*56 + nzc2[k]] += FE0_D001[ip][j]*FE0_D010[ip][k]*Gip2;
        }// end loop over 'k'
      }// end loop over 'j'
    }// end loop over 'ip'
  }

};

/// This class defines the interface for the tabulation of the cell
/// tensor corresponding to the local contribution to a form from
/// the integral over a cell.

class poisson3d_5_0_cell_integral_0: public ufc::cell_integral
{
private:

  poisson3d_5_0_cell_integral_0_quadrature integral_0_quadrature;

public:

  /// Constructor
  poisson3d_5_0_cell_integral_0() : ufc::cell_integral()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_0_cell_integral_0()
  {
    // Do nothing
  }

  /// Tabulate the tensor for the contribution from a local cell
  virtual void tabulate_tensor(double* A,
                               const double * const * w,
                               const ufc::cell& c) const
  {
    // Reset values of the element tensor block
    A[0] = 0;
    A[1] = 0;
    A[2] = 0;
    A[3] = 0;
    A[4] = 0;
    A[5] = 0;
    A[6] = 0;
    A[7] = 0;
    A[8] = 0;
    A[9] = 0;
    A[10] = 0;
    A[11] = 0;
    A[12] = 0;
    A[13] = 0;
    A[14] = 0;
    A[15] = 0;
    A[16] = 0;
    A[17] = 0;
    A[18] = 0;
    A[19] = 0;
    A[20] = 0;
    A[21] = 0;
    A[22] = 0;
    A[23] = 0;
    A[24] = 0;
    A[25] = 0;
    A[26] = 0;
    A[27] = 0;
    A[28] = 0;
    A[29] = 0;
    A[30] = 0;
    A[31] = 0;
    A[32] = 0;
    A[33] = 0;
    A[34] = 0;
    A[35] = 0;
    A[36] = 0;
    A[37] = 0;
    A[38] = 0;
    A[39] = 0;
    A[40] = 0;
    A[41] = 0;
    A[42] = 0;
    A[43] = 0;
    A[44] = 0;
    A[45] = 0;
    A[46] = 0;
    A[47] = 0;
    A[48] = 0;
    A[49] = 0;
    A[50] = 0;
    A[51] = 0;
    A[52] = 0;
    A[53] = 0;
    A[54] = 0;
    A[55] = 0;
    A[56] = 0;
    A[57] = 0;
    A[58] = 0;
    A[59] = 0;
    A[60] = 0;
    A[61] = 0;
    A[62] = 0;
    A[63] = 0;
    A[64] = 0;
    A[65] = 0;
    A[66] = 0;
    A[67] = 0;
    A[68] = 0;
    A[69] = 0;
    A[70] = 0;
    A[71] = 0;
    A[72] = 0;
    A[73] = 0;
    A[74] = 0;
    A[75] = 0;
    A[76] = 0;
    A[77] = 0;
    A[78] = 0;
    A[79] = 0;
    A[80] = 0;
    A[81] = 0;
    A[82] = 0;
    A[83] = 0;
    A[84] = 0;
    A[85] = 0;
    A[86] = 0;
    A[87] = 0;
    A[88] = 0;
    A[89] = 0;
    A[90] = 0;
    A[91] = 0;
    A[92] = 0;
    A[93] = 0;
    A[94] = 0;
    A[95] = 0;
    A[96] = 0;
    A[97] = 0;
    A[98] = 0;
    A[99] = 0;
    A[100] = 0;
    A[101] = 0;
    A[102] = 0;
    A[103] = 0;
    A[104] = 0;
    A[105] = 0;
    A[106] = 0;
    A[107] = 0;
    A[108] = 0;
    A[109] = 0;
    A[110] = 0;
    A[111] = 0;
    A[112] = 0;
    A[113] = 0;
    A[114] = 0;
    A[115] = 0;
    A[116] = 0;
    A[117] = 0;
    A[118] = 0;
    A[119] = 0;
    A[120] = 0;
    A[121] = 0;
    A[122] = 0;
    A[123] = 0;
    A[124] = 0;
    A[125] = 0;
    A[126] = 0;
    A[127] = 0;
    A[128] = 0;
    A[129] = 0;
    A[130] = 0;
    A[131] = 0;
    A[132] = 0;
    A[133] = 0;
    A[134] = 0;
    A[135] = 0;
    A[136] = 0;
    A[137] = 0;
    A[138] = 0;
    A[139] = 0;
    A[140] = 0;
    A[141] = 0;
    A[142] = 0;
    A[143] = 0;
    A[144] = 0;
    A[145] = 0;
    A[146] = 0;
    A[147] = 0;
    A[148] = 0;
    A[149] = 0;
    A[150] = 0;
    A[151] = 0;
    A[152] = 0;
    A[153] = 0;
    A[154] = 0;
    A[155] = 0;
    A[156] = 0;
    A[157] = 0;
    A[158] = 0;
    A[159] = 0;
    A[160] = 0;
    A[161] = 0;
    A[162] = 0;
    A[163] = 0;
    A[164] = 0;
    A[165] = 0;
    A[166] = 0;
    A[167] = 0;
    A[168] = 0;
    A[169] = 0;
    A[170] = 0;
    A[171] = 0;
    A[172] = 0;
    A[173] = 0;
    A[174] = 0;
    A[175] = 0;
    A[176] = 0;
    A[177] = 0;
    A[178] = 0;
    A[179] = 0;
    A[180] = 0;
    A[181] = 0;
    A[182] = 0;
    A[183] = 0;
    A[184] = 0;
    A[185] = 0;
    A[186] = 0;
    A[187] = 0;
    A[188] = 0;
    A[189] = 0;
    A[190] = 0;
    A[191] = 0;
    A[192] = 0;
    A[193] = 0;
    A[194] = 0;
    A[195] = 0;
    A[196] = 0;
    A[197] = 0;
    A[198] = 0;
    A[199] = 0;
    A[200] = 0;
    A[201] = 0;
    A[202] = 0;
    A[203] = 0;
    A[204] = 0;
    A[205] = 0;
    A[206] = 0;
    A[207] = 0;
    A[208] = 0;
    A[209] = 0;
    A[210] = 0;
    A[211] = 0;
    A[212] = 0;
    A[213] = 0;
    A[214] = 0;
    A[215] = 0;
    A[216] = 0;
    A[217] = 0;
    A[218] = 0;
    A[219] = 0;
    A[220] = 0;
    A[221] = 0;
    A[222] = 0;
    A[223] = 0;
    A[224] = 0;
    A[225] = 0;
    A[226] = 0;
    A[227] = 0;
    A[228] = 0;
    A[229] = 0;
    A[230] = 0;
    A[231] = 0;
    A[232] = 0;
    A[233] = 0;
    A[234] = 0;
    A[235] = 0;
    A[236] = 0;
    A[237] = 0;
    A[238] = 0;
    A[239] = 0;
    A[240] = 0;
    A[241] = 0;
    A[242] = 0;
    A[243] = 0;
    A[244] = 0;
    A[245] = 0;
    A[246] = 0;
    A[247] = 0;
    A[248] = 0;
    A[249] = 0;
    A[250] = 0;
    A[251] = 0;
    A[252] = 0;
    A[253] = 0;
    A[254] = 0;
    A[255] = 0;
    A[256] = 0;
    A[257] = 0;
    A[258] = 0;
    A[259] = 0;
    A[260] = 0;
    A[261] = 0;
    A[262] = 0;
    A[263] = 0;
    A[264] = 0;
    A[265] = 0;
    A[266] = 0;
    A[267] = 0;
    A[268] = 0;
    A[269] = 0;
    A[270] = 0;
    A[271] = 0;
    A[272] = 0;
    A[273] = 0;
    A[274] = 0;
    A[275] = 0;
    A[276] = 0;
    A[277] = 0;
    A[278] = 0;
    A[279] = 0;
    A[280] = 0;
    A[281] = 0;
    A[282] = 0;
    A[283] = 0;
    A[284] = 0;
    A[285] = 0;
    A[286] = 0;
    A[287] = 0;
    A[288] = 0;
    A[289] = 0;
    A[290] = 0;
    A[291] = 0;
    A[292] = 0;
    A[293] = 0;
    A[294] = 0;
    A[295] = 0;
    A[296] = 0;
    A[297] = 0;
    A[298] = 0;
    A[299] = 0;
    A[300] = 0;
    A[301] = 0;
    A[302] = 0;
    A[303] = 0;
    A[304] = 0;
    A[305] = 0;
    A[306] = 0;
    A[307] = 0;
    A[308] = 0;
    A[309] = 0;
    A[310] = 0;
    A[311] = 0;
    A[312] = 0;
    A[313] = 0;
    A[314] = 0;
    A[315] = 0;
    A[316] = 0;
    A[317] = 0;
    A[318] = 0;
    A[319] = 0;
    A[320] = 0;
    A[321] = 0;
    A[322] = 0;
    A[323] = 0;
    A[324] = 0;
    A[325] = 0;
    A[326] = 0;
    A[327] = 0;
    A[328] = 0;
    A[329] = 0;
    A[330] = 0;
    A[331] = 0;
    A[332] = 0;
    A[333] = 0;
    A[334] = 0;
    A[335] = 0;
    A[336] = 0;
    A[337] = 0;
    A[338] = 0;
    A[339] = 0;
    A[340] = 0;
    A[341] = 0;
    A[342] = 0;
    A[343] = 0;
    A[344] = 0;
    A[345] = 0;
    A[346] = 0;
    A[347] = 0;
    A[348] = 0;
    A[349] = 0;
    A[350] = 0;
    A[351] = 0;
    A[352] = 0;
    A[353] = 0;
    A[354] = 0;
    A[355] = 0;
    A[356] = 0;
    A[357] = 0;
    A[358] = 0;
    A[359] = 0;
    A[360] = 0;
    A[361] = 0;
    A[362] = 0;
    A[363] = 0;
    A[364] = 0;
    A[365] = 0;
    A[366] = 0;
    A[367] = 0;
    A[368] = 0;
    A[369] = 0;
    A[370] = 0;
    A[371] = 0;
    A[372] = 0;
    A[373] = 0;
    A[374] = 0;
    A[375] = 0;
    A[376] = 0;
    A[377] = 0;
    A[378] = 0;
    A[379] = 0;
    A[380] = 0;
    A[381] = 0;
    A[382] = 0;
    A[383] = 0;
    A[384] = 0;
    A[385] = 0;
    A[386] = 0;
    A[387] = 0;
    A[388] = 0;
    A[389] = 0;
    A[390] = 0;
    A[391] = 0;
    A[392] = 0;
    A[393] = 0;
    A[394] = 0;
    A[395] = 0;
    A[396] = 0;
    A[397] = 0;
    A[398] = 0;
    A[399] = 0;
    A[400] = 0;
    A[401] = 0;
    A[402] = 0;
    A[403] = 0;
    A[404] = 0;
    A[405] = 0;
    A[406] = 0;
    A[407] = 0;
    A[408] = 0;
    A[409] = 0;
    A[410] = 0;
    A[411] = 0;
    A[412] = 0;
    A[413] = 0;
    A[414] = 0;
    A[415] = 0;
    A[416] = 0;
    A[417] = 0;
    A[418] = 0;
    A[419] = 0;
    A[420] = 0;
    A[421] = 0;
    A[422] = 0;
    A[423] = 0;
    A[424] = 0;
    A[425] = 0;
    A[426] = 0;
    A[427] = 0;
    A[428] = 0;
    A[429] = 0;
    A[430] = 0;
    A[431] = 0;
    A[432] = 0;
    A[433] = 0;
    A[434] = 0;
    A[435] = 0;
    A[436] = 0;
    A[437] = 0;
    A[438] = 0;
    A[439] = 0;
    A[440] = 0;
    A[441] = 0;
    A[442] = 0;
    A[443] = 0;
    A[444] = 0;
    A[445] = 0;
    A[446] = 0;
    A[447] = 0;
    A[448] = 0;
    A[449] = 0;
    A[450] = 0;
    A[451] = 0;
    A[452] = 0;
    A[453] = 0;
    A[454] = 0;
    A[455] = 0;
    A[456] = 0;
    A[457] = 0;
    A[458] = 0;
    A[459] = 0;
    A[460] = 0;
    A[461] = 0;
    A[462] = 0;
    A[463] = 0;
    A[464] = 0;
    A[465] = 0;
    A[466] = 0;
    A[467] = 0;
    A[468] = 0;
    A[469] = 0;
    A[470] = 0;
    A[471] = 0;
    A[472] = 0;
    A[473] = 0;
    A[474] = 0;
    A[475] = 0;
    A[476] = 0;
    A[477] = 0;
    A[478] = 0;
    A[479] = 0;
    A[480] = 0;
    A[481] = 0;
    A[482] = 0;
    A[483] = 0;
    A[484] = 0;
    A[485] = 0;
    A[486] = 0;
    A[487] = 0;
    A[488] = 0;
    A[489] = 0;
    A[490] = 0;
    A[491] = 0;
    A[492] = 0;
    A[493] = 0;
    A[494] = 0;
    A[495] = 0;
    A[496] = 0;
    A[497] = 0;
    A[498] = 0;
    A[499] = 0;
    A[500] = 0;
    A[501] = 0;
    A[502] = 0;
    A[503] = 0;
    A[504] = 0;
    A[505] = 0;
    A[506] = 0;
    A[507] = 0;
    A[508] = 0;
    A[509] = 0;
    A[510] = 0;
    A[511] = 0;
    A[512] = 0;
    A[513] = 0;
    A[514] = 0;
    A[515] = 0;
    A[516] = 0;
    A[517] = 0;
    A[518] = 0;
    A[519] = 0;
    A[520] = 0;
    A[521] = 0;
    A[522] = 0;
    A[523] = 0;
    A[524] = 0;
    A[525] = 0;
    A[526] = 0;
    A[527] = 0;
    A[528] = 0;
    A[529] = 0;
    A[530] = 0;
    A[531] = 0;
    A[532] = 0;
    A[533] = 0;
    A[534] = 0;
    A[535] = 0;
    A[536] = 0;
    A[537] = 0;
    A[538] = 0;
    A[539] = 0;
    A[540] = 0;
    A[541] = 0;
    A[542] = 0;
    A[543] = 0;
    A[544] = 0;
    A[545] = 0;
    A[546] = 0;
    A[547] = 0;
    A[548] = 0;
    A[549] = 0;
    A[550] = 0;
    A[551] = 0;
    A[552] = 0;
    A[553] = 0;
    A[554] = 0;
    A[555] = 0;
    A[556] = 0;
    A[557] = 0;
    A[558] = 0;
    A[559] = 0;
    A[560] = 0;
    A[561] = 0;
    A[562] = 0;
    A[563] = 0;
    A[564] = 0;
    A[565] = 0;
    A[566] = 0;
    A[567] = 0;
    A[568] = 0;
    A[569] = 0;
    A[570] = 0;
    A[571] = 0;
    A[572] = 0;
    A[573] = 0;
    A[574] = 0;
    A[575] = 0;
    A[576] = 0;
    A[577] = 0;
    A[578] = 0;
    A[579] = 0;
    A[580] = 0;
    A[581] = 0;
    A[582] = 0;
    A[583] = 0;
    A[584] = 0;
    A[585] = 0;
    A[586] = 0;
    A[587] = 0;
    A[588] = 0;
    A[589] = 0;
    A[590] = 0;
    A[591] = 0;
    A[592] = 0;
    A[593] = 0;
    A[594] = 0;
    A[595] = 0;
    A[596] = 0;
    A[597] = 0;
    A[598] = 0;
    A[599] = 0;
    A[600] = 0;
    A[601] = 0;
    A[602] = 0;
    A[603] = 0;
    A[604] = 0;
    A[605] = 0;
    A[606] = 0;
    A[607] = 0;
    A[608] = 0;
    A[609] = 0;
    A[610] = 0;
    A[611] = 0;
    A[612] = 0;
    A[613] = 0;
    A[614] = 0;
    A[615] = 0;
    A[616] = 0;
    A[617] = 0;
    A[618] = 0;
    A[619] = 0;
    A[620] = 0;
    A[621] = 0;
    A[622] = 0;
    A[623] = 0;
    A[624] = 0;
    A[625] = 0;
    A[626] = 0;
    A[627] = 0;
    A[628] = 0;
    A[629] = 0;
    A[630] = 0;
    A[631] = 0;
    A[632] = 0;
    A[633] = 0;
    A[634] = 0;
    A[635] = 0;
    A[636] = 0;
    A[637] = 0;
    A[638] = 0;
    A[639] = 0;
    A[640] = 0;
    A[641] = 0;
    A[642] = 0;
    A[643] = 0;
    A[644] = 0;
    A[645] = 0;
    A[646] = 0;
    A[647] = 0;
    A[648] = 0;
    A[649] = 0;
    A[650] = 0;
    A[651] = 0;
    A[652] = 0;
    A[653] = 0;
    A[654] = 0;
    A[655] = 0;
    A[656] = 0;
    A[657] = 0;
    A[658] = 0;
    A[659] = 0;
    A[660] = 0;
    A[661] = 0;
    A[662] = 0;
    A[663] = 0;
    A[664] = 0;
    A[665] = 0;
    A[666] = 0;
    A[667] = 0;
    A[668] = 0;
    A[669] = 0;
    A[670] = 0;
    A[671] = 0;
    A[672] = 0;
    A[673] = 0;
    A[674] = 0;
    A[675] = 0;
    A[676] = 0;
    A[677] = 0;
    A[678] = 0;
    A[679] = 0;
    A[680] = 0;
    A[681] = 0;
    A[682] = 0;
    A[683] = 0;
    A[684] = 0;
    A[685] = 0;
    A[686] = 0;
    A[687] = 0;
    A[688] = 0;
    A[689] = 0;
    A[690] = 0;
    A[691] = 0;
    A[692] = 0;
    A[693] = 0;
    A[694] = 0;
    A[695] = 0;
    A[696] = 0;
    A[697] = 0;
    A[698] = 0;
    A[699] = 0;
    A[700] = 0;
    A[701] = 0;
    A[702] = 0;
    A[703] = 0;
    A[704] = 0;
    A[705] = 0;
    A[706] = 0;
    A[707] = 0;
    A[708] = 0;
    A[709] = 0;
    A[710] = 0;
    A[711] = 0;
    A[712] = 0;
    A[713] = 0;
    A[714] = 0;
    A[715] = 0;
    A[716] = 0;
    A[717] = 0;
    A[718] = 0;
    A[719] = 0;
    A[720] = 0;
    A[721] = 0;
    A[722] = 0;
    A[723] = 0;
    A[724] = 0;
    A[725] = 0;
    A[726] = 0;
    A[727] = 0;
    A[728] = 0;
    A[729] = 0;
    A[730] = 0;
    A[731] = 0;
    A[732] = 0;
    A[733] = 0;
    A[734] = 0;
    A[735] = 0;
    A[736] = 0;
    A[737] = 0;
    A[738] = 0;
    A[739] = 0;
    A[740] = 0;
    A[741] = 0;
    A[742] = 0;
    A[743] = 0;
    A[744] = 0;
    A[745] = 0;
    A[746] = 0;
    A[747] = 0;
    A[748] = 0;
    A[749] = 0;
    A[750] = 0;
    A[751] = 0;
    A[752] = 0;
    A[753] = 0;
    A[754] = 0;
    A[755] = 0;
    A[756] = 0;
    A[757] = 0;
    A[758] = 0;
    A[759] = 0;
    A[760] = 0;
    A[761] = 0;
    A[762] = 0;
    A[763] = 0;
    A[764] = 0;
    A[765] = 0;
    A[766] = 0;
    A[767] = 0;
    A[768] = 0;
    A[769] = 0;
    A[770] = 0;
    A[771] = 0;
    A[772] = 0;
    A[773] = 0;
    A[774] = 0;
    A[775] = 0;
    A[776] = 0;
    A[777] = 0;
    A[778] = 0;
    A[779] = 0;
    A[780] = 0;
    A[781] = 0;
    A[782] = 0;
    A[783] = 0;
    A[784] = 0;
    A[785] = 0;
    A[786] = 0;
    A[787] = 0;
    A[788] = 0;
    A[789] = 0;
    A[790] = 0;
    A[791] = 0;
    A[792] = 0;
    A[793] = 0;
    A[794] = 0;
    A[795] = 0;
    A[796] = 0;
    A[797] = 0;
    A[798] = 0;
    A[799] = 0;
    A[800] = 0;
    A[801] = 0;
    A[802] = 0;
    A[803] = 0;
    A[804] = 0;
    A[805] = 0;
    A[806] = 0;
    A[807] = 0;
    A[808] = 0;
    A[809] = 0;
    A[810] = 0;
    A[811] = 0;
    A[812] = 0;
    A[813] = 0;
    A[814] = 0;
    A[815] = 0;
    A[816] = 0;
    A[817] = 0;
    A[818] = 0;
    A[819] = 0;
    A[820] = 0;
    A[821] = 0;
    A[822] = 0;
    A[823] = 0;
    A[824] = 0;
    A[825] = 0;
    A[826] = 0;
    A[827] = 0;
    A[828] = 0;
    A[829] = 0;
    A[830] = 0;
    A[831] = 0;
    A[832] = 0;
    A[833] = 0;
    A[834] = 0;
    A[835] = 0;
    A[836] = 0;
    A[837] = 0;
    A[838] = 0;
    A[839] = 0;
    A[840] = 0;
    A[841] = 0;
    A[842] = 0;
    A[843] = 0;
    A[844] = 0;
    A[845] = 0;
    A[846] = 0;
    A[847] = 0;
    A[848] = 0;
    A[849] = 0;
    A[850] = 0;
    A[851] = 0;
    A[852] = 0;
    A[853] = 0;
    A[854] = 0;
    A[855] = 0;
    A[856] = 0;
    A[857] = 0;
    A[858] = 0;
    A[859] = 0;
    A[860] = 0;
    A[861] = 0;
    A[862] = 0;
    A[863] = 0;
    A[864] = 0;
    A[865] = 0;
    A[866] = 0;
    A[867] = 0;
    A[868] = 0;
    A[869] = 0;
    A[870] = 0;
    A[871] = 0;
    A[872] = 0;
    A[873] = 0;
    A[874] = 0;
    A[875] = 0;
    A[876] = 0;
    A[877] = 0;
    A[878] = 0;
    A[879] = 0;
    A[880] = 0;
    A[881] = 0;
    A[882] = 0;
    A[883] = 0;
    A[884] = 0;
    A[885] = 0;
    A[886] = 0;
    A[887] = 0;
    A[888] = 0;
    A[889] = 0;
    A[890] = 0;
    A[891] = 0;
    A[892] = 0;
    A[893] = 0;
    A[894] = 0;
    A[895] = 0;
    A[896] = 0;
    A[897] = 0;
    A[898] = 0;
    A[899] = 0;
    A[900] = 0;
    A[901] = 0;
    A[902] = 0;
    A[903] = 0;
    A[904] = 0;
    A[905] = 0;
    A[906] = 0;
    A[907] = 0;
    A[908] = 0;
    A[909] = 0;
    A[910] = 0;
    A[911] = 0;
    A[912] = 0;
    A[913] = 0;
    A[914] = 0;
    A[915] = 0;
    A[916] = 0;
    A[917] = 0;
    A[918] = 0;
    A[919] = 0;
    A[920] = 0;
    A[921] = 0;
    A[922] = 0;
    A[923] = 0;
    A[924] = 0;
    A[925] = 0;
    A[926] = 0;
    A[927] = 0;
    A[928] = 0;
    A[929] = 0;
    A[930] = 0;
    A[931] = 0;
    A[932] = 0;
    A[933] = 0;
    A[934] = 0;
    A[935] = 0;
    A[936] = 0;
    A[937] = 0;
    A[938] = 0;
    A[939] = 0;
    A[940] = 0;
    A[941] = 0;
    A[942] = 0;
    A[943] = 0;
    A[944] = 0;
    A[945] = 0;
    A[946] = 0;
    A[947] = 0;
    A[948] = 0;
    A[949] = 0;
    A[950] = 0;
    A[951] = 0;
    A[952] = 0;
    A[953] = 0;
    A[954] = 0;
    A[955] = 0;
    A[956] = 0;
    A[957] = 0;
    A[958] = 0;
    A[959] = 0;
    A[960] = 0;
    A[961] = 0;
    A[962] = 0;
    A[963] = 0;
    A[964] = 0;
    A[965] = 0;
    A[966] = 0;
    A[967] = 0;
    A[968] = 0;
    A[969] = 0;
    A[970] = 0;
    A[971] = 0;
    A[972] = 0;
    A[973] = 0;
    A[974] = 0;
    A[975] = 0;
    A[976] = 0;
    A[977] = 0;
    A[978] = 0;
    A[979] = 0;
    A[980] = 0;
    A[981] = 0;
    A[982] = 0;
    A[983] = 0;
    A[984] = 0;
    A[985] = 0;
    A[986] = 0;
    A[987] = 0;
    A[988] = 0;
    A[989] = 0;
    A[990] = 0;
    A[991] = 0;
    A[992] = 0;
    A[993] = 0;
    A[994] = 0;
    A[995] = 0;
    A[996] = 0;
    A[997] = 0;
    A[998] = 0;
    A[999] = 0;
    A[1000] = 0;
    A[1001] = 0;
    A[1002] = 0;
    A[1003] = 0;
    A[1004] = 0;
    A[1005] = 0;
    A[1006] = 0;
    A[1007] = 0;
    A[1008] = 0;
    A[1009] = 0;
    A[1010] = 0;
    A[1011] = 0;
    A[1012] = 0;
    A[1013] = 0;
    A[1014] = 0;
    A[1015] = 0;
    A[1016] = 0;
    A[1017] = 0;
    A[1018] = 0;
    A[1019] = 0;
    A[1020] = 0;
    A[1021] = 0;
    A[1022] = 0;
    A[1023] = 0;
    A[1024] = 0;
    A[1025] = 0;
    A[1026] = 0;
    A[1027] = 0;
    A[1028] = 0;
    A[1029] = 0;
    A[1030] = 0;
    A[1031] = 0;
    A[1032] = 0;
    A[1033] = 0;
    A[1034] = 0;
    A[1035] = 0;
    A[1036] = 0;
    A[1037] = 0;
    A[1038] = 0;
    A[1039] = 0;
    A[1040] = 0;
    A[1041] = 0;
    A[1042] = 0;
    A[1043] = 0;
    A[1044] = 0;
    A[1045] = 0;
    A[1046] = 0;
    A[1047] = 0;
    A[1048] = 0;
    A[1049] = 0;
    A[1050] = 0;
    A[1051] = 0;
    A[1052] = 0;
    A[1053] = 0;
    A[1054] = 0;
    A[1055] = 0;
    A[1056] = 0;
    A[1057] = 0;
    A[1058] = 0;
    A[1059] = 0;
    A[1060] = 0;
    A[1061] = 0;
    A[1062] = 0;
    A[1063] = 0;
    A[1064] = 0;
    A[1065] = 0;
    A[1066] = 0;
    A[1067] = 0;
    A[1068] = 0;
    A[1069] = 0;
    A[1070] = 0;
    A[1071] = 0;
    A[1072] = 0;
    A[1073] = 0;
    A[1074] = 0;
    A[1075] = 0;
    A[1076] = 0;
    A[1077] = 0;
    A[1078] = 0;
    A[1079] = 0;
    A[1080] = 0;
    A[1081] = 0;
    A[1082] = 0;
    A[1083] = 0;
    A[1084] = 0;
    A[1085] = 0;
    A[1086] = 0;
    A[1087] = 0;
    A[1088] = 0;
    A[1089] = 0;
    A[1090] = 0;
    A[1091] = 0;
    A[1092] = 0;
    A[1093] = 0;
    A[1094] = 0;
    A[1095] = 0;
    A[1096] = 0;
    A[1097] = 0;
    A[1098] = 0;
    A[1099] = 0;
    A[1100] = 0;
    A[1101] = 0;
    A[1102] = 0;
    A[1103] = 0;
    A[1104] = 0;
    A[1105] = 0;
    A[1106] = 0;
    A[1107] = 0;
    A[1108] = 0;
    A[1109] = 0;
    A[1110] = 0;
    A[1111] = 0;
    A[1112] = 0;
    A[1113] = 0;
    A[1114] = 0;
    A[1115] = 0;
    A[1116] = 0;
    A[1117] = 0;
    A[1118] = 0;
    A[1119] = 0;
    A[1120] = 0;
    A[1121] = 0;
    A[1122] = 0;
    A[1123] = 0;
    A[1124] = 0;
    A[1125] = 0;
    A[1126] = 0;
    A[1127] = 0;
    A[1128] = 0;
    A[1129] = 0;
    A[1130] = 0;
    A[1131] = 0;
    A[1132] = 0;
    A[1133] = 0;
    A[1134] = 0;
    A[1135] = 0;
    A[1136] = 0;
    A[1137] = 0;
    A[1138] = 0;
    A[1139] = 0;
    A[1140] = 0;
    A[1141] = 0;
    A[1142] = 0;
    A[1143] = 0;
    A[1144] = 0;
    A[1145] = 0;
    A[1146] = 0;
    A[1147] = 0;
    A[1148] = 0;
    A[1149] = 0;
    A[1150] = 0;
    A[1151] = 0;
    A[1152] = 0;
    A[1153] = 0;
    A[1154] = 0;
    A[1155] = 0;
    A[1156] = 0;
    A[1157] = 0;
    A[1158] = 0;
    A[1159] = 0;
    A[1160] = 0;
    A[1161] = 0;
    A[1162] = 0;
    A[1163] = 0;
    A[1164] = 0;
    A[1165] = 0;
    A[1166] = 0;
    A[1167] = 0;
    A[1168] = 0;
    A[1169] = 0;
    A[1170] = 0;
    A[1171] = 0;
    A[1172] = 0;
    A[1173] = 0;
    A[1174] = 0;
    A[1175] = 0;
    A[1176] = 0;
    A[1177] = 0;
    A[1178] = 0;
    A[1179] = 0;
    A[1180] = 0;
    A[1181] = 0;
    A[1182] = 0;
    A[1183] = 0;
    A[1184] = 0;
    A[1185] = 0;
    A[1186] = 0;
    A[1187] = 0;
    A[1188] = 0;
    A[1189] = 0;
    A[1190] = 0;
    A[1191] = 0;
    A[1192] = 0;
    A[1193] = 0;
    A[1194] = 0;
    A[1195] = 0;
    A[1196] = 0;
    A[1197] = 0;
    A[1198] = 0;
    A[1199] = 0;
    A[1200] = 0;
    A[1201] = 0;
    A[1202] = 0;
    A[1203] = 0;
    A[1204] = 0;
    A[1205] = 0;
    A[1206] = 0;
    A[1207] = 0;
    A[1208] = 0;
    A[1209] = 0;
    A[1210] = 0;
    A[1211] = 0;
    A[1212] = 0;
    A[1213] = 0;
    A[1214] = 0;
    A[1215] = 0;
    A[1216] = 0;
    A[1217] = 0;
    A[1218] = 0;
    A[1219] = 0;
    A[1220] = 0;
    A[1221] = 0;
    A[1222] = 0;
    A[1223] = 0;
    A[1224] = 0;
    A[1225] = 0;
    A[1226] = 0;
    A[1227] = 0;
    A[1228] = 0;
    A[1229] = 0;
    A[1230] = 0;
    A[1231] = 0;
    A[1232] = 0;
    A[1233] = 0;
    A[1234] = 0;
    A[1235] = 0;
    A[1236] = 0;
    A[1237] = 0;
    A[1238] = 0;
    A[1239] = 0;
    A[1240] = 0;
    A[1241] = 0;
    A[1242] = 0;
    A[1243] = 0;
    A[1244] = 0;
    A[1245] = 0;
    A[1246] = 0;
    A[1247] = 0;
    A[1248] = 0;
    A[1249] = 0;
    A[1250] = 0;
    A[1251] = 0;
    A[1252] = 0;
    A[1253] = 0;
    A[1254] = 0;
    A[1255] = 0;
    A[1256] = 0;
    A[1257] = 0;
    A[1258] = 0;
    A[1259] = 0;
    A[1260] = 0;
    A[1261] = 0;
    A[1262] = 0;
    A[1263] = 0;
    A[1264] = 0;
    A[1265] = 0;
    A[1266] = 0;
    A[1267] = 0;
    A[1268] = 0;
    A[1269] = 0;
    A[1270] = 0;
    A[1271] = 0;
    A[1272] = 0;
    A[1273] = 0;
    A[1274] = 0;
    A[1275] = 0;
    A[1276] = 0;
    A[1277] = 0;
    A[1278] = 0;
    A[1279] = 0;
    A[1280] = 0;
    A[1281] = 0;
    A[1282] = 0;
    A[1283] = 0;
    A[1284] = 0;
    A[1285] = 0;
    A[1286] = 0;
    A[1287] = 0;
    A[1288] = 0;
    A[1289] = 0;
    A[1290] = 0;
    A[1291] = 0;
    A[1292] = 0;
    A[1293] = 0;
    A[1294] = 0;
    A[1295] = 0;
    A[1296] = 0;
    A[1297] = 0;
    A[1298] = 0;
    A[1299] = 0;
    A[1300] = 0;
    A[1301] = 0;
    A[1302] = 0;
    A[1303] = 0;
    A[1304] = 0;
    A[1305] = 0;
    A[1306] = 0;
    A[1307] = 0;
    A[1308] = 0;
    A[1309] = 0;
    A[1310] = 0;
    A[1311] = 0;
    A[1312] = 0;
    A[1313] = 0;
    A[1314] = 0;
    A[1315] = 0;
    A[1316] = 0;
    A[1317] = 0;
    A[1318] = 0;
    A[1319] = 0;
    A[1320] = 0;
    A[1321] = 0;
    A[1322] = 0;
    A[1323] = 0;
    A[1324] = 0;
    A[1325] = 0;
    A[1326] = 0;
    A[1327] = 0;
    A[1328] = 0;
    A[1329] = 0;
    A[1330] = 0;
    A[1331] = 0;
    A[1332] = 0;
    A[1333] = 0;
    A[1334] = 0;
    A[1335] = 0;
    A[1336] = 0;
    A[1337] = 0;
    A[1338] = 0;
    A[1339] = 0;
    A[1340] = 0;
    A[1341] = 0;
    A[1342] = 0;
    A[1343] = 0;
    A[1344] = 0;
    A[1345] = 0;
    A[1346] = 0;
    A[1347] = 0;
    A[1348] = 0;
    A[1349] = 0;
    A[1350] = 0;
    A[1351] = 0;
    A[1352] = 0;
    A[1353] = 0;
    A[1354] = 0;
    A[1355] = 0;
    A[1356] = 0;
    A[1357] = 0;
    A[1358] = 0;
    A[1359] = 0;
    A[1360] = 0;
    A[1361] = 0;
    A[1362] = 0;
    A[1363] = 0;
    A[1364] = 0;
    A[1365] = 0;
    A[1366] = 0;
    A[1367] = 0;
    A[1368] = 0;
    A[1369] = 0;
    A[1370] = 0;
    A[1371] = 0;
    A[1372] = 0;
    A[1373] = 0;
    A[1374] = 0;
    A[1375] = 0;
    A[1376] = 0;
    A[1377] = 0;
    A[1378] = 0;
    A[1379] = 0;
    A[1380] = 0;
    A[1381] = 0;
    A[1382] = 0;
    A[1383] = 0;
    A[1384] = 0;
    A[1385] = 0;
    A[1386] = 0;
    A[1387] = 0;
    A[1388] = 0;
    A[1389] = 0;
    A[1390] = 0;
    A[1391] = 0;
    A[1392] = 0;
    A[1393] = 0;
    A[1394] = 0;
    A[1395] = 0;
    A[1396] = 0;
    A[1397] = 0;
    A[1398] = 0;
    A[1399] = 0;
    A[1400] = 0;
    A[1401] = 0;
    A[1402] = 0;
    A[1403] = 0;
    A[1404] = 0;
    A[1405] = 0;
    A[1406] = 0;
    A[1407] = 0;
    A[1408] = 0;
    A[1409] = 0;
    A[1410] = 0;
    A[1411] = 0;
    A[1412] = 0;
    A[1413] = 0;
    A[1414] = 0;
    A[1415] = 0;
    A[1416] = 0;
    A[1417] = 0;
    A[1418] = 0;
    A[1419] = 0;
    A[1420] = 0;
    A[1421] = 0;
    A[1422] = 0;
    A[1423] = 0;
    A[1424] = 0;
    A[1425] = 0;
    A[1426] = 0;
    A[1427] = 0;
    A[1428] = 0;
    A[1429] = 0;
    A[1430] = 0;
    A[1431] = 0;
    A[1432] = 0;
    A[1433] = 0;
    A[1434] = 0;
    A[1435] = 0;
    A[1436] = 0;
    A[1437] = 0;
    A[1438] = 0;
    A[1439] = 0;
    A[1440] = 0;
    A[1441] = 0;
    A[1442] = 0;
    A[1443] = 0;
    A[1444] = 0;
    A[1445] = 0;
    A[1446] = 0;
    A[1447] = 0;
    A[1448] = 0;
    A[1449] = 0;
    A[1450] = 0;
    A[1451] = 0;
    A[1452] = 0;
    A[1453] = 0;
    A[1454] = 0;
    A[1455] = 0;
    A[1456] = 0;
    A[1457] = 0;
    A[1458] = 0;
    A[1459] = 0;
    A[1460] = 0;
    A[1461] = 0;
    A[1462] = 0;
    A[1463] = 0;
    A[1464] = 0;
    A[1465] = 0;
    A[1466] = 0;
    A[1467] = 0;
    A[1468] = 0;
    A[1469] = 0;
    A[1470] = 0;
    A[1471] = 0;
    A[1472] = 0;
    A[1473] = 0;
    A[1474] = 0;
    A[1475] = 0;
    A[1476] = 0;
    A[1477] = 0;
    A[1478] = 0;
    A[1479] = 0;
    A[1480] = 0;
    A[1481] = 0;
    A[1482] = 0;
    A[1483] = 0;
    A[1484] = 0;
    A[1485] = 0;
    A[1486] = 0;
    A[1487] = 0;
    A[1488] = 0;
    A[1489] = 0;
    A[1490] = 0;
    A[1491] = 0;
    A[1492] = 0;
    A[1493] = 0;
    A[1494] = 0;
    A[1495] = 0;
    A[1496] = 0;
    A[1497] = 0;
    A[1498] = 0;
    A[1499] = 0;
    A[1500] = 0;
    A[1501] = 0;
    A[1502] = 0;
    A[1503] = 0;
    A[1504] = 0;
    A[1505] = 0;
    A[1506] = 0;
    A[1507] = 0;
    A[1508] = 0;
    A[1509] = 0;
    A[1510] = 0;
    A[1511] = 0;
    A[1512] = 0;
    A[1513] = 0;
    A[1514] = 0;
    A[1515] = 0;
    A[1516] = 0;
    A[1517] = 0;
    A[1518] = 0;
    A[1519] = 0;
    A[1520] = 0;
    A[1521] = 0;
    A[1522] = 0;
    A[1523] = 0;
    A[1524] = 0;
    A[1525] = 0;
    A[1526] = 0;
    A[1527] = 0;
    A[1528] = 0;
    A[1529] = 0;
    A[1530] = 0;
    A[1531] = 0;
    A[1532] = 0;
    A[1533] = 0;
    A[1534] = 0;
    A[1535] = 0;
    A[1536] = 0;
    A[1537] = 0;
    A[1538] = 0;
    A[1539] = 0;
    A[1540] = 0;
    A[1541] = 0;
    A[1542] = 0;
    A[1543] = 0;
    A[1544] = 0;
    A[1545] = 0;
    A[1546] = 0;
    A[1547] = 0;
    A[1548] = 0;
    A[1549] = 0;
    A[1550] = 0;
    A[1551] = 0;
    A[1552] = 0;
    A[1553] = 0;
    A[1554] = 0;
    A[1555] = 0;
    A[1556] = 0;
    A[1557] = 0;
    A[1558] = 0;
    A[1559] = 0;
    A[1560] = 0;
    A[1561] = 0;
    A[1562] = 0;
    A[1563] = 0;
    A[1564] = 0;
    A[1565] = 0;
    A[1566] = 0;
    A[1567] = 0;
    A[1568] = 0;
    A[1569] = 0;
    A[1570] = 0;
    A[1571] = 0;
    A[1572] = 0;
    A[1573] = 0;
    A[1574] = 0;
    A[1575] = 0;
    A[1576] = 0;
    A[1577] = 0;
    A[1578] = 0;
    A[1579] = 0;
    A[1580] = 0;
    A[1581] = 0;
    A[1582] = 0;
    A[1583] = 0;
    A[1584] = 0;
    A[1585] = 0;
    A[1586] = 0;
    A[1587] = 0;
    A[1588] = 0;
    A[1589] = 0;
    A[1590] = 0;
    A[1591] = 0;
    A[1592] = 0;
    A[1593] = 0;
    A[1594] = 0;
    A[1595] = 0;
    A[1596] = 0;
    A[1597] = 0;
    A[1598] = 0;
    A[1599] = 0;
    A[1600] = 0;
    A[1601] = 0;
    A[1602] = 0;
    A[1603] = 0;
    A[1604] = 0;
    A[1605] = 0;
    A[1606] = 0;
    A[1607] = 0;
    A[1608] = 0;
    A[1609] = 0;
    A[1610] = 0;
    A[1611] = 0;
    A[1612] = 0;
    A[1613] = 0;
    A[1614] = 0;
    A[1615] = 0;
    A[1616] = 0;
    A[1617] = 0;
    A[1618] = 0;
    A[1619] = 0;
    A[1620] = 0;
    A[1621] = 0;
    A[1622] = 0;
    A[1623] = 0;
    A[1624] = 0;
    A[1625] = 0;
    A[1626] = 0;
    A[1627] = 0;
    A[1628] = 0;
    A[1629] = 0;
    A[1630] = 0;
    A[1631] = 0;
    A[1632] = 0;
    A[1633] = 0;
    A[1634] = 0;
    A[1635] = 0;
    A[1636] = 0;
    A[1637] = 0;
    A[1638] = 0;
    A[1639] = 0;
    A[1640] = 0;
    A[1641] = 0;
    A[1642] = 0;
    A[1643] = 0;
    A[1644] = 0;
    A[1645] = 0;
    A[1646] = 0;
    A[1647] = 0;
    A[1648] = 0;
    A[1649] = 0;
    A[1650] = 0;
    A[1651] = 0;
    A[1652] = 0;
    A[1653] = 0;
    A[1654] = 0;
    A[1655] = 0;
    A[1656] = 0;
    A[1657] = 0;
    A[1658] = 0;
    A[1659] = 0;
    A[1660] = 0;
    A[1661] = 0;
    A[1662] = 0;
    A[1663] = 0;
    A[1664] = 0;
    A[1665] = 0;
    A[1666] = 0;
    A[1667] = 0;
    A[1668] = 0;
    A[1669] = 0;
    A[1670] = 0;
    A[1671] = 0;
    A[1672] = 0;
    A[1673] = 0;
    A[1674] = 0;
    A[1675] = 0;
    A[1676] = 0;
    A[1677] = 0;
    A[1678] = 0;
    A[1679] = 0;
    A[1680] = 0;
    A[1681] = 0;
    A[1682] = 0;
    A[1683] = 0;
    A[1684] = 0;
    A[1685] = 0;
    A[1686] = 0;
    A[1687] = 0;
    A[1688] = 0;
    A[1689] = 0;
    A[1690] = 0;
    A[1691] = 0;
    A[1692] = 0;
    A[1693] = 0;
    A[1694] = 0;
    A[1695] = 0;
    A[1696] = 0;
    A[1697] = 0;
    A[1698] = 0;
    A[1699] = 0;
    A[1700] = 0;
    A[1701] = 0;
    A[1702] = 0;
    A[1703] = 0;
    A[1704] = 0;
    A[1705] = 0;
    A[1706] = 0;
    A[1707] = 0;
    A[1708] = 0;
    A[1709] = 0;
    A[1710] = 0;
    A[1711] = 0;
    A[1712] = 0;
    A[1713] = 0;
    A[1714] = 0;
    A[1715] = 0;
    A[1716] = 0;
    A[1717] = 0;
    A[1718] = 0;
    A[1719] = 0;
    A[1720] = 0;
    A[1721] = 0;
    A[1722] = 0;
    A[1723] = 0;
    A[1724] = 0;
    A[1725] = 0;
    A[1726] = 0;
    A[1727] = 0;
    A[1728] = 0;
    A[1729] = 0;
    A[1730] = 0;
    A[1731] = 0;
    A[1732] = 0;
    A[1733] = 0;
    A[1734] = 0;
    A[1735] = 0;
    A[1736] = 0;
    A[1737] = 0;
    A[1738] = 0;
    A[1739] = 0;
    A[1740] = 0;
    A[1741] = 0;
    A[1742] = 0;
    A[1743] = 0;
    A[1744] = 0;
    A[1745] = 0;
    A[1746] = 0;
    A[1747] = 0;
    A[1748] = 0;
    A[1749] = 0;
    A[1750] = 0;
    A[1751] = 0;
    A[1752] = 0;
    A[1753] = 0;
    A[1754] = 0;
    A[1755] = 0;
    A[1756] = 0;
    A[1757] = 0;
    A[1758] = 0;
    A[1759] = 0;
    A[1760] = 0;
    A[1761] = 0;
    A[1762] = 0;
    A[1763] = 0;
    A[1764] = 0;
    A[1765] = 0;
    A[1766] = 0;
    A[1767] = 0;
    A[1768] = 0;
    A[1769] = 0;
    A[1770] = 0;
    A[1771] = 0;
    A[1772] = 0;
    A[1773] = 0;
    A[1774] = 0;
    A[1775] = 0;
    A[1776] = 0;
    A[1777] = 0;
    A[1778] = 0;
    A[1779] = 0;
    A[1780] = 0;
    A[1781] = 0;
    A[1782] = 0;
    A[1783] = 0;
    A[1784] = 0;
    A[1785] = 0;
    A[1786] = 0;
    A[1787] = 0;
    A[1788] = 0;
    A[1789] = 0;
    A[1790] = 0;
    A[1791] = 0;
    A[1792] = 0;
    A[1793] = 0;
    A[1794] = 0;
    A[1795] = 0;
    A[1796] = 0;
    A[1797] = 0;
    A[1798] = 0;
    A[1799] = 0;
    A[1800] = 0;
    A[1801] = 0;
    A[1802] = 0;
    A[1803] = 0;
    A[1804] = 0;
    A[1805] = 0;
    A[1806] = 0;
    A[1807] = 0;
    A[1808] = 0;
    A[1809] = 0;
    A[1810] = 0;
    A[1811] = 0;
    A[1812] = 0;
    A[1813] = 0;
    A[1814] = 0;
    A[1815] = 0;
    A[1816] = 0;
    A[1817] = 0;
    A[1818] = 0;
    A[1819] = 0;
    A[1820] = 0;
    A[1821] = 0;
    A[1822] = 0;
    A[1823] = 0;
    A[1824] = 0;
    A[1825] = 0;
    A[1826] = 0;
    A[1827] = 0;
    A[1828] = 0;
    A[1829] = 0;
    A[1830] = 0;
    A[1831] = 0;
    A[1832] = 0;
    A[1833] = 0;
    A[1834] = 0;
    A[1835] = 0;
    A[1836] = 0;
    A[1837] = 0;
    A[1838] = 0;
    A[1839] = 0;
    A[1840] = 0;
    A[1841] = 0;
    A[1842] = 0;
    A[1843] = 0;
    A[1844] = 0;
    A[1845] = 0;
    A[1846] = 0;
    A[1847] = 0;
    A[1848] = 0;
    A[1849] = 0;
    A[1850] = 0;
    A[1851] = 0;
    A[1852] = 0;
    A[1853] = 0;
    A[1854] = 0;
    A[1855] = 0;
    A[1856] = 0;
    A[1857] = 0;
    A[1858] = 0;
    A[1859] = 0;
    A[1860] = 0;
    A[1861] = 0;
    A[1862] = 0;
    A[1863] = 0;
    A[1864] = 0;
    A[1865] = 0;
    A[1866] = 0;
    A[1867] = 0;
    A[1868] = 0;
    A[1869] = 0;
    A[1870] = 0;
    A[1871] = 0;
    A[1872] = 0;
    A[1873] = 0;
    A[1874] = 0;
    A[1875] = 0;
    A[1876] = 0;
    A[1877] = 0;
    A[1878] = 0;
    A[1879] = 0;
    A[1880] = 0;
    A[1881] = 0;
    A[1882] = 0;
    A[1883] = 0;
    A[1884] = 0;
    A[1885] = 0;
    A[1886] = 0;
    A[1887] = 0;
    A[1888] = 0;
    A[1889] = 0;
    A[1890] = 0;
    A[1891] = 0;
    A[1892] = 0;
    A[1893] = 0;
    A[1894] = 0;
    A[1895] = 0;
    A[1896] = 0;
    A[1897] = 0;
    A[1898] = 0;
    A[1899] = 0;
    A[1900] = 0;
    A[1901] = 0;
    A[1902] = 0;
    A[1903] = 0;
    A[1904] = 0;
    A[1905] = 0;
    A[1906] = 0;
    A[1907] = 0;
    A[1908] = 0;
    A[1909] = 0;
    A[1910] = 0;
    A[1911] = 0;
    A[1912] = 0;
    A[1913] = 0;
    A[1914] = 0;
    A[1915] = 0;
    A[1916] = 0;
    A[1917] = 0;
    A[1918] = 0;
    A[1919] = 0;
    A[1920] = 0;
    A[1921] = 0;
    A[1922] = 0;
    A[1923] = 0;
    A[1924] = 0;
    A[1925] = 0;
    A[1926] = 0;
    A[1927] = 0;
    A[1928] = 0;
    A[1929] = 0;
    A[1930] = 0;
    A[1931] = 0;
    A[1932] = 0;
    A[1933] = 0;
    A[1934] = 0;
    A[1935] = 0;
    A[1936] = 0;
    A[1937] = 0;
    A[1938] = 0;
    A[1939] = 0;
    A[1940] = 0;
    A[1941] = 0;
    A[1942] = 0;
    A[1943] = 0;
    A[1944] = 0;
    A[1945] = 0;
    A[1946] = 0;
    A[1947] = 0;
    A[1948] = 0;
    A[1949] = 0;
    A[1950] = 0;
    A[1951] = 0;
    A[1952] = 0;
    A[1953] = 0;
    A[1954] = 0;
    A[1955] = 0;
    A[1956] = 0;
    A[1957] = 0;
    A[1958] = 0;
    A[1959] = 0;
    A[1960] = 0;
    A[1961] = 0;
    A[1962] = 0;
    A[1963] = 0;
    A[1964] = 0;
    A[1965] = 0;
    A[1966] = 0;
    A[1967] = 0;
    A[1968] = 0;
    A[1969] = 0;
    A[1970] = 0;
    A[1971] = 0;
    A[1972] = 0;
    A[1973] = 0;
    A[1974] = 0;
    A[1975] = 0;
    A[1976] = 0;
    A[1977] = 0;
    A[1978] = 0;
    A[1979] = 0;
    A[1980] = 0;
    A[1981] = 0;
    A[1982] = 0;
    A[1983] = 0;
    A[1984] = 0;
    A[1985] = 0;
    A[1986] = 0;
    A[1987] = 0;
    A[1988] = 0;
    A[1989] = 0;
    A[1990] = 0;
    A[1991] = 0;
    A[1992] = 0;
    A[1993] = 0;
    A[1994] = 0;
    A[1995] = 0;
    A[1996] = 0;
    A[1997] = 0;
    A[1998] = 0;
    A[1999] = 0;
    A[2000] = 0;
    A[2001] = 0;
    A[2002] = 0;
    A[2003] = 0;
    A[2004] = 0;
    A[2005] = 0;
    A[2006] = 0;
    A[2007] = 0;
    A[2008] = 0;
    A[2009] = 0;
    A[2010] = 0;
    A[2011] = 0;
    A[2012] = 0;
    A[2013] = 0;
    A[2014] = 0;
    A[2015] = 0;
    A[2016] = 0;
    A[2017] = 0;
    A[2018] = 0;
    A[2019] = 0;
    A[2020] = 0;
    A[2021] = 0;
    A[2022] = 0;
    A[2023] = 0;
    A[2024] = 0;
    A[2025] = 0;
    A[2026] = 0;
    A[2027] = 0;
    A[2028] = 0;
    A[2029] = 0;
    A[2030] = 0;
    A[2031] = 0;
    A[2032] = 0;
    A[2033] = 0;
    A[2034] = 0;
    A[2035] = 0;
    A[2036] = 0;
    A[2037] = 0;
    A[2038] = 0;
    A[2039] = 0;
    A[2040] = 0;
    A[2041] = 0;
    A[2042] = 0;
    A[2043] = 0;
    A[2044] = 0;
    A[2045] = 0;
    A[2046] = 0;
    A[2047] = 0;
    A[2048] = 0;
    A[2049] = 0;
    A[2050] = 0;
    A[2051] = 0;
    A[2052] = 0;
    A[2053] = 0;
    A[2054] = 0;
    A[2055] = 0;
    A[2056] = 0;
    A[2057] = 0;
    A[2058] = 0;
    A[2059] = 0;
    A[2060] = 0;
    A[2061] = 0;
    A[2062] = 0;
    A[2063] = 0;
    A[2064] = 0;
    A[2065] = 0;
    A[2066] = 0;
    A[2067] = 0;
    A[2068] = 0;
    A[2069] = 0;
    A[2070] = 0;
    A[2071] = 0;
    A[2072] = 0;
    A[2073] = 0;
    A[2074] = 0;
    A[2075] = 0;
    A[2076] = 0;
    A[2077] = 0;
    A[2078] = 0;
    A[2079] = 0;
    A[2080] = 0;
    A[2081] = 0;
    A[2082] = 0;
    A[2083] = 0;
    A[2084] = 0;
    A[2085] = 0;
    A[2086] = 0;
    A[2087] = 0;
    A[2088] = 0;
    A[2089] = 0;
    A[2090] = 0;
    A[2091] = 0;
    A[2092] = 0;
    A[2093] = 0;
    A[2094] = 0;
    A[2095] = 0;
    A[2096] = 0;
    A[2097] = 0;
    A[2098] = 0;
    A[2099] = 0;
    A[2100] = 0;
    A[2101] = 0;
    A[2102] = 0;
    A[2103] = 0;
    A[2104] = 0;
    A[2105] = 0;
    A[2106] = 0;
    A[2107] = 0;
    A[2108] = 0;
    A[2109] = 0;
    A[2110] = 0;
    A[2111] = 0;
    A[2112] = 0;
    A[2113] = 0;
    A[2114] = 0;
    A[2115] = 0;
    A[2116] = 0;
    A[2117] = 0;
    A[2118] = 0;
    A[2119] = 0;
    A[2120] = 0;
    A[2121] = 0;
    A[2122] = 0;
    A[2123] = 0;
    A[2124] = 0;
    A[2125] = 0;
    A[2126] = 0;
    A[2127] = 0;
    A[2128] = 0;
    A[2129] = 0;
    A[2130] = 0;
    A[2131] = 0;
    A[2132] = 0;
    A[2133] = 0;
    A[2134] = 0;
    A[2135] = 0;
    A[2136] = 0;
    A[2137] = 0;
    A[2138] = 0;
    A[2139] = 0;
    A[2140] = 0;
    A[2141] = 0;
    A[2142] = 0;
    A[2143] = 0;
    A[2144] = 0;
    A[2145] = 0;
    A[2146] = 0;
    A[2147] = 0;
    A[2148] = 0;
    A[2149] = 0;
    A[2150] = 0;
    A[2151] = 0;
    A[2152] = 0;
    A[2153] = 0;
    A[2154] = 0;
    A[2155] = 0;
    A[2156] = 0;
    A[2157] = 0;
    A[2158] = 0;
    A[2159] = 0;
    A[2160] = 0;
    A[2161] = 0;
    A[2162] = 0;
    A[2163] = 0;
    A[2164] = 0;
    A[2165] = 0;
    A[2166] = 0;
    A[2167] = 0;
    A[2168] = 0;
    A[2169] = 0;
    A[2170] = 0;
    A[2171] = 0;
    A[2172] = 0;
    A[2173] = 0;
    A[2174] = 0;
    A[2175] = 0;
    A[2176] = 0;
    A[2177] = 0;
    A[2178] = 0;
    A[2179] = 0;
    A[2180] = 0;
    A[2181] = 0;
    A[2182] = 0;
    A[2183] = 0;
    A[2184] = 0;
    A[2185] = 0;
    A[2186] = 0;
    A[2187] = 0;
    A[2188] = 0;
    A[2189] = 0;
    A[2190] = 0;
    A[2191] = 0;
    A[2192] = 0;
    A[2193] = 0;
    A[2194] = 0;
    A[2195] = 0;
    A[2196] = 0;
    A[2197] = 0;
    A[2198] = 0;
    A[2199] = 0;
    A[2200] = 0;
    A[2201] = 0;
    A[2202] = 0;
    A[2203] = 0;
    A[2204] = 0;
    A[2205] = 0;
    A[2206] = 0;
    A[2207] = 0;
    A[2208] = 0;
    A[2209] = 0;
    A[2210] = 0;
    A[2211] = 0;
    A[2212] = 0;
    A[2213] = 0;
    A[2214] = 0;
    A[2215] = 0;
    A[2216] = 0;
    A[2217] = 0;
    A[2218] = 0;
    A[2219] = 0;
    A[2220] = 0;
    A[2221] = 0;
    A[2222] = 0;
    A[2223] = 0;
    A[2224] = 0;
    A[2225] = 0;
    A[2226] = 0;
    A[2227] = 0;
    A[2228] = 0;
    A[2229] = 0;
    A[2230] = 0;
    A[2231] = 0;
    A[2232] = 0;
    A[2233] = 0;
    A[2234] = 0;
    A[2235] = 0;
    A[2236] = 0;
    A[2237] = 0;
    A[2238] = 0;
    A[2239] = 0;
    A[2240] = 0;
    A[2241] = 0;
    A[2242] = 0;
    A[2243] = 0;
    A[2244] = 0;
    A[2245] = 0;
    A[2246] = 0;
    A[2247] = 0;
    A[2248] = 0;
    A[2249] = 0;
    A[2250] = 0;
    A[2251] = 0;
    A[2252] = 0;
    A[2253] = 0;
    A[2254] = 0;
    A[2255] = 0;
    A[2256] = 0;
    A[2257] = 0;
    A[2258] = 0;
    A[2259] = 0;
    A[2260] = 0;
    A[2261] = 0;
    A[2262] = 0;
    A[2263] = 0;
    A[2264] = 0;
    A[2265] = 0;
    A[2266] = 0;
    A[2267] = 0;
    A[2268] = 0;
    A[2269] = 0;
    A[2270] = 0;
    A[2271] = 0;
    A[2272] = 0;
    A[2273] = 0;
    A[2274] = 0;
    A[2275] = 0;
    A[2276] = 0;
    A[2277] = 0;
    A[2278] = 0;
    A[2279] = 0;
    A[2280] = 0;
    A[2281] = 0;
    A[2282] = 0;
    A[2283] = 0;
    A[2284] = 0;
    A[2285] = 0;
    A[2286] = 0;
    A[2287] = 0;
    A[2288] = 0;
    A[2289] = 0;
    A[2290] = 0;
    A[2291] = 0;
    A[2292] = 0;
    A[2293] = 0;
    A[2294] = 0;
    A[2295] = 0;
    A[2296] = 0;
    A[2297] = 0;
    A[2298] = 0;
    A[2299] = 0;
    A[2300] = 0;
    A[2301] = 0;
    A[2302] = 0;
    A[2303] = 0;
    A[2304] = 0;
    A[2305] = 0;
    A[2306] = 0;
    A[2307] = 0;
    A[2308] = 0;
    A[2309] = 0;
    A[2310] = 0;
    A[2311] = 0;
    A[2312] = 0;
    A[2313] = 0;
    A[2314] = 0;
    A[2315] = 0;
    A[2316] = 0;
    A[2317] = 0;
    A[2318] = 0;
    A[2319] = 0;
    A[2320] = 0;
    A[2321] = 0;
    A[2322] = 0;
    A[2323] = 0;
    A[2324] = 0;
    A[2325] = 0;
    A[2326] = 0;
    A[2327] = 0;
    A[2328] = 0;
    A[2329] = 0;
    A[2330] = 0;
    A[2331] = 0;
    A[2332] = 0;
    A[2333] = 0;
    A[2334] = 0;
    A[2335] = 0;
    A[2336] = 0;
    A[2337] = 0;
    A[2338] = 0;
    A[2339] = 0;
    A[2340] = 0;
    A[2341] = 0;
    A[2342] = 0;
    A[2343] = 0;
    A[2344] = 0;
    A[2345] = 0;
    A[2346] = 0;
    A[2347] = 0;
    A[2348] = 0;
    A[2349] = 0;
    A[2350] = 0;
    A[2351] = 0;
    A[2352] = 0;
    A[2353] = 0;
    A[2354] = 0;
    A[2355] = 0;
    A[2356] = 0;
    A[2357] = 0;
    A[2358] = 0;
    A[2359] = 0;
    A[2360] = 0;
    A[2361] = 0;
    A[2362] = 0;
    A[2363] = 0;
    A[2364] = 0;
    A[2365] = 0;
    A[2366] = 0;
    A[2367] = 0;
    A[2368] = 0;
    A[2369] = 0;
    A[2370] = 0;
    A[2371] = 0;
    A[2372] = 0;
    A[2373] = 0;
    A[2374] = 0;
    A[2375] = 0;
    A[2376] = 0;
    A[2377] = 0;
    A[2378] = 0;
    A[2379] = 0;
    A[2380] = 0;
    A[2381] = 0;
    A[2382] = 0;
    A[2383] = 0;
    A[2384] = 0;
    A[2385] = 0;
    A[2386] = 0;
    A[2387] = 0;
    A[2388] = 0;
    A[2389] = 0;
    A[2390] = 0;
    A[2391] = 0;
    A[2392] = 0;
    A[2393] = 0;
    A[2394] = 0;
    A[2395] = 0;
    A[2396] = 0;
    A[2397] = 0;
    A[2398] = 0;
    A[2399] = 0;
    A[2400] = 0;
    A[2401] = 0;
    A[2402] = 0;
    A[2403] = 0;
    A[2404] = 0;
    A[2405] = 0;
    A[2406] = 0;
    A[2407] = 0;
    A[2408] = 0;
    A[2409] = 0;
    A[2410] = 0;
    A[2411] = 0;
    A[2412] = 0;
    A[2413] = 0;
    A[2414] = 0;
    A[2415] = 0;
    A[2416] = 0;
    A[2417] = 0;
    A[2418] = 0;
    A[2419] = 0;
    A[2420] = 0;
    A[2421] = 0;
    A[2422] = 0;
    A[2423] = 0;
    A[2424] = 0;
    A[2425] = 0;
    A[2426] = 0;
    A[2427] = 0;
    A[2428] = 0;
    A[2429] = 0;
    A[2430] = 0;
    A[2431] = 0;
    A[2432] = 0;
    A[2433] = 0;
    A[2434] = 0;
    A[2435] = 0;
    A[2436] = 0;
    A[2437] = 0;
    A[2438] = 0;
    A[2439] = 0;
    A[2440] = 0;
    A[2441] = 0;
    A[2442] = 0;
    A[2443] = 0;
    A[2444] = 0;
    A[2445] = 0;
    A[2446] = 0;
    A[2447] = 0;
    A[2448] = 0;
    A[2449] = 0;
    A[2450] = 0;
    A[2451] = 0;
    A[2452] = 0;
    A[2453] = 0;
    A[2454] = 0;
    A[2455] = 0;
    A[2456] = 0;
    A[2457] = 0;
    A[2458] = 0;
    A[2459] = 0;
    A[2460] = 0;
    A[2461] = 0;
    A[2462] = 0;
    A[2463] = 0;
    A[2464] = 0;
    A[2465] = 0;
    A[2466] = 0;
    A[2467] = 0;
    A[2468] = 0;
    A[2469] = 0;
    A[2470] = 0;
    A[2471] = 0;
    A[2472] = 0;
    A[2473] = 0;
    A[2474] = 0;
    A[2475] = 0;
    A[2476] = 0;
    A[2477] = 0;
    A[2478] = 0;
    A[2479] = 0;
    A[2480] = 0;
    A[2481] = 0;
    A[2482] = 0;
    A[2483] = 0;
    A[2484] = 0;
    A[2485] = 0;
    A[2486] = 0;
    A[2487] = 0;
    A[2488] = 0;
    A[2489] = 0;
    A[2490] = 0;
    A[2491] = 0;
    A[2492] = 0;
    A[2493] = 0;
    A[2494] = 0;
    A[2495] = 0;
    A[2496] = 0;
    A[2497] = 0;
    A[2498] = 0;
    A[2499] = 0;
    A[2500] = 0;
    A[2501] = 0;
    A[2502] = 0;
    A[2503] = 0;
    A[2504] = 0;
    A[2505] = 0;
    A[2506] = 0;
    A[2507] = 0;
    A[2508] = 0;
    A[2509] = 0;
    A[2510] = 0;
    A[2511] = 0;
    A[2512] = 0;
    A[2513] = 0;
    A[2514] = 0;
    A[2515] = 0;
    A[2516] = 0;
    A[2517] = 0;
    A[2518] = 0;
    A[2519] = 0;
    A[2520] = 0;
    A[2521] = 0;
    A[2522] = 0;
    A[2523] = 0;
    A[2524] = 0;
    A[2525] = 0;
    A[2526] = 0;
    A[2527] = 0;
    A[2528] = 0;
    A[2529] = 0;
    A[2530] = 0;
    A[2531] = 0;
    A[2532] = 0;
    A[2533] = 0;
    A[2534] = 0;
    A[2535] = 0;
    A[2536] = 0;
    A[2537] = 0;
    A[2538] = 0;
    A[2539] = 0;
    A[2540] = 0;
    A[2541] = 0;
    A[2542] = 0;
    A[2543] = 0;
    A[2544] = 0;
    A[2545] = 0;
    A[2546] = 0;
    A[2547] = 0;
    A[2548] = 0;
    A[2549] = 0;
    A[2550] = 0;
    A[2551] = 0;
    A[2552] = 0;
    A[2553] = 0;
    A[2554] = 0;
    A[2555] = 0;
    A[2556] = 0;
    A[2557] = 0;
    A[2558] = 0;
    A[2559] = 0;
    A[2560] = 0;
    A[2561] = 0;
    A[2562] = 0;
    A[2563] = 0;
    A[2564] = 0;
    A[2565] = 0;
    A[2566] = 0;
    A[2567] = 0;
    A[2568] = 0;
    A[2569] = 0;
    A[2570] = 0;
    A[2571] = 0;
    A[2572] = 0;
    A[2573] = 0;
    A[2574] = 0;
    A[2575] = 0;
    A[2576] = 0;
    A[2577] = 0;
    A[2578] = 0;
    A[2579] = 0;
    A[2580] = 0;
    A[2581] = 0;
    A[2582] = 0;
    A[2583] = 0;
    A[2584] = 0;
    A[2585] = 0;
    A[2586] = 0;
    A[2587] = 0;
    A[2588] = 0;
    A[2589] = 0;
    A[2590] = 0;
    A[2591] = 0;
    A[2592] = 0;
    A[2593] = 0;
    A[2594] = 0;
    A[2595] = 0;
    A[2596] = 0;
    A[2597] = 0;
    A[2598] = 0;
    A[2599] = 0;
    A[2600] = 0;
    A[2601] = 0;
    A[2602] = 0;
    A[2603] = 0;
    A[2604] = 0;
    A[2605] = 0;
    A[2606] = 0;
    A[2607] = 0;
    A[2608] = 0;
    A[2609] = 0;
    A[2610] = 0;
    A[2611] = 0;
    A[2612] = 0;
    A[2613] = 0;
    A[2614] = 0;
    A[2615] = 0;
    A[2616] = 0;
    A[2617] = 0;
    A[2618] = 0;
    A[2619] = 0;
    A[2620] = 0;
    A[2621] = 0;
    A[2622] = 0;
    A[2623] = 0;
    A[2624] = 0;
    A[2625] = 0;
    A[2626] = 0;
    A[2627] = 0;
    A[2628] = 0;
    A[2629] = 0;
    A[2630] = 0;
    A[2631] = 0;
    A[2632] = 0;
    A[2633] = 0;
    A[2634] = 0;
    A[2635] = 0;
    A[2636] = 0;
    A[2637] = 0;
    A[2638] = 0;
    A[2639] = 0;
    A[2640] = 0;
    A[2641] = 0;
    A[2642] = 0;
    A[2643] = 0;
    A[2644] = 0;
    A[2645] = 0;
    A[2646] = 0;
    A[2647] = 0;
    A[2648] = 0;
    A[2649] = 0;
    A[2650] = 0;
    A[2651] = 0;
    A[2652] = 0;
    A[2653] = 0;
    A[2654] = 0;
    A[2655] = 0;
    A[2656] = 0;
    A[2657] = 0;
    A[2658] = 0;
    A[2659] = 0;
    A[2660] = 0;
    A[2661] = 0;
    A[2662] = 0;
    A[2663] = 0;
    A[2664] = 0;
    A[2665] = 0;
    A[2666] = 0;
    A[2667] = 0;
    A[2668] = 0;
    A[2669] = 0;
    A[2670] = 0;
    A[2671] = 0;
    A[2672] = 0;
    A[2673] = 0;
    A[2674] = 0;
    A[2675] = 0;
    A[2676] = 0;
    A[2677] = 0;
    A[2678] = 0;
    A[2679] = 0;
    A[2680] = 0;
    A[2681] = 0;
    A[2682] = 0;
    A[2683] = 0;
    A[2684] = 0;
    A[2685] = 0;
    A[2686] = 0;
    A[2687] = 0;
    A[2688] = 0;
    A[2689] = 0;
    A[2690] = 0;
    A[2691] = 0;
    A[2692] = 0;
    A[2693] = 0;
    A[2694] = 0;
    A[2695] = 0;
    A[2696] = 0;
    A[2697] = 0;
    A[2698] = 0;
    A[2699] = 0;
    A[2700] = 0;
    A[2701] = 0;
    A[2702] = 0;
    A[2703] = 0;
    A[2704] = 0;
    A[2705] = 0;
    A[2706] = 0;
    A[2707] = 0;
    A[2708] = 0;
    A[2709] = 0;
    A[2710] = 0;
    A[2711] = 0;
    A[2712] = 0;
    A[2713] = 0;
    A[2714] = 0;
    A[2715] = 0;
    A[2716] = 0;
    A[2717] = 0;
    A[2718] = 0;
    A[2719] = 0;
    A[2720] = 0;
    A[2721] = 0;
    A[2722] = 0;
    A[2723] = 0;
    A[2724] = 0;
    A[2725] = 0;
    A[2726] = 0;
    A[2727] = 0;
    A[2728] = 0;
    A[2729] = 0;
    A[2730] = 0;
    A[2731] = 0;
    A[2732] = 0;
    A[2733] = 0;
    A[2734] = 0;
    A[2735] = 0;
    A[2736] = 0;
    A[2737] = 0;
    A[2738] = 0;
    A[2739] = 0;
    A[2740] = 0;
    A[2741] = 0;
    A[2742] = 0;
    A[2743] = 0;
    A[2744] = 0;
    A[2745] = 0;
    A[2746] = 0;
    A[2747] = 0;
    A[2748] = 0;
    A[2749] = 0;
    A[2750] = 0;
    A[2751] = 0;
    A[2752] = 0;
    A[2753] = 0;
    A[2754] = 0;
    A[2755] = 0;
    A[2756] = 0;
    A[2757] = 0;
    A[2758] = 0;
    A[2759] = 0;
    A[2760] = 0;
    A[2761] = 0;
    A[2762] = 0;
    A[2763] = 0;
    A[2764] = 0;
    A[2765] = 0;
    A[2766] = 0;
    A[2767] = 0;
    A[2768] = 0;
    A[2769] = 0;
    A[2770] = 0;
    A[2771] = 0;
    A[2772] = 0;
    A[2773] = 0;
    A[2774] = 0;
    A[2775] = 0;
    A[2776] = 0;
    A[2777] = 0;
    A[2778] = 0;
    A[2779] = 0;
    A[2780] = 0;
    A[2781] = 0;
    A[2782] = 0;
    A[2783] = 0;
    A[2784] = 0;
    A[2785] = 0;
    A[2786] = 0;
    A[2787] = 0;
    A[2788] = 0;
    A[2789] = 0;
    A[2790] = 0;
    A[2791] = 0;
    A[2792] = 0;
    A[2793] = 0;
    A[2794] = 0;
    A[2795] = 0;
    A[2796] = 0;
    A[2797] = 0;
    A[2798] = 0;
    A[2799] = 0;
    A[2800] = 0;
    A[2801] = 0;
    A[2802] = 0;
    A[2803] = 0;
    A[2804] = 0;
    A[2805] = 0;
    A[2806] = 0;
    A[2807] = 0;
    A[2808] = 0;
    A[2809] = 0;
    A[2810] = 0;
    A[2811] = 0;
    A[2812] = 0;
    A[2813] = 0;
    A[2814] = 0;
    A[2815] = 0;
    A[2816] = 0;
    A[2817] = 0;
    A[2818] = 0;
    A[2819] = 0;
    A[2820] = 0;
    A[2821] = 0;
    A[2822] = 0;
    A[2823] = 0;
    A[2824] = 0;
    A[2825] = 0;
    A[2826] = 0;
    A[2827] = 0;
    A[2828] = 0;
    A[2829] = 0;
    A[2830] = 0;
    A[2831] = 0;
    A[2832] = 0;
    A[2833] = 0;
    A[2834] = 0;
    A[2835] = 0;
    A[2836] = 0;
    A[2837] = 0;
    A[2838] = 0;
    A[2839] = 0;
    A[2840] = 0;
    A[2841] = 0;
    A[2842] = 0;
    A[2843] = 0;
    A[2844] = 0;
    A[2845] = 0;
    A[2846] = 0;
    A[2847] = 0;
    A[2848] = 0;
    A[2849] = 0;
    A[2850] = 0;
    A[2851] = 0;
    A[2852] = 0;
    A[2853] = 0;
    A[2854] = 0;
    A[2855] = 0;
    A[2856] = 0;
    A[2857] = 0;
    A[2858] = 0;
    A[2859] = 0;
    A[2860] = 0;
    A[2861] = 0;
    A[2862] = 0;
    A[2863] = 0;
    A[2864] = 0;
    A[2865] = 0;
    A[2866] = 0;
    A[2867] = 0;
    A[2868] = 0;
    A[2869] = 0;
    A[2870] = 0;
    A[2871] = 0;
    A[2872] = 0;
    A[2873] = 0;
    A[2874] = 0;
    A[2875] = 0;
    A[2876] = 0;
    A[2877] = 0;
    A[2878] = 0;
    A[2879] = 0;
    A[2880] = 0;
    A[2881] = 0;
    A[2882] = 0;
    A[2883] = 0;
    A[2884] = 0;
    A[2885] = 0;
    A[2886] = 0;
    A[2887] = 0;
    A[2888] = 0;
    A[2889] = 0;
    A[2890] = 0;
    A[2891] = 0;
    A[2892] = 0;
    A[2893] = 0;
    A[2894] = 0;
    A[2895] = 0;
    A[2896] = 0;
    A[2897] = 0;
    A[2898] = 0;
    A[2899] = 0;
    A[2900] = 0;
    A[2901] = 0;
    A[2902] = 0;
    A[2903] = 0;
    A[2904] = 0;
    A[2905] = 0;
    A[2906] = 0;
    A[2907] = 0;
    A[2908] = 0;
    A[2909] = 0;
    A[2910] = 0;
    A[2911] = 0;
    A[2912] = 0;
    A[2913] = 0;
    A[2914] = 0;
    A[2915] = 0;
    A[2916] = 0;
    A[2917] = 0;
    A[2918] = 0;
    A[2919] = 0;
    A[2920] = 0;
    A[2921] = 0;
    A[2922] = 0;
    A[2923] = 0;
    A[2924] = 0;
    A[2925] = 0;
    A[2926] = 0;
    A[2927] = 0;
    A[2928] = 0;
    A[2929] = 0;
    A[2930] = 0;
    A[2931] = 0;
    A[2932] = 0;
    A[2933] = 0;
    A[2934] = 0;
    A[2935] = 0;
    A[2936] = 0;
    A[2937] = 0;
    A[2938] = 0;
    A[2939] = 0;
    A[2940] = 0;
    A[2941] = 0;
    A[2942] = 0;
    A[2943] = 0;
    A[2944] = 0;
    A[2945] = 0;
    A[2946] = 0;
    A[2947] = 0;
    A[2948] = 0;
    A[2949] = 0;
    A[2950] = 0;
    A[2951] = 0;
    A[2952] = 0;
    A[2953] = 0;
    A[2954] = 0;
    A[2955] = 0;
    A[2956] = 0;
    A[2957] = 0;
    A[2958] = 0;
    A[2959] = 0;
    A[2960] = 0;
    A[2961] = 0;
    A[2962] = 0;
    A[2963] = 0;
    A[2964] = 0;
    A[2965] = 0;
    A[2966] = 0;
    A[2967] = 0;
    A[2968] = 0;
    A[2969] = 0;
    A[2970] = 0;
    A[2971] = 0;
    A[2972] = 0;
    A[2973] = 0;
    A[2974] = 0;
    A[2975] = 0;
    A[2976] = 0;
    A[2977] = 0;
    A[2978] = 0;
    A[2979] = 0;
    A[2980] = 0;
    A[2981] = 0;
    A[2982] = 0;
    A[2983] = 0;
    A[2984] = 0;
    A[2985] = 0;
    A[2986] = 0;
    A[2987] = 0;
    A[2988] = 0;
    A[2989] = 0;
    A[2990] = 0;
    A[2991] = 0;
    A[2992] = 0;
    A[2993] = 0;
    A[2994] = 0;
    A[2995] = 0;
    A[2996] = 0;
    A[2997] = 0;
    A[2998] = 0;
    A[2999] = 0;
    A[3000] = 0;
    A[3001] = 0;
    A[3002] = 0;
    A[3003] = 0;
    A[3004] = 0;
    A[3005] = 0;
    A[3006] = 0;
    A[3007] = 0;
    A[3008] = 0;
    A[3009] = 0;
    A[3010] = 0;
    A[3011] = 0;
    A[3012] = 0;
    A[3013] = 0;
    A[3014] = 0;
    A[3015] = 0;
    A[3016] = 0;
    A[3017] = 0;
    A[3018] = 0;
    A[3019] = 0;
    A[3020] = 0;
    A[3021] = 0;
    A[3022] = 0;
    A[3023] = 0;
    A[3024] = 0;
    A[3025] = 0;
    A[3026] = 0;
    A[3027] = 0;
    A[3028] = 0;
    A[3029] = 0;
    A[3030] = 0;
    A[3031] = 0;
    A[3032] = 0;
    A[3033] = 0;
    A[3034] = 0;
    A[3035] = 0;
    A[3036] = 0;
    A[3037] = 0;
    A[3038] = 0;
    A[3039] = 0;
    A[3040] = 0;
    A[3041] = 0;
    A[3042] = 0;
    A[3043] = 0;
    A[3044] = 0;
    A[3045] = 0;
    A[3046] = 0;
    A[3047] = 0;
    A[3048] = 0;
    A[3049] = 0;
    A[3050] = 0;
    A[3051] = 0;
    A[3052] = 0;
    A[3053] = 0;
    A[3054] = 0;
    A[3055] = 0;
    A[3056] = 0;
    A[3057] = 0;
    A[3058] = 0;
    A[3059] = 0;
    A[3060] = 0;
    A[3061] = 0;
    A[3062] = 0;
    A[3063] = 0;
    A[3064] = 0;
    A[3065] = 0;
    A[3066] = 0;
    A[3067] = 0;
    A[3068] = 0;
    A[3069] = 0;
    A[3070] = 0;
    A[3071] = 0;
    A[3072] = 0;
    A[3073] = 0;
    A[3074] = 0;
    A[3075] = 0;
    A[3076] = 0;
    A[3077] = 0;
    A[3078] = 0;
    A[3079] = 0;
    A[3080] = 0;
    A[3081] = 0;
    A[3082] = 0;
    A[3083] = 0;
    A[3084] = 0;
    A[3085] = 0;
    A[3086] = 0;
    A[3087] = 0;
    A[3088] = 0;
    A[3089] = 0;
    A[3090] = 0;
    A[3091] = 0;
    A[3092] = 0;
    A[3093] = 0;
    A[3094] = 0;
    A[3095] = 0;
    A[3096] = 0;
    A[3097] = 0;
    A[3098] = 0;
    A[3099] = 0;
    A[3100] = 0;
    A[3101] = 0;
    A[3102] = 0;
    A[3103] = 0;
    A[3104] = 0;
    A[3105] = 0;
    A[3106] = 0;
    A[3107] = 0;
    A[3108] = 0;
    A[3109] = 0;
    A[3110] = 0;
    A[3111] = 0;
    A[3112] = 0;
    A[3113] = 0;
    A[3114] = 0;
    A[3115] = 0;
    A[3116] = 0;
    A[3117] = 0;
    A[3118] = 0;
    A[3119] = 0;
    A[3120] = 0;
    A[3121] = 0;
    A[3122] = 0;
    A[3123] = 0;
    A[3124] = 0;
    A[3125] = 0;
    A[3126] = 0;
    A[3127] = 0;
    A[3128] = 0;
    A[3129] = 0;
    A[3130] = 0;
    A[3131] = 0;
    A[3132] = 0;
    A[3133] = 0;
    A[3134] = 0;
    A[3135] = 0;
    
    // Add all contributions to element tensor
    integral_0_quadrature.tabulate_tensor(A, w, c);
  }

};

/// This class defines the interface for the assembly of the global
/// tensor corresponding to a form with r + n arguments, that is, a
/// mapping
///
///     a : V1 x V2 x ... Vr x W1 x W2 x ... x Wn -> R
///
/// with arguments v1, v2, ..., vr, w1, w2, ..., wn. The rank r
/// global tensor A is defined by
///
///     A = a(V1, V2, ..., Vr, w1, w2, ..., wn),
///
/// where each argument Vj represents the application to the
/// sequence of basis functions of Vj and w1, w2, ..., wn are given
/// fixed functions (coefficients).

class poisson3d_5_form_0: public ufc::form
{
public:

  /// Constructor
  poisson3d_5_form_0() : ufc::form()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_form_0()
  {
    // Do nothing
  }

  /// Return a string identifying the form
  virtual const char* signature() const
  {
    return "Form([Integral(IndexSum(Product(SpatialDerivative(BasisFunction(FiniteElement('Lagrange', Cell('tetrahedron', 1), 5), 0), MultiIndex((Index(0),), {Index(0): 3})), SpatialDerivative(BasisFunction(FiniteElement('Lagrange', Cell('tetrahedron', 1), 5), 1), MultiIndex((Index(0),), {Index(0): 3}))), MultiIndex((Index(0),), {Index(0): 3})), Measure('cell', 0, None))])";
  }

  /// Return the rank of the global tensor (r)
  virtual unsigned int rank() const
  {
    return 2;
  }

  /// Return the number of coefficients (n)
  virtual unsigned int num_coefficients() const
  {
    return 0;
  }

  /// Return the number of cell integrals
  virtual unsigned int num_cell_integrals() const
  {
    return 1;
  }
  
  /// Return the number of exterior facet integrals
  virtual unsigned int num_exterior_facet_integrals() const
  {
    return 0;
  }
  
  /// Return the number of interior facet integrals
  virtual unsigned int num_interior_facet_integrals() const
  {
    return 0;
  }
    
  /// Create a new finite element for argument function i
  virtual ufc::finite_element* create_finite_element(unsigned int i) const
  {
    switch ( i )
    {
    case 0:
      return new poisson3d_5_0_finite_element_0();
      break;
    case 1:
      return new poisson3d_5_0_finite_element_1();
      break;
    }
    return 0;
  }
  
  /// Create a new dof map for argument function i
  virtual ufc::dof_map* create_dof_map(unsigned int i) const
  {
    switch ( i )
    {
    case 0:
      return new poisson3d_5_0_dof_map_0();
      break;
    case 1:
      return new poisson3d_5_0_dof_map_1();
      break;
    }
    return 0;
  }

  /// Create a new cell integral on sub domain i
  virtual ufc::cell_integral* create_cell_integral(unsigned int i) const
  {
    return new poisson3d_5_0_cell_integral_0();
  }

  /// Create a new exterior facet integral on sub domain i
  virtual ufc::exterior_facet_integral* create_exterior_facet_integral(unsigned int i) const
  {
    return 0;
  }

  /// Create a new interior facet integral on sub domain i
  virtual ufc::interior_facet_integral* create_interior_facet_integral(unsigned int i) const
  {
    return 0;
  }

};

/// This class defines the interface for a finite element.

class poisson3d_5_1_finite_element_0: public ufc::finite_element
{
public:

  /// Constructor
  poisson3d_5_1_finite_element_0() : ufc::finite_element()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_1_finite_element_0()
  {
    // Do nothing
  }

  /// Return a string identifying the finite element
  virtual const char* signature() const
  {
    return "FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return the cell shape
  virtual ufc::shape cell_shape() const
  {
    return ufc::tetrahedron;
  }

  /// Return the dimension of the finite element function space
  virtual unsigned int space_dimension() const
  {
    return 56;
  }

  /// Return the rank of the value space
  virtual unsigned int value_rank() const
  {
    return 0;
  }

  /// Return the dimension of the value space for axis i
  virtual unsigned int value_dimension(unsigned int i) const
  {
    return 1;
  }

  /// Evaluate basis function i at given point in cell
  virtual void evaluate_basis(unsigned int i,
                              double* values,
                              const double* coordinates,
                              const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Reset values
    *values = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Extract relevant coefficients
    const double coeff0_0 = coefficients0[dof][0];
    const double coeff0_1 = coefficients0[dof][1];
    const double coeff0_2 = coefficients0[dof][2];
    const double coeff0_3 = coefficients0[dof][3];
    const double coeff0_4 = coefficients0[dof][4];
    const double coeff0_5 = coefficients0[dof][5];
    const double coeff0_6 = coefficients0[dof][6];
    const double coeff0_7 = coefficients0[dof][7];
    const double coeff0_8 = coefficients0[dof][8];
    const double coeff0_9 = coefficients0[dof][9];
    const double coeff0_10 = coefficients0[dof][10];
    const double coeff0_11 = coefficients0[dof][11];
    const double coeff0_12 = coefficients0[dof][12];
    const double coeff0_13 = coefficients0[dof][13];
    const double coeff0_14 = coefficients0[dof][14];
    const double coeff0_15 = coefficients0[dof][15];
    const double coeff0_16 = coefficients0[dof][16];
    const double coeff0_17 = coefficients0[dof][17];
    const double coeff0_18 = coefficients0[dof][18];
    const double coeff0_19 = coefficients0[dof][19];
    const double coeff0_20 = coefficients0[dof][20];
    const double coeff0_21 = coefficients0[dof][21];
    const double coeff0_22 = coefficients0[dof][22];
    const double coeff0_23 = coefficients0[dof][23];
    const double coeff0_24 = coefficients0[dof][24];
    const double coeff0_25 = coefficients0[dof][25];
    const double coeff0_26 = coefficients0[dof][26];
    const double coeff0_27 = coefficients0[dof][27];
    const double coeff0_28 = coefficients0[dof][28];
    const double coeff0_29 = coefficients0[dof][29];
    const double coeff0_30 = coefficients0[dof][30];
    const double coeff0_31 = coefficients0[dof][31];
    const double coeff0_32 = coefficients0[dof][32];
    const double coeff0_33 = coefficients0[dof][33];
    const double coeff0_34 = coefficients0[dof][34];
    const double coeff0_35 = coefficients0[dof][35];
    const double coeff0_36 = coefficients0[dof][36];
    const double coeff0_37 = coefficients0[dof][37];
    const double coeff0_38 = coefficients0[dof][38];
    const double coeff0_39 = coefficients0[dof][39];
    const double coeff0_40 = coefficients0[dof][40];
    const double coeff0_41 = coefficients0[dof][41];
    const double coeff0_42 = coefficients0[dof][42];
    const double coeff0_43 = coefficients0[dof][43];
    const double coeff0_44 = coefficients0[dof][44];
    const double coeff0_45 = coefficients0[dof][45];
    const double coeff0_46 = coefficients0[dof][46];
    const double coeff0_47 = coefficients0[dof][47];
    const double coeff0_48 = coefficients0[dof][48];
    const double coeff0_49 = coefficients0[dof][49];
    const double coeff0_50 = coefficients0[dof][50];
    const double coeff0_51 = coefficients0[dof][51];
    const double coeff0_52 = coefficients0[dof][52];
    const double coeff0_53 = coefficients0[dof][53];
    const double coeff0_54 = coefficients0[dof][54];
    const double coeff0_55 = coefficients0[dof][55];
    
    // Compute value(s)
    *values = coeff0_0*basisvalue0 + coeff0_1*basisvalue1 + coeff0_2*basisvalue2 + coeff0_3*basisvalue3 + coeff0_4*basisvalue4 + coeff0_5*basisvalue5 + coeff0_6*basisvalue6 + coeff0_7*basisvalue7 + coeff0_8*basisvalue8 + coeff0_9*basisvalue9 + coeff0_10*basisvalue10 + coeff0_11*basisvalue11 + coeff0_12*basisvalue12 + coeff0_13*basisvalue13 + coeff0_14*basisvalue14 + coeff0_15*basisvalue15 + coeff0_16*basisvalue16 + coeff0_17*basisvalue17 + coeff0_18*basisvalue18 + coeff0_19*basisvalue19 + coeff0_20*basisvalue20 + coeff0_21*basisvalue21 + coeff0_22*basisvalue22 + coeff0_23*basisvalue23 + coeff0_24*basisvalue24 + coeff0_25*basisvalue25 + coeff0_26*basisvalue26 + coeff0_27*basisvalue27 + coeff0_28*basisvalue28 + coeff0_29*basisvalue29 + coeff0_30*basisvalue30 + coeff0_31*basisvalue31 + coeff0_32*basisvalue32 + coeff0_33*basisvalue33 + coeff0_34*basisvalue34 + coeff0_35*basisvalue35 + coeff0_36*basisvalue36 + coeff0_37*basisvalue37 + coeff0_38*basisvalue38 + coeff0_39*basisvalue39 + coeff0_40*basisvalue40 + coeff0_41*basisvalue41 + coeff0_42*basisvalue42 + coeff0_43*basisvalue43 + coeff0_44*basisvalue44 + coeff0_45*basisvalue45 + coeff0_46*basisvalue46 + coeff0_47*basisvalue47 + coeff0_48*basisvalue48 + coeff0_49*basisvalue49 + coeff0_50*basisvalue50 + coeff0_51*basisvalue51 + coeff0_52*basisvalue52 + coeff0_53*basisvalue53 + coeff0_54*basisvalue54 + coeff0_55*basisvalue55;
  }

  /// Evaluate all basis functions at given point in cell
  virtual void evaluate_basis_all(double* values,
                                  const double* coordinates,
                                  const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis() is not yet implemented.");
  }

  /// Evaluate order n derivatives of basis function i at given point in cell
  virtual void evaluate_basis_derivatives(unsigned int i,
                                          unsigned int n,
                                          double* values,
                                          const double* coordinates,
                                          const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Compute number of derivatives
    unsigned int num_derivatives = 1;
    
    for (unsigned int j = 0; j < n; j++)
      num_derivatives *= 3;
    
    
    // Declare pointer to two dimensional array that holds combinations of derivatives and initialise
    unsigned int **combinations = new unsigned int *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      combinations[j] = new unsigned int [n];
      for (unsigned int k = 0; k < n; k++)
        combinations[j][k] = 0;
    }
        
    // Generate combinations of derivatives
    for (unsigned int row = 1; row < num_derivatives; row++)
    {
      for (unsigned int num = 0; num < row; num++)
      {
        for (unsigned int col = n-1; col+1 > 0; col--)
        {
          if (combinations[row][col] + 1 > 2)
            combinations[row][col] = 0;
          else
          {
            combinations[row][col] += 1;
            break;
          }
        }
      }
    }
    
    // Compute inverse of Jacobian
    const double Jinv[3][3] ={{d00 / detJ, d10 / detJ, d20 / detJ}, {d01 / detJ, d11 / detJ, d21 / detJ}, {d02 / detJ, d12 / detJ, d22 / detJ}};
    
    // Declare transformation matrix
    // Declare pointer to two dimensional array and initialise
    double **transform = new double *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      transform[j] = new double [num_derivatives];
      for (unsigned int k = 0; k < num_derivatives; k++)
        transform[j][k] = 1;
    }
    
    // Construct transformation matrix
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        for (unsigned int k = 0; k < n; k++)
          transform[row][col] *= Jinv[combinations[col][k]][combinations[row][k]];
      }
    }
    
    // Reset values
    for (unsigned int j = 0; j < 1*num_derivatives; j++)
      values[j] = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Interesting (new) part
    // Tables of derivatives of the polynomial base (transpose)
    const static double dmats0[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.32455532033676, 0, -1.14376677014985e-14, 1.62513232038197e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.226276025168e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.2249721603218, 0, 0, 0, 1.51109207276003e-14, 0, 0, 1.7779939846807e-14, 0, -1.0584837800154e-14, 0, 0, 0, 0, 0, -1.00872575799093e-14, 0, 0, 1.03757106873844e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.58257569495584, 0, 8.36660026534074, -1.18321595661991, 0, -1.45923311721618e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.02203768115554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.74165738677394, 0, 0, 8.69482604771369, 0, 0, 0, 0, 1.78666554661835e-14, 0, 0, 0, 0, 0, 1.07473131066306e-14, 0, 0, 0, -1.11533477710537e-14, 2.38264269425414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.49909083394701, -1.6247766670982e-14, -3.3466401061363, -2.36643191323984, 15.4919333848297, 0, 0.692820323027544, 0, 0.565685424949235, 0.4, -1.83948951574252e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00288811754535e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.89897948556636, -1.43896667584992e-14, 0, 1.15516000140692e-14, 14.1985914794391, 0, -0.828078671210835, 2.47538399283584e-14, 0, 0, -1.83091262688552e-14, 1.02722007327841e-14, -1.56195834108856e-14, 0, 0, -1.91729044059553e-14, 0, 0, 0, 0, 0, 1.12036901882012e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.41804190462393e-14, 0, -1.19125833850358e-14, 0, 0, -1.13598572445865e-14, 0, -1.07549059979877e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.60000000000001, 0, 8.76356092008264, -1.54919333848296, 0, 0, 9.52470471983252, 0, -1.48131215963608, 0.261861468283188, 0, 0, 0, -2.03129367268393e-14, 0, 0, 2.48374782197935e-14, 0, -2.78808329533534e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.04489815276121e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00610790048597e-14, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.24264068711929, 0, 1.13239065646931e-14, 0, 0, 0, 14.3427433120127, 1.68846056927685e-14, 0, 0, 0, 0, 0, 1.92963956808162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.11769145362398, -1.38374576748428e-14, 3.16227766016837, 4.91934955049958, 0, 0, -1.29538515160783e-14, -1.04815557124913e-14, 10.690449676497, -2.41897262725904, 0, 0, 0, 0, 0, 2.10489624344795e-14, 0, -1.67945221763201e-14, -3.13102977027619e-14, 2.84355872182118e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.79907925474428e-14, 0, -1.53961627596513e-14, 1.10259024133086e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.54558441227157, 0, 0, 7.66811580507233, 0, 0, 0, 0, 2.32369836935692e-14, 10.3691851174526, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.60576914948, 0, 1.09730925298582e-14, 0, -4.20458932936042, 0, -3.43303281162797, 0, 0, 19.6214168703486, 0, 0.611677741841187, 1.15273118941668e-14, 0, 0.529728463363971, 0, 0.432521479156778, 0, 1.6058715222196e-14, 0, -1.16729361337554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.53137212479104, -1.01690618327065e-14, 3.54562104171169, -2.50713268211205, 4.78713553878169, 0, -5.56626745075489, 0, -1.04880884817015, 0.741619848709564, 0, 18.8034951158403, 0, 1.68183573174418, -0.603122387046456, 0, 0.70128378121765, 0, 0.132137494528682, -0.0934353184302471, 0, 0, 0, -1.0082826842246e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07842270669413e-14, 0, 0, 0, 0, 0, -1.43736268462506e-14, 0, 1.40644587163015e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.5951288749407, 0, 0, 0, 10.0285307284481, 0, -0.767649473578742, 0, 0, 0, 0, 16.4130361329658, -1.65111444887587e-14, 0, -1.26347611061158, 0, 0.0967147429123319, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.96647939483827, 0, 8.12403840463594, -1.64130361329659, 0, 0, 11.7728501222091, 0, -2.40312296813958, 0.48550415622761, 0, 0, 0, 10.2761860629321, 0, 0, -1.48323969741912, 0, 0.302765035409732, -0.0611677741841287, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.05298244095218, 0, -1.58564993434419, 4.48489528465109, 4.28174419288837, 0, 0.191485421551277, 0, -3.75233260785876, -4.31161222746203, 0, 0, 0, 0, 18.8807171866294, 0, 0.844371341865034, -1.40094110434133e-14, 1.18187368057056, 1.04463861754666, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.321153829896, 0, 0, 0, 3.92428337406971, 0, 5.49285249860475, 1.63666823149722e-14, 0, 0, 0, 0, -1.21592089550238e-14, 0, 17.3044631365566, -1.98459387250407e-14, -1.73008591662713, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.78485070541082e-14, 0, 0, 0, 0, -1.10973688891617e-14, 0, 2.78631828811134e-14, 0, 0, 0, 0},
    {2.65329983228432, -1.19347092313647e-14, 4.1522061999051, 2.93605316083777, 0, -1.18275179297788e-14, 2.63248931621762, 0, 9.82591326180786, -2.8226127713774, 0, 0, 0, -1.25702218603545e-14, 0, 1.56555930303565e-14, 11.6081867662439, -2.18250550506549e-14, -3.09487177319471, 0.68387650554026, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47816108620456e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.14018107676926e-14, 0, 0, 1.65626348131594e-14, 0, -2.85468388090362e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.01017818278146, 0, 1.31743415178767e-14, 0, 0, 0, 8.91928088068604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.8558564884489, 1.01802247187699e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.2978250586152, 0, 1.49829835452877, 5.50917601898538, 0, 0, 0, 0, 6.64803945320941, 4.13676892548488, 0, 0, 0, 0, 0, 1.7956276449824e-14, 0, 0, 12.5636136423842, -3.55352656109504, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.18752842449636e-14, 0, -1.81638809042383e-14, 1.41922064378353e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87616630392937, 0, 0, 6.22830929985768, 0, 0, 0, 0, 1.27788751430286e-14, 11.0541524195338, 0, 0, 0, 0, -1.24460589269538e-14, 0, 1.31323882635267e-14, 0, 0, 11.6057691494799, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.83186700722507, 0, -4.41087092453692, -3.11895674167863, 16.6749979177077, 0, 2.13065307820924, 0, 1.73967095350099, 1.23013312825382, 0, -4.3665394383501, 0, -0.557935943461974, -3.78153408023783, 0, -0.483186700722511, 0, -0.394520289089677, -0.278967971730981, 23.6981011897578, 0, 0.490653381462665, 0, 0.0626933893908993, 0, 0.438853725736261, 0, 0.05607467216716, 0.380058475033047, 0, 0.0485620906056402, 0, 0.0396507809422115, 0.028037336083582, 0, 0, 0, 0, 0, 0, -1.4054211872897e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.91050664139875, -2.39578864559553e-14, 0, 0, 10.5706241650195, 0, -2.72554057547698, -1.52585599320562e-14, 0, 4.67332857821918, 0, -7.8670586781146, -2.04874497115916e-14, 0, -2.39719223514613, 0, 0.618094504365256, 0, 0, 0, 23.10555488766, 0, 1.62065746295906, 0, -0.469687194424187, 0, 0.790669146636839, 0, 0, 0.240926884676761, 0, -0.0621208350291021, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00653548533975e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.85449644663772, 0, 5.98171817966648, -2.48806675764062, 1.90029237516522, 1.1743756718293e-14, -0.339934634239532, 0, -2.35922146606161, 0.981306762925312, 1.26408545402584e-14, 9.95226703056241, 0, -6.45364422706459, -0.430945803685666, 0, 0.0770899289327487, 1.15125419787792e-14, 0.535021138879238, -0.222539456105688, 0, 0, 21.5273297444417, 0, 2.75066129614998, 0, -1.00024047132728, 0, 0.648615649442923, 0.0433116829031338, 0, -0.00774782937530679, 0, -0.0537716476536673, 0.022366056877342, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.54523626091315, 0, 0, 0, 6.71778024562961, 0, -0.609449400220043, 0, 0, 0, 1.34513153299042e-14, 14.6593983227032, 0, 0, -1.52344936219872, 0, 0.138210132827979, 0, 0, 0, 0, 0, 18.119501277094, 0, 0, 0, -1.47332496632642, 0, 0, 0.153112421864225, 0, -0.0138906409944101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.52336024752225, 0, 7.37120708415866, -1.62882203585592, 0, 0, 12.0171306297064, 0, -2.90724328050878, 0.642416074439622, 0, 0, 0, 13.9858820944259, 0, -1.58432045778813e-14, -2.72522906732402, 0, 0.659300804656272, -0.145686271816947, 0, 0, 0, 0, 10.8043830863937, 0, 0, 0, -1.40563403846548, 0, 0, 0.273895826790425, 0, -0.066262224031037, 0.0146420212340151, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00201541731901e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.3084006188056, 0, -1.26706433592532e-14, 0, -1.52362350055011, 0, 11.1963004093827, -1.80488219855834e-14, 0, 4.26614580154031, 0, 0.132992762321602, 0, -2.81814707567137e-14, -4.72217953828916, 0, -6.6768459701302, 0, 0, 0, 0, 0, 0, 0, 23.1532444221696, 0, 0.721778878560592, 0, 0, 1.11125127955291, 0, 1.19087439227729, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.75883613229288e-14, 0, 0},
    {3.51865775274499, 0, 1.92724822331887, 2.72554057547696, 1.73472166622177, 0, -2.01705689521106, 0, 3.42052627529741, -4.03112887414929, 0, 4.08831086321549, 0, 0.365669640132029, 5.37643791520786, 0, -6.25148194071026, 0, -2.03981013744549, 1.80803322065276, 0, 0, 0, 0, 0, 0, 22.1880978975596, 0, 1.98456380761454, -1.26521523890981, 0, 1.4711357857929, 0, 0.363818136386341, -0.294009452979946, 0, 0, 0, 0, 0, 0, 0, -1.54553205611541e-14, 0, 1.15952481122279e-14, 0, 0, 1.43620668240546e-14, 0, 0, 0, 0, -1.05116925393268e-14, 0, 0, -1.5785116269651e-14},
    {0, 1.41060126129509, 0, 0, 0, 3.63405410063598, 0, 2.50356888118884, 0, 0, 0, 0, 3.56857028479907, 0, 0, 11.263055412878, 0, -1.49298814645068, 1.38190240500657e-14, 0, 0, 0, 0, 0, 0, 0, 0, 19.3673596462205, 0, 0, -2.65048896124153, 0, 0.266287609379577, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.60041438401192e-14, 0, 0, 0, -1.39285916740261e-14, 0, 0, 0, 0, -1.79660973598228e-14, 0, 0},
    {2.30350221379959, 0, 4.4158804331639, 1.78428514239954, 0, 0, 4.2661458015403, 0, 7.83741028656788, -2.63899331455874, 0, 0, 0, 2.23427840700301, 0, 0, 13.2221027072096, 0, -4.67379217909115, 1.18363558466232, 0, 0, 0, 0, 0, 0, 0, 0, 12.1258851598179, 0, 0, -3.11150358274815, 0, 0.833612074594106, -0.192474367616157, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18321633904026e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.80903542948782e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.14718316987778, 1.13474050017499e-14, -0.86189160737134, 6.09449400220041, 1.55158222708543, 0, 0.0693888666488805, 0, -3.0594117081557, 1.80277563773198, 1.20363012761808e-14, -1.0807889766904e-14, 0, 0, 9.03122156537878, 0, 0.403888506800973, -1.0302390341142e-14, -3.67461994579464, -5.49650682721195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21.7841260588564, -1.02507068376833e-14, 0.974215733960552, 0, 1.78974858569576, 1.8079190879493, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.26168012376113, 1.18273446592099e-14, 1.57200977122562e-14, 0, 1.42204860051343, 0, 4.47852016375308, 0, 0, 0, 1.10987276082662e-14, 0, 0, 0, 8.27725128825318, 0, 5.37909280973871, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.9654813226339, 0, -2.61992366301004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.24759447164935e-14, 0, 0},
    {2.06031501455084, -1.74209683534797e-14, 2.25696201807214, 3.98978286964829, 0, 0, 0.953939201416936, 0, 8.01142041980429, 1.18019368870418, 0, 0, 0, 0, 0, 1.94785199387925e-14, 5.55254896421454, -2.57142210914795e-14, 9.62241374388478, -3.59830837050572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13.3932520322736, 0, -4.68666192508058, 1.18356086726904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06752353778446e-14, 0, 0, -2.32785032194072e-14, 1.53466649110978e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.09264703862701, 0, -1.95067300612033e-14, 0, 0, 0, 5.38682254607084, 0, 0, 0, 0, 0, 0, -1.87552786673862e-14, 0, 0, 13.4377817958112, 0, -1.51672730138571e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18.907670401189, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.38196745713692e-14, 0, 0},
    {1.78428514239955, 0, 0.814411017927951, 5.06770487035908, 0, 0, 0, 0, 4.01510046524765, 6.58672305740272, 0, 0, 0, -1.66919444397739e-14, 0, 0, 0, 0, 10.0159311874144, 2.83293314500741, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14.0929454377398, -4.55552790213387, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.0397792145408e-14, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.45686271816937, 0, 0, 5.07816454066238, 0, 0, 0, 0, 0, 10.0142755247554, 0, 0, 1.12786864624392e-14, 0, 0, 2.17930072871246e-14, 0, 0, 0, 13.8784813613723, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.5535587278944, 0, 0, 0, 0, 0, 0, 0, 1.19526598856153e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats1[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.47722557505166, 0, 0, 1.40751126032068e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06911007824451e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.76376261582596, 0, 0, 0, 0, 1.14716615426708e-14, 0, -1.04150722074414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.09700660014256e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747793, 7.24568837309471, 4.18330013267037, -0.591607978309947, 0, 0, 0, 0, 1.56424483988496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-2.64575131106459, 0, 9.66091783079295, 0.683130051063975, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00911719995905e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 0, 0, 4.34741302385685, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.19132134712707e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.24037034920393, 0, 0, 7.52994023880671, 0, 0, 0, 0, 1.5531385856235e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00830684779644e-14, 2.81476231211997e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847576, -1.67332005306815, -1.18321595661991, 7.74596669241484, -1.2, 0.346410161513776, -0.979795897113268, 0.282842712474625, 0.200000000000004, -1.25790505365476e-14, 0, 0, 1.05528898544744e-14, 0, 0, 0, -1.12515066521072e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 9.16515138991169, 7.09929573971953, -2.04939015319193, -0.414039335605418, -0.478091443733742, 0.169030850945706, -1.25706005145317e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07716088515501e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.8, -5.69209978830307, 4.3817804600413, -0.774596669241499, 0, 10.998181667894, 4.76235235991625, 0.962140470884724, -0.740656079818034, 0.13093073414159, 0, -1.12401392033415e-14, 0, -3.21594604552363e-14, -1.31211420896762e-14, 0, 0, 0, -1.70767152060798e-14, -1.55264798414045e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2325574011616e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.03479319100648e-14, 0, 0, 0, 0, 0, 0},
    {5.19615242270665, 0, -3.16227766016841, -2.2360679774998, 0, 0, 13.7477270848675, 0, 0.534522483824853, 0.37796447300922, 0, 0, 0, -3.83748191193675e-14, 0, 0, 2.1315292421099e-14, 0, -1.62182060497289e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.68659168002595e-14, 0, 0, 0, 0, 1.40965823998977e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974982, 2.12132034355964, -0.40824829046386, 3.17542648054296, 0, 0, 0, 7.17137165600636, -1.38013111868469, -1.56144011671765, 0, 0, 0, 0, 1.60086230480545e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 2.73861278752582, 1.58113883008418, 2.4596747752498, 0, 0, 0, 9.25820099772551, 5.34522483824851, -1.20948631362952, 0, 0, 0, 0, 1.34977494398807e-14, 1.99156888319442e-14, 0, 0, -2.15636170105579e-14, 2.42856949828063e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16523470700075e-14, 0, 0, -1.09194628747146e-14, 1.11395268009851e-14},
    {-1.80000000000001, -1.20044841895264e-14, 3.6514837167011, -2.84018778721876, 0, -1.08976206329851e-14, -1.29819986860444e-14, 0, 12.3442679969674, 1.39659449751036, 0, 0, 0, 0, -1.50769312330474e-14, 1.13191919416064e-14, 1.11250942527182e-14, -1.93488728499311e-14, -2.44419195896427e-14, 1.02799713186386e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.16729566976785e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.23874183066048e-14, 0, -1.16953047556544e-14, 0},
    {1.27279220613579, 0, 0, 3.83405790253616, 0, 0, 0, 0, 1.22025515571026e-14, 5.18459255872629, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.20454076850486, 0, 0, 6.6407830863536, 0, 0, 0, 0, 2.01466364901978e-14, 8.97997772825746, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573302, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341419, -1.71651640581399, 0.594618725379066, 0.420458932936045, 9.8107084351743, -1.18450885369836, 0.305838870920594, -0.105945692672787, -1.02581475831037, 0.264864231681993, -0.09175166127617, 0.21626073957839, -0.0749149177264317, -0.0529728463363858, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403131, -2.78313372537745, -0.908295106229251, -0.524404424085076, 0.370809924354782, 11.1242977306435, 9.40174755792014, -2.42752078113806, 0.840917865872085, -0.301561193523232, -0.794200206656966, 0.350641890608823, 0.114434427054266, 0.0660687472643449, -0.0467176592151217, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747036, 3.74574588632197, -1.05945692672796, -8.09173593712688, 5.01426536422408, 1.80936716113936, -0.383824736789376, -1.10800657553489, 0.313391585263996, 0, 12.7134831207354, 8.2065180664829, -2.84282124887607, 1.01946290306866, -0.631738055305799, -0.227958835180076, 0.0483573714561715, 0.139595707137601, -0.0394836284566235, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 7.03562363973514, 4.06201920231798, -0.820651806648283, 0, -6.79705818718658, 5.88642506110458, -2.08116553882673, -1.2015614840698, 0.242752078113809, 0, 0, 14.8323969741913, 5.13809303146605, 0, 0.856348838577665, -0.741619848709558, 0.262202212042531, 0.151382517704873, -0.0305838870920523, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-3.42539535431071, 0, 9.38083151964686, 1.89521416591735, 0, 0, -3.39852909359328, 0, -2.77488738510233, -0.560611910581382, 0, 0, 0, 17.7988763690296, 0, 0, 0.4281744192888, 0, 0.34960294939005, 0.0706304617818509, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.19229891779162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172086, 2.24244764232556, 2.14087209644419, -0.331662479035536, 0.0957427107756383, 6.49923072370878, -1.87616630392937, -2.15580611373101, 0, 0, 0, 0, 9.4403585933147, -1.46249406456535, 0.422185670932515, -2.04706526287666, 0.590936840285285, 0.522319308773338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.05431025609327e-14, 0, 0},
    {1.71269767715535, 1.16057691494799, 1.34011878852097, 1.89521416591737, 2.53311402559511, 1.96214168703485, -0.56642151559888, 2.74642624930238, 3.17129986868838, -1.82198870938951, 0, 0, 0, 0, 11.1699829238239, 8.6522315682783, -2.49768411251823, -0.865042958313582, -0.998865569685885, 0.441440386136645, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.03475770530409e-14, 1.29209414685306e-14, 0, 0, 0, 0, 0, 0, 1.60120018608036e-14, 0, 0, -1.26160718303102e-14, 0},
    {1.32664991614215, -2.69693703815181, 2.07610309995255, 1.46802658041886, 0, 3.03973683071412, 1.3162446581088, -6.38211787508102, 4.91295663090393, -1.4113063856887, 0, 0, 0, -1.51913273054672e-14, -2.55599087474972e-14, 13.4039795085888, 5.80409338312195, 2.01017818278148, -1.54743588659735, 0.341938252770119, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2030832256185e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.39126707790871e-14, 1.05862461256535e-14, 0, 0, 0, 0, -1.27456553064636e-14, 0, 1.42541964027269e-14, 0, 0, -1.47910175216627e-14, 0},
    {3.82970843102536, 0, -1.49829835452879, 4.23782770691178, 0, 0, 3.79967103839267, 0, -3.54562104171168, -4.07409060843207, 0, 0, 0, 0, 0, 0, 16.7549743857359, 0, 1.11676565710082, 0.987090711415275, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.21705165839016e-14, 0, 0, 0, 0, 0, -1.21257170970779e-14},
    {1.48323969741913, 1.00508909139073, -0.193429485824663, 3.55615782880927, 0, 0, 0, 4.45964044034302, -0.858258202906985, 2.67027285925187, 0, 0, 0, 0, 0, 0, 0, 8.42792824422443, -1.62195554683794, -2.29379153190447, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.14891252930761, 1.29756443747035, 0.749149177264386, 2.75458800949269, 0, 0, 0, 5.75737105184054, 3.3240197266047, 2.06838446274244, 0, 0, 0, 0, 0, 1.63535268777982e-14, 0, 10.8804085776374, 6.28180682119208, -1.77676328054753, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.10314190327717e-14, 0, 0, 0},
    {-1.32664991614216, -1.36618976334274e-14, 1.73008591662712, -3.18072425757423, 0, 0, 0, 0, 7.67649473578737, -2.38836465270395, 0, 0, 0, 0, 0, 1.75825778552664e-14, -1.61250752397677e-14, -2.1076052013037e-14, 14.5072114368499, 2.05162951662072, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.938083151964686, 0, 0, 3.11415464992885, 0, 0, 0, 0, 0, 5.52707620976691, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62480768092719, 0, 0, 5.39387407630363, 0, 0, 0, 0, 1.11162283755055e-14, 9.57317681262151, 0, 0, 0, 0, -1.0778909817559e-14, 0, 1.14540099911627e-14, 0, 0, 10.0508909139073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993662, 0.86983547675049, 0.615066564126915, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.278967971730982, -1.89076704011892, 0.627677936394719, -0.241593350361255, 0.512496888990065, -0.197260144544833, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954525, -1.03851746182648, 0.219426862868131, -0.0728431359084663, 0.0280373360835797, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711053, 0.0140186680417948, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725405, 3.45525332069938, 0.997445717412069, -1.41060126129511, 3.23209352764251, 5.28531208250978, -2.8908723349783, -1.3627702877385, -0.393397896234731, 0.556348640264194, 2.3366642891096, 9.0278480722887, -3.93352933905729, 1.64018416088946, -0.732969916135167, -1.19859611757306, 0.655588223176202, 0.309047252182634, 0.0892142571199805, -0.12616801237611, 13.0996183150502, 11.55277744383, -2.44096975264614, 0.810328731479527, -0.311895674167858, -0.234843597212094, -0.907332870306511, 0.39533457331842, -0.16484471056831, 0.0736662483163195, 0.120463442338379, -0.0658890955530703, -0.0310604175145504, -0.00896637020658568, 0.0126803623514093, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066012, 2.99085908983323, -1.24403337882031, 0.950146187582609, 5.74064456311311, -0.169967317119758, -0.721110255092799, -1.17961073303081, 0.490653381462658, -10.3037210107158, 4.9761335152812, 5.78174466995658, -3.2268221135323, -0.215472901842833, -1.3018558182182, 0.0385449644663712, 0.163532434528623, 0.267510569439619, -0.111269728052842, 0, 14.555131461167, 10.7636648722209, -3.5732138395088, 1.37533064807499, 1.03556292536503, -0.500120235663637, -0.581087203147972, 0.324307824721462, 0.0216558414515678, 0.13084143273245, -0.0038739146876535, -0.0164356280722662, -0.0268858238268361, 0.011183028438671, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585591, 0.772618130456579, 3.86595114186566, -1.05140010313427, 9.1544290607646, 3.35889012281481, 3.878512233171, -0.304724700110019, -1.52475169285616, 0.414677792940096, 0, -9.46260092820841, 7.32969916135161, 0.564240504518017, -2.07602937339135, -0.761724681099362, -0.879563899362184, 0.0691050664139924, 0.345781182036189, -0.0940400840863445, 0, 0, 16.3745228938128, 9.05975063854702, -3.48709964663734, 0, 0.951027176355638, -0.736662483163211, -0.0567083043941542, 0.208648802584722, 0.0765562109321131, 0.0883994979795834, -0.006945320497205, -0.0347523163751387, 0.00945138406569424, 0, 0, 0, 0, 0, -1.0442355414814e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, -6.78263087840204, 3.68560354207932, -0.814411017927972, 0, 10.0216907612581, 6.00856531485321, 2.67510569439611, -1.45362164025439, 0.321208037219812, 0, 0, -7.5700807425667, 6.99294104721295, 0, -2.27270584034422, -1.36261453366201, -0.60665694841583, 0.329650402328123, -0.0728431359084861, 0, 0, 0, 18.7137404500718, 5.40219154319687, 0, 0, 0.760821741084505, -0.702817019232738, 0, 0.228415531250637, 0.136947913395213, 0.0609713174047677, -0.0331311120155155, 0.00732101061700594, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.13362172336404e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.09901951359279, 0, -4.65474668125631, -3.2914029430219, 0, 1.1660466779942e-14, 13.490737563232, 0, 1.83585684909537, 1.29814682728311, 0, 0, 0, -3.53270434653113, 0, -2.35369542990423e-14, -3.05941170815564, 0, -0.416333199893202, -0.294392028877585, 0, 0, 0, 0, 21.8326971917504, 0, 0, 0, 0.355050145839434, 0, 0, 0.307482445914322, 0, 0.0418430609640539, 0.0295875121532883, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.51979983923137e-14, 1.31936453578951e-14, 0, 0, 0, 1.03690494372784e-14, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.1542003094028, -1.09264703862703, 1.54523626091313, 2.95048422176041, -0.76181175027506, 0.263899331455881, 5.59815020469135, -1.93925611658552, -2.28543525082516, 2.13307290077015, -0.257539376818861, 0.0664963811608048, -0.0230350221379904, 9.14446135479764, -2.36108976914457, 0.817905488277896, -3.3384229850651, 1.1564636454577, 1.02505848514081, 0, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280294, -0.125015768949701, -2.15192884958005, 0.555625639776455, -0.192474367616153, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07577610922145e-14, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659431, 1.36277028773846, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871973, 1.7102631376487, -2.01556443707465, 2.41867732448956, 2.04415543160775, -0.527798662911745, 0.182834820066009, 2.68821895760391, 7.07977053255618, -3.12574097035514, -1.76652739792483, -1.01990506872274, 0.904016610326372, 0, 0, 0, 0, 0, 13.1266557397187, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454906, -1.66605356688628, 0.735567892896448, 0.315075748468082, 0.181909068193171, -0.147004726489972, 0, 0, 0, 0, 0, 0, 0, -1.19843614648072e-14, 0, 1.70149229231864e-14, 0, 0, 1.13549801043889e-14, 0, 0, 0, 0, 0, -1.36131053899298e-14, 0, -1.03720200830826e-14},
    {1.48690428533295, 0.705300630647538, 2.0360275448199, 1.15175110689976, -2.93221479395416, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967313, 0, 2.76420265655951, 1.78428514239953, -0.618094504365259, -9.08783875864328, 5.631527706439, 2.03210252328835, -0.746494073225345, -2.15494277062552, 0.764033484562584, 0, 0, 0, 0, 0, 0, 15.0018922739643, 9.68367982311023, -3.3545250915713, 2.13860408462396, -1.32524448062077, -0.478206411017798, 0.133143804689786, 0.384353057392894, -0.124241670058205, 0, 0, 0, 0, 0, 0, 0, -1.06952639252695e-14, 0, 1.24523903365769e-14, 0, 0, 1.13816587687308e-14, -1.06362575304491e-14, 0, 1.13288756971e-14, 0, -1.21696875531858e-14, -1.03472165536955e-14, 0, -1.2600380808192e-14},
    {1.15175110689979, 3.82426463519456, 2.20794021658195, 0.892142571199782, 0, -2.46306042692148, 2.13307290077015, 6.78739640804928, 3.91870514328393, -1.31949665727936, 0, 0, 3.22490309931941, 1.11713920350152, 1.32014938580353e-14, -7.63378455726037, 6.61105135360481, -4.04762275910198, -2.33689608954557, 0.591817792331178, 0, 0, 0, 0, 0, 0, 0, 17.5022076529583, 6.06294257990892, 0, 1.79642743108413, -1.55575179137408, 0.721929233499942, 0.416806037297049, -0.096237183808073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.27043515283634e-14, 0, 0},
    {-2.65985524643219, 1.31595766643121e-14, 5.09901951359278, -2.06031501455086, 0, 1.2454667647061e-14, -1.23153021346074, 0, 9.04986187739902, 3.04724700110024, 0, 0, 0, 3.8698837191833, 1.50559796220762e-14, -1.82444885045587e-14, -3.81689227863021, 2.48972418334491e-14, -5.39683034546926, -1.36674464685442, 0, 0, 0, 0, 1.11023026702718e-14, 0, 0, 0, 21.00264918355, 0, 0, 0.898213715542071, 0, 0.962572311333264, 0.222250255910579, 0, 0, 0, 0, 0, 0, 0, 0, 1.30048635444922e-14, 0, -2.8168247578276e-14, 0, 0, 0, 0, 0, -1.22574722556207e-14, 0, 0, 0, 0},
    {1.57359158493889, 1.49284005458437, -0.430945803685673, 3.04724700110021, 0.775791113542717, -0.120185042515475, 0.0346944333244397, 5.29905651979671, -1.52970585407785, 0.901387818865986, 0, 0, 0, 0, 4.51561078268939, -0.699555414372413, 0.201944253400488, 6.36462844462229, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980277, -3.09993548319961, 0.894874292847881, 0.903959543974646, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880569, 0.728431359084677, 2.57539376818856, 0.917928424547677, 0.71102430025671, -0.205255035576791, 2.23926008187654, 2.58567482211399, 0.761811750275056, 0, 0, 0, 0, 5.34294273196306, 4.13862564412661, -1.19471831485579, 2.68954640486934, 3.1056206816986, -2.32269806558124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.8876627769294, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.76398525469263, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, -1.46593983227033, 1.12848100903608, 1.99489143482414, 0, 1.10151410945722, 0.476969600708474, -5.20357020296093, 4.00571020990214, 0.590096844352093, 0, 0, 0, 0, -1.06679106813357e-14, 6.4115312783557, 2.77627448210726, -6.24994106094659, 4.81120687194238, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.4651953323153, 6.69662601613678, 3.0440762145518, -2.34333096254029, 0.591780433634522, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.29095028749876e-14, 0},
    {2.97380857066591, 0, -0.814411017927952, 5.75875553449896, 0, 0, 1.37689263682153, 0, -2.89087233497831, 1.70346285967311, 0, 0, 0, 0, 0, 0, 8.01441409794461, 0, -3.47218947830365, -5.19371076584693, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.3314941653941, 0, 1.69115345252877, 1.70832296330021, 0, 0, 0, 0, 0, 0, 0, 0, 1.01698699146052e-14, 0, 0, 0, 0, 0, 1.04634390793553e-14, 0, 0, -1.24951195166655e-14, 0, 0, 0},
    {1.15175110689979, 0.546323519313506, -0.105140010313426, 3.27118942773248, 0, 0, 0, 2.69341127303542, -0.518347241175112, 4.25171145123352, 0, 0, 0, 0, -1.50547813101981e-14, 0, 0, 6.71889089790563, -1.29305115618718, 1.82865048192211, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635795, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199775, 0.705300630647549, 0.407205508963978, 2.53385243517953, 0, 0, 0, 3.47717900165117, 2.00755023262382, 3.29336152870136, 0, 0, 0, 0, 0, 0, 0, 8.6740508508577, 5.0079655937072, 1.41646657250369, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.2048487632307, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.09128807146668e-14, 0, 0, 0, 0, 0, 0, 0},
    {-1.03015750727542, 0, 0.940400840863396, -2.92584077107542, 0, 0, 0, 0, 4.6362386688682, -3.80284633026898, 0, 0, 0, 0, 1.68691976659293e-14, 0, -1.57365387853084e-14, 0, 11.5654011344769, -1.63559471386627, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.2731316843076, 2.63013526059784, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.15424097657397e-14, 0, 0, -1.09417683247237e-14},
    {0.728431359084685, 0, 0, 2.53908227033119, 0, 0, 0, 0, 0, 5.00713776237767, 0, 0, 0, 0, 0, 1.10587002885661e-14, 0, 0, 0, 6.93924068068616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6.2767793639472, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376112, 0, 0, 4.39781949681095, 0, 0, 0, 0, 0, 8.67261700493487, 0, 0, 0, 0, 0, 1.88729435175678e-14, 0, 0, 0, 12.0191174248973, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8717007662564, 0, 0, 0, 0, 0, 0, 0, 1.03515041106796e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats2[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.82574185835055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.16397779494323, 0, 0, 1.29984998459287e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00622635224035e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.763762615825961, 0, 0, 0, 0, 0, 0, -1.12787476580434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.00211722600663e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747792, 1.44913767461894, 4.18330013267037, -0.591607978309952, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00245830515541e-14, 0, 0, 0, 0, -1.10514927319296e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.3228756555323, 0, 3.86436713231717, -0.341565025531983, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 7.09929573971953, 0, 4.34741302385685, 0, 1.16116958235673e-14, 0, 0, 1.97703621279534e-14, 0, 0, 0, 0, 0, 1.19025197250128e-14, 0, 0, 0, 0, 1.15385132004597e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.08012344973465, 0, 7.09929573971953, 2.50998007960224, 0, 0, 0, 0, 1.2984107062089e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.21524148795069e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18401735111452e-14, 0},
    {-3.81881307912987, 0, 1.20295604068146e-14, 8.87411967464943, 0, 1.13142405616155e-14, 0, 0, 0, 0, 0, 0, 0, 1.25032789779226e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847577, -1.67332005306815, -1.18321595661992, 7.74596669241485, -1.2, 0.346410161513777, -0.979795897113271, 0.282842712474625, 0.200000000000004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 1.30930734141596, 7.09929573971954, -2.04939015319192, -0.41403933560542, -0.47809144373374, 0.169030850945707, 0, 0, 0, -1.01115137587522e-14, 0, 0, -1.19390261962029e-14, 0, -1.01768611746272e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.80000000000001, 0.632455532033679, 4.38178046004131, -0.77459666924148, 0, 3.14233761939829, 4.76235235991626, -0.106904496764969, -0.740656079818034, 0.130930734141593, 0, 0, 0, -1.8947471087206e-14, 0, 0, 1.24782077916574e-14, 0, -1.57210017045496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03923048454133, 0, 3.16227766016837, -0.447213595499959, 0, 0, 5.89188303637179, 0, -0.534522483824846, 0.0755928946018422, 0, 0, 0, -1.32102604647237e-14, 0, 0, 1.28087199916397e-14, 0, -1.09806075799093e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974981, 2.12132034355963, -0.408248290463856, 3.17542648054296, 9.07114735222146, 0, 0, 7.17137165600636, -1.3801311186847, -1.56144011671765, 0, 0, 0, 1.05914511754833e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 0.547722557505163, 1.58113883008417, 2.45967477524979, 0, 9.07114735222145, 0, 1.85164019954509, 5.34522483824851, -1.20948631362952, 0, 0, 0, -1.11256081632663e-14, 0, 0, 0, 0, -2.1484687092401e-14, 1.51441359452775e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.03593488692865e-14, 0, -1.10855626475394e-14, 0},
    {0.900000000000005, 0, 1.46059348668043, 1.4200938936094, 0, 0, 9.07114735222145, 0, 4.93770719878695, -0.698297248755175, 0, 0, 0, 0, 0, 0, 2.13673764691668e-14, 0, -1.74964245430402e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07342779687771e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.27279220613579, -6.2609903369994, 0, 3.83405790253616, 0, -1.49065575463019e-14, 0, 10.5830052442584, 0, 5.18459255872628, 0, 0, 0, 0, 0, 1.30274753827373e-14, 0, 1.32206973351868e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.734846922834947, -1.04202290943615e-14, -6.26099033699941, 2.21359436211788, 0, 0, 0, 0, 10.5830052442584, 2.99332590941916, 0, 0, 0, 0, 0, 0, 0, 0, -1.10071029919877e-14, 1.58024635044107e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.71576766497729, 0, 0, -4.69574275274958, 0, -1.13946705425176e-14, 0, 0, 1.07947992678322e-14, 12.69960629311, 0, 0, 0, -2.12576157138471e-14, -1.14768107589579e-14, 0, 0, 0, 0, -1.45786160921091e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.11099168517849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16464450008484e-14, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573303, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341418, -1.71651640581399, 0.594618725379066, 0.420458932936047, 9.81070843517429, -1.18450885369836, 0.305838870920593, -0.105945692672788, -1.02581475831037, 0.264864231681991, -0.0917516612761725, 0.216260739578389, -0.0749149177264338, -0.0529728463363881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403132, -2.78313372537745, -0.908295106229256, -0.524404424085065, 0.370809924354784, 1.23603308118261, 9.40174755792014, -2.42752078113806, 0.840917865872082, -0.301561193523232, -0.794200206656965, 0.350641890608817, 0.114434427054266, 0.0660687472643408, -0.0467176592151232, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.09687112732375e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747035, 3.74574588632197, -1.05945692672795, 0.404586796856342, 5.01426536422407, 1.80936716113936, -0.38382473678937, -1.10800657553489, 0.313391585264001, 0, 2.82521847127454, 8.2065180664829, -2.84282124887607, -0.0509731451534336, -0.631738055305794, -0.227958835180071, 0.0483573714561653, 0.139595707137598, -0.0394836284566152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 0.335029697130247, 4.06201920231797, -0.820651806648293, 0, 1.69926454679664, 5.88642506110457, -0.0991031208965088, -1.20156148406979, 0.242752078113803, 0, 0, 4.94413232473044, 5.13809303146604, 0, -0.214087209644424, -0.741619848709556, 0.0124858196210727, 0.151382517704866, -0.030583887092065, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.856348838577677, 0, 2.68023757704196, -0.473803541479351, 0, 0, 5.09779364038993, 0, -0.792824967172094, 0.140152977645347, 0, 0, 0, 7.9106117195687, 0, 0, -0.642261628933262, 0, 0.0998865569685846, -0.0176576154454718, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172091, 2.24244764232556, 2.14087209644418, -0.331662479035544, 0.0957427107756388, 6.49923072370878, -1.87616630392938, -2.15580611373101, 11.0554159678513, 0, 0, 0, 9.44035859331469, -1.46249406456535, 0.42218567093252, -2.04706526287666, 0.590936840285289, 0.522319308773339, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.71269767715534, 1.160576914948, 1.34011878852098, 1.89521416591738, 0.361873432227874, 1.96214168703486, -0.566421515598884, 2.74642624930237, 3.17129986868839, -1.82198870938951, 0, 11.0554159678513, 0, 0, 1.59571184626056, 8.6522315682783, -2.49768411251823, -0.865042958313566, -0.99886556968588, 0.441440386136656, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.67261791825198e-14, 0, 0, 0, 0, 0, 0, 1.30794708089814e-14, 0, 0, -1.0374605283645e-14, 0},
    {1.32664991614216, 0.29965967090575, 2.07610309995255, 1.46802658041888, 0, 0.868496237346876, 1.31624465810881, 0.709124208342335, 4.91295663090393, -1.4113063856887, 0, 0, 11.0554159678513, 0, 0, 3.82970843102537, 5.80409338312195, -0.223353131420173, -1.54743588659735, 0.341938252770127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.50077495359425e-14, 0},
    {0.765941686205065, 0, 1.49829835452878, 0.84756554138235, 0, 0, 1.62843044502543, 0, 3.54562104171167, -0.81481812168641, 0, 0, -1.13658139175294e-14, 11.0554159678513, 0, 0, 7.18070330817253, 0, -1.11676565710083, 0.197418142283055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 1.00508909139074, -0.193429485824671, 3.55615782880925, -8.46157280212813, 0, 0, 4.45964044034302, -0.85825820290699, 2.67027285925187, 0, 0, 0, -1.0471287355653e-14, 12.4373429638327, 0, 0, 8.42792824422442, -1.62195554683794, -2.29379153190449, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.1489125293076, 0.259512887494065, 0.749149177264405, 2.75458800949269, 0, -8.46157280212812, 0, 1.15147421036811, 3.3240197266047, 2.06838446274243, 0, 1.28739579884012e-14, 0, 1.43483072465507e-14, 0, 12.4373429638328, 0, 2.17608171552748, 6.28180682119208, -1.77676328054752, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.1069077748037e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.66332495807107, 0, 0.692034366650861, 1.5903621287871, 0, 0, -8.46157280212812, 0, 3.07059789431495, 1.19418232635199, 0, 0, 0, 1.58467639420295e-14, 0, 1.59120238800483e-14, 12.4373429638327, -1.09120262064712e-14, 5.80288457473997, -1.02581475831036, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.17878507096849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.93808315196469, 7.62808987244124, 0, 3.11415464992885, 0, 0, 0, -7.5213980463361, 0, 5.52707620976692, -1.06609684736951e-14, 0, 0, 0, -1.38639078823126e-14, 0, 1.48563198377856e-14, 14.2141062443803, 1.67911998216622e-14, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.541602560309069, 0, 7.62808987244124, 1.79795802543454, 0, 0, 0, 0, -7.5213980463361, 3.19105893754051, 0, 0, 0, 0, 0, 0, 0, 0, 14.2141062443803, 3.35029697130244, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-5.3615918034355, 0, 0, 8.89943818451481, 0, 0, 0, 0, 0, -5.26497863243528, 0, 0, 0, 1.27752977123219e-14, 0, 0, 0, -1.16097894474412e-14, 1.10230978840132e-14, 16.583123951777, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993663, 0.86983547675049, 0.615066564126914, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.27896797173098, -1.89076704011892, 0.627677936394719, -0.241593350361254, 0.512496888990065, -0.197260144544832, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954516, -1.03851746182648, 0.219426862868131, -0.0728431359084662, 0.0280373360835794, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711051, 0.0140186680417946, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725404, 3.45525332069938, 0.997445717412055, -1.41060126129511, 3.23209352764251, 5.28531208250977, -2.8908723349783, -1.3627702877385, -0.393397896234727, 0.556348640264192, 2.33666428910959, 9.02784807228868, -3.93352933905729, 1.64018416088945, -0.732969916135173, -1.19859611757306, 0.655588223176204, 0.309047252182629, 0.0892142571199751, -0.126168012376112, 1.19087439227729, 11.55277744383, -2.44096975264613, 0.810328731479525, -0.311895674167859, -0.234843597212091, -0.907332870306511, 0.395334573318418, -0.164844710568308, 0.0736662483163234, 0.120463442338379, -0.0658890955530668, -0.0310604175145528, -0.00896637020658492, 0.012680362351411, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.04376434543615e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066013, 2.99085908983323, -1.24403337882031, 0.950146187582614, 5.74064456311311, -0.169967317119763, -0.721110255092803, -1.1796107330308, 0.490653381462655, 0.294392028877601, 4.97613351528119, 5.78174466995657, -3.2268221135323, -0.215472901842835, -1.3018558182182, 0.0385449644663701, 0.16353243452863, 0.267510569439621, -0.111269728052844, 0, 2.64638753839399, 10.7636648722209, -3.5732138395088, 1.37533064807499, -0.0295875121532872, -0.500120235663636, -0.581087203147972, 0.324307824721462, 0.0216558414515659, 0.130841432732449, -0.00387391468765372, -0.0164356280722662, -0.0268858238268349, 0.0111830284386701, 0, 0, 0, 0, -1.28026114151189e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585592, 0.772618130456574, 3.86595114186566, -1.05140010313427, 0.160604018609906, 3.35889012281481, 3.878512233171, -0.30472470011002, -1.52475169285616, 0.414677792940093, 0, 1.13551211138501, 7.32969916135161, 0.564240504518021, -0.0364215679542351, -0.761724681099363, -0.879563899362178, 0.0691050664139924, 0.345781182036181, -0.094040084086348, 0, 0, 4.46577897103986, 9.05975063854702, -3.48709964663735, 0, -0.114123261162678, -0.736662483163213, -0.0567083043941508, 0.00366050530850509, 0.076556210932112, 0.0883994979795821, -0.00694532049720509, -0.0347523163751398, 0.00945138406569354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, 0.199489143482414, 3.68560354207933, -0.814411017927961, 0, 1.0278657191034, 6.00856531485322, -0.0786795792469394, -1.45362164025439, 0.321208037219813, 0, 0, 3.02803229702669, 6.99294104721296, 0, -0.23309803490711, -1.36261453366201, 0.0178428514239989, 0.329650402328134, -0.072843135908474, 0, 0, 0, 6.80499652729884, 5.40219154319687, 0, 0, -0.304328696433804, -0.70281701923274, 0, 0.0234272339744255, 0.136947913395213, -0.00179327404131462, -0.0331311120155176, 0.00732101061700848, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.728431359084683, 0, 2.32737334062817, -0.470200420431708, 0, 0, 4.49691252107735, 0, -0.917928424547684, 0.185449546754732, 0, 0, 0, 7.06540869306229, 0, -1.02749514743743e-14, -1.01980390271856, 0, 0.208166599946621, -0.0420560041253766, 0, 0, 0, 0, 9.92395326897747, 0, 0, 0, -0.710100291678883, 0, 0, 0.102494148638111, 0, -0.0209215304820291, 0.00422678745046967, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.15420030940281, -1.09264703862702, 1.54523626091312, 2.95048422176041, -0.761811750275057, 0.263899331455879, 5.59815020469135, -1.93925611658552, -2.28543525082517, 2.13307290077016, -0.257539376818857, 0.0664963811608075, -0.0230350221379865, 9.14446135479764, -2.36108976914457, 0.817905488277892, -3.3384229850651, 1.1564636454577, 1.02505848514081, 13.0453753561106, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280297, -0.125015768949703, -2.15192884958005, 0.555625639776455, -0.192474367616155, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659433, 1.36277028773847, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871972, 1.7102631376487, -2.01556443707464, 0.268741924943282, 2.04415543160775, -0.527798662911754, 0.182834820066007, 2.68821895760393, 7.07977053255618, -3.12574097035514, -1.76652739792482, -1.01990506872274, 0.904016610326381, 0, 13.0453753561106, 0, 0, 0, 1.4585173044132, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454905, -1.66605356688628, 0.735567892896452, 0.315075748468088, 0.181909068193171, -0.14700472648997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.76253856517652e-14, 0, 0, 0, 0, 0, 0, 0, -1.02644438987504e-14, 0, 0, 0},
    {1.48690428533294, 0.705300630647549, 2.0360275448199, 1.15175110689978, 0.146610739697706, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967312, 1.19461378362765e-14, 0.614267257013224, 1.78428514239954, -0.61809450436525, 0.454391937932155, 5.631527706439, 2.03210252328835, -0.746494073225347, -2.1549427706255, 0.764033484562606, 0, 0, 13.0453753561106, 0, 0, 0, 3.33375383865873, 9.68367982311023, -3.3545250915713, -0.1069302042312, -1.32524448062077, -0.47820641101779, 0.133143804689788, 0.384353057392899, -0.124241670058195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.33133676896015e-14, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.182107839771165, 2.20794021658195, 0.892142571199765, 0, 0.615765106730381, 2.13307290077015, 0.323209352764259, 3.91870514328393, -1.31949665727937, 0, 0, 1.07496769977315, 1.11713920350151, 0, 1.90844613931509, 6.61105135360481, -0.192743940909622, -2.33689608954558, 0.591817792331162, 0, 0, 0, 13.0453753561106, 0, 0, 0, 5.83406921765277, 6.06294257990893, 0, -0.449106857771032, -1.55575179137408, 0.0343775825476156, 0.416806037297052, -0.0962371838080755, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.664963811608044, 0, 1.45686271816936, 0.515078753637704, 0, 0, 1.84729532019112, 0, 2.58567482211401, -0.761811750275049, 0, 0, 0, 1.71994831963702, 1.05069828708852e-14, -1.56804141189904e-14, 5.72533841794525, 1.28292660358282e-14, -1.54195152727692, 0.341686161713602, 0, 0, 0, 0, 13.0453753561106, 0, 0, 0, 9.33451074824443, 0, 0, -1.34732057331309, 0, 0.275020660380932, -0.0555625639776445, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.3208801604271e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.57359158493888, 1.49284005458436, -0.430945803685674, 3.04724700110019, 0.775791113542713, -0.120185042515468, 0.0346944333244412, 5.29905651979672, -1.52970585407786, 0.901387818865991, -10.576283741361, 0, 0, 0, 4.51561078268937, -0.699555414372417, 0.20194425340049, 6.36462844462228, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980274, -3.09993548319962, 0.894874292847881, 0.903959543974651, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880566, 0.72843135908468, 2.57539376818856, 0.131132632078236, 0.71102430025671, -0.205255035576782, 2.23926008187654, 2.585674822114, 0.761811750275049, 0, -10.576283741361, 0, 0, 0.763277533137571, 4.1386256441266, -1.19471831485579, 2.68954640486935, 3.1056206816986, -2.32269806558126, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 1.84109468241848, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.763985254692621, 0, 0, 0, 0, 0, 0, 0, 0, -1.35629152642122e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, 0.162882203585585, 1.12848100903607, 1.99489143482414, 0, 0.31471831698778, 0.476969600708467, 0.578174466995659, 4.00571020990214, 0.590096844352089, 0, 0, -10.576283741361, 0, -1.14841985676491e-14, 1.83186607953021, 2.77627448210727, 0.694437895660718, 4.8112068719424, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 4.41862723780437, 6.69662601613678, -0.338230690505757, -2.34333096254029, 0.591780433634517, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.594761714133188, 0, 0.814411017927947, 1.1517511068998, 0, 1.39874122938874e-14, 0.590096844352078, 0, 2.89087233497829, 0.340692571934624, 0, 0, 1.04169365895487e-14, -10.576283741361, 0, 0, 3.43474889911913, 0, 3.47218947830366, -1.03874215316938, 0, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 8.28492607088319, 0, -1.69115345252878, 0.341664592660038, 0, 0, 0, 0, 0, 0, 0, 0, 1.04348006604658e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.546323519313508, -0.105140010313428, 3.27118942773248, 9.65295620481433, 0, 0, 2.69341127303542, -0.51834724117513, 4.25171145123353, 0, 0, 0, 0, -9.91526600752599, 0, 0, 6.71889089790562, -1.29305115618718, 1.82865048192213, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635794, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199779, 0.141060126129514, 0.407205508963965, 2.53385243517954, 0, 9.65295620481433, 0, 0.695435800330239, 2.00755023262382, 3.29336152870136, 0, 0, 0, -1.35671976966506e-14, 0, -9.91526600752598, 0, 1.73481017017155, 5.00796559370719, 1.4164665725037, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 2.44096975264614, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.515078753637729, 0, 0.376160336345341, 1.46292038553772, 0, 0, 9.65295620481433, 0, 1.85449546754728, 1.90142316513449, 0, 0, 0, -2.50850100800641e-14, 0, -1.15008035787034e-14, -9.91526600752594, 0, 4.62616045379078, 0.817797356933146, 0, 0, 0, 0, -1.24919104274206e-14, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 6.50925267372303, -1.31506763029891, 0, 0, 0, 0, 0, -1.31906496265821e-14, 0, 0, 1.19318131197878e-14, -1.10848897873181e-14, 1.67436700563434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.72843135908468, -7.94708263760856, 0, 2.53908227033116, 0, 0, 0, 10.2207771580387, 0, 5.00713776237768, 0, 0, 1.91058434396028e-14, 0, -1.58541378910724e-14, 1.90136980421293e-14, -1.88766397254795e-14, -8.49879943502228, -1.97928218732183e-14, 6.93924068068615, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 0, 6.27677936394721, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47602702235557e-14, 0, 0},
    {0.420560041253711, 0, -7.94708263760856, 1.46593983227032, 0, 0, 0, 0, 10.2207771580387, 2.89087233497828, 0, 0, 0, -1.08180349039434e-14, 1.10015960051229e-14, 0, 1.60406067004907e-14, 0, -8.49879943502225, 4.00637247496576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 3.62390025541881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00860104949949e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.542378855465, 1.44235171923932e-14, 0, -6.91050664139876, 0, 0, 0, 0, -1.41976691442264e-14, 12.2649325896464, 0, 0, 1.30312779804118e-14, 0, 0, 2.24879933982623e-14, 0, 1.64486782168017e-14, -1.79783245387702e-14, -5.66586629001484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20.4998755596024, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16147208367439e-14, 0, 0, 0, 0, 0, 0, 1.28659042607863e-14, 0, 0, 0, 0}};
    
    // Compute reference derivatives
    // Declare pointer to array of derivatives on FIAT element
    double *derivatives = new double [num_derivatives];
    
    // Declare coefficients
    double coeff0_0 = 0;
    double coeff0_1 = 0;
    double coeff0_2 = 0;
    double coeff0_3 = 0;
    double coeff0_4 = 0;
    double coeff0_5 = 0;
    double coeff0_6 = 0;
    double coeff0_7 = 0;
    double coeff0_8 = 0;
    double coeff0_9 = 0;
    double coeff0_10 = 0;
    double coeff0_11 = 0;
    double coeff0_12 = 0;
    double coeff0_13 = 0;
    double coeff0_14 = 0;
    double coeff0_15 = 0;
    double coeff0_16 = 0;
    double coeff0_17 = 0;
    double coeff0_18 = 0;
    double coeff0_19 = 0;
    double coeff0_20 = 0;
    double coeff0_21 = 0;
    double coeff0_22 = 0;
    double coeff0_23 = 0;
    double coeff0_24 = 0;
    double coeff0_25 = 0;
    double coeff0_26 = 0;
    double coeff0_27 = 0;
    double coeff0_28 = 0;
    double coeff0_29 = 0;
    double coeff0_30 = 0;
    double coeff0_31 = 0;
    double coeff0_32 = 0;
    double coeff0_33 = 0;
    double coeff0_34 = 0;
    double coeff0_35 = 0;
    double coeff0_36 = 0;
    double coeff0_37 = 0;
    double coeff0_38 = 0;
    double coeff0_39 = 0;
    double coeff0_40 = 0;
    double coeff0_41 = 0;
    double coeff0_42 = 0;
    double coeff0_43 = 0;
    double coeff0_44 = 0;
    double coeff0_45 = 0;
    double coeff0_46 = 0;
    double coeff0_47 = 0;
    double coeff0_48 = 0;
    double coeff0_49 = 0;
    double coeff0_50 = 0;
    double coeff0_51 = 0;
    double coeff0_52 = 0;
    double coeff0_53 = 0;
    double coeff0_54 = 0;
    double coeff0_55 = 0;
    
    // Declare new coefficients
    double new_coeff0_0 = 0;
    double new_coeff0_1 = 0;
    double new_coeff0_2 = 0;
    double new_coeff0_3 = 0;
    double new_coeff0_4 = 0;
    double new_coeff0_5 = 0;
    double new_coeff0_6 = 0;
    double new_coeff0_7 = 0;
    double new_coeff0_8 = 0;
    double new_coeff0_9 = 0;
    double new_coeff0_10 = 0;
    double new_coeff0_11 = 0;
    double new_coeff0_12 = 0;
    double new_coeff0_13 = 0;
    double new_coeff0_14 = 0;
    double new_coeff0_15 = 0;
    double new_coeff0_16 = 0;
    double new_coeff0_17 = 0;
    double new_coeff0_18 = 0;
    double new_coeff0_19 = 0;
    double new_coeff0_20 = 0;
    double new_coeff0_21 = 0;
    double new_coeff0_22 = 0;
    double new_coeff0_23 = 0;
    double new_coeff0_24 = 0;
    double new_coeff0_25 = 0;
    double new_coeff0_26 = 0;
    double new_coeff0_27 = 0;
    double new_coeff0_28 = 0;
    double new_coeff0_29 = 0;
    double new_coeff0_30 = 0;
    double new_coeff0_31 = 0;
    double new_coeff0_32 = 0;
    double new_coeff0_33 = 0;
    double new_coeff0_34 = 0;
    double new_coeff0_35 = 0;
    double new_coeff0_36 = 0;
    double new_coeff0_37 = 0;
    double new_coeff0_38 = 0;
    double new_coeff0_39 = 0;
    double new_coeff0_40 = 0;
    double new_coeff0_41 = 0;
    double new_coeff0_42 = 0;
    double new_coeff0_43 = 0;
    double new_coeff0_44 = 0;
    double new_coeff0_45 = 0;
    double new_coeff0_46 = 0;
    double new_coeff0_47 = 0;
    double new_coeff0_48 = 0;
    double new_coeff0_49 = 0;
    double new_coeff0_50 = 0;
    double new_coeff0_51 = 0;
    double new_coeff0_52 = 0;
    double new_coeff0_53 = 0;
    double new_coeff0_54 = 0;
    double new_coeff0_55 = 0;
    
    // Loop possible derivatives
    for (unsigned int deriv_num = 0; deriv_num < num_derivatives; deriv_num++)
    {
      // Get values from coefficients array
      new_coeff0_0 = coefficients0[dof][0];
      new_coeff0_1 = coefficients0[dof][1];
      new_coeff0_2 = coefficients0[dof][2];
      new_coeff0_3 = coefficients0[dof][3];
      new_coeff0_4 = coefficients0[dof][4];
      new_coeff0_5 = coefficients0[dof][5];
      new_coeff0_6 = coefficients0[dof][6];
      new_coeff0_7 = coefficients0[dof][7];
      new_coeff0_8 = coefficients0[dof][8];
      new_coeff0_9 = coefficients0[dof][9];
      new_coeff0_10 = coefficients0[dof][10];
      new_coeff0_11 = coefficients0[dof][11];
      new_coeff0_12 = coefficients0[dof][12];
      new_coeff0_13 = coefficients0[dof][13];
      new_coeff0_14 = coefficients0[dof][14];
      new_coeff0_15 = coefficients0[dof][15];
      new_coeff0_16 = coefficients0[dof][16];
      new_coeff0_17 = coefficients0[dof][17];
      new_coeff0_18 = coefficients0[dof][18];
      new_coeff0_19 = coefficients0[dof][19];
      new_coeff0_20 = coefficients0[dof][20];
      new_coeff0_21 = coefficients0[dof][21];
      new_coeff0_22 = coefficients0[dof][22];
      new_coeff0_23 = coefficients0[dof][23];
      new_coeff0_24 = coefficients0[dof][24];
      new_coeff0_25 = coefficients0[dof][25];
      new_coeff0_26 = coefficients0[dof][26];
      new_coeff0_27 = coefficients0[dof][27];
      new_coeff0_28 = coefficients0[dof][28];
      new_coeff0_29 = coefficients0[dof][29];
      new_coeff0_30 = coefficients0[dof][30];
      new_coeff0_31 = coefficients0[dof][31];
      new_coeff0_32 = coefficients0[dof][32];
      new_coeff0_33 = coefficients0[dof][33];
      new_coeff0_34 = coefficients0[dof][34];
      new_coeff0_35 = coefficients0[dof][35];
      new_coeff0_36 = coefficients0[dof][36];
      new_coeff0_37 = coefficients0[dof][37];
      new_coeff0_38 = coefficients0[dof][38];
      new_coeff0_39 = coefficients0[dof][39];
      new_coeff0_40 = coefficients0[dof][40];
      new_coeff0_41 = coefficients0[dof][41];
      new_coeff0_42 = coefficients0[dof][42];
      new_coeff0_43 = coefficients0[dof][43];
      new_coeff0_44 = coefficients0[dof][44];
      new_coeff0_45 = coefficients0[dof][45];
      new_coeff0_46 = coefficients0[dof][46];
      new_coeff0_47 = coefficients0[dof][47];
      new_coeff0_48 = coefficients0[dof][48];
      new_coeff0_49 = coefficients0[dof][49];
      new_coeff0_50 = coefficients0[dof][50];
      new_coeff0_51 = coefficients0[dof][51];
      new_coeff0_52 = coefficients0[dof][52];
      new_coeff0_53 = coefficients0[dof][53];
      new_coeff0_54 = coefficients0[dof][54];
      new_coeff0_55 = coefficients0[dof][55];
    
      // Loop derivative order
      for (unsigned int j = 0; j < n; j++)
      {
        // Update old coefficients
        coeff0_0 = new_coeff0_0;
        coeff0_1 = new_coeff0_1;
        coeff0_2 = new_coeff0_2;
        coeff0_3 = new_coeff0_3;
        coeff0_4 = new_coeff0_4;
        coeff0_5 = new_coeff0_5;
        coeff0_6 = new_coeff0_6;
        coeff0_7 = new_coeff0_7;
        coeff0_8 = new_coeff0_8;
        coeff0_9 = new_coeff0_9;
        coeff0_10 = new_coeff0_10;
        coeff0_11 = new_coeff0_11;
        coeff0_12 = new_coeff0_12;
        coeff0_13 = new_coeff0_13;
        coeff0_14 = new_coeff0_14;
        coeff0_15 = new_coeff0_15;
        coeff0_16 = new_coeff0_16;
        coeff0_17 = new_coeff0_17;
        coeff0_18 = new_coeff0_18;
        coeff0_19 = new_coeff0_19;
        coeff0_20 = new_coeff0_20;
        coeff0_21 = new_coeff0_21;
        coeff0_22 = new_coeff0_22;
        coeff0_23 = new_coeff0_23;
        coeff0_24 = new_coeff0_24;
        coeff0_25 = new_coeff0_25;
        coeff0_26 = new_coeff0_26;
        coeff0_27 = new_coeff0_27;
        coeff0_28 = new_coeff0_28;
        coeff0_29 = new_coeff0_29;
        coeff0_30 = new_coeff0_30;
        coeff0_31 = new_coeff0_31;
        coeff0_32 = new_coeff0_32;
        coeff0_33 = new_coeff0_33;
        coeff0_34 = new_coeff0_34;
        coeff0_35 = new_coeff0_35;
        coeff0_36 = new_coeff0_36;
        coeff0_37 = new_coeff0_37;
        coeff0_38 = new_coeff0_38;
        coeff0_39 = new_coeff0_39;
        coeff0_40 = new_coeff0_40;
        coeff0_41 = new_coeff0_41;
        coeff0_42 = new_coeff0_42;
        coeff0_43 = new_coeff0_43;
        coeff0_44 = new_coeff0_44;
        coeff0_45 = new_coeff0_45;
        coeff0_46 = new_coeff0_46;
        coeff0_47 = new_coeff0_47;
        coeff0_48 = new_coeff0_48;
        coeff0_49 = new_coeff0_49;
        coeff0_50 = new_coeff0_50;
        coeff0_51 = new_coeff0_51;
        coeff0_52 = new_coeff0_52;
        coeff0_53 = new_coeff0_53;
        coeff0_54 = new_coeff0_54;
        coeff0_55 = new_coeff0_55;
    
        if(combinations[deriv_num][j] == 0)
        {
          new_coeff0_0 = coeff0_0*dmats0[0][0] + coeff0_1*dmats0[1][0] + coeff0_2*dmats0[2][0] + coeff0_3*dmats0[3][0] + coeff0_4*dmats0[4][0] + coeff0_5*dmats0[5][0] + coeff0_6*dmats0[6][0] + coeff0_7*dmats0[7][0] + coeff0_8*dmats0[8][0] + coeff0_9*dmats0[9][0] + coeff0_10*dmats0[10][0] + coeff0_11*dmats0[11][0] + coeff0_12*dmats0[12][0] + coeff0_13*dmats0[13][0] + coeff0_14*dmats0[14][0] + coeff0_15*dmats0[15][0] + coeff0_16*dmats0[16][0] + coeff0_17*dmats0[17][0] + coeff0_18*dmats0[18][0] + coeff0_19*dmats0[19][0] + coeff0_20*dmats0[20][0] + coeff0_21*dmats0[21][0] + coeff0_22*dmats0[22][0] + coeff0_23*dmats0[23][0] + coeff0_24*dmats0[24][0] + coeff0_25*dmats0[25][0] + coeff0_26*dmats0[26][0] + coeff0_27*dmats0[27][0] + coeff0_28*dmats0[28][0] + coeff0_29*dmats0[29][0] + coeff0_30*dmats0[30][0] + coeff0_31*dmats0[31][0] + coeff0_32*dmats0[32][0] + coeff0_33*dmats0[33][0] + coeff0_34*dmats0[34][0] + coeff0_35*dmats0[35][0] + coeff0_36*dmats0[36][0] + coeff0_37*dmats0[37][0] + coeff0_38*dmats0[38][0] + coeff0_39*dmats0[39][0] + coeff0_40*dmats0[40][0] + coeff0_41*dmats0[41][0] + coeff0_42*dmats0[42][0] + coeff0_43*dmats0[43][0] + coeff0_44*dmats0[44][0] + coeff0_45*dmats0[45][0] + coeff0_46*dmats0[46][0] + coeff0_47*dmats0[47][0] + coeff0_48*dmats0[48][0] + coeff0_49*dmats0[49][0] + coeff0_50*dmats0[50][0] + coeff0_51*dmats0[51][0] + coeff0_52*dmats0[52][0] + coeff0_53*dmats0[53][0] + coeff0_54*dmats0[54][0] + coeff0_55*dmats0[55][0];
          new_coeff0_1 = coeff0_0*dmats0[0][1] + coeff0_1*dmats0[1][1] + coeff0_2*dmats0[2][1] + coeff0_3*dmats0[3][1] + coeff0_4*dmats0[4][1] + coeff0_5*dmats0[5][1] + coeff0_6*dmats0[6][1] + coeff0_7*dmats0[7][1] + coeff0_8*dmats0[8][1] + coeff0_9*dmats0[9][1] + coeff0_10*dmats0[10][1] + coeff0_11*dmats0[11][1] + coeff0_12*dmats0[12][1] + coeff0_13*dmats0[13][1] + coeff0_14*dmats0[14][1] + coeff0_15*dmats0[15][1] + coeff0_16*dmats0[16][1] + coeff0_17*dmats0[17][1] + coeff0_18*dmats0[18][1] + coeff0_19*dmats0[19][1] + coeff0_20*dmats0[20][1] + coeff0_21*dmats0[21][1] + coeff0_22*dmats0[22][1] + coeff0_23*dmats0[23][1] + coeff0_24*dmats0[24][1] + coeff0_25*dmats0[25][1] + coeff0_26*dmats0[26][1] + coeff0_27*dmats0[27][1] + coeff0_28*dmats0[28][1] + coeff0_29*dmats0[29][1] + coeff0_30*dmats0[30][1] + coeff0_31*dmats0[31][1] + coeff0_32*dmats0[32][1] + coeff0_33*dmats0[33][1] + coeff0_34*dmats0[34][1] + coeff0_35*dmats0[35][1] + coeff0_36*dmats0[36][1] + coeff0_37*dmats0[37][1] + coeff0_38*dmats0[38][1] + coeff0_39*dmats0[39][1] + coeff0_40*dmats0[40][1] + coeff0_41*dmats0[41][1] + coeff0_42*dmats0[42][1] + coeff0_43*dmats0[43][1] + coeff0_44*dmats0[44][1] + coeff0_45*dmats0[45][1] + coeff0_46*dmats0[46][1] + coeff0_47*dmats0[47][1] + coeff0_48*dmats0[48][1] + coeff0_49*dmats0[49][1] + coeff0_50*dmats0[50][1] + coeff0_51*dmats0[51][1] + coeff0_52*dmats0[52][1] + coeff0_53*dmats0[53][1] + coeff0_54*dmats0[54][1] + coeff0_55*dmats0[55][1];
          new_coeff0_2 = coeff0_0*dmats0[0][2] + coeff0_1*dmats0[1][2] + coeff0_2*dmats0[2][2] + coeff0_3*dmats0[3][2] + coeff0_4*dmats0[4][2] + coeff0_5*dmats0[5][2] + coeff0_6*dmats0[6][2] + coeff0_7*dmats0[7][2] + coeff0_8*dmats0[8][2] + coeff0_9*dmats0[9][2] + coeff0_10*dmats0[10][2] + coeff0_11*dmats0[11][2] + coeff0_12*dmats0[12][2] + coeff0_13*dmats0[13][2] + coeff0_14*dmats0[14][2] + coeff0_15*dmats0[15][2] + coeff0_16*dmats0[16][2] + coeff0_17*dmats0[17][2] + coeff0_18*dmats0[18][2] + coeff0_19*dmats0[19][2] + coeff0_20*dmats0[20][2] + coeff0_21*dmats0[21][2] + coeff0_22*dmats0[22][2] + coeff0_23*dmats0[23][2] + coeff0_24*dmats0[24][2] + coeff0_25*dmats0[25][2] + coeff0_26*dmats0[26][2] + coeff0_27*dmats0[27][2] + coeff0_28*dmats0[28][2] + coeff0_29*dmats0[29][2] + coeff0_30*dmats0[30][2] + coeff0_31*dmats0[31][2] + coeff0_32*dmats0[32][2] + coeff0_33*dmats0[33][2] + coeff0_34*dmats0[34][2] + coeff0_35*dmats0[35][2] + coeff0_36*dmats0[36][2] + coeff0_37*dmats0[37][2] + coeff0_38*dmats0[38][2] + coeff0_39*dmats0[39][2] + coeff0_40*dmats0[40][2] + coeff0_41*dmats0[41][2] + coeff0_42*dmats0[42][2] + coeff0_43*dmats0[43][2] + coeff0_44*dmats0[44][2] + coeff0_45*dmats0[45][2] + coeff0_46*dmats0[46][2] + coeff0_47*dmats0[47][2] + coeff0_48*dmats0[48][2] + coeff0_49*dmats0[49][2] + coeff0_50*dmats0[50][2] + coeff0_51*dmats0[51][2] + coeff0_52*dmats0[52][2] + coeff0_53*dmats0[53][2] + coeff0_54*dmats0[54][2] + coeff0_55*dmats0[55][2];
          new_coeff0_3 = coeff0_0*dmats0[0][3] + coeff0_1*dmats0[1][3] + coeff0_2*dmats0[2][3] + coeff0_3*dmats0[3][3] + coeff0_4*dmats0[4][3] + coeff0_5*dmats0[5][3] + coeff0_6*dmats0[6][3] + coeff0_7*dmats0[7][3] + coeff0_8*dmats0[8][3] + coeff0_9*dmats0[9][3] + coeff0_10*dmats0[10][3] + coeff0_11*dmats0[11][3] + coeff0_12*dmats0[12][3] + coeff0_13*dmats0[13][3] + coeff0_14*dmats0[14][3] + coeff0_15*dmats0[15][3] + coeff0_16*dmats0[16][3] + coeff0_17*dmats0[17][3] + coeff0_18*dmats0[18][3] + coeff0_19*dmats0[19][3] + coeff0_20*dmats0[20][3] + coeff0_21*dmats0[21][3] + coeff0_22*dmats0[22][3] + coeff0_23*dmats0[23][3] + coeff0_24*dmats0[24][3] + coeff0_25*dmats0[25][3] + coeff0_26*dmats0[26][3] + coeff0_27*dmats0[27][3] + coeff0_28*dmats0[28][3] + coeff0_29*dmats0[29][3] + coeff0_30*dmats0[30][3] + coeff0_31*dmats0[31][3] + coeff0_32*dmats0[32][3] + coeff0_33*dmats0[33][3] + coeff0_34*dmats0[34][3] + coeff0_35*dmats0[35][3] + coeff0_36*dmats0[36][3] + coeff0_37*dmats0[37][3] + coeff0_38*dmats0[38][3] + coeff0_39*dmats0[39][3] + coeff0_40*dmats0[40][3] + coeff0_41*dmats0[41][3] + coeff0_42*dmats0[42][3] + coeff0_43*dmats0[43][3] + coeff0_44*dmats0[44][3] + coeff0_45*dmats0[45][3] + coeff0_46*dmats0[46][3] + coeff0_47*dmats0[47][3] + coeff0_48*dmats0[48][3] + coeff0_49*dmats0[49][3] + coeff0_50*dmats0[50][3] + coeff0_51*dmats0[51][3] + coeff0_52*dmats0[52][3] + coeff0_53*dmats0[53][3] + coeff0_54*dmats0[54][3] + coeff0_55*dmats0[55][3];
          new_coeff0_4 = coeff0_0*dmats0[0][4] + coeff0_1*dmats0[1][4] + coeff0_2*dmats0[2][4] + coeff0_3*dmats0[3][4] + coeff0_4*dmats0[4][4] + coeff0_5*dmats0[5][4] + coeff0_6*dmats0[6][4] + coeff0_7*dmats0[7][4] + coeff0_8*dmats0[8][4] + coeff0_9*dmats0[9][4] + coeff0_10*dmats0[10][4] + coeff0_11*dmats0[11][4] + coeff0_12*dmats0[12][4] + coeff0_13*dmats0[13][4] + coeff0_14*dmats0[14][4] + coeff0_15*dmats0[15][4] + coeff0_16*dmats0[16][4] + coeff0_17*dmats0[17][4] + coeff0_18*dmats0[18][4] + coeff0_19*dmats0[19][4] + coeff0_20*dmats0[20][4] + coeff0_21*dmats0[21][4] + coeff0_22*dmats0[22][4] + coeff0_23*dmats0[23][4] + coeff0_24*dmats0[24][4] + coeff0_25*dmats0[25][4] + coeff0_26*dmats0[26][4] + coeff0_27*dmats0[27][4] + coeff0_28*dmats0[28][4] + coeff0_29*dmats0[29][4] + coeff0_30*dmats0[30][4] + coeff0_31*dmats0[31][4] + coeff0_32*dmats0[32][4] + coeff0_33*dmats0[33][4] + coeff0_34*dmats0[34][4] + coeff0_35*dmats0[35][4] + coeff0_36*dmats0[36][4] + coeff0_37*dmats0[37][4] + coeff0_38*dmats0[38][4] + coeff0_39*dmats0[39][4] + coeff0_40*dmats0[40][4] + coeff0_41*dmats0[41][4] + coeff0_42*dmats0[42][4] + coeff0_43*dmats0[43][4] + coeff0_44*dmats0[44][4] + coeff0_45*dmats0[45][4] + coeff0_46*dmats0[46][4] + coeff0_47*dmats0[47][4] + coeff0_48*dmats0[48][4] + coeff0_49*dmats0[49][4] + coeff0_50*dmats0[50][4] + coeff0_51*dmats0[51][4] + coeff0_52*dmats0[52][4] + coeff0_53*dmats0[53][4] + coeff0_54*dmats0[54][4] + coeff0_55*dmats0[55][4];
          new_coeff0_5 = coeff0_0*dmats0[0][5] + coeff0_1*dmats0[1][5] + coeff0_2*dmats0[2][5] + coeff0_3*dmats0[3][5] + coeff0_4*dmats0[4][5] + coeff0_5*dmats0[5][5] + coeff0_6*dmats0[6][5] + coeff0_7*dmats0[7][5] + coeff0_8*dmats0[8][5] + coeff0_9*dmats0[9][5] + coeff0_10*dmats0[10][5] + coeff0_11*dmats0[11][5] + coeff0_12*dmats0[12][5] + coeff0_13*dmats0[13][5] + coeff0_14*dmats0[14][5] + coeff0_15*dmats0[15][5] + coeff0_16*dmats0[16][5] + coeff0_17*dmats0[17][5] + coeff0_18*dmats0[18][5] + coeff0_19*dmats0[19][5] + coeff0_20*dmats0[20][5] + coeff0_21*dmats0[21][5] + coeff0_22*dmats0[22][5] + coeff0_23*dmats0[23][5] + coeff0_24*dmats0[24][5] + coeff0_25*dmats0[25][5] + coeff0_26*dmats0[26][5] + coeff0_27*dmats0[27][5] + coeff0_28*dmats0[28][5] + coeff0_29*dmats0[29][5] + coeff0_30*dmats0[30][5] + coeff0_31*dmats0[31][5] + coeff0_32*dmats0[32][5] + coeff0_33*dmats0[33][5] + coeff0_34*dmats0[34][5] + coeff0_35*dmats0[35][5] + coeff0_36*dmats0[36][5] + coeff0_37*dmats0[37][5] + coeff0_38*dmats0[38][5] + coeff0_39*dmats0[39][5] + coeff0_40*dmats0[40][5] + coeff0_41*dmats0[41][5] + coeff0_42*dmats0[42][5] + coeff0_43*dmats0[43][5] + coeff0_44*dmats0[44][5] + coeff0_45*dmats0[45][5] + coeff0_46*dmats0[46][5] + coeff0_47*dmats0[47][5] + coeff0_48*dmats0[48][5] + coeff0_49*dmats0[49][5] + coeff0_50*dmats0[50][5] + coeff0_51*dmats0[51][5] + coeff0_52*dmats0[52][5] + coeff0_53*dmats0[53][5] + coeff0_54*dmats0[54][5] + coeff0_55*dmats0[55][5];
          new_coeff0_6 = coeff0_0*dmats0[0][6] + coeff0_1*dmats0[1][6] + coeff0_2*dmats0[2][6] + coeff0_3*dmats0[3][6] + coeff0_4*dmats0[4][6] + coeff0_5*dmats0[5][6] + coeff0_6*dmats0[6][6] + coeff0_7*dmats0[7][6] + coeff0_8*dmats0[8][6] + coeff0_9*dmats0[9][6] + coeff0_10*dmats0[10][6] + coeff0_11*dmats0[11][6] + coeff0_12*dmats0[12][6] + coeff0_13*dmats0[13][6] + coeff0_14*dmats0[14][6] + coeff0_15*dmats0[15][6] + coeff0_16*dmats0[16][6] + coeff0_17*dmats0[17][6] + coeff0_18*dmats0[18][6] + coeff0_19*dmats0[19][6] + coeff0_20*dmats0[20][6] + coeff0_21*dmats0[21][6] + coeff0_22*dmats0[22][6] + coeff0_23*dmats0[23][6] + coeff0_24*dmats0[24][6] + coeff0_25*dmats0[25][6] + coeff0_26*dmats0[26][6] + coeff0_27*dmats0[27][6] + coeff0_28*dmats0[28][6] + coeff0_29*dmats0[29][6] + coeff0_30*dmats0[30][6] + coeff0_31*dmats0[31][6] + coeff0_32*dmats0[32][6] + coeff0_33*dmats0[33][6] + coeff0_34*dmats0[34][6] + coeff0_35*dmats0[35][6] + coeff0_36*dmats0[36][6] + coeff0_37*dmats0[37][6] + coeff0_38*dmats0[38][6] + coeff0_39*dmats0[39][6] + coeff0_40*dmats0[40][6] + coeff0_41*dmats0[41][6] + coeff0_42*dmats0[42][6] + coeff0_43*dmats0[43][6] + coeff0_44*dmats0[44][6] + coeff0_45*dmats0[45][6] + coeff0_46*dmats0[46][6] + coeff0_47*dmats0[47][6] + coeff0_48*dmats0[48][6] + coeff0_49*dmats0[49][6] + coeff0_50*dmats0[50][6] + coeff0_51*dmats0[51][6] + coeff0_52*dmats0[52][6] + coeff0_53*dmats0[53][6] + coeff0_54*dmats0[54][6] + coeff0_55*dmats0[55][6];
          new_coeff0_7 = coeff0_0*dmats0[0][7] + coeff0_1*dmats0[1][7] + coeff0_2*dmats0[2][7] + coeff0_3*dmats0[3][7] + coeff0_4*dmats0[4][7] + coeff0_5*dmats0[5][7] + coeff0_6*dmats0[6][7] + coeff0_7*dmats0[7][7] + coeff0_8*dmats0[8][7] + coeff0_9*dmats0[9][7] + coeff0_10*dmats0[10][7] + coeff0_11*dmats0[11][7] + coeff0_12*dmats0[12][7] + coeff0_13*dmats0[13][7] + coeff0_14*dmats0[14][7] + coeff0_15*dmats0[15][7] + coeff0_16*dmats0[16][7] + coeff0_17*dmats0[17][7] + coeff0_18*dmats0[18][7] + coeff0_19*dmats0[19][7] + coeff0_20*dmats0[20][7] + coeff0_21*dmats0[21][7] + coeff0_22*dmats0[22][7] + coeff0_23*dmats0[23][7] + coeff0_24*dmats0[24][7] + coeff0_25*dmats0[25][7] + coeff0_26*dmats0[26][7] + coeff0_27*dmats0[27][7] + coeff0_28*dmats0[28][7] + coeff0_29*dmats0[29][7] + coeff0_30*dmats0[30][7] + coeff0_31*dmats0[31][7] + coeff0_32*dmats0[32][7] + coeff0_33*dmats0[33][7] + coeff0_34*dmats0[34][7] + coeff0_35*dmats0[35][7] + coeff0_36*dmats0[36][7] + coeff0_37*dmats0[37][7] + coeff0_38*dmats0[38][7] + coeff0_39*dmats0[39][7] + coeff0_40*dmats0[40][7] + coeff0_41*dmats0[41][7] + coeff0_42*dmats0[42][7] + coeff0_43*dmats0[43][7] + coeff0_44*dmats0[44][7] + coeff0_45*dmats0[45][7] + coeff0_46*dmats0[46][7] + coeff0_47*dmats0[47][7] + coeff0_48*dmats0[48][7] + coeff0_49*dmats0[49][7] + coeff0_50*dmats0[50][7] + coeff0_51*dmats0[51][7] + coeff0_52*dmats0[52][7] + coeff0_53*dmats0[53][7] + coeff0_54*dmats0[54][7] + coeff0_55*dmats0[55][7];
          new_coeff0_8 = coeff0_0*dmats0[0][8] + coeff0_1*dmats0[1][8] + coeff0_2*dmats0[2][8] + coeff0_3*dmats0[3][8] + coeff0_4*dmats0[4][8] + coeff0_5*dmats0[5][8] + coeff0_6*dmats0[6][8] + coeff0_7*dmats0[7][8] + coeff0_8*dmats0[8][8] + coeff0_9*dmats0[9][8] + coeff0_10*dmats0[10][8] + coeff0_11*dmats0[11][8] + coeff0_12*dmats0[12][8] + coeff0_13*dmats0[13][8] + coeff0_14*dmats0[14][8] + coeff0_15*dmats0[15][8] + coeff0_16*dmats0[16][8] + coeff0_17*dmats0[17][8] + coeff0_18*dmats0[18][8] + coeff0_19*dmats0[19][8] + coeff0_20*dmats0[20][8] + coeff0_21*dmats0[21][8] + coeff0_22*dmats0[22][8] + coeff0_23*dmats0[23][8] + coeff0_24*dmats0[24][8] + coeff0_25*dmats0[25][8] + coeff0_26*dmats0[26][8] + coeff0_27*dmats0[27][8] + coeff0_28*dmats0[28][8] + coeff0_29*dmats0[29][8] + coeff0_30*dmats0[30][8] + coeff0_31*dmats0[31][8] + coeff0_32*dmats0[32][8] + coeff0_33*dmats0[33][8] + coeff0_34*dmats0[34][8] + coeff0_35*dmats0[35][8] + coeff0_36*dmats0[36][8] + coeff0_37*dmats0[37][8] + coeff0_38*dmats0[38][8] + coeff0_39*dmats0[39][8] + coeff0_40*dmats0[40][8] + coeff0_41*dmats0[41][8] + coeff0_42*dmats0[42][8] + coeff0_43*dmats0[43][8] + coeff0_44*dmats0[44][8] + coeff0_45*dmats0[45][8] + coeff0_46*dmats0[46][8] + coeff0_47*dmats0[47][8] + coeff0_48*dmats0[48][8] + coeff0_49*dmats0[49][8] + coeff0_50*dmats0[50][8] + coeff0_51*dmats0[51][8] + coeff0_52*dmats0[52][8] + coeff0_53*dmats0[53][8] + coeff0_54*dmats0[54][8] + coeff0_55*dmats0[55][8];
          new_coeff0_9 = coeff0_0*dmats0[0][9] + coeff0_1*dmats0[1][9] + coeff0_2*dmats0[2][9] + coeff0_3*dmats0[3][9] + coeff0_4*dmats0[4][9] + coeff0_5*dmats0[5][9] + coeff0_6*dmats0[6][9] + coeff0_7*dmats0[7][9] + coeff0_8*dmats0[8][9] + coeff0_9*dmats0[9][9] + coeff0_10*dmats0[10][9] + coeff0_11*dmats0[11][9] + coeff0_12*dmats0[12][9] + coeff0_13*dmats0[13][9] + coeff0_14*dmats0[14][9] + coeff0_15*dmats0[15][9] + coeff0_16*dmats0[16][9] + coeff0_17*dmats0[17][9] + coeff0_18*dmats0[18][9] + coeff0_19*dmats0[19][9] + coeff0_20*dmats0[20][9] + coeff0_21*dmats0[21][9] + coeff0_22*dmats0[22][9] + coeff0_23*dmats0[23][9] + coeff0_24*dmats0[24][9] + coeff0_25*dmats0[25][9] + coeff0_26*dmats0[26][9] + coeff0_27*dmats0[27][9] + coeff0_28*dmats0[28][9] + coeff0_29*dmats0[29][9] + coeff0_30*dmats0[30][9] + coeff0_31*dmats0[31][9] + coeff0_32*dmats0[32][9] + coeff0_33*dmats0[33][9] + coeff0_34*dmats0[34][9] + coeff0_35*dmats0[35][9] + coeff0_36*dmats0[36][9] + coeff0_37*dmats0[37][9] + coeff0_38*dmats0[38][9] + coeff0_39*dmats0[39][9] + coeff0_40*dmats0[40][9] + coeff0_41*dmats0[41][9] + coeff0_42*dmats0[42][9] + coeff0_43*dmats0[43][9] + coeff0_44*dmats0[44][9] + coeff0_45*dmats0[45][9] + coeff0_46*dmats0[46][9] + coeff0_47*dmats0[47][9] + coeff0_48*dmats0[48][9] + coeff0_49*dmats0[49][9] + coeff0_50*dmats0[50][9] + coeff0_51*dmats0[51][9] + coeff0_52*dmats0[52][9] + coeff0_53*dmats0[53][9] + coeff0_54*dmats0[54][9] + coeff0_55*dmats0[55][9];
          new_coeff0_10 = coeff0_0*dmats0[0][10] + coeff0_1*dmats0[1][10] + coeff0_2*dmats0[2][10] + coeff0_3*dmats0[3][10] + coeff0_4*dmats0[4][10] + coeff0_5*dmats0[5][10] + coeff0_6*dmats0[6][10] + coeff0_7*dmats0[7][10] + coeff0_8*dmats0[8][10] + coeff0_9*dmats0[9][10] + coeff0_10*dmats0[10][10] + coeff0_11*dmats0[11][10] + coeff0_12*dmats0[12][10] + coeff0_13*dmats0[13][10] + coeff0_14*dmats0[14][10] + coeff0_15*dmats0[15][10] + coeff0_16*dmats0[16][10] + coeff0_17*dmats0[17][10] + coeff0_18*dmats0[18][10] + coeff0_19*dmats0[19][10] + coeff0_20*dmats0[20][10] + coeff0_21*dmats0[21][10] + coeff0_22*dmats0[22][10] + coeff0_23*dmats0[23][10] + coeff0_24*dmats0[24][10] + coeff0_25*dmats0[25][10] + coeff0_26*dmats0[26][10] + coeff0_27*dmats0[27][10] + coeff0_28*dmats0[28][10] + coeff0_29*dmats0[29][10] + coeff0_30*dmats0[30][10] + coeff0_31*dmats0[31][10] + coeff0_32*dmats0[32][10] + coeff0_33*dmats0[33][10] + coeff0_34*dmats0[34][10] + coeff0_35*dmats0[35][10] + coeff0_36*dmats0[36][10] + coeff0_37*dmats0[37][10] + coeff0_38*dmats0[38][10] + coeff0_39*dmats0[39][10] + coeff0_40*dmats0[40][10] + coeff0_41*dmats0[41][10] + coeff0_42*dmats0[42][10] + coeff0_43*dmats0[43][10] + coeff0_44*dmats0[44][10] + coeff0_45*dmats0[45][10] + coeff0_46*dmats0[46][10] + coeff0_47*dmats0[47][10] + coeff0_48*dmats0[48][10] + coeff0_49*dmats0[49][10] + coeff0_50*dmats0[50][10] + coeff0_51*dmats0[51][10] + coeff0_52*dmats0[52][10] + coeff0_53*dmats0[53][10] + coeff0_54*dmats0[54][10] + coeff0_55*dmats0[55][10];
          new_coeff0_11 = coeff0_0*dmats0[0][11] + coeff0_1*dmats0[1][11] + coeff0_2*dmats0[2][11] + coeff0_3*dmats0[3][11] + coeff0_4*dmats0[4][11] + coeff0_5*dmats0[5][11] + coeff0_6*dmats0[6][11] + coeff0_7*dmats0[7][11] + coeff0_8*dmats0[8][11] + coeff0_9*dmats0[9][11] + coeff0_10*dmats0[10][11] + coeff0_11*dmats0[11][11] + coeff0_12*dmats0[12][11] + coeff0_13*dmats0[13][11] + coeff0_14*dmats0[14][11] + coeff0_15*dmats0[15][11] + coeff0_16*dmats0[16][11] + coeff0_17*dmats0[17][11] + coeff0_18*dmats0[18][11] + coeff0_19*dmats0[19][11] + coeff0_20*dmats0[20][11] + coeff0_21*dmats0[21][11] + coeff0_22*dmats0[22][11] + coeff0_23*dmats0[23][11] + coeff0_24*dmats0[24][11] + coeff0_25*dmats0[25][11] + coeff0_26*dmats0[26][11] + coeff0_27*dmats0[27][11] + coeff0_28*dmats0[28][11] + coeff0_29*dmats0[29][11] + coeff0_30*dmats0[30][11] + coeff0_31*dmats0[31][11] + coeff0_32*dmats0[32][11] + coeff0_33*dmats0[33][11] + coeff0_34*dmats0[34][11] + coeff0_35*dmats0[35][11] + coeff0_36*dmats0[36][11] + coeff0_37*dmats0[37][11] + coeff0_38*dmats0[38][11] + coeff0_39*dmats0[39][11] + coeff0_40*dmats0[40][11] + coeff0_41*dmats0[41][11] + coeff0_42*dmats0[42][11] + coeff0_43*dmats0[43][11] + coeff0_44*dmats0[44][11] + coeff0_45*dmats0[45][11] + coeff0_46*dmats0[46][11] + coeff0_47*dmats0[47][11] + coeff0_48*dmats0[48][11] + coeff0_49*dmats0[49][11] + coeff0_50*dmats0[50][11] + coeff0_51*dmats0[51][11] + coeff0_52*dmats0[52][11] + coeff0_53*dmats0[53][11] + coeff0_54*dmats0[54][11] + coeff0_55*dmats0[55][11];
          new_coeff0_12 = coeff0_0*dmats0[0][12] + coeff0_1*dmats0[1][12] + coeff0_2*dmats0[2][12] + coeff0_3*dmats0[3][12] + coeff0_4*dmats0[4][12] + coeff0_5*dmats0[5][12] + coeff0_6*dmats0[6][12] + coeff0_7*dmats0[7][12] + coeff0_8*dmats0[8][12] + coeff0_9*dmats0[9][12] + coeff0_10*dmats0[10][12] + coeff0_11*dmats0[11][12] + coeff0_12*dmats0[12][12] + coeff0_13*dmats0[13][12] + coeff0_14*dmats0[14][12] + coeff0_15*dmats0[15][12] + coeff0_16*dmats0[16][12] + coeff0_17*dmats0[17][12] + coeff0_18*dmats0[18][12] + coeff0_19*dmats0[19][12] + coeff0_20*dmats0[20][12] + coeff0_21*dmats0[21][12] + coeff0_22*dmats0[22][12] + coeff0_23*dmats0[23][12] + coeff0_24*dmats0[24][12] + coeff0_25*dmats0[25][12] + coeff0_26*dmats0[26][12] + coeff0_27*dmats0[27][12] + coeff0_28*dmats0[28][12] + coeff0_29*dmats0[29][12] + coeff0_30*dmats0[30][12] + coeff0_31*dmats0[31][12] + coeff0_32*dmats0[32][12] + coeff0_33*dmats0[33][12] + coeff0_34*dmats0[34][12] + coeff0_35*dmats0[35][12] + coeff0_36*dmats0[36][12] + coeff0_37*dmats0[37][12] + coeff0_38*dmats0[38][12] + coeff0_39*dmats0[39][12] + coeff0_40*dmats0[40][12] + coeff0_41*dmats0[41][12] + coeff0_42*dmats0[42][12] + coeff0_43*dmats0[43][12] + coeff0_44*dmats0[44][12] + coeff0_45*dmats0[45][12] + coeff0_46*dmats0[46][12] + coeff0_47*dmats0[47][12] + coeff0_48*dmats0[48][12] + coeff0_49*dmats0[49][12] + coeff0_50*dmats0[50][12] + coeff0_51*dmats0[51][12] + coeff0_52*dmats0[52][12] + coeff0_53*dmats0[53][12] + coeff0_54*dmats0[54][12] + coeff0_55*dmats0[55][12];
          new_coeff0_13 = coeff0_0*dmats0[0][13] + coeff0_1*dmats0[1][13] + coeff0_2*dmats0[2][13] + coeff0_3*dmats0[3][13] + coeff0_4*dmats0[4][13] + coeff0_5*dmats0[5][13] + coeff0_6*dmats0[6][13] + coeff0_7*dmats0[7][13] + coeff0_8*dmats0[8][13] + coeff0_9*dmats0[9][13] + coeff0_10*dmats0[10][13] + coeff0_11*dmats0[11][13] + coeff0_12*dmats0[12][13] + coeff0_13*dmats0[13][13] + coeff0_14*dmats0[14][13] + coeff0_15*dmats0[15][13] + coeff0_16*dmats0[16][13] + coeff0_17*dmats0[17][13] + coeff0_18*dmats0[18][13] + coeff0_19*dmats0[19][13] + coeff0_20*dmats0[20][13] + coeff0_21*dmats0[21][13] + coeff0_22*dmats0[22][13] + coeff0_23*dmats0[23][13] + coeff0_24*dmats0[24][13] + coeff0_25*dmats0[25][13] + coeff0_26*dmats0[26][13] + coeff0_27*dmats0[27][13] + coeff0_28*dmats0[28][13] + coeff0_29*dmats0[29][13] + coeff0_30*dmats0[30][13] + coeff0_31*dmats0[31][13] + coeff0_32*dmats0[32][13] + coeff0_33*dmats0[33][13] + coeff0_34*dmats0[34][13] + coeff0_35*dmats0[35][13] + coeff0_36*dmats0[36][13] + coeff0_37*dmats0[37][13] + coeff0_38*dmats0[38][13] + coeff0_39*dmats0[39][13] + coeff0_40*dmats0[40][13] + coeff0_41*dmats0[41][13] + coeff0_42*dmats0[42][13] + coeff0_43*dmats0[43][13] + coeff0_44*dmats0[44][13] + coeff0_45*dmats0[45][13] + coeff0_46*dmats0[46][13] + coeff0_47*dmats0[47][13] + coeff0_48*dmats0[48][13] + coeff0_49*dmats0[49][13] + coeff0_50*dmats0[50][13] + coeff0_51*dmats0[51][13] + coeff0_52*dmats0[52][13] + coeff0_53*dmats0[53][13] + coeff0_54*dmats0[54][13] + coeff0_55*dmats0[55][13];
          new_coeff0_14 = coeff0_0*dmats0[0][14] + coeff0_1*dmats0[1][14] + coeff0_2*dmats0[2][14] + coeff0_3*dmats0[3][14] + coeff0_4*dmats0[4][14] + coeff0_5*dmats0[5][14] + coeff0_6*dmats0[6][14] + coeff0_7*dmats0[7][14] + coeff0_8*dmats0[8][14] + coeff0_9*dmats0[9][14] + coeff0_10*dmats0[10][14] + coeff0_11*dmats0[11][14] + coeff0_12*dmats0[12][14] + coeff0_13*dmats0[13][14] + coeff0_14*dmats0[14][14] + coeff0_15*dmats0[15][14] + coeff0_16*dmats0[16][14] + coeff0_17*dmats0[17][14] + coeff0_18*dmats0[18][14] + coeff0_19*dmats0[19][14] + coeff0_20*dmats0[20][14] + coeff0_21*dmats0[21][14] + coeff0_22*dmats0[22][14] + coeff0_23*dmats0[23][14] + coeff0_24*dmats0[24][14] + coeff0_25*dmats0[25][14] + coeff0_26*dmats0[26][14] + coeff0_27*dmats0[27][14] + coeff0_28*dmats0[28][14] + coeff0_29*dmats0[29][14] + coeff0_30*dmats0[30][14] + coeff0_31*dmats0[31][14] + coeff0_32*dmats0[32][14] + coeff0_33*dmats0[33][14] + coeff0_34*dmats0[34][14] + coeff0_35*dmats0[35][14] + coeff0_36*dmats0[36][14] + coeff0_37*dmats0[37][14] + coeff0_38*dmats0[38][14] + coeff0_39*dmats0[39][14] + coeff0_40*dmats0[40][14] + coeff0_41*dmats0[41][14] + coeff0_42*dmats0[42][14] + coeff0_43*dmats0[43][14] + coeff0_44*dmats0[44][14] + coeff0_45*dmats0[45][14] + coeff0_46*dmats0[46][14] + coeff0_47*dmats0[47][14] + coeff0_48*dmats0[48][14] + coeff0_49*dmats0[49][14] + coeff0_50*dmats0[50][14] + coeff0_51*dmats0[51][14] + coeff0_52*dmats0[52][14] + coeff0_53*dmats0[53][14] + coeff0_54*dmats0[54][14] + coeff0_55*dmats0[55][14];
          new_coeff0_15 = coeff0_0*dmats0[0][15] + coeff0_1*dmats0[1][15] + coeff0_2*dmats0[2][15] + coeff0_3*dmats0[3][15] + coeff0_4*dmats0[4][15] + coeff0_5*dmats0[5][15] + coeff0_6*dmats0[6][15] + coeff0_7*dmats0[7][15] + coeff0_8*dmats0[8][15] + coeff0_9*dmats0[9][15] + coeff0_10*dmats0[10][15] + coeff0_11*dmats0[11][15] + coeff0_12*dmats0[12][15] + coeff0_13*dmats0[13][15] + coeff0_14*dmats0[14][15] + coeff0_15*dmats0[15][15] + coeff0_16*dmats0[16][15] + coeff0_17*dmats0[17][15] + coeff0_18*dmats0[18][15] + coeff0_19*dmats0[19][15] + coeff0_20*dmats0[20][15] + coeff0_21*dmats0[21][15] + coeff0_22*dmats0[22][15] + coeff0_23*dmats0[23][15] + coeff0_24*dmats0[24][15] + coeff0_25*dmats0[25][15] + coeff0_26*dmats0[26][15] + coeff0_27*dmats0[27][15] + coeff0_28*dmats0[28][15] + coeff0_29*dmats0[29][15] + coeff0_30*dmats0[30][15] + coeff0_31*dmats0[31][15] + coeff0_32*dmats0[32][15] + coeff0_33*dmats0[33][15] + coeff0_34*dmats0[34][15] + coeff0_35*dmats0[35][15] + coeff0_36*dmats0[36][15] + coeff0_37*dmats0[37][15] + coeff0_38*dmats0[38][15] + coeff0_39*dmats0[39][15] + coeff0_40*dmats0[40][15] + coeff0_41*dmats0[41][15] + coeff0_42*dmats0[42][15] + coeff0_43*dmats0[43][15] + coeff0_44*dmats0[44][15] + coeff0_45*dmats0[45][15] + coeff0_46*dmats0[46][15] + coeff0_47*dmats0[47][15] + coeff0_48*dmats0[48][15] + coeff0_49*dmats0[49][15] + coeff0_50*dmats0[50][15] + coeff0_51*dmats0[51][15] + coeff0_52*dmats0[52][15] + coeff0_53*dmats0[53][15] + coeff0_54*dmats0[54][15] + coeff0_55*dmats0[55][15];
          new_coeff0_16 = coeff0_0*dmats0[0][16] + coeff0_1*dmats0[1][16] + coeff0_2*dmats0[2][16] + coeff0_3*dmats0[3][16] + coeff0_4*dmats0[4][16] + coeff0_5*dmats0[5][16] + coeff0_6*dmats0[6][16] + coeff0_7*dmats0[7][16] + coeff0_8*dmats0[8][16] + coeff0_9*dmats0[9][16] + coeff0_10*dmats0[10][16] + coeff0_11*dmats0[11][16] + coeff0_12*dmats0[12][16] + coeff0_13*dmats0[13][16] + coeff0_14*dmats0[14][16] + coeff0_15*dmats0[15][16] + coeff0_16*dmats0[16][16] + coeff0_17*dmats0[17][16] + coeff0_18*dmats0[18][16] + coeff0_19*dmats0[19][16] + coeff0_20*dmats0[20][16] + coeff0_21*dmats0[21][16] + coeff0_22*dmats0[22][16] + coeff0_23*dmats0[23][16] + coeff0_24*dmats0[24][16] + coeff0_25*dmats0[25][16] + coeff0_26*dmats0[26][16] + coeff0_27*dmats0[27][16] + coeff0_28*dmats0[28][16] + coeff0_29*dmats0[29][16] + coeff0_30*dmats0[30][16] + coeff0_31*dmats0[31][16] + coeff0_32*dmats0[32][16] + coeff0_33*dmats0[33][16] + coeff0_34*dmats0[34][16] + coeff0_35*dmats0[35][16] + coeff0_36*dmats0[36][16] + coeff0_37*dmats0[37][16] + coeff0_38*dmats0[38][16] + coeff0_39*dmats0[39][16] + coeff0_40*dmats0[40][16] + coeff0_41*dmats0[41][16] + coeff0_42*dmats0[42][16] + coeff0_43*dmats0[43][16] + coeff0_44*dmats0[44][16] + coeff0_45*dmats0[45][16] + coeff0_46*dmats0[46][16] + coeff0_47*dmats0[47][16] + coeff0_48*dmats0[48][16] + coeff0_49*dmats0[49][16] + coeff0_50*dmats0[50][16] + coeff0_51*dmats0[51][16] + coeff0_52*dmats0[52][16] + coeff0_53*dmats0[53][16] + coeff0_54*dmats0[54][16] + coeff0_55*dmats0[55][16];
          new_coeff0_17 = coeff0_0*dmats0[0][17] + coeff0_1*dmats0[1][17] + coeff0_2*dmats0[2][17] + coeff0_3*dmats0[3][17] + coeff0_4*dmats0[4][17] + coeff0_5*dmats0[5][17] + coeff0_6*dmats0[6][17] + coeff0_7*dmats0[7][17] + coeff0_8*dmats0[8][17] + coeff0_9*dmats0[9][17] + coeff0_10*dmats0[10][17] + coeff0_11*dmats0[11][17] + coeff0_12*dmats0[12][17] + coeff0_13*dmats0[13][17] + coeff0_14*dmats0[14][17] + coeff0_15*dmats0[15][17] + coeff0_16*dmats0[16][17] + coeff0_17*dmats0[17][17] + coeff0_18*dmats0[18][17] + coeff0_19*dmats0[19][17] + coeff0_20*dmats0[20][17] + coeff0_21*dmats0[21][17] + coeff0_22*dmats0[22][17] + coeff0_23*dmats0[23][17] + coeff0_24*dmats0[24][17] + coeff0_25*dmats0[25][17] + coeff0_26*dmats0[26][17] + coeff0_27*dmats0[27][17] + coeff0_28*dmats0[28][17] + coeff0_29*dmats0[29][17] + coeff0_30*dmats0[30][17] + coeff0_31*dmats0[31][17] + coeff0_32*dmats0[32][17] + coeff0_33*dmats0[33][17] + coeff0_34*dmats0[34][17] + coeff0_35*dmats0[35][17] + coeff0_36*dmats0[36][17] + coeff0_37*dmats0[37][17] + coeff0_38*dmats0[38][17] + coeff0_39*dmats0[39][17] + coeff0_40*dmats0[40][17] + coeff0_41*dmats0[41][17] + coeff0_42*dmats0[42][17] + coeff0_43*dmats0[43][17] + coeff0_44*dmats0[44][17] + coeff0_45*dmats0[45][17] + coeff0_46*dmats0[46][17] + coeff0_47*dmats0[47][17] + coeff0_48*dmats0[48][17] + coeff0_49*dmats0[49][17] + coeff0_50*dmats0[50][17] + coeff0_51*dmats0[51][17] + coeff0_52*dmats0[52][17] + coeff0_53*dmats0[53][17] + coeff0_54*dmats0[54][17] + coeff0_55*dmats0[55][17];
          new_coeff0_18 = coeff0_0*dmats0[0][18] + coeff0_1*dmats0[1][18] + coeff0_2*dmats0[2][18] + coeff0_3*dmats0[3][18] + coeff0_4*dmats0[4][18] + coeff0_5*dmats0[5][18] + coeff0_6*dmats0[6][18] + coeff0_7*dmats0[7][18] + coeff0_8*dmats0[8][18] + coeff0_9*dmats0[9][18] + coeff0_10*dmats0[10][18] + coeff0_11*dmats0[11][18] + coeff0_12*dmats0[12][18] + coeff0_13*dmats0[13][18] + coeff0_14*dmats0[14][18] + coeff0_15*dmats0[15][18] + coeff0_16*dmats0[16][18] + coeff0_17*dmats0[17][18] + coeff0_18*dmats0[18][18] + coeff0_19*dmats0[19][18] + coeff0_20*dmats0[20][18] + coeff0_21*dmats0[21][18] + coeff0_22*dmats0[22][18] + coeff0_23*dmats0[23][18] + coeff0_24*dmats0[24][18] + coeff0_25*dmats0[25][18] + coeff0_26*dmats0[26][18] + coeff0_27*dmats0[27][18] + coeff0_28*dmats0[28][18] + coeff0_29*dmats0[29][18] + coeff0_30*dmats0[30][18] + coeff0_31*dmats0[31][18] + coeff0_32*dmats0[32][18] + coeff0_33*dmats0[33][18] + coeff0_34*dmats0[34][18] + coeff0_35*dmats0[35][18] + coeff0_36*dmats0[36][18] + coeff0_37*dmats0[37][18] + coeff0_38*dmats0[38][18] + coeff0_39*dmats0[39][18] + coeff0_40*dmats0[40][18] + coeff0_41*dmats0[41][18] + coeff0_42*dmats0[42][18] + coeff0_43*dmats0[43][18] + coeff0_44*dmats0[44][18] + coeff0_45*dmats0[45][18] + coeff0_46*dmats0[46][18] + coeff0_47*dmats0[47][18] + coeff0_48*dmats0[48][18] + coeff0_49*dmats0[49][18] + coeff0_50*dmats0[50][18] + coeff0_51*dmats0[51][18] + coeff0_52*dmats0[52][18] + coeff0_53*dmats0[53][18] + coeff0_54*dmats0[54][18] + coeff0_55*dmats0[55][18];
          new_coeff0_19 = coeff0_0*dmats0[0][19] + coeff0_1*dmats0[1][19] + coeff0_2*dmats0[2][19] + coeff0_3*dmats0[3][19] + coeff0_4*dmats0[4][19] + coeff0_5*dmats0[5][19] + coeff0_6*dmats0[6][19] + coeff0_7*dmats0[7][19] + coeff0_8*dmats0[8][19] + coeff0_9*dmats0[9][19] + coeff0_10*dmats0[10][19] + coeff0_11*dmats0[11][19] + coeff0_12*dmats0[12][19] + coeff0_13*dmats0[13][19] + coeff0_14*dmats0[14][19] + coeff0_15*dmats0[15][19] + coeff0_16*dmats0[16][19] + coeff0_17*dmats0[17][19] + coeff0_18*dmats0[18][19] + coeff0_19*dmats0[19][19] + coeff0_20*dmats0[20][19] + coeff0_21*dmats0[21][19] + coeff0_22*dmats0[22][19] + coeff0_23*dmats0[23][19] + coeff0_24*dmats0[24][19] + coeff0_25*dmats0[25][19] + coeff0_26*dmats0[26][19] + coeff0_27*dmats0[27][19] + coeff0_28*dmats0[28][19] + coeff0_29*dmats0[29][19] + coeff0_30*dmats0[30][19] + coeff0_31*dmats0[31][19] + coeff0_32*dmats0[32][19] + coeff0_33*dmats0[33][19] + coeff0_34*dmats0[34][19] + coeff0_35*dmats0[35][19] + coeff0_36*dmats0[36][19] + coeff0_37*dmats0[37][19] + coeff0_38*dmats0[38][19] + coeff0_39*dmats0[39][19] + coeff0_40*dmats0[40][19] + coeff0_41*dmats0[41][19] + coeff0_42*dmats0[42][19] + coeff0_43*dmats0[43][19] + coeff0_44*dmats0[44][19] + coeff0_45*dmats0[45][19] + coeff0_46*dmats0[46][19] + coeff0_47*dmats0[47][19] + coeff0_48*dmats0[48][19] + coeff0_49*dmats0[49][19] + coeff0_50*dmats0[50][19] + coeff0_51*dmats0[51][19] + coeff0_52*dmats0[52][19] + coeff0_53*dmats0[53][19] + coeff0_54*dmats0[54][19] + coeff0_55*dmats0[55][19];
          new_coeff0_20 = coeff0_0*dmats0[0][20] + coeff0_1*dmats0[1][20] + coeff0_2*dmats0[2][20] + coeff0_3*dmats0[3][20] + coeff0_4*dmats0[4][20] + coeff0_5*dmats0[5][20] + coeff0_6*dmats0[6][20] + coeff0_7*dmats0[7][20] + coeff0_8*dmats0[8][20] + coeff0_9*dmats0[9][20] + coeff0_10*dmats0[10][20] + coeff0_11*dmats0[11][20] + coeff0_12*dmats0[12][20] + coeff0_13*dmats0[13][20] + coeff0_14*dmats0[14][20] + coeff0_15*dmats0[15][20] + coeff0_16*dmats0[16][20] + coeff0_17*dmats0[17][20] + coeff0_18*dmats0[18][20] + coeff0_19*dmats0[19][20] + coeff0_20*dmats0[20][20] + coeff0_21*dmats0[21][20] + coeff0_22*dmats0[22][20] + coeff0_23*dmats0[23][20] + coeff0_24*dmats0[24][20] + coeff0_25*dmats0[25][20] + coeff0_26*dmats0[26][20] + coeff0_27*dmats0[27][20] + coeff0_28*dmats0[28][20] + coeff0_29*dmats0[29][20] + coeff0_30*dmats0[30][20] + coeff0_31*dmats0[31][20] + coeff0_32*dmats0[32][20] + coeff0_33*dmats0[33][20] + coeff0_34*dmats0[34][20] + coeff0_35*dmats0[35][20] + coeff0_36*dmats0[36][20] + coeff0_37*dmats0[37][20] + coeff0_38*dmats0[38][20] + coeff0_39*dmats0[39][20] + coeff0_40*dmats0[40][20] + coeff0_41*dmats0[41][20] + coeff0_42*dmats0[42][20] + coeff0_43*dmats0[43][20] + coeff0_44*dmats0[44][20] + coeff0_45*dmats0[45][20] + coeff0_46*dmats0[46][20] + coeff0_47*dmats0[47][20] + coeff0_48*dmats0[48][20] + coeff0_49*dmats0[49][20] + coeff0_50*dmats0[50][20] + coeff0_51*dmats0[51][20] + coeff0_52*dmats0[52][20] + coeff0_53*dmats0[53][20] + coeff0_54*dmats0[54][20] + coeff0_55*dmats0[55][20];
          new_coeff0_21 = coeff0_0*dmats0[0][21] + coeff0_1*dmats0[1][21] + coeff0_2*dmats0[2][21] + coeff0_3*dmats0[3][21] + coeff0_4*dmats0[4][21] + coeff0_5*dmats0[5][21] + coeff0_6*dmats0[6][21] + coeff0_7*dmats0[7][21] + coeff0_8*dmats0[8][21] + coeff0_9*dmats0[9][21] + coeff0_10*dmats0[10][21] + coeff0_11*dmats0[11][21] + coeff0_12*dmats0[12][21] + coeff0_13*dmats0[13][21] + coeff0_14*dmats0[14][21] + coeff0_15*dmats0[15][21] + coeff0_16*dmats0[16][21] + coeff0_17*dmats0[17][21] + coeff0_18*dmats0[18][21] + coeff0_19*dmats0[19][21] + coeff0_20*dmats0[20][21] + coeff0_21*dmats0[21][21] + coeff0_22*dmats0[22][21] + coeff0_23*dmats0[23][21] + coeff0_24*dmats0[24][21] + coeff0_25*dmats0[25][21] + coeff0_26*dmats0[26][21] + coeff0_27*dmats0[27][21] + coeff0_28*dmats0[28][21] + coeff0_29*dmats0[29][21] + coeff0_30*dmats0[30][21] + coeff0_31*dmats0[31][21] + coeff0_32*dmats0[32][21] + coeff0_33*dmats0[33][21] + coeff0_34*dmats0[34][21] + coeff0_35*dmats0[35][21] + coeff0_36*dmats0[36][21] + coeff0_37*dmats0[37][21] + coeff0_38*dmats0[38][21] + coeff0_39*dmats0[39][21] + coeff0_40*dmats0[40][21] + coeff0_41*dmats0[41][21] + coeff0_42*dmats0[42][21] + coeff0_43*dmats0[43][21] + coeff0_44*dmats0[44][21] + coeff0_45*dmats0[45][21] + coeff0_46*dmats0[46][21] + coeff0_47*dmats0[47][21] + coeff0_48*dmats0[48][21] + coeff0_49*dmats0[49][21] + coeff0_50*dmats0[50][21] + coeff0_51*dmats0[51][21] + coeff0_52*dmats0[52][21] + coeff0_53*dmats0[53][21] + coeff0_54*dmats0[54][21] + coeff0_55*dmats0[55][21];
          new_coeff0_22 = coeff0_0*dmats0[0][22] + coeff0_1*dmats0[1][22] + coeff0_2*dmats0[2][22] + coeff0_3*dmats0[3][22] + coeff0_4*dmats0[4][22] + coeff0_5*dmats0[5][22] + coeff0_6*dmats0[6][22] + coeff0_7*dmats0[7][22] + coeff0_8*dmats0[8][22] + coeff0_9*dmats0[9][22] + coeff0_10*dmats0[10][22] + coeff0_11*dmats0[11][22] + coeff0_12*dmats0[12][22] + coeff0_13*dmats0[13][22] + coeff0_14*dmats0[14][22] + coeff0_15*dmats0[15][22] + coeff0_16*dmats0[16][22] + coeff0_17*dmats0[17][22] + coeff0_18*dmats0[18][22] + coeff0_19*dmats0[19][22] + coeff0_20*dmats0[20][22] + coeff0_21*dmats0[21][22] + coeff0_22*dmats0[22][22] + coeff0_23*dmats0[23][22] + coeff0_24*dmats0[24][22] + coeff0_25*dmats0[25][22] + coeff0_26*dmats0[26][22] + coeff0_27*dmats0[27][22] + coeff0_28*dmats0[28][22] + coeff0_29*dmats0[29][22] + coeff0_30*dmats0[30][22] + coeff0_31*dmats0[31][22] + coeff0_32*dmats0[32][22] + coeff0_33*dmats0[33][22] + coeff0_34*dmats0[34][22] + coeff0_35*dmats0[35][22] + coeff0_36*dmats0[36][22] + coeff0_37*dmats0[37][22] + coeff0_38*dmats0[38][22] + coeff0_39*dmats0[39][22] + coeff0_40*dmats0[40][22] + coeff0_41*dmats0[41][22] + coeff0_42*dmats0[42][22] + coeff0_43*dmats0[43][22] + coeff0_44*dmats0[44][22] + coeff0_45*dmats0[45][22] + coeff0_46*dmats0[46][22] + coeff0_47*dmats0[47][22] + coeff0_48*dmats0[48][22] + coeff0_49*dmats0[49][22] + coeff0_50*dmats0[50][22] + coeff0_51*dmats0[51][22] + coeff0_52*dmats0[52][22] + coeff0_53*dmats0[53][22] + coeff0_54*dmats0[54][22] + coeff0_55*dmats0[55][22];
          new_coeff0_23 = coeff0_0*dmats0[0][23] + coeff0_1*dmats0[1][23] + coeff0_2*dmats0[2][23] + coeff0_3*dmats0[3][23] + coeff0_4*dmats0[4][23] + coeff0_5*dmats0[5][23] + coeff0_6*dmats0[6][23] + coeff0_7*dmats0[7][23] + coeff0_8*dmats0[8][23] + coeff0_9*dmats0[9][23] + coeff0_10*dmats0[10][23] + coeff0_11*dmats0[11][23] + coeff0_12*dmats0[12][23] + coeff0_13*dmats0[13][23] + coeff0_14*dmats0[14][23] + coeff0_15*dmats0[15][23] + coeff0_16*dmats0[16][23] + coeff0_17*dmats0[17][23] + coeff0_18*dmats0[18][23] + coeff0_19*dmats0[19][23] + coeff0_20*dmats0[20][23] + coeff0_21*dmats0[21][23] + coeff0_22*dmats0[22][23] + coeff0_23*dmats0[23][23] + coeff0_24*dmats0[24][23] + coeff0_25*dmats0[25][23] + coeff0_26*dmats0[26][23] + coeff0_27*dmats0[27][23] + coeff0_28*dmats0[28][23] + coeff0_29*dmats0[29][23] + coeff0_30*dmats0[30][23] + coeff0_31*dmats0[31][23] + coeff0_32*dmats0[32][23] + coeff0_33*dmats0[33][23] + coeff0_34*dmats0[34][23] + coeff0_35*dmats0[35][23] + coeff0_36*dmats0[36][23] + coeff0_37*dmats0[37][23] + coeff0_38*dmats0[38][23] + coeff0_39*dmats0[39][23] + coeff0_40*dmats0[40][23] + coeff0_41*dmats0[41][23] + coeff0_42*dmats0[42][23] + coeff0_43*dmats0[43][23] + coeff0_44*dmats0[44][23] + coeff0_45*dmats0[45][23] + coeff0_46*dmats0[46][23] + coeff0_47*dmats0[47][23] + coeff0_48*dmats0[48][23] + coeff0_49*dmats0[49][23] + coeff0_50*dmats0[50][23] + coeff0_51*dmats0[51][23] + coeff0_52*dmats0[52][23] + coeff0_53*dmats0[53][23] + coeff0_54*dmats0[54][23] + coeff0_55*dmats0[55][23];
          new_coeff0_24 = coeff0_0*dmats0[0][24] + coeff0_1*dmats0[1][24] + coeff0_2*dmats0[2][24] + coeff0_3*dmats0[3][24] + coeff0_4*dmats0[4][24] + coeff0_5*dmats0[5][24] + coeff0_6*dmats0[6][24] + coeff0_7*dmats0[7][24] + coeff0_8*dmats0[8][24] + coeff0_9*dmats0[9][24] + coeff0_10*dmats0[10][24] + coeff0_11*dmats0[11][24] + coeff0_12*dmats0[12][24] + coeff0_13*dmats0[13][24] + coeff0_14*dmats0[14][24] + coeff0_15*dmats0[15][24] + coeff0_16*dmats0[16][24] + coeff0_17*dmats0[17][24] + coeff0_18*dmats0[18][24] + coeff0_19*dmats0[19][24] + coeff0_20*dmats0[20][24] + coeff0_21*dmats0[21][24] + coeff0_22*dmats0[22][24] + coeff0_23*dmats0[23][24] + coeff0_24*dmats0[24][24] + coeff0_25*dmats0[25][24] + coeff0_26*dmats0[26][24] + coeff0_27*dmats0[27][24] + coeff0_28*dmats0[28][24] + coeff0_29*dmats0[29][24] + coeff0_30*dmats0[30][24] + coeff0_31*dmats0[31][24] + coeff0_32*dmats0[32][24] + coeff0_33*dmats0[33][24] + coeff0_34*dmats0[34][24] + coeff0_35*dmats0[35][24] + coeff0_36*dmats0[36][24] + coeff0_37*dmats0[37][24] + coeff0_38*dmats0[38][24] + coeff0_39*dmats0[39][24] + coeff0_40*dmats0[40][24] + coeff0_41*dmats0[41][24] + coeff0_42*dmats0[42][24] + coeff0_43*dmats0[43][24] + coeff0_44*dmats0[44][24] + coeff0_45*dmats0[45][24] + coeff0_46*dmats0[46][24] + coeff0_47*dmats0[47][24] + coeff0_48*dmats0[48][24] + coeff0_49*dmats0[49][24] + coeff0_50*dmats0[50][24] + coeff0_51*dmats0[51][24] + coeff0_52*dmats0[52][24] + coeff0_53*dmats0[53][24] + coeff0_54*dmats0[54][24] + coeff0_55*dmats0[55][24];
          new_coeff0_25 = coeff0_0*dmats0[0][25] + coeff0_1*dmats0[1][25] + coeff0_2*dmats0[2][25] + coeff0_3*dmats0[3][25] + coeff0_4*dmats0[4][25] + coeff0_5*dmats0[5][25] + coeff0_6*dmats0[6][25] + coeff0_7*dmats0[7][25] + coeff0_8*dmats0[8][25] + coeff0_9*dmats0[9][25] + coeff0_10*dmats0[10][25] + coeff0_11*dmats0[11][25] + coeff0_12*dmats0[12][25] + coeff0_13*dmats0[13][25] + coeff0_14*dmats0[14][25] + coeff0_15*dmats0[15][25] + coeff0_16*dmats0[16][25] + coeff0_17*dmats0[17][25] + coeff0_18*dmats0[18][25] + coeff0_19*dmats0[19][25] + coeff0_20*dmats0[20][25] + coeff0_21*dmats0[21][25] + coeff0_22*dmats0[22][25] + coeff0_23*dmats0[23][25] + coeff0_24*dmats0[24][25] + coeff0_25*dmats0[25][25] + coeff0_26*dmats0[26][25] + coeff0_27*dmats0[27][25] + coeff0_28*dmats0[28][25] + coeff0_29*dmats0[29][25] + coeff0_30*dmats0[30][25] + coeff0_31*dmats0[31][25] + coeff0_32*dmats0[32][25] + coeff0_33*dmats0[33][25] + coeff0_34*dmats0[34][25] + coeff0_35*dmats0[35][25] + coeff0_36*dmats0[36][25] + coeff0_37*dmats0[37][25] + coeff0_38*dmats0[38][25] + coeff0_39*dmats0[39][25] + coeff0_40*dmats0[40][25] + coeff0_41*dmats0[41][25] + coeff0_42*dmats0[42][25] + coeff0_43*dmats0[43][25] + coeff0_44*dmats0[44][25] + coeff0_45*dmats0[45][25] + coeff0_46*dmats0[46][25] + coeff0_47*dmats0[47][25] + coeff0_48*dmats0[48][25] + coeff0_49*dmats0[49][25] + coeff0_50*dmats0[50][25] + coeff0_51*dmats0[51][25] + coeff0_52*dmats0[52][25] + coeff0_53*dmats0[53][25] + coeff0_54*dmats0[54][25] + coeff0_55*dmats0[55][25];
          new_coeff0_26 = coeff0_0*dmats0[0][26] + coeff0_1*dmats0[1][26] + coeff0_2*dmats0[2][26] + coeff0_3*dmats0[3][26] + coeff0_4*dmats0[4][26] + coeff0_5*dmats0[5][26] + coeff0_6*dmats0[6][26] + coeff0_7*dmats0[7][26] + coeff0_8*dmats0[8][26] + coeff0_9*dmats0[9][26] + coeff0_10*dmats0[10][26] + coeff0_11*dmats0[11][26] + coeff0_12*dmats0[12][26] + coeff0_13*dmats0[13][26] + coeff0_14*dmats0[14][26] + coeff0_15*dmats0[15][26] + coeff0_16*dmats0[16][26] + coeff0_17*dmats0[17][26] + coeff0_18*dmats0[18][26] + coeff0_19*dmats0[19][26] + coeff0_20*dmats0[20][26] + coeff0_21*dmats0[21][26] + coeff0_22*dmats0[22][26] + coeff0_23*dmats0[23][26] + coeff0_24*dmats0[24][26] + coeff0_25*dmats0[25][26] + coeff0_26*dmats0[26][26] + coeff0_27*dmats0[27][26] + coeff0_28*dmats0[28][26] + coeff0_29*dmats0[29][26] + coeff0_30*dmats0[30][26] + coeff0_31*dmats0[31][26] + coeff0_32*dmats0[32][26] + coeff0_33*dmats0[33][26] + coeff0_34*dmats0[34][26] + coeff0_35*dmats0[35][26] + coeff0_36*dmats0[36][26] + coeff0_37*dmats0[37][26] + coeff0_38*dmats0[38][26] + coeff0_39*dmats0[39][26] + coeff0_40*dmats0[40][26] + coeff0_41*dmats0[41][26] + coeff0_42*dmats0[42][26] + coeff0_43*dmats0[43][26] + coeff0_44*dmats0[44][26] + coeff0_45*dmats0[45][26] + coeff0_46*dmats0[46][26] + coeff0_47*dmats0[47][26] + coeff0_48*dmats0[48][26] + coeff0_49*dmats0[49][26] + coeff0_50*dmats0[50][26] + coeff0_51*dmats0[51][26] + coeff0_52*dmats0[52][26] + coeff0_53*dmats0[53][26] + coeff0_54*dmats0[54][26] + coeff0_55*dmats0[55][26];
          new_coeff0_27 = coeff0_0*dmats0[0][27] + coeff0_1*dmats0[1][27] + coeff0_2*dmats0[2][27] + coeff0_3*dmats0[3][27] + coeff0_4*dmats0[4][27] + coeff0_5*dmats0[5][27] + coeff0_6*dmats0[6][27] + coeff0_7*dmats0[7][27] + coeff0_8*dmats0[8][27] + coeff0_9*dmats0[9][27] + coeff0_10*dmats0[10][27] + coeff0_11*dmats0[11][27] + coeff0_12*dmats0[12][27] + coeff0_13*dmats0[13][27] + coeff0_14*dmats0[14][27] + coeff0_15*dmats0[15][27] + coeff0_16*dmats0[16][27] + coeff0_17*dmats0[17][27] + coeff0_18*dmats0[18][27] + coeff0_19*dmats0[19][27] + coeff0_20*dmats0[20][27] + coeff0_21*dmats0[21][27] + coeff0_22*dmats0[22][27] + coeff0_23*dmats0[23][27] + coeff0_24*dmats0[24][27] + coeff0_25*dmats0[25][27] + coeff0_26*dmats0[26][27] + coeff0_27*dmats0[27][27] + coeff0_28*dmats0[28][27] + coeff0_29*dmats0[29][27] + coeff0_30*dmats0[30][27] + coeff0_31*dmats0[31][27] + coeff0_32*dmats0[32][27] + coeff0_33*dmats0[33][27] + coeff0_34*dmats0[34][27] + coeff0_35*dmats0[35][27] + coeff0_36*dmats0[36][27] + coeff0_37*dmats0[37][27] + coeff0_38*dmats0[38][27] + coeff0_39*dmats0[39][27] + coeff0_40*dmats0[40][27] + coeff0_41*dmats0[41][27] + coeff0_42*dmats0[42][27] + coeff0_43*dmats0[43][27] + coeff0_44*dmats0[44][27] + coeff0_45*dmats0[45][27] + coeff0_46*dmats0[46][27] + coeff0_47*dmats0[47][27] + coeff0_48*dmats0[48][27] + coeff0_49*dmats0[49][27] + coeff0_50*dmats0[50][27] + coeff0_51*dmats0[51][27] + coeff0_52*dmats0[52][27] + coeff0_53*dmats0[53][27] + coeff0_54*dmats0[54][27] + coeff0_55*dmats0[55][27];
          new_coeff0_28 = coeff0_0*dmats0[0][28] + coeff0_1*dmats0[1][28] + coeff0_2*dmats0[2][28] + coeff0_3*dmats0[3][28] + coeff0_4*dmats0[4][28] + coeff0_5*dmats0[5][28] + coeff0_6*dmats0[6][28] + coeff0_7*dmats0[7][28] + coeff0_8*dmats0[8][28] + coeff0_9*dmats0[9][28] + coeff0_10*dmats0[10][28] + coeff0_11*dmats0[11][28] + coeff0_12*dmats0[12][28] + coeff0_13*dmats0[13][28] + coeff0_14*dmats0[14][28] + coeff0_15*dmats0[15][28] + coeff0_16*dmats0[16][28] + coeff0_17*dmats0[17][28] + coeff0_18*dmats0[18][28] + coeff0_19*dmats0[19][28] + coeff0_20*dmats0[20][28] + coeff0_21*dmats0[21][28] + coeff0_22*dmats0[22][28] + coeff0_23*dmats0[23][28] + coeff0_24*dmats0[24][28] + coeff0_25*dmats0[25][28] + coeff0_26*dmats0[26][28] + coeff0_27*dmats0[27][28] + coeff0_28*dmats0[28][28] + coeff0_29*dmats0[29][28] + coeff0_30*dmats0[30][28] + coeff0_31*dmats0[31][28] + coeff0_32*dmats0[32][28] + coeff0_33*dmats0[33][28] + coeff0_34*dmats0[34][28] + coeff0_35*dmats0[35][28] + coeff0_36*dmats0[36][28] + coeff0_37*dmats0[37][28] + coeff0_38*dmats0[38][28] + coeff0_39*dmats0[39][28] + coeff0_40*dmats0[40][28] + coeff0_41*dmats0[41][28] + coeff0_42*dmats0[42][28] + coeff0_43*dmats0[43][28] + coeff0_44*dmats0[44][28] + coeff0_45*dmats0[45][28] + coeff0_46*dmats0[46][28] + coeff0_47*dmats0[47][28] + coeff0_48*dmats0[48][28] + coeff0_49*dmats0[49][28] + coeff0_50*dmats0[50][28] + coeff0_51*dmats0[51][28] + coeff0_52*dmats0[52][28] + coeff0_53*dmats0[53][28] + coeff0_54*dmats0[54][28] + coeff0_55*dmats0[55][28];
          new_coeff0_29 = coeff0_0*dmats0[0][29] + coeff0_1*dmats0[1][29] + coeff0_2*dmats0[2][29] + coeff0_3*dmats0[3][29] + coeff0_4*dmats0[4][29] + coeff0_5*dmats0[5][29] + coeff0_6*dmats0[6][29] + coeff0_7*dmats0[7][29] + coeff0_8*dmats0[8][29] + coeff0_9*dmats0[9][29] + coeff0_10*dmats0[10][29] + coeff0_11*dmats0[11][29] + coeff0_12*dmats0[12][29] + coeff0_13*dmats0[13][29] + coeff0_14*dmats0[14][29] + coeff0_15*dmats0[15][29] + coeff0_16*dmats0[16][29] + coeff0_17*dmats0[17][29] + coeff0_18*dmats0[18][29] + coeff0_19*dmats0[19][29] + coeff0_20*dmats0[20][29] + coeff0_21*dmats0[21][29] + coeff0_22*dmats0[22][29] + coeff0_23*dmats0[23][29] + coeff0_24*dmats0[24][29] + coeff0_25*dmats0[25][29] + coeff0_26*dmats0[26][29] + coeff0_27*dmats0[27][29] + coeff0_28*dmats0[28][29] + coeff0_29*dmats0[29][29] + coeff0_30*dmats0[30][29] + coeff0_31*dmats0[31][29] + coeff0_32*dmats0[32][29] + coeff0_33*dmats0[33][29] + coeff0_34*dmats0[34][29] + coeff0_35*dmats0[35][29] + coeff0_36*dmats0[36][29] + coeff0_37*dmats0[37][29] + coeff0_38*dmats0[38][29] + coeff0_39*dmats0[39][29] + coeff0_40*dmats0[40][29] + coeff0_41*dmats0[41][29] + coeff0_42*dmats0[42][29] + coeff0_43*dmats0[43][29] + coeff0_44*dmats0[44][29] + coeff0_45*dmats0[45][29] + coeff0_46*dmats0[46][29] + coeff0_47*dmats0[47][29] + coeff0_48*dmats0[48][29] + coeff0_49*dmats0[49][29] + coeff0_50*dmats0[50][29] + coeff0_51*dmats0[51][29] + coeff0_52*dmats0[52][29] + coeff0_53*dmats0[53][29] + coeff0_54*dmats0[54][29] + coeff0_55*dmats0[55][29];
          new_coeff0_30 = coeff0_0*dmats0[0][30] + coeff0_1*dmats0[1][30] + coeff0_2*dmats0[2][30] + coeff0_3*dmats0[3][30] + coeff0_4*dmats0[4][30] + coeff0_5*dmats0[5][30] + coeff0_6*dmats0[6][30] + coeff0_7*dmats0[7][30] + coeff0_8*dmats0[8][30] + coeff0_9*dmats0[9][30] + coeff0_10*dmats0[10][30] + coeff0_11*dmats0[11][30] + coeff0_12*dmats0[12][30] + coeff0_13*dmats0[13][30] + coeff0_14*dmats0[14][30] + coeff0_15*dmats0[15][30] + coeff0_16*dmats0[16][30] + coeff0_17*dmats0[17][30] + coeff0_18*dmats0[18][30] + coeff0_19*dmats0[19][30] + coeff0_20*dmats0[20][30] + coeff0_21*dmats0[21][30] + coeff0_22*dmats0[22][30] + coeff0_23*dmats0[23][30] + coeff0_24*dmats0[24][30] + coeff0_25*dmats0[25][30] + coeff0_26*dmats0[26][30] + coeff0_27*dmats0[27][30] + coeff0_28*dmats0[28][30] + coeff0_29*dmats0[29][30] + coeff0_30*dmats0[30][30] + coeff0_31*dmats0[31][30] + coeff0_32*dmats0[32][30] + coeff0_33*dmats0[33][30] + coeff0_34*dmats0[34][30] + coeff0_35*dmats0[35][30] + coeff0_36*dmats0[36][30] + coeff0_37*dmats0[37][30] + coeff0_38*dmats0[38][30] + coeff0_39*dmats0[39][30] + coeff0_40*dmats0[40][30] + coeff0_41*dmats0[41][30] + coeff0_42*dmats0[42][30] + coeff0_43*dmats0[43][30] + coeff0_44*dmats0[44][30] + coeff0_45*dmats0[45][30] + coeff0_46*dmats0[46][30] + coeff0_47*dmats0[47][30] + coeff0_48*dmats0[48][30] + coeff0_49*dmats0[49][30] + coeff0_50*dmats0[50][30] + coeff0_51*dmats0[51][30] + coeff0_52*dmats0[52][30] + coeff0_53*dmats0[53][30] + coeff0_54*dmats0[54][30] + coeff0_55*dmats0[55][30];
          new_coeff0_31 = coeff0_0*dmats0[0][31] + coeff0_1*dmats0[1][31] + coeff0_2*dmats0[2][31] + coeff0_3*dmats0[3][31] + coeff0_4*dmats0[4][31] + coeff0_5*dmats0[5][31] + coeff0_6*dmats0[6][31] + coeff0_7*dmats0[7][31] + coeff0_8*dmats0[8][31] + coeff0_9*dmats0[9][31] + coeff0_10*dmats0[10][31] + coeff0_11*dmats0[11][31] + coeff0_12*dmats0[12][31] + coeff0_13*dmats0[13][31] + coeff0_14*dmats0[14][31] + coeff0_15*dmats0[15][31] + coeff0_16*dmats0[16][31] + coeff0_17*dmats0[17][31] + coeff0_18*dmats0[18][31] + coeff0_19*dmats0[19][31] + coeff0_20*dmats0[20][31] + coeff0_21*dmats0[21][31] + coeff0_22*dmats0[22][31] + coeff0_23*dmats0[23][31] + coeff0_24*dmats0[24][31] + coeff0_25*dmats0[25][31] + coeff0_26*dmats0[26][31] + coeff0_27*dmats0[27][31] + coeff0_28*dmats0[28][31] + coeff0_29*dmats0[29][31] + coeff0_30*dmats0[30][31] + coeff0_31*dmats0[31][31] + coeff0_32*dmats0[32][31] + coeff0_33*dmats0[33][31] + coeff0_34*dmats0[34][31] + coeff0_35*dmats0[35][31] + coeff0_36*dmats0[36][31] + coeff0_37*dmats0[37][31] + coeff0_38*dmats0[38][31] + coeff0_39*dmats0[39][31] + coeff0_40*dmats0[40][31] + coeff0_41*dmats0[41][31] + coeff0_42*dmats0[42][31] + coeff0_43*dmats0[43][31] + coeff0_44*dmats0[44][31] + coeff0_45*dmats0[45][31] + coeff0_46*dmats0[46][31] + coeff0_47*dmats0[47][31] + coeff0_48*dmats0[48][31] + coeff0_49*dmats0[49][31] + coeff0_50*dmats0[50][31] + coeff0_51*dmats0[51][31] + coeff0_52*dmats0[52][31] + coeff0_53*dmats0[53][31] + coeff0_54*dmats0[54][31] + coeff0_55*dmats0[55][31];
          new_coeff0_32 = coeff0_0*dmats0[0][32] + coeff0_1*dmats0[1][32] + coeff0_2*dmats0[2][32] + coeff0_3*dmats0[3][32] + coeff0_4*dmats0[4][32] + coeff0_5*dmats0[5][32] + coeff0_6*dmats0[6][32] + coeff0_7*dmats0[7][32] + coeff0_8*dmats0[8][32] + coeff0_9*dmats0[9][32] + coeff0_10*dmats0[10][32] + coeff0_11*dmats0[11][32] + coeff0_12*dmats0[12][32] + coeff0_13*dmats0[13][32] + coeff0_14*dmats0[14][32] + coeff0_15*dmats0[15][32] + coeff0_16*dmats0[16][32] + coeff0_17*dmats0[17][32] + coeff0_18*dmats0[18][32] + coeff0_19*dmats0[19][32] + coeff0_20*dmats0[20][32] + coeff0_21*dmats0[21][32] + coeff0_22*dmats0[22][32] + coeff0_23*dmats0[23][32] + coeff0_24*dmats0[24][32] + coeff0_25*dmats0[25][32] + coeff0_26*dmats0[26][32] + coeff0_27*dmats0[27][32] + coeff0_28*dmats0[28][32] + coeff0_29*dmats0[29][32] + coeff0_30*dmats0[30][32] + coeff0_31*dmats0[31][32] + coeff0_32*dmats0[32][32] + coeff0_33*dmats0[33][32] + coeff0_34*dmats0[34][32] + coeff0_35*dmats0[35][32] + coeff0_36*dmats0[36][32] + coeff0_37*dmats0[37][32] + coeff0_38*dmats0[38][32] + coeff0_39*dmats0[39][32] + coeff0_40*dmats0[40][32] + coeff0_41*dmats0[41][32] + coeff0_42*dmats0[42][32] + coeff0_43*dmats0[43][32] + coeff0_44*dmats0[44][32] + coeff0_45*dmats0[45][32] + coeff0_46*dmats0[46][32] + coeff0_47*dmats0[47][32] + coeff0_48*dmats0[48][32] + coeff0_49*dmats0[49][32] + coeff0_50*dmats0[50][32] + coeff0_51*dmats0[51][32] + coeff0_52*dmats0[52][32] + coeff0_53*dmats0[53][32] + coeff0_54*dmats0[54][32] + coeff0_55*dmats0[55][32];
          new_coeff0_33 = coeff0_0*dmats0[0][33] + coeff0_1*dmats0[1][33] + coeff0_2*dmats0[2][33] + coeff0_3*dmats0[3][33] + coeff0_4*dmats0[4][33] + coeff0_5*dmats0[5][33] + coeff0_6*dmats0[6][33] + coeff0_7*dmats0[7][33] + coeff0_8*dmats0[8][33] + coeff0_9*dmats0[9][33] + coeff0_10*dmats0[10][33] + coeff0_11*dmats0[11][33] + coeff0_12*dmats0[12][33] + coeff0_13*dmats0[13][33] + coeff0_14*dmats0[14][33] + coeff0_15*dmats0[15][33] + coeff0_16*dmats0[16][33] + coeff0_17*dmats0[17][33] + coeff0_18*dmats0[18][33] + coeff0_19*dmats0[19][33] + coeff0_20*dmats0[20][33] + coeff0_21*dmats0[21][33] + coeff0_22*dmats0[22][33] + coeff0_23*dmats0[23][33] + coeff0_24*dmats0[24][33] + coeff0_25*dmats0[25][33] + coeff0_26*dmats0[26][33] + coeff0_27*dmats0[27][33] + coeff0_28*dmats0[28][33] + coeff0_29*dmats0[29][33] + coeff0_30*dmats0[30][33] + coeff0_31*dmats0[31][33] + coeff0_32*dmats0[32][33] + coeff0_33*dmats0[33][33] + coeff0_34*dmats0[34][33] + coeff0_35*dmats0[35][33] + coeff0_36*dmats0[36][33] + coeff0_37*dmats0[37][33] + coeff0_38*dmats0[38][33] + coeff0_39*dmats0[39][33] + coeff0_40*dmats0[40][33] + coeff0_41*dmats0[41][33] + coeff0_42*dmats0[42][33] + coeff0_43*dmats0[43][33] + coeff0_44*dmats0[44][33] + coeff0_45*dmats0[45][33] + coeff0_46*dmats0[46][33] + coeff0_47*dmats0[47][33] + coeff0_48*dmats0[48][33] + coeff0_49*dmats0[49][33] + coeff0_50*dmats0[50][33] + coeff0_51*dmats0[51][33] + coeff0_52*dmats0[52][33] + coeff0_53*dmats0[53][33] + coeff0_54*dmats0[54][33] + coeff0_55*dmats0[55][33];
          new_coeff0_34 = coeff0_0*dmats0[0][34] + coeff0_1*dmats0[1][34] + coeff0_2*dmats0[2][34] + coeff0_3*dmats0[3][34] + coeff0_4*dmats0[4][34] + coeff0_5*dmats0[5][34] + coeff0_6*dmats0[6][34] + coeff0_7*dmats0[7][34] + coeff0_8*dmats0[8][34] + coeff0_9*dmats0[9][34] + coeff0_10*dmats0[10][34] + coeff0_11*dmats0[11][34] + coeff0_12*dmats0[12][34] + coeff0_13*dmats0[13][34] + coeff0_14*dmats0[14][34] + coeff0_15*dmats0[15][34] + coeff0_16*dmats0[16][34] + coeff0_17*dmats0[17][34] + coeff0_18*dmats0[18][34] + coeff0_19*dmats0[19][34] + coeff0_20*dmats0[20][34] + coeff0_21*dmats0[21][34] + coeff0_22*dmats0[22][34] + coeff0_23*dmats0[23][34] + coeff0_24*dmats0[24][34] + coeff0_25*dmats0[25][34] + coeff0_26*dmats0[26][34] + coeff0_27*dmats0[27][34] + coeff0_28*dmats0[28][34] + coeff0_29*dmats0[29][34] + coeff0_30*dmats0[30][34] + coeff0_31*dmats0[31][34] + coeff0_32*dmats0[32][34] + coeff0_33*dmats0[33][34] + coeff0_34*dmats0[34][34] + coeff0_35*dmats0[35][34] + coeff0_36*dmats0[36][34] + coeff0_37*dmats0[37][34] + coeff0_38*dmats0[38][34] + coeff0_39*dmats0[39][34] + coeff0_40*dmats0[40][34] + coeff0_41*dmats0[41][34] + coeff0_42*dmats0[42][34] + coeff0_43*dmats0[43][34] + coeff0_44*dmats0[44][34] + coeff0_45*dmats0[45][34] + coeff0_46*dmats0[46][34] + coeff0_47*dmats0[47][34] + coeff0_48*dmats0[48][34] + coeff0_49*dmats0[49][34] + coeff0_50*dmats0[50][34] + coeff0_51*dmats0[51][34] + coeff0_52*dmats0[52][34] + coeff0_53*dmats0[53][34] + coeff0_54*dmats0[54][34] + coeff0_55*dmats0[55][34];
          new_coeff0_35 = coeff0_0*dmats0[0][35] + coeff0_1*dmats0[1][35] + coeff0_2*dmats0[2][35] + coeff0_3*dmats0[3][35] + coeff0_4*dmats0[4][35] + coeff0_5*dmats0[5][35] + coeff0_6*dmats0[6][35] + coeff0_7*dmats0[7][35] + coeff0_8*dmats0[8][35] + coeff0_9*dmats0[9][35] + coeff0_10*dmats0[10][35] + coeff0_11*dmats0[11][35] + coeff0_12*dmats0[12][35] + coeff0_13*dmats0[13][35] + coeff0_14*dmats0[14][35] + coeff0_15*dmats0[15][35] + coeff0_16*dmats0[16][35] + coeff0_17*dmats0[17][35] + coeff0_18*dmats0[18][35] + coeff0_19*dmats0[19][35] + coeff0_20*dmats0[20][35] + coeff0_21*dmats0[21][35] + coeff0_22*dmats0[22][35] + coeff0_23*dmats0[23][35] + coeff0_24*dmats0[24][35] + coeff0_25*dmats0[25][35] + coeff0_26*dmats0[26][35] + coeff0_27*dmats0[27][35] + coeff0_28*dmats0[28][35] + coeff0_29*dmats0[29][35] + coeff0_30*dmats0[30][35] + coeff0_31*dmats0[31][35] + coeff0_32*dmats0[32][35] + coeff0_33*dmats0[33][35] + coeff0_34*dmats0[34][35] + coeff0_35*dmats0[35][35] + coeff0_36*dmats0[36][35] + coeff0_37*dmats0[37][35] + coeff0_38*dmats0[38][35] + coeff0_39*dmats0[39][35] + coeff0_40*dmats0[40][35] + coeff0_41*dmats0[41][35] + coeff0_42*dmats0[42][35] + coeff0_43*dmats0[43][35] + coeff0_44*dmats0[44][35] + coeff0_45*dmats0[45][35] + coeff0_46*dmats0[46][35] + coeff0_47*dmats0[47][35] + coeff0_48*dmats0[48][35] + coeff0_49*dmats0[49][35] + coeff0_50*dmats0[50][35] + coeff0_51*dmats0[51][35] + coeff0_52*dmats0[52][35] + coeff0_53*dmats0[53][35] + coeff0_54*dmats0[54][35] + coeff0_55*dmats0[55][35];
          new_coeff0_36 = coeff0_0*dmats0[0][36] + coeff0_1*dmats0[1][36] + coeff0_2*dmats0[2][36] + coeff0_3*dmats0[3][36] + coeff0_4*dmats0[4][36] + coeff0_5*dmats0[5][36] + coeff0_6*dmats0[6][36] + coeff0_7*dmats0[7][36] + coeff0_8*dmats0[8][36] + coeff0_9*dmats0[9][36] + coeff0_10*dmats0[10][36] + coeff0_11*dmats0[11][36] + coeff0_12*dmats0[12][36] + coeff0_13*dmats0[13][36] + coeff0_14*dmats0[14][36] + coeff0_15*dmats0[15][36] + coeff0_16*dmats0[16][36] + coeff0_17*dmats0[17][36] + coeff0_18*dmats0[18][36] + coeff0_19*dmats0[19][36] + coeff0_20*dmats0[20][36] + coeff0_21*dmats0[21][36] + coeff0_22*dmats0[22][36] + coeff0_23*dmats0[23][36] + coeff0_24*dmats0[24][36] + coeff0_25*dmats0[25][36] + coeff0_26*dmats0[26][36] + coeff0_27*dmats0[27][36] + coeff0_28*dmats0[28][36] + coeff0_29*dmats0[29][36] + coeff0_30*dmats0[30][36] + coeff0_31*dmats0[31][36] + coeff0_32*dmats0[32][36] + coeff0_33*dmats0[33][36] + coeff0_34*dmats0[34][36] + coeff0_35*dmats0[35][36] + coeff0_36*dmats0[36][36] + coeff0_37*dmats0[37][36] + coeff0_38*dmats0[38][36] + coeff0_39*dmats0[39][36] + coeff0_40*dmats0[40][36] + coeff0_41*dmats0[41][36] + coeff0_42*dmats0[42][36] + coeff0_43*dmats0[43][36] + coeff0_44*dmats0[44][36] + coeff0_45*dmats0[45][36] + coeff0_46*dmats0[46][36] + coeff0_47*dmats0[47][36] + coeff0_48*dmats0[48][36] + coeff0_49*dmats0[49][36] + coeff0_50*dmats0[50][36] + coeff0_51*dmats0[51][36] + coeff0_52*dmats0[52][36] + coeff0_53*dmats0[53][36] + coeff0_54*dmats0[54][36] + coeff0_55*dmats0[55][36];
          new_coeff0_37 = coeff0_0*dmats0[0][37] + coeff0_1*dmats0[1][37] + coeff0_2*dmats0[2][37] + coeff0_3*dmats0[3][37] + coeff0_4*dmats0[4][37] + coeff0_5*dmats0[5][37] + coeff0_6*dmats0[6][37] + coeff0_7*dmats0[7][37] + coeff0_8*dmats0[8][37] + coeff0_9*dmats0[9][37] + coeff0_10*dmats0[10][37] + coeff0_11*dmats0[11][37] + coeff0_12*dmats0[12][37] + coeff0_13*dmats0[13][37] + coeff0_14*dmats0[14][37] + coeff0_15*dmats0[15][37] + coeff0_16*dmats0[16][37] + coeff0_17*dmats0[17][37] + coeff0_18*dmats0[18][37] + coeff0_19*dmats0[19][37] + coeff0_20*dmats0[20][37] + coeff0_21*dmats0[21][37] + coeff0_22*dmats0[22][37] + coeff0_23*dmats0[23][37] + coeff0_24*dmats0[24][37] + coeff0_25*dmats0[25][37] + coeff0_26*dmats0[26][37] + coeff0_27*dmats0[27][37] + coeff0_28*dmats0[28][37] + coeff0_29*dmats0[29][37] + coeff0_30*dmats0[30][37] + coeff0_31*dmats0[31][37] + coeff0_32*dmats0[32][37] + coeff0_33*dmats0[33][37] + coeff0_34*dmats0[34][37] + coeff0_35*dmats0[35][37] + coeff0_36*dmats0[36][37] + coeff0_37*dmats0[37][37] + coeff0_38*dmats0[38][37] + coeff0_39*dmats0[39][37] + coeff0_40*dmats0[40][37] + coeff0_41*dmats0[41][37] + coeff0_42*dmats0[42][37] + coeff0_43*dmats0[43][37] + coeff0_44*dmats0[44][37] + coeff0_45*dmats0[45][37] + coeff0_46*dmats0[46][37] + coeff0_47*dmats0[47][37] + coeff0_48*dmats0[48][37] + coeff0_49*dmats0[49][37] + coeff0_50*dmats0[50][37] + coeff0_51*dmats0[51][37] + coeff0_52*dmats0[52][37] + coeff0_53*dmats0[53][37] + coeff0_54*dmats0[54][37] + coeff0_55*dmats0[55][37];
          new_coeff0_38 = coeff0_0*dmats0[0][38] + coeff0_1*dmats0[1][38] + coeff0_2*dmats0[2][38] + coeff0_3*dmats0[3][38] + coeff0_4*dmats0[4][38] + coeff0_5*dmats0[5][38] + coeff0_6*dmats0[6][38] + coeff0_7*dmats0[7][38] + coeff0_8*dmats0[8][38] + coeff0_9*dmats0[9][38] + coeff0_10*dmats0[10][38] + coeff0_11*dmats0[11][38] + coeff0_12*dmats0[12][38] + coeff0_13*dmats0[13][38] + coeff0_14*dmats0[14][38] + coeff0_15*dmats0[15][38] + coeff0_16*dmats0[16][38] + coeff0_17*dmats0[17][38] + coeff0_18*dmats0[18][38] + coeff0_19*dmats0[19][38] + coeff0_20*dmats0[20][38] + coeff0_21*dmats0[21][38] + coeff0_22*dmats0[22][38] + coeff0_23*dmats0[23][38] + coeff0_24*dmats0[24][38] + coeff0_25*dmats0[25][38] + coeff0_26*dmats0[26][38] + coeff0_27*dmats0[27][38] + coeff0_28*dmats0[28][38] + coeff0_29*dmats0[29][38] + coeff0_30*dmats0[30][38] + coeff0_31*dmats0[31][38] + coeff0_32*dmats0[32][38] + coeff0_33*dmats0[33][38] + coeff0_34*dmats0[34][38] + coeff0_35*dmats0[35][38] + coeff0_36*dmats0[36][38] + coeff0_37*dmats0[37][38] + coeff0_38*dmats0[38][38] + coeff0_39*dmats0[39][38] + coeff0_40*dmats0[40][38] + coeff0_41*dmats0[41][38] + coeff0_42*dmats0[42][38] + coeff0_43*dmats0[43][38] + coeff0_44*dmats0[44][38] + coeff0_45*dmats0[45][38] + coeff0_46*dmats0[46][38] + coeff0_47*dmats0[47][38] + coeff0_48*dmats0[48][38] + coeff0_49*dmats0[49][38] + coeff0_50*dmats0[50][38] + coeff0_51*dmats0[51][38] + coeff0_52*dmats0[52][38] + coeff0_53*dmats0[53][38] + coeff0_54*dmats0[54][38] + coeff0_55*dmats0[55][38];
          new_coeff0_39 = coeff0_0*dmats0[0][39] + coeff0_1*dmats0[1][39] + coeff0_2*dmats0[2][39] + coeff0_3*dmats0[3][39] + coeff0_4*dmats0[4][39] + coeff0_5*dmats0[5][39] + coeff0_6*dmats0[6][39] + coeff0_7*dmats0[7][39] + coeff0_8*dmats0[8][39] + coeff0_9*dmats0[9][39] + coeff0_10*dmats0[10][39] + coeff0_11*dmats0[11][39] + coeff0_12*dmats0[12][39] + coeff0_13*dmats0[13][39] + coeff0_14*dmats0[14][39] + coeff0_15*dmats0[15][39] + coeff0_16*dmats0[16][39] + coeff0_17*dmats0[17][39] + coeff0_18*dmats0[18][39] + coeff0_19*dmats0[19][39] + coeff0_20*dmats0[20][39] + coeff0_21*dmats0[21][39] + coeff0_22*dmats0[22][39] + coeff0_23*dmats0[23][39] + coeff0_24*dmats0[24][39] + coeff0_25*dmats0[25][39] + coeff0_26*dmats0[26][39] + coeff0_27*dmats0[27][39] + coeff0_28*dmats0[28][39] + coeff0_29*dmats0[29][39] + coeff0_30*dmats0[30][39] + coeff0_31*dmats0[31][39] + coeff0_32*dmats0[32][39] + coeff0_33*dmats0[33][39] + coeff0_34*dmats0[34][39] + coeff0_35*dmats0[35][39] + coeff0_36*dmats0[36][39] + coeff0_37*dmats0[37][39] + coeff0_38*dmats0[38][39] + coeff0_39*dmats0[39][39] + coeff0_40*dmats0[40][39] + coeff0_41*dmats0[41][39] + coeff0_42*dmats0[42][39] + coeff0_43*dmats0[43][39] + coeff0_44*dmats0[44][39] + coeff0_45*dmats0[45][39] + coeff0_46*dmats0[46][39] + coeff0_47*dmats0[47][39] + coeff0_48*dmats0[48][39] + coeff0_49*dmats0[49][39] + coeff0_50*dmats0[50][39] + coeff0_51*dmats0[51][39] + coeff0_52*dmats0[52][39] + coeff0_53*dmats0[53][39] + coeff0_54*dmats0[54][39] + coeff0_55*dmats0[55][39];
          new_coeff0_40 = coeff0_0*dmats0[0][40] + coeff0_1*dmats0[1][40] + coeff0_2*dmats0[2][40] + coeff0_3*dmats0[3][40] + coeff0_4*dmats0[4][40] + coeff0_5*dmats0[5][40] + coeff0_6*dmats0[6][40] + coeff0_7*dmats0[7][40] + coeff0_8*dmats0[8][40] + coeff0_9*dmats0[9][40] + coeff0_10*dmats0[10][40] + coeff0_11*dmats0[11][40] + coeff0_12*dmats0[12][40] + coeff0_13*dmats0[13][40] + coeff0_14*dmats0[14][40] + coeff0_15*dmats0[15][40] + coeff0_16*dmats0[16][40] + coeff0_17*dmats0[17][40] + coeff0_18*dmats0[18][40] + coeff0_19*dmats0[19][40] + coeff0_20*dmats0[20][40] + coeff0_21*dmats0[21][40] + coeff0_22*dmats0[22][40] + coeff0_23*dmats0[23][40] + coeff0_24*dmats0[24][40] + coeff0_25*dmats0[25][40] + coeff0_26*dmats0[26][40] + coeff0_27*dmats0[27][40] + coeff0_28*dmats0[28][40] + coeff0_29*dmats0[29][40] + coeff0_30*dmats0[30][40] + coeff0_31*dmats0[31][40] + coeff0_32*dmats0[32][40] + coeff0_33*dmats0[33][40] + coeff0_34*dmats0[34][40] + coeff0_35*dmats0[35][40] + coeff0_36*dmats0[36][40] + coeff0_37*dmats0[37][40] + coeff0_38*dmats0[38][40] + coeff0_39*dmats0[39][40] + coeff0_40*dmats0[40][40] + coeff0_41*dmats0[41][40] + coeff0_42*dmats0[42][40] + coeff0_43*dmats0[43][40] + coeff0_44*dmats0[44][40] + coeff0_45*dmats0[45][40] + coeff0_46*dmats0[46][40] + coeff0_47*dmats0[47][40] + coeff0_48*dmats0[48][40] + coeff0_49*dmats0[49][40] + coeff0_50*dmats0[50][40] + coeff0_51*dmats0[51][40] + coeff0_52*dmats0[52][40] + coeff0_53*dmats0[53][40] + coeff0_54*dmats0[54][40] + coeff0_55*dmats0[55][40];
          new_coeff0_41 = coeff0_0*dmats0[0][41] + coeff0_1*dmats0[1][41] + coeff0_2*dmats0[2][41] + coeff0_3*dmats0[3][41] + coeff0_4*dmats0[4][41] + coeff0_5*dmats0[5][41] + coeff0_6*dmats0[6][41] + coeff0_7*dmats0[7][41] + coeff0_8*dmats0[8][41] + coeff0_9*dmats0[9][41] + coeff0_10*dmats0[10][41] + coeff0_11*dmats0[11][41] + coeff0_12*dmats0[12][41] + coeff0_13*dmats0[13][41] + coeff0_14*dmats0[14][41] + coeff0_15*dmats0[15][41] + coeff0_16*dmats0[16][41] + coeff0_17*dmats0[17][41] + coeff0_18*dmats0[18][41] + coeff0_19*dmats0[19][41] + coeff0_20*dmats0[20][41] + coeff0_21*dmats0[21][41] + coeff0_22*dmats0[22][41] + coeff0_23*dmats0[23][41] + coeff0_24*dmats0[24][41] + coeff0_25*dmats0[25][41] + coeff0_26*dmats0[26][41] + coeff0_27*dmats0[27][41] + coeff0_28*dmats0[28][41] + coeff0_29*dmats0[29][41] + coeff0_30*dmats0[30][41] + coeff0_31*dmats0[31][41] + coeff0_32*dmats0[32][41] + coeff0_33*dmats0[33][41] + coeff0_34*dmats0[34][41] + coeff0_35*dmats0[35][41] + coeff0_36*dmats0[36][41] + coeff0_37*dmats0[37][41] + coeff0_38*dmats0[38][41] + coeff0_39*dmats0[39][41] + coeff0_40*dmats0[40][41] + coeff0_41*dmats0[41][41] + coeff0_42*dmats0[42][41] + coeff0_43*dmats0[43][41] + coeff0_44*dmats0[44][41] + coeff0_45*dmats0[45][41] + coeff0_46*dmats0[46][41] + coeff0_47*dmats0[47][41] + coeff0_48*dmats0[48][41] + coeff0_49*dmats0[49][41] + coeff0_50*dmats0[50][41] + coeff0_51*dmats0[51][41] + coeff0_52*dmats0[52][41] + coeff0_53*dmats0[53][41] + coeff0_54*dmats0[54][41] + coeff0_55*dmats0[55][41];
          new_coeff0_42 = coeff0_0*dmats0[0][42] + coeff0_1*dmats0[1][42] + coeff0_2*dmats0[2][42] + coeff0_3*dmats0[3][42] + coeff0_4*dmats0[4][42] + coeff0_5*dmats0[5][42] + coeff0_6*dmats0[6][42] + coeff0_7*dmats0[7][42] + coeff0_8*dmats0[8][42] + coeff0_9*dmats0[9][42] + coeff0_10*dmats0[10][42] + coeff0_11*dmats0[11][42] + coeff0_12*dmats0[12][42] + coeff0_13*dmats0[13][42] + coeff0_14*dmats0[14][42] + coeff0_15*dmats0[15][42] + coeff0_16*dmats0[16][42] + coeff0_17*dmats0[17][42] + coeff0_18*dmats0[18][42] + coeff0_19*dmats0[19][42] + coeff0_20*dmats0[20][42] + coeff0_21*dmats0[21][42] + coeff0_22*dmats0[22][42] + coeff0_23*dmats0[23][42] + coeff0_24*dmats0[24][42] + coeff0_25*dmats0[25][42] + coeff0_26*dmats0[26][42] + coeff0_27*dmats0[27][42] + coeff0_28*dmats0[28][42] + coeff0_29*dmats0[29][42] + coeff0_30*dmats0[30][42] + coeff0_31*dmats0[31][42] + coeff0_32*dmats0[32][42] + coeff0_33*dmats0[33][42] + coeff0_34*dmats0[34][42] + coeff0_35*dmats0[35][42] + coeff0_36*dmats0[36][42] + coeff0_37*dmats0[37][42] + coeff0_38*dmats0[38][42] + coeff0_39*dmats0[39][42] + coeff0_40*dmats0[40][42] + coeff0_41*dmats0[41][42] + coeff0_42*dmats0[42][42] + coeff0_43*dmats0[43][42] + coeff0_44*dmats0[44][42] + coeff0_45*dmats0[45][42] + coeff0_46*dmats0[46][42] + coeff0_47*dmats0[47][42] + coeff0_48*dmats0[48][42] + coeff0_49*dmats0[49][42] + coeff0_50*dmats0[50][42] + coeff0_51*dmats0[51][42] + coeff0_52*dmats0[52][42] + coeff0_53*dmats0[53][42] + coeff0_54*dmats0[54][42] + coeff0_55*dmats0[55][42];
          new_coeff0_43 = coeff0_0*dmats0[0][43] + coeff0_1*dmats0[1][43] + coeff0_2*dmats0[2][43] + coeff0_3*dmats0[3][43] + coeff0_4*dmats0[4][43] + coeff0_5*dmats0[5][43] + coeff0_6*dmats0[6][43] + coeff0_7*dmats0[7][43] + coeff0_8*dmats0[8][43] + coeff0_9*dmats0[9][43] + coeff0_10*dmats0[10][43] + coeff0_11*dmats0[11][43] + coeff0_12*dmats0[12][43] + coeff0_13*dmats0[13][43] + coeff0_14*dmats0[14][43] + coeff0_15*dmats0[15][43] + coeff0_16*dmats0[16][43] + coeff0_17*dmats0[17][43] + coeff0_18*dmats0[18][43] + coeff0_19*dmats0[19][43] + coeff0_20*dmats0[20][43] + coeff0_21*dmats0[21][43] + coeff0_22*dmats0[22][43] + coeff0_23*dmats0[23][43] + coeff0_24*dmats0[24][43] + coeff0_25*dmats0[25][43] + coeff0_26*dmats0[26][43] + coeff0_27*dmats0[27][43] + coeff0_28*dmats0[28][43] + coeff0_29*dmats0[29][43] + coeff0_30*dmats0[30][43] + coeff0_31*dmats0[31][43] + coeff0_32*dmats0[32][43] + coeff0_33*dmats0[33][43] + coeff0_34*dmats0[34][43] + coeff0_35*dmats0[35][43] + coeff0_36*dmats0[36][43] + coeff0_37*dmats0[37][43] + coeff0_38*dmats0[38][43] + coeff0_39*dmats0[39][43] + coeff0_40*dmats0[40][43] + coeff0_41*dmats0[41][43] + coeff0_42*dmats0[42][43] + coeff0_43*dmats0[43][43] + coeff0_44*dmats0[44][43] + coeff0_45*dmats0[45][43] + coeff0_46*dmats0[46][43] + coeff0_47*dmats0[47][43] + coeff0_48*dmats0[48][43] + coeff0_49*dmats0[49][43] + coeff0_50*dmats0[50][43] + coeff0_51*dmats0[51][43] + coeff0_52*dmats0[52][43] + coeff0_53*dmats0[53][43] + coeff0_54*dmats0[54][43] + coeff0_55*dmats0[55][43];
          new_coeff0_44 = coeff0_0*dmats0[0][44] + coeff0_1*dmats0[1][44] + coeff0_2*dmats0[2][44] + coeff0_3*dmats0[3][44] + coeff0_4*dmats0[4][44] + coeff0_5*dmats0[5][44] + coeff0_6*dmats0[6][44] + coeff0_7*dmats0[7][44] + coeff0_8*dmats0[8][44] + coeff0_9*dmats0[9][44] + coeff0_10*dmats0[10][44] + coeff0_11*dmats0[11][44] + coeff0_12*dmats0[12][44] + coeff0_13*dmats0[13][44] + coeff0_14*dmats0[14][44] + coeff0_15*dmats0[15][44] + coeff0_16*dmats0[16][44] + coeff0_17*dmats0[17][44] + coeff0_18*dmats0[18][44] + coeff0_19*dmats0[19][44] + coeff0_20*dmats0[20][44] + coeff0_21*dmats0[21][44] + coeff0_22*dmats0[22][44] + coeff0_23*dmats0[23][44] + coeff0_24*dmats0[24][44] + coeff0_25*dmats0[25][44] + coeff0_26*dmats0[26][44] + coeff0_27*dmats0[27][44] + coeff0_28*dmats0[28][44] + coeff0_29*dmats0[29][44] + coeff0_30*dmats0[30][44] + coeff0_31*dmats0[31][44] + coeff0_32*dmats0[32][44] + coeff0_33*dmats0[33][44] + coeff0_34*dmats0[34][44] + coeff0_35*dmats0[35][44] + coeff0_36*dmats0[36][44] + coeff0_37*dmats0[37][44] + coeff0_38*dmats0[38][44] + coeff0_39*dmats0[39][44] + coeff0_40*dmats0[40][44] + coeff0_41*dmats0[41][44] + coeff0_42*dmats0[42][44] + coeff0_43*dmats0[43][44] + coeff0_44*dmats0[44][44] + coeff0_45*dmats0[45][44] + coeff0_46*dmats0[46][44] + coeff0_47*dmats0[47][44] + coeff0_48*dmats0[48][44] + coeff0_49*dmats0[49][44] + coeff0_50*dmats0[50][44] + coeff0_51*dmats0[51][44] + coeff0_52*dmats0[52][44] + coeff0_53*dmats0[53][44] + coeff0_54*dmats0[54][44] + coeff0_55*dmats0[55][44];
          new_coeff0_45 = coeff0_0*dmats0[0][45] + coeff0_1*dmats0[1][45] + coeff0_2*dmats0[2][45] + coeff0_3*dmats0[3][45] + coeff0_4*dmats0[4][45] + coeff0_5*dmats0[5][45] + coeff0_6*dmats0[6][45] + coeff0_7*dmats0[7][45] + coeff0_8*dmats0[8][45] + coeff0_9*dmats0[9][45] + coeff0_10*dmats0[10][45] + coeff0_11*dmats0[11][45] + coeff0_12*dmats0[12][45] + coeff0_13*dmats0[13][45] + coeff0_14*dmats0[14][45] + coeff0_15*dmats0[15][45] + coeff0_16*dmats0[16][45] + coeff0_17*dmats0[17][45] + coeff0_18*dmats0[18][45] + coeff0_19*dmats0[19][45] + coeff0_20*dmats0[20][45] + coeff0_21*dmats0[21][45] + coeff0_22*dmats0[22][45] + coeff0_23*dmats0[23][45] + coeff0_24*dmats0[24][45] + coeff0_25*dmats0[25][45] + coeff0_26*dmats0[26][45] + coeff0_27*dmats0[27][45] + coeff0_28*dmats0[28][45] + coeff0_29*dmats0[29][45] + coeff0_30*dmats0[30][45] + coeff0_31*dmats0[31][45] + coeff0_32*dmats0[32][45] + coeff0_33*dmats0[33][45] + coeff0_34*dmats0[34][45] + coeff0_35*dmats0[35][45] + coeff0_36*dmats0[36][45] + coeff0_37*dmats0[37][45] + coeff0_38*dmats0[38][45] + coeff0_39*dmats0[39][45] + coeff0_40*dmats0[40][45] + coeff0_41*dmats0[41][45] + coeff0_42*dmats0[42][45] + coeff0_43*dmats0[43][45] + coeff0_44*dmats0[44][45] + coeff0_45*dmats0[45][45] + coeff0_46*dmats0[46][45] + coeff0_47*dmats0[47][45] + coeff0_48*dmats0[48][45] + coeff0_49*dmats0[49][45] + coeff0_50*dmats0[50][45] + coeff0_51*dmats0[51][45] + coeff0_52*dmats0[52][45] + coeff0_53*dmats0[53][45] + coeff0_54*dmats0[54][45] + coeff0_55*dmats0[55][45];
          new_coeff0_46 = coeff0_0*dmats0[0][46] + coeff0_1*dmats0[1][46] + coeff0_2*dmats0[2][46] + coeff0_3*dmats0[3][46] + coeff0_4*dmats0[4][46] + coeff0_5*dmats0[5][46] + coeff0_6*dmats0[6][46] + coeff0_7*dmats0[7][46] + coeff0_8*dmats0[8][46] + coeff0_9*dmats0[9][46] + coeff0_10*dmats0[10][46] + coeff0_11*dmats0[11][46] + coeff0_12*dmats0[12][46] + coeff0_13*dmats0[13][46] + coeff0_14*dmats0[14][46] + coeff0_15*dmats0[15][46] + coeff0_16*dmats0[16][46] + coeff0_17*dmats0[17][46] + coeff0_18*dmats0[18][46] + coeff0_19*dmats0[19][46] + coeff0_20*dmats0[20][46] + coeff0_21*dmats0[21][46] + coeff0_22*dmats0[22][46] + coeff0_23*dmats0[23][46] + coeff0_24*dmats0[24][46] + coeff0_25*dmats0[25][46] + coeff0_26*dmats0[26][46] + coeff0_27*dmats0[27][46] + coeff0_28*dmats0[28][46] + coeff0_29*dmats0[29][46] + coeff0_30*dmats0[30][46] + coeff0_31*dmats0[31][46] + coeff0_32*dmats0[32][46] + coeff0_33*dmats0[33][46] + coeff0_34*dmats0[34][46] + coeff0_35*dmats0[35][46] + coeff0_36*dmats0[36][46] + coeff0_37*dmats0[37][46] + coeff0_38*dmats0[38][46] + coeff0_39*dmats0[39][46] + coeff0_40*dmats0[40][46] + coeff0_41*dmats0[41][46] + coeff0_42*dmats0[42][46] + coeff0_43*dmats0[43][46] + coeff0_44*dmats0[44][46] + coeff0_45*dmats0[45][46] + coeff0_46*dmats0[46][46] + coeff0_47*dmats0[47][46] + coeff0_48*dmats0[48][46] + coeff0_49*dmats0[49][46] + coeff0_50*dmats0[50][46] + coeff0_51*dmats0[51][46] + coeff0_52*dmats0[52][46] + coeff0_53*dmats0[53][46] + coeff0_54*dmats0[54][46] + coeff0_55*dmats0[55][46];
          new_coeff0_47 = coeff0_0*dmats0[0][47] + coeff0_1*dmats0[1][47] + coeff0_2*dmats0[2][47] + coeff0_3*dmats0[3][47] + coeff0_4*dmats0[4][47] + coeff0_5*dmats0[5][47] + coeff0_6*dmats0[6][47] + coeff0_7*dmats0[7][47] + coeff0_8*dmats0[8][47] + coeff0_9*dmats0[9][47] + coeff0_10*dmats0[10][47] + coeff0_11*dmats0[11][47] + coeff0_12*dmats0[12][47] + coeff0_13*dmats0[13][47] + coeff0_14*dmats0[14][47] + coeff0_15*dmats0[15][47] + coeff0_16*dmats0[16][47] + coeff0_17*dmats0[17][47] + coeff0_18*dmats0[18][47] + coeff0_19*dmats0[19][47] + coeff0_20*dmats0[20][47] + coeff0_21*dmats0[21][47] + coeff0_22*dmats0[22][47] + coeff0_23*dmats0[23][47] + coeff0_24*dmats0[24][47] + coeff0_25*dmats0[25][47] + coeff0_26*dmats0[26][47] + coeff0_27*dmats0[27][47] + coeff0_28*dmats0[28][47] + coeff0_29*dmats0[29][47] + coeff0_30*dmats0[30][47] + coeff0_31*dmats0[31][47] + coeff0_32*dmats0[32][47] + coeff0_33*dmats0[33][47] + coeff0_34*dmats0[34][47] + coeff0_35*dmats0[35][47] + coeff0_36*dmats0[36][47] + coeff0_37*dmats0[37][47] + coeff0_38*dmats0[38][47] + coeff0_39*dmats0[39][47] + coeff0_40*dmats0[40][47] + coeff0_41*dmats0[41][47] + coeff0_42*dmats0[42][47] + coeff0_43*dmats0[43][47] + coeff0_44*dmats0[44][47] + coeff0_45*dmats0[45][47] + coeff0_46*dmats0[46][47] + coeff0_47*dmats0[47][47] + coeff0_48*dmats0[48][47] + coeff0_49*dmats0[49][47] + coeff0_50*dmats0[50][47] + coeff0_51*dmats0[51][47] + coeff0_52*dmats0[52][47] + coeff0_53*dmats0[53][47] + coeff0_54*dmats0[54][47] + coeff0_55*dmats0[55][47];
          new_coeff0_48 = coeff0_0*dmats0[0][48] + coeff0_1*dmats0[1][48] + coeff0_2*dmats0[2][48] + coeff0_3*dmats0[3][48] + coeff0_4*dmats0[4][48] + coeff0_5*dmats0[5][48] + coeff0_6*dmats0[6][48] + coeff0_7*dmats0[7][48] + coeff0_8*dmats0[8][48] + coeff0_9*dmats0[9][48] + coeff0_10*dmats0[10][48] + coeff0_11*dmats0[11][48] + coeff0_12*dmats0[12][48] + coeff0_13*dmats0[13][48] + coeff0_14*dmats0[14][48] + coeff0_15*dmats0[15][48] + coeff0_16*dmats0[16][48] + coeff0_17*dmats0[17][48] + coeff0_18*dmats0[18][48] + coeff0_19*dmats0[19][48] + coeff0_20*dmats0[20][48] + coeff0_21*dmats0[21][48] + coeff0_22*dmats0[22][48] + coeff0_23*dmats0[23][48] + coeff0_24*dmats0[24][48] + coeff0_25*dmats0[25][48] + coeff0_26*dmats0[26][48] + coeff0_27*dmats0[27][48] + coeff0_28*dmats0[28][48] + coeff0_29*dmats0[29][48] + coeff0_30*dmats0[30][48] + coeff0_31*dmats0[31][48] + coeff0_32*dmats0[32][48] + coeff0_33*dmats0[33][48] + coeff0_34*dmats0[34][48] + coeff0_35*dmats0[35][48] + coeff0_36*dmats0[36][48] + coeff0_37*dmats0[37][48] + coeff0_38*dmats0[38][48] + coeff0_39*dmats0[39][48] + coeff0_40*dmats0[40][48] + coeff0_41*dmats0[41][48] + coeff0_42*dmats0[42][48] + coeff0_43*dmats0[43][48] + coeff0_44*dmats0[44][48] + coeff0_45*dmats0[45][48] + coeff0_46*dmats0[46][48] + coeff0_47*dmats0[47][48] + coeff0_48*dmats0[48][48] + coeff0_49*dmats0[49][48] + coeff0_50*dmats0[50][48] + coeff0_51*dmats0[51][48] + coeff0_52*dmats0[52][48] + coeff0_53*dmats0[53][48] + coeff0_54*dmats0[54][48] + coeff0_55*dmats0[55][48];
          new_coeff0_49 = coeff0_0*dmats0[0][49] + coeff0_1*dmats0[1][49] + coeff0_2*dmats0[2][49] + coeff0_3*dmats0[3][49] + coeff0_4*dmats0[4][49] + coeff0_5*dmats0[5][49] + coeff0_6*dmats0[6][49] + coeff0_7*dmats0[7][49] + coeff0_8*dmats0[8][49] + coeff0_9*dmats0[9][49] + coeff0_10*dmats0[10][49] + coeff0_11*dmats0[11][49] + coeff0_12*dmats0[12][49] + coeff0_13*dmats0[13][49] + coeff0_14*dmats0[14][49] + coeff0_15*dmats0[15][49] + coeff0_16*dmats0[16][49] + coeff0_17*dmats0[17][49] + coeff0_18*dmats0[18][49] + coeff0_19*dmats0[19][49] + coeff0_20*dmats0[20][49] + coeff0_21*dmats0[21][49] + coeff0_22*dmats0[22][49] + coeff0_23*dmats0[23][49] + coeff0_24*dmats0[24][49] + coeff0_25*dmats0[25][49] + coeff0_26*dmats0[26][49] + coeff0_27*dmats0[27][49] + coeff0_28*dmats0[28][49] + coeff0_29*dmats0[29][49] + coeff0_30*dmats0[30][49] + coeff0_31*dmats0[31][49] + coeff0_32*dmats0[32][49] + coeff0_33*dmats0[33][49] + coeff0_34*dmats0[34][49] + coeff0_35*dmats0[35][49] + coeff0_36*dmats0[36][49] + coeff0_37*dmats0[37][49] + coeff0_38*dmats0[38][49] + coeff0_39*dmats0[39][49] + coeff0_40*dmats0[40][49] + coeff0_41*dmats0[41][49] + coeff0_42*dmats0[42][49] + coeff0_43*dmats0[43][49] + coeff0_44*dmats0[44][49] + coeff0_45*dmats0[45][49] + coeff0_46*dmats0[46][49] + coeff0_47*dmats0[47][49] + coeff0_48*dmats0[48][49] + coeff0_49*dmats0[49][49] + coeff0_50*dmats0[50][49] + coeff0_51*dmats0[51][49] + coeff0_52*dmats0[52][49] + coeff0_53*dmats0[53][49] + coeff0_54*dmats0[54][49] + coeff0_55*dmats0[55][49];
          new_coeff0_50 = coeff0_0*dmats0[0][50] + coeff0_1*dmats0[1][50] + coeff0_2*dmats0[2][50] + coeff0_3*dmats0[3][50] + coeff0_4*dmats0[4][50] + coeff0_5*dmats0[5][50] + coeff0_6*dmats0[6][50] + coeff0_7*dmats0[7][50] + coeff0_8*dmats0[8][50] + coeff0_9*dmats0[9][50] + coeff0_10*dmats0[10][50] + coeff0_11*dmats0[11][50] + coeff0_12*dmats0[12][50] + coeff0_13*dmats0[13][50] + coeff0_14*dmats0[14][50] + coeff0_15*dmats0[15][50] + coeff0_16*dmats0[16][50] + coeff0_17*dmats0[17][50] + coeff0_18*dmats0[18][50] + coeff0_19*dmats0[19][50] + coeff0_20*dmats0[20][50] + coeff0_21*dmats0[21][50] + coeff0_22*dmats0[22][50] + coeff0_23*dmats0[23][50] + coeff0_24*dmats0[24][50] + coeff0_25*dmats0[25][50] + coeff0_26*dmats0[26][50] + coeff0_27*dmats0[27][50] + coeff0_28*dmats0[28][50] + coeff0_29*dmats0[29][50] + coeff0_30*dmats0[30][50] + coeff0_31*dmats0[31][50] + coeff0_32*dmats0[32][50] + coeff0_33*dmats0[33][50] + coeff0_34*dmats0[34][50] + coeff0_35*dmats0[35][50] + coeff0_36*dmats0[36][50] + coeff0_37*dmats0[37][50] + coeff0_38*dmats0[38][50] + coeff0_39*dmats0[39][50] + coeff0_40*dmats0[40][50] + coeff0_41*dmats0[41][50] + coeff0_42*dmats0[42][50] + coeff0_43*dmats0[43][50] + coeff0_44*dmats0[44][50] + coeff0_45*dmats0[45][50] + coeff0_46*dmats0[46][50] + coeff0_47*dmats0[47][50] + coeff0_48*dmats0[48][50] + coeff0_49*dmats0[49][50] + coeff0_50*dmats0[50][50] + coeff0_51*dmats0[51][50] + coeff0_52*dmats0[52][50] + coeff0_53*dmats0[53][50] + coeff0_54*dmats0[54][50] + coeff0_55*dmats0[55][50];
          new_coeff0_51 = coeff0_0*dmats0[0][51] + coeff0_1*dmats0[1][51] + coeff0_2*dmats0[2][51] + coeff0_3*dmats0[3][51] + coeff0_4*dmats0[4][51] + coeff0_5*dmats0[5][51] + coeff0_6*dmats0[6][51] + coeff0_7*dmats0[7][51] + coeff0_8*dmats0[8][51] + coeff0_9*dmats0[9][51] + coeff0_10*dmats0[10][51] + coeff0_11*dmats0[11][51] + coeff0_12*dmats0[12][51] + coeff0_13*dmats0[13][51] + coeff0_14*dmats0[14][51] + coeff0_15*dmats0[15][51] + coeff0_16*dmats0[16][51] + coeff0_17*dmats0[17][51] + coeff0_18*dmats0[18][51] + coeff0_19*dmats0[19][51] + coeff0_20*dmats0[20][51] + coeff0_21*dmats0[21][51] + coeff0_22*dmats0[22][51] + coeff0_23*dmats0[23][51] + coeff0_24*dmats0[24][51] + coeff0_25*dmats0[25][51] + coeff0_26*dmats0[26][51] + coeff0_27*dmats0[27][51] + coeff0_28*dmats0[28][51] + coeff0_29*dmats0[29][51] + coeff0_30*dmats0[30][51] + coeff0_31*dmats0[31][51] + coeff0_32*dmats0[32][51] + coeff0_33*dmats0[33][51] + coeff0_34*dmats0[34][51] + coeff0_35*dmats0[35][51] + coeff0_36*dmats0[36][51] + coeff0_37*dmats0[37][51] + coeff0_38*dmats0[38][51] + coeff0_39*dmats0[39][51] + coeff0_40*dmats0[40][51] + coeff0_41*dmats0[41][51] + coeff0_42*dmats0[42][51] + coeff0_43*dmats0[43][51] + coeff0_44*dmats0[44][51] + coeff0_45*dmats0[45][51] + coeff0_46*dmats0[46][51] + coeff0_47*dmats0[47][51] + coeff0_48*dmats0[48][51] + coeff0_49*dmats0[49][51] + coeff0_50*dmats0[50][51] + coeff0_51*dmats0[51][51] + coeff0_52*dmats0[52][51] + coeff0_53*dmats0[53][51] + coeff0_54*dmats0[54][51] + coeff0_55*dmats0[55][51];
          new_coeff0_52 = coeff0_0*dmats0[0][52] + coeff0_1*dmats0[1][52] + coeff0_2*dmats0[2][52] + coeff0_3*dmats0[3][52] + coeff0_4*dmats0[4][52] + coeff0_5*dmats0[5][52] + coeff0_6*dmats0[6][52] + coeff0_7*dmats0[7][52] + coeff0_8*dmats0[8][52] + coeff0_9*dmats0[9][52] + coeff0_10*dmats0[10][52] + coeff0_11*dmats0[11][52] + coeff0_12*dmats0[12][52] + coeff0_13*dmats0[13][52] + coeff0_14*dmats0[14][52] + coeff0_15*dmats0[15][52] + coeff0_16*dmats0[16][52] + coeff0_17*dmats0[17][52] + coeff0_18*dmats0[18][52] + coeff0_19*dmats0[19][52] + coeff0_20*dmats0[20][52] + coeff0_21*dmats0[21][52] + coeff0_22*dmats0[22][52] + coeff0_23*dmats0[23][52] + coeff0_24*dmats0[24][52] + coeff0_25*dmats0[25][52] + coeff0_26*dmats0[26][52] + coeff0_27*dmats0[27][52] + coeff0_28*dmats0[28][52] + coeff0_29*dmats0[29][52] + coeff0_30*dmats0[30][52] + coeff0_31*dmats0[31][52] + coeff0_32*dmats0[32][52] + coeff0_33*dmats0[33][52] + coeff0_34*dmats0[34][52] + coeff0_35*dmats0[35][52] + coeff0_36*dmats0[36][52] + coeff0_37*dmats0[37][52] + coeff0_38*dmats0[38][52] + coeff0_39*dmats0[39][52] + coeff0_40*dmats0[40][52] + coeff0_41*dmats0[41][52] + coeff0_42*dmats0[42][52] + coeff0_43*dmats0[43][52] + coeff0_44*dmats0[44][52] + coeff0_45*dmats0[45][52] + coeff0_46*dmats0[46][52] + coeff0_47*dmats0[47][52] + coeff0_48*dmats0[48][52] + coeff0_49*dmats0[49][52] + coeff0_50*dmats0[50][52] + coeff0_51*dmats0[51][52] + coeff0_52*dmats0[52][52] + coeff0_53*dmats0[53][52] + coeff0_54*dmats0[54][52] + coeff0_55*dmats0[55][52];
          new_coeff0_53 = coeff0_0*dmats0[0][53] + coeff0_1*dmats0[1][53] + coeff0_2*dmats0[2][53] + coeff0_3*dmats0[3][53] + coeff0_4*dmats0[4][53] + coeff0_5*dmats0[5][53] + coeff0_6*dmats0[6][53] + coeff0_7*dmats0[7][53] + coeff0_8*dmats0[8][53] + coeff0_9*dmats0[9][53] + coeff0_10*dmats0[10][53] + coeff0_11*dmats0[11][53] + coeff0_12*dmats0[12][53] + coeff0_13*dmats0[13][53] + coeff0_14*dmats0[14][53] + coeff0_15*dmats0[15][53] + coeff0_16*dmats0[16][53] + coeff0_17*dmats0[17][53] + coeff0_18*dmats0[18][53] + coeff0_19*dmats0[19][53] + coeff0_20*dmats0[20][53] + coeff0_21*dmats0[21][53] + coeff0_22*dmats0[22][53] + coeff0_23*dmats0[23][53] + coeff0_24*dmats0[24][53] + coeff0_25*dmats0[25][53] + coeff0_26*dmats0[26][53] + coeff0_27*dmats0[27][53] + coeff0_28*dmats0[28][53] + coeff0_29*dmats0[29][53] + coeff0_30*dmats0[30][53] + coeff0_31*dmats0[31][53] + coeff0_32*dmats0[32][53] + coeff0_33*dmats0[33][53] + coeff0_34*dmats0[34][53] + coeff0_35*dmats0[35][53] + coeff0_36*dmats0[36][53] + coeff0_37*dmats0[37][53] + coeff0_38*dmats0[38][53] + coeff0_39*dmats0[39][53] + coeff0_40*dmats0[40][53] + coeff0_41*dmats0[41][53] + coeff0_42*dmats0[42][53] + coeff0_43*dmats0[43][53] + coeff0_44*dmats0[44][53] + coeff0_45*dmats0[45][53] + coeff0_46*dmats0[46][53] + coeff0_47*dmats0[47][53] + coeff0_48*dmats0[48][53] + coeff0_49*dmats0[49][53] + coeff0_50*dmats0[50][53] + coeff0_51*dmats0[51][53] + coeff0_52*dmats0[52][53] + coeff0_53*dmats0[53][53] + coeff0_54*dmats0[54][53] + coeff0_55*dmats0[55][53];
          new_coeff0_54 = coeff0_0*dmats0[0][54] + coeff0_1*dmats0[1][54] + coeff0_2*dmats0[2][54] + coeff0_3*dmats0[3][54] + coeff0_4*dmats0[4][54] + coeff0_5*dmats0[5][54] + coeff0_6*dmats0[6][54] + coeff0_7*dmats0[7][54] + coeff0_8*dmats0[8][54] + coeff0_9*dmats0[9][54] + coeff0_10*dmats0[10][54] + coeff0_11*dmats0[11][54] + coeff0_12*dmats0[12][54] + coeff0_13*dmats0[13][54] + coeff0_14*dmats0[14][54] + coeff0_15*dmats0[15][54] + coeff0_16*dmats0[16][54] + coeff0_17*dmats0[17][54] + coeff0_18*dmats0[18][54] + coeff0_19*dmats0[19][54] + coeff0_20*dmats0[20][54] + coeff0_21*dmats0[21][54] + coeff0_22*dmats0[22][54] + coeff0_23*dmats0[23][54] + coeff0_24*dmats0[24][54] + coeff0_25*dmats0[25][54] + coeff0_26*dmats0[26][54] + coeff0_27*dmats0[27][54] + coeff0_28*dmats0[28][54] + coeff0_29*dmats0[29][54] + coeff0_30*dmats0[30][54] + coeff0_31*dmats0[31][54] + coeff0_32*dmats0[32][54] + coeff0_33*dmats0[33][54] + coeff0_34*dmats0[34][54] + coeff0_35*dmats0[35][54] + coeff0_36*dmats0[36][54] + coeff0_37*dmats0[37][54] + coeff0_38*dmats0[38][54] + coeff0_39*dmats0[39][54] + coeff0_40*dmats0[40][54] + coeff0_41*dmats0[41][54] + coeff0_42*dmats0[42][54] + coeff0_43*dmats0[43][54] + coeff0_44*dmats0[44][54] + coeff0_45*dmats0[45][54] + coeff0_46*dmats0[46][54] + coeff0_47*dmats0[47][54] + coeff0_48*dmats0[48][54] + coeff0_49*dmats0[49][54] + coeff0_50*dmats0[50][54] + coeff0_51*dmats0[51][54] + coeff0_52*dmats0[52][54] + coeff0_53*dmats0[53][54] + coeff0_54*dmats0[54][54] + coeff0_55*dmats0[55][54];
          new_coeff0_55 = coeff0_0*dmats0[0][55] + coeff0_1*dmats0[1][55] + coeff0_2*dmats0[2][55] + coeff0_3*dmats0[3][55] + coeff0_4*dmats0[4][55] + coeff0_5*dmats0[5][55] + coeff0_6*dmats0[6][55] + coeff0_7*dmats0[7][55] + coeff0_8*dmats0[8][55] + coeff0_9*dmats0[9][55] + coeff0_10*dmats0[10][55] + coeff0_11*dmats0[11][55] + coeff0_12*dmats0[12][55] + coeff0_13*dmats0[13][55] + coeff0_14*dmats0[14][55] + coeff0_15*dmats0[15][55] + coeff0_16*dmats0[16][55] + coeff0_17*dmats0[17][55] + coeff0_18*dmats0[18][55] + coeff0_19*dmats0[19][55] + coeff0_20*dmats0[20][55] + coeff0_21*dmats0[21][55] + coeff0_22*dmats0[22][55] + coeff0_23*dmats0[23][55] + coeff0_24*dmats0[24][55] + coeff0_25*dmats0[25][55] + coeff0_26*dmats0[26][55] + coeff0_27*dmats0[27][55] + coeff0_28*dmats0[28][55] + coeff0_29*dmats0[29][55] + coeff0_30*dmats0[30][55] + coeff0_31*dmats0[31][55] + coeff0_32*dmats0[32][55] + coeff0_33*dmats0[33][55] + coeff0_34*dmats0[34][55] + coeff0_35*dmats0[35][55] + coeff0_36*dmats0[36][55] + coeff0_37*dmats0[37][55] + coeff0_38*dmats0[38][55] + coeff0_39*dmats0[39][55] + coeff0_40*dmats0[40][55] + coeff0_41*dmats0[41][55] + coeff0_42*dmats0[42][55] + coeff0_43*dmats0[43][55] + coeff0_44*dmats0[44][55] + coeff0_45*dmats0[45][55] + coeff0_46*dmats0[46][55] + coeff0_47*dmats0[47][55] + coeff0_48*dmats0[48][55] + coeff0_49*dmats0[49][55] + coeff0_50*dmats0[50][55] + coeff0_51*dmats0[51][55] + coeff0_52*dmats0[52][55] + coeff0_53*dmats0[53][55] + coeff0_54*dmats0[54][55] + coeff0_55*dmats0[55][55];
        }
        if(combinations[deriv_num][j] == 1)
        {
          new_coeff0_0 = coeff0_0*dmats1[0][0] + coeff0_1*dmats1[1][0] + coeff0_2*dmats1[2][0] + coeff0_3*dmats1[3][0] + coeff0_4*dmats1[4][0] + coeff0_5*dmats1[5][0] + coeff0_6*dmats1[6][0] + coeff0_7*dmats1[7][0] + coeff0_8*dmats1[8][0] + coeff0_9*dmats1[9][0] + coeff0_10*dmats1[10][0] + coeff0_11*dmats1[11][0] + coeff0_12*dmats1[12][0] + coeff0_13*dmats1[13][0] + coeff0_14*dmats1[14][0] + coeff0_15*dmats1[15][0] + coeff0_16*dmats1[16][0] + coeff0_17*dmats1[17][0] + coeff0_18*dmats1[18][0] + coeff0_19*dmats1[19][0] + coeff0_20*dmats1[20][0] + coeff0_21*dmats1[21][0] + coeff0_22*dmats1[22][0] + coeff0_23*dmats1[23][0] + coeff0_24*dmats1[24][0] + coeff0_25*dmats1[25][0] + coeff0_26*dmats1[26][0] + coeff0_27*dmats1[27][0] + coeff0_28*dmats1[28][0] + coeff0_29*dmats1[29][0] + coeff0_30*dmats1[30][0] + coeff0_31*dmats1[31][0] + coeff0_32*dmats1[32][0] + coeff0_33*dmats1[33][0] + coeff0_34*dmats1[34][0] + coeff0_35*dmats1[35][0] + coeff0_36*dmats1[36][0] + coeff0_37*dmats1[37][0] + coeff0_38*dmats1[38][0] + coeff0_39*dmats1[39][0] + coeff0_40*dmats1[40][0] + coeff0_41*dmats1[41][0] + coeff0_42*dmats1[42][0] + coeff0_43*dmats1[43][0] + coeff0_44*dmats1[44][0] + coeff0_45*dmats1[45][0] + coeff0_46*dmats1[46][0] + coeff0_47*dmats1[47][0] + coeff0_48*dmats1[48][0] + coeff0_49*dmats1[49][0] + coeff0_50*dmats1[50][0] + coeff0_51*dmats1[51][0] + coeff0_52*dmats1[52][0] + coeff0_53*dmats1[53][0] + coeff0_54*dmats1[54][0] + coeff0_55*dmats1[55][0];
          new_coeff0_1 = coeff0_0*dmats1[0][1] + coeff0_1*dmats1[1][1] + coeff0_2*dmats1[2][1] + coeff0_3*dmats1[3][1] + coeff0_4*dmats1[4][1] + coeff0_5*dmats1[5][1] + coeff0_6*dmats1[6][1] + coeff0_7*dmats1[7][1] + coeff0_8*dmats1[8][1] + coeff0_9*dmats1[9][1] + coeff0_10*dmats1[10][1] + coeff0_11*dmats1[11][1] + coeff0_12*dmats1[12][1] + coeff0_13*dmats1[13][1] + coeff0_14*dmats1[14][1] + coeff0_15*dmats1[15][1] + coeff0_16*dmats1[16][1] + coeff0_17*dmats1[17][1] + coeff0_18*dmats1[18][1] + coeff0_19*dmats1[19][1] + coeff0_20*dmats1[20][1] + coeff0_21*dmats1[21][1] + coeff0_22*dmats1[22][1] + coeff0_23*dmats1[23][1] + coeff0_24*dmats1[24][1] + coeff0_25*dmats1[25][1] + coeff0_26*dmats1[26][1] + coeff0_27*dmats1[27][1] + coeff0_28*dmats1[28][1] + coeff0_29*dmats1[29][1] + coeff0_30*dmats1[30][1] + coeff0_31*dmats1[31][1] + coeff0_32*dmats1[32][1] + coeff0_33*dmats1[33][1] + coeff0_34*dmats1[34][1] + coeff0_35*dmats1[35][1] + coeff0_36*dmats1[36][1] + coeff0_37*dmats1[37][1] + coeff0_38*dmats1[38][1] + coeff0_39*dmats1[39][1] + coeff0_40*dmats1[40][1] + coeff0_41*dmats1[41][1] + coeff0_42*dmats1[42][1] + coeff0_43*dmats1[43][1] + coeff0_44*dmats1[44][1] + coeff0_45*dmats1[45][1] + coeff0_46*dmats1[46][1] + coeff0_47*dmats1[47][1] + coeff0_48*dmats1[48][1] + coeff0_49*dmats1[49][1] + coeff0_50*dmats1[50][1] + coeff0_51*dmats1[51][1] + coeff0_52*dmats1[52][1] + coeff0_53*dmats1[53][1] + coeff0_54*dmats1[54][1] + coeff0_55*dmats1[55][1];
          new_coeff0_2 = coeff0_0*dmats1[0][2] + coeff0_1*dmats1[1][2] + coeff0_2*dmats1[2][2] + coeff0_3*dmats1[3][2] + coeff0_4*dmats1[4][2] + coeff0_5*dmats1[5][2] + coeff0_6*dmats1[6][2] + coeff0_7*dmats1[7][2] + coeff0_8*dmats1[8][2] + coeff0_9*dmats1[9][2] + coeff0_10*dmats1[10][2] + coeff0_11*dmats1[11][2] + coeff0_12*dmats1[12][2] + coeff0_13*dmats1[13][2] + coeff0_14*dmats1[14][2] + coeff0_15*dmats1[15][2] + coeff0_16*dmats1[16][2] + coeff0_17*dmats1[17][2] + coeff0_18*dmats1[18][2] + coeff0_19*dmats1[19][2] + coeff0_20*dmats1[20][2] + coeff0_21*dmats1[21][2] + coeff0_22*dmats1[22][2] + coeff0_23*dmats1[23][2] + coeff0_24*dmats1[24][2] + coeff0_25*dmats1[25][2] + coeff0_26*dmats1[26][2] + coeff0_27*dmats1[27][2] + coeff0_28*dmats1[28][2] + coeff0_29*dmats1[29][2] + coeff0_30*dmats1[30][2] + coeff0_31*dmats1[31][2] + coeff0_32*dmats1[32][2] + coeff0_33*dmats1[33][2] + coeff0_34*dmats1[34][2] + coeff0_35*dmats1[35][2] + coeff0_36*dmats1[36][2] + coeff0_37*dmats1[37][2] + coeff0_38*dmats1[38][2] + coeff0_39*dmats1[39][2] + coeff0_40*dmats1[40][2] + coeff0_41*dmats1[41][2] + coeff0_42*dmats1[42][2] + coeff0_43*dmats1[43][2] + coeff0_44*dmats1[44][2] + coeff0_45*dmats1[45][2] + coeff0_46*dmats1[46][2] + coeff0_47*dmats1[47][2] + coeff0_48*dmats1[48][2] + coeff0_49*dmats1[49][2] + coeff0_50*dmats1[50][2] + coeff0_51*dmats1[51][2] + coeff0_52*dmats1[52][2] + coeff0_53*dmats1[53][2] + coeff0_54*dmats1[54][2] + coeff0_55*dmats1[55][2];
          new_coeff0_3 = coeff0_0*dmats1[0][3] + coeff0_1*dmats1[1][3] + coeff0_2*dmats1[2][3] + coeff0_3*dmats1[3][3] + coeff0_4*dmats1[4][3] + coeff0_5*dmats1[5][3] + coeff0_6*dmats1[6][3] + coeff0_7*dmats1[7][3] + coeff0_8*dmats1[8][3] + coeff0_9*dmats1[9][3] + coeff0_10*dmats1[10][3] + coeff0_11*dmats1[11][3] + coeff0_12*dmats1[12][3] + coeff0_13*dmats1[13][3] + coeff0_14*dmats1[14][3] + coeff0_15*dmats1[15][3] + coeff0_16*dmats1[16][3] + coeff0_17*dmats1[17][3] + coeff0_18*dmats1[18][3] + coeff0_19*dmats1[19][3] + coeff0_20*dmats1[20][3] + coeff0_21*dmats1[21][3] + coeff0_22*dmats1[22][3] + coeff0_23*dmats1[23][3] + coeff0_24*dmats1[24][3] + coeff0_25*dmats1[25][3] + coeff0_26*dmats1[26][3] + coeff0_27*dmats1[27][3] + coeff0_28*dmats1[28][3] + coeff0_29*dmats1[29][3] + coeff0_30*dmats1[30][3] + coeff0_31*dmats1[31][3] + coeff0_32*dmats1[32][3] + coeff0_33*dmats1[33][3] + coeff0_34*dmats1[34][3] + coeff0_35*dmats1[35][3] + coeff0_36*dmats1[36][3] + coeff0_37*dmats1[37][3] + coeff0_38*dmats1[38][3] + coeff0_39*dmats1[39][3] + coeff0_40*dmats1[40][3] + coeff0_41*dmats1[41][3] + coeff0_42*dmats1[42][3] + coeff0_43*dmats1[43][3] + coeff0_44*dmats1[44][3] + coeff0_45*dmats1[45][3] + coeff0_46*dmats1[46][3] + coeff0_47*dmats1[47][3] + coeff0_48*dmats1[48][3] + coeff0_49*dmats1[49][3] + coeff0_50*dmats1[50][3] + coeff0_51*dmats1[51][3] + coeff0_52*dmats1[52][3] + coeff0_53*dmats1[53][3] + coeff0_54*dmats1[54][3] + coeff0_55*dmats1[55][3];
          new_coeff0_4 = coeff0_0*dmats1[0][4] + coeff0_1*dmats1[1][4] + coeff0_2*dmats1[2][4] + coeff0_3*dmats1[3][4] + coeff0_4*dmats1[4][4] + coeff0_5*dmats1[5][4] + coeff0_6*dmats1[6][4] + coeff0_7*dmats1[7][4] + coeff0_8*dmats1[8][4] + coeff0_9*dmats1[9][4] + coeff0_10*dmats1[10][4] + coeff0_11*dmats1[11][4] + coeff0_12*dmats1[12][4] + coeff0_13*dmats1[13][4] + coeff0_14*dmats1[14][4] + coeff0_15*dmats1[15][4] + coeff0_16*dmats1[16][4] + coeff0_17*dmats1[17][4] + coeff0_18*dmats1[18][4] + coeff0_19*dmats1[19][4] + coeff0_20*dmats1[20][4] + coeff0_21*dmats1[21][4] + coeff0_22*dmats1[22][4] + coeff0_23*dmats1[23][4] + coeff0_24*dmats1[24][4] + coeff0_25*dmats1[25][4] + coeff0_26*dmats1[26][4] + coeff0_27*dmats1[27][4] + coeff0_28*dmats1[28][4] + coeff0_29*dmats1[29][4] + coeff0_30*dmats1[30][4] + coeff0_31*dmats1[31][4] + coeff0_32*dmats1[32][4] + coeff0_33*dmats1[33][4] + coeff0_34*dmats1[34][4] + coeff0_35*dmats1[35][4] + coeff0_36*dmats1[36][4] + coeff0_37*dmats1[37][4] + coeff0_38*dmats1[38][4] + coeff0_39*dmats1[39][4] + coeff0_40*dmats1[40][4] + coeff0_41*dmats1[41][4] + coeff0_42*dmats1[42][4] + coeff0_43*dmats1[43][4] + coeff0_44*dmats1[44][4] + coeff0_45*dmats1[45][4] + coeff0_46*dmats1[46][4] + coeff0_47*dmats1[47][4] + coeff0_48*dmats1[48][4] + coeff0_49*dmats1[49][4] + coeff0_50*dmats1[50][4] + coeff0_51*dmats1[51][4] + coeff0_52*dmats1[52][4] + coeff0_53*dmats1[53][4] + coeff0_54*dmats1[54][4] + coeff0_55*dmats1[55][4];
          new_coeff0_5 = coeff0_0*dmats1[0][5] + coeff0_1*dmats1[1][5] + coeff0_2*dmats1[2][5] + coeff0_3*dmats1[3][5] + coeff0_4*dmats1[4][5] + coeff0_5*dmats1[5][5] + coeff0_6*dmats1[6][5] + coeff0_7*dmats1[7][5] + coeff0_8*dmats1[8][5] + coeff0_9*dmats1[9][5] + coeff0_10*dmats1[10][5] + coeff0_11*dmats1[11][5] + coeff0_12*dmats1[12][5] + coeff0_13*dmats1[13][5] + coeff0_14*dmats1[14][5] + coeff0_15*dmats1[15][5] + coeff0_16*dmats1[16][5] + coeff0_17*dmats1[17][5] + coeff0_18*dmats1[18][5] + coeff0_19*dmats1[19][5] + coeff0_20*dmats1[20][5] + coeff0_21*dmats1[21][5] + coeff0_22*dmats1[22][5] + coeff0_23*dmats1[23][5] + coeff0_24*dmats1[24][5] + coeff0_25*dmats1[25][5] + coeff0_26*dmats1[26][5] + coeff0_27*dmats1[27][5] + coeff0_28*dmats1[28][5] + coeff0_29*dmats1[29][5] + coeff0_30*dmats1[30][5] + coeff0_31*dmats1[31][5] + coeff0_32*dmats1[32][5] + coeff0_33*dmats1[33][5] + coeff0_34*dmats1[34][5] + coeff0_35*dmats1[35][5] + coeff0_36*dmats1[36][5] + coeff0_37*dmats1[37][5] + coeff0_38*dmats1[38][5] + coeff0_39*dmats1[39][5] + coeff0_40*dmats1[40][5] + coeff0_41*dmats1[41][5] + coeff0_42*dmats1[42][5] + coeff0_43*dmats1[43][5] + coeff0_44*dmats1[44][5] + coeff0_45*dmats1[45][5] + coeff0_46*dmats1[46][5] + coeff0_47*dmats1[47][5] + coeff0_48*dmats1[48][5] + coeff0_49*dmats1[49][5] + coeff0_50*dmats1[50][5] + coeff0_51*dmats1[51][5] + coeff0_52*dmats1[52][5] + coeff0_53*dmats1[53][5] + coeff0_54*dmats1[54][5] + coeff0_55*dmats1[55][5];
          new_coeff0_6 = coeff0_0*dmats1[0][6] + coeff0_1*dmats1[1][6] + coeff0_2*dmats1[2][6] + coeff0_3*dmats1[3][6] + coeff0_4*dmats1[4][6] + coeff0_5*dmats1[5][6] + coeff0_6*dmats1[6][6] + coeff0_7*dmats1[7][6] + coeff0_8*dmats1[8][6] + coeff0_9*dmats1[9][6] + coeff0_10*dmats1[10][6] + coeff0_11*dmats1[11][6] + coeff0_12*dmats1[12][6] + coeff0_13*dmats1[13][6] + coeff0_14*dmats1[14][6] + coeff0_15*dmats1[15][6] + coeff0_16*dmats1[16][6] + coeff0_17*dmats1[17][6] + coeff0_18*dmats1[18][6] + coeff0_19*dmats1[19][6] + coeff0_20*dmats1[20][6] + coeff0_21*dmats1[21][6] + coeff0_22*dmats1[22][6] + coeff0_23*dmats1[23][6] + coeff0_24*dmats1[24][6] + coeff0_25*dmats1[25][6] + coeff0_26*dmats1[26][6] + coeff0_27*dmats1[27][6] + coeff0_28*dmats1[28][6] + coeff0_29*dmats1[29][6] + coeff0_30*dmats1[30][6] + coeff0_31*dmats1[31][6] + coeff0_32*dmats1[32][6] + coeff0_33*dmats1[33][6] + coeff0_34*dmats1[34][6] + coeff0_35*dmats1[35][6] + coeff0_36*dmats1[36][6] + coeff0_37*dmats1[37][6] + coeff0_38*dmats1[38][6] + coeff0_39*dmats1[39][6] + coeff0_40*dmats1[40][6] + coeff0_41*dmats1[41][6] + coeff0_42*dmats1[42][6] + coeff0_43*dmats1[43][6] + coeff0_44*dmats1[44][6] + coeff0_45*dmats1[45][6] + coeff0_46*dmats1[46][6] + coeff0_47*dmats1[47][6] + coeff0_48*dmats1[48][6] + coeff0_49*dmats1[49][6] + coeff0_50*dmats1[50][6] + coeff0_51*dmats1[51][6] + coeff0_52*dmats1[52][6] + coeff0_53*dmats1[53][6] + coeff0_54*dmats1[54][6] + coeff0_55*dmats1[55][6];
          new_coeff0_7 = coeff0_0*dmats1[0][7] + coeff0_1*dmats1[1][7] + coeff0_2*dmats1[2][7] + coeff0_3*dmats1[3][7] + coeff0_4*dmats1[4][7] + coeff0_5*dmats1[5][7] + coeff0_6*dmats1[6][7] + coeff0_7*dmats1[7][7] + coeff0_8*dmats1[8][7] + coeff0_9*dmats1[9][7] + coeff0_10*dmats1[10][7] + coeff0_11*dmats1[11][7] + coeff0_12*dmats1[12][7] + coeff0_13*dmats1[13][7] + coeff0_14*dmats1[14][7] + coeff0_15*dmats1[15][7] + coeff0_16*dmats1[16][7] + coeff0_17*dmats1[17][7] + coeff0_18*dmats1[18][7] + coeff0_19*dmats1[19][7] + coeff0_20*dmats1[20][7] + coeff0_21*dmats1[21][7] + coeff0_22*dmats1[22][7] + coeff0_23*dmats1[23][7] + coeff0_24*dmats1[24][7] + coeff0_25*dmats1[25][7] + coeff0_26*dmats1[26][7] + coeff0_27*dmats1[27][7] + coeff0_28*dmats1[28][7] + coeff0_29*dmats1[29][7] + coeff0_30*dmats1[30][7] + coeff0_31*dmats1[31][7] + coeff0_32*dmats1[32][7] + coeff0_33*dmats1[33][7] + coeff0_34*dmats1[34][7] + coeff0_35*dmats1[35][7] + coeff0_36*dmats1[36][7] + coeff0_37*dmats1[37][7] + coeff0_38*dmats1[38][7] + coeff0_39*dmats1[39][7] + coeff0_40*dmats1[40][7] + coeff0_41*dmats1[41][7] + coeff0_42*dmats1[42][7] + coeff0_43*dmats1[43][7] + coeff0_44*dmats1[44][7] + coeff0_45*dmats1[45][7] + coeff0_46*dmats1[46][7] + coeff0_47*dmats1[47][7] + coeff0_48*dmats1[48][7] + coeff0_49*dmats1[49][7] + coeff0_50*dmats1[50][7] + coeff0_51*dmats1[51][7] + coeff0_52*dmats1[52][7] + coeff0_53*dmats1[53][7] + coeff0_54*dmats1[54][7] + coeff0_55*dmats1[55][7];
          new_coeff0_8 = coeff0_0*dmats1[0][8] + coeff0_1*dmats1[1][8] + coeff0_2*dmats1[2][8] + coeff0_3*dmats1[3][8] + coeff0_4*dmats1[4][8] + coeff0_5*dmats1[5][8] + coeff0_6*dmats1[6][8] + coeff0_7*dmats1[7][8] + coeff0_8*dmats1[8][8] + coeff0_9*dmats1[9][8] + coeff0_10*dmats1[10][8] + coeff0_11*dmats1[11][8] + coeff0_12*dmats1[12][8] + coeff0_13*dmats1[13][8] + coeff0_14*dmats1[14][8] + coeff0_15*dmats1[15][8] + coeff0_16*dmats1[16][8] + coeff0_17*dmats1[17][8] + coeff0_18*dmats1[18][8] + coeff0_19*dmats1[19][8] + coeff0_20*dmats1[20][8] + coeff0_21*dmats1[21][8] + coeff0_22*dmats1[22][8] + coeff0_23*dmats1[23][8] + coeff0_24*dmats1[24][8] + coeff0_25*dmats1[25][8] + coeff0_26*dmats1[26][8] + coeff0_27*dmats1[27][8] + coeff0_28*dmats1[28][8] + coeff0_29*dmats1[29][8] + coeff0_30*dmats1[30][8] + coeff0_31*dmats1[31][8] + coeff0_32*dmats1[32][8] + coeff0_33*dmats1[33][8] + coeff0_34*dmats1[34][8] + coeff0_35*dmats1[35][8] + coeff0_36*dmats1[36][8] + coeff0_37*dmats1[37][8] + coeff0_38*dmats1[38][8] + coeff0_39*dmats1[39][8] + coeff0_40*dmats1[40][8] + coeff0_41*dmats1[41][8] + coeff0_42*dmats1[42][8] + coeff0_43*dmats1[43][8] + coeff0_44*dmats1[44][8] + coeff0_45*dmats1[45][8] + coeff0_46*dmats1[46][8] + coeff0_47*dmats1[47][8] + coeff0_48*dmats1[48][8] + coeff0_49*dmats1[49][8] + coeff0_50*dmats1[50][8] + coeff0_51*dmats1[51][8] + coeff0_52*dmats1[52][8] + coeff0_53*dmats1[53][8] + coeff0_54*dmats1[54][8] + coeff0_55*dmats1[55][8];
          new_coeff0_9 = coeff0_0*dmats1[0][9] + coeff0_1*dmats1[1][9] + coeff0_2*dmats1[2][9] + coeff0_3*dmats1[3][9] + coeff0_4*dmats1[4][9] + coeff0_5*dmats1[5][9] + coeff0_6*dmats1[6][9] + coeff0_7*dmats1[7][9] + coeff0_8*dmats1[8][9] + coeff0_9*dmats1[9][9] + coeff0_10*dmats1[10][9] + coeff0_11*dmats1[11][9] + coeff0_12*dmats1[12][9] + coeff0_13*dmats1[13][9] + coeff0_14*dmats1[14][9] + coeff0_15*dmats1[15][9] + coeff0_16*dmats1[16][9] + coeff0_17*dmats1[17][9] + coeff0_18*dmats1[18][9] + coeff0_19*dmats1[19][9] + coeff0_20*dmats1[20][9] + coeff0_21*dmats1[21][9] + coeff0_22*dmats1[22][9] + coeff0_23*dmats1[23][9] + coeff0_24*dmats1[24][9] + coeff0_25*dmats1[25][9] + coeff0_26*dmats1[26][9] + coeff0_27*dmats1[27][9] + coeff0_28*dmats1[28][9] + coeff0_29*dmats1[29][9] + coeff0_30*dmats1[30][9] + coeff0_31*dmats1[31][9] + coeff0_32*dmats1[32][9] + coeff0_33*dmats1[33][9] + coeff0_34*dmats1[34][9] + coeff0_35*dmats1[35][9] + coeff0_36*dmats1[36][9] + coeff0_37*dmats1[37][9] + coeff0_38*dmats1[38][9] + coeff0_39*dmats1[39][9] + coeff0_40*dmats1[40][9] + coeff0_41*dmats1[41][9] + coeff0_42*dmats1[42][9] + coeff0_43*dmats1[43][9] + coeff0_44*dmats1[44][9] + coeff0_45*dmats1[45][9] + coeff0_46*dmats1[46][9] + coeff0_47*dmats1[47][9] + coeff0_48*dmats1[48][9] + coeff0_49*dmats1[49][9] + coeff0_50*dmats1[50][9] + coeff0_51*dmats1[51][9] + coeff0_52*dmats1[52][9] + coeff0_53*dmats1[53][9] + coeff0_54*dmats1[54][9] + coeff0_55*dmats1[55][9];
          new_coeff0_10 = coeff0_0*dmats1[0][10] + coeff0_1*dmats1[1][10] + coeff0_2*dmats1[2][10] + coeff0_3*dmats1[3][10] + coeff0_4*dmats1[4][10] + coeff0_5*dmats1[5][10] + coeff0_6*dmats1[6][10] + coeff0_7*dmats1[7][10] + coeff0_8*dmats1[8][10] + coeff0_9*dmats1[9][10] + coeff0_10*dmats1[10][10] + coeff0_11*dmats1[11][10] + coeff0_12*dmats1[12][10] + coeff0_13*dmats1[13][10] + coeff0_14*dmats1[14][10] + coeff0_15*dmats1[15][10] + coeff0_16*dmats1[16][10] + coeff0_17*dmats1[17][10] + coeff0_18*dmats1[18][10] + coeff0_19*dmats1[19][10] + coeff0_20*dmats1[20][10] + coeff0_21*dmats1[21][10] + coeff0_22*dmats1[22][10] + coeff0_23*dmats1[23][10] + coeff0_24*dmats1[24][10] + coeff0_25*dmats1[25][10] + coeff0_26*dmats1[26][10] + coeff0_27*dmats1[27][10] + coeff0_28*dmats1[28][10] + coeff0_29*dmats1[29][10] + coeff0_30*dmats1[30][10] + coeff0_31*dmats1[31][10] + coeff0_32*dmats1[32][10] + coeff0_33*dmats1[33][10] + coeff0_34*dmats1[34][10] + coeff0_35*dmats1[35][10] + coeff0_36*dmats1[36][10] + coeff0_37*dmats1[37][10] + coeff0_38*dmats1[38][10] + coeff0_39*dmats1[39][10] + coeff0_40*dmats1[40][10] + coeff0_41*dmats1[41][10] + coeff0_42*dmats1[42][10] + coeff0_43*dmats1[43][10] + coeff0_44*dmats1[44][10] + coeff0_45*dmats1[45][10] + coeff0_46*dmats1[46][10] + coeff0_47*dmats1[47][10] + coeff0_48*dmats1[48][10] + coeff0_49*dmats1[49][10] + coeff0_50*dmats1[50][10] + coeff0_51*dmats1[51][10] + coeff0_52*dmats1[52][10] + coeff0_53*dmats1[53][10] + coeff0_54*dmats1[54][10] + coeff0_55*dmats1[55][10];
          new_coeff0_11 = coeff0_0*dmats1[0][11] + coeff0_1*dmats1[1][11] + coeff0_2*dmats1[2][11] + coeff0_3*dmats1[3][11] + coeff0_4*dmats1[4][11] + coeff0_5*dmats1[5][11] + coeff0_6*dmats1[6][11] + coeff0_7*dmats1[7][11] + coeff0_8*dmats1[8][11] + coeff0_9*dmats1[9][11] + coeff0_10*dmats1[10][11] + coeff0_11*dmats1[11][11] + coeff0_12*dmats1[12][11] + coeff0_13*dmats1[13][11] + coeff0_14*dmats1[14][11] + coeff0_15*dmats1[15][11] + coeff0_16*dmats1[16][11] + coeff0_17*dmats1[17][11] + coeff0_18*dmats1[18][11] + coeff0_19*dmats1[19][11] + coeff0_20*dmats1[20][11] + coeff0_21*dmats1[21][11] + coeff0_22*dmats1[22][11] + coeff0_23*dmats1[23][11] + coeff0_24*dmats1[24][11] + coeff0_25*dmats1[25][11] + coeff0_26*dmats1[26][11] + coeff0_27*dmats1[27][11] + coeff0_28*dmats1[28][11] + coeff0_29*dmats1[29][11] + coeff0_30*dmats1[30][11] + coeff0_31*dmats1[31][11] + coeff0_32*dmats1[32][11] + coeff0_33*dmats1[33][11] + coeff0_34*dmats1[34][11] + coeff0_35*dmats1[35][11] + coeff0_36*dmats1[36][11] + coeff0_37*dmats1[37][11] + coeff0_38*dmats1[38][11] + coeff0_39*dmats1[39][11] + coeff0_40*dmats1[40][11] + coeff0_41*dmats1[41][11] + coeff0_42*dmats1[42][11] + coeff0_43*dmats1[43][11] + coeff0_44*dmats1[44][11] + coeff0_45*dmats1[45][11] + coeff0_46*dmats1[46][11] + coeff0_47*dmats1[47][11] + coeff0_48*dmats1[48][11] + coeff0_49*dmats1[49][11] + coeff0_50*dmats1[50][11] + coeff0_51*dmats1[51][11] + coeff0_52*dmats1[52][11] + coeff0_53*dmats1[53][11] + coeff0_54*dmats1[54][11] + coeff0_55*dmats1[55][11];
          new_coeff0_12 = coeff0_0*dmats1[0][12] + coeff0_1*dmats1[1][12] + coeff0_2*dmats1[2][12] + coeff0_3*dmats1[3][12] + coeff0_4*dmats1[4][12] + coeff0_5*dmats1[5][12] + coeff0_6*dmats1[6][12] + coeff0_7*dmats1[7][12] + coeff0_8*dmats1[8][12] + coeff0_9*dmats1[9][12] + coeff0_10*dmats1[10][12] + coeff0_11*dmats1[11][12] + coeff0_12*dmats1[12][12] + coeff0_13*dmats1[13][12] + coeff0_14*dmats1[14][12] + coeff0_15*dmats1[15][12] + coeff0_16*dmats1[16][12] + coeff0_17*dmats1[17][12] + coeff0_18*dmats1[18][12] + coeff0_19*dmats1[19][12] + coeff0_20*dmats1[20][12] + coeff0_21*dmats1[21][12] + coeff0_22*dmats1[22][12] + coeff0_23*dmats1[23][12] + coeff0_24*dmats1[24][12] + coeff0_25*dmats1[25][12] + coeff0_26*dmats1[26][12] + coeff0_27*dmats1[27][12] + coeff0_28*dmats1[28][12] + coeff0_29*dmats1[29][12] + coeff0_30*dmats1[30][12] + coeff0_31*dmats1[31][12] + coeff0_32*dmats1[32][12] + coeff0_33*dmats1[33][12] + coeff0_34*dmats1[34][12] + coeff0_35*dmats1[35][12] + coeff0_36*dmats1[36][12] + coeff0_37*dmats1[37][12] + coeff0_38*dmats1[38][12] + coeff0_39*dmats1[39][12] + coeff0_40*dmats1[40][12] + coeff0_41*dmats1[41][12] + coeff0_42*dmats1[42][12] + coeff0_43*dmats1[43][12] + coeff0_44*dmats1[44][12] + coeff0_45*dmats1[45][12] + coeff0_46*dmats1[46][12] + coeff0_47*dmats1[47][12] + coeff0_48*dmats1[48][12] + coeff0_49*dmats1[49][12] + coeff0_50*dmats1[50][12] + coeff0_51*dmats1[51][12] + coeff0_52*dmats1[52][12] + coeff0_53*dmats1[53][12] + coeff0_54*dmats1[54][12] + coeff0_55*dmats1[55][12];
          new_coeff0_13 = coeff0_0*dmats1[0][13] + coeff0_1*dmats1[1][13] + coeff0_2*dmats1[2][13] + coeff0_3*dmats1[3][13] + coeff0_4*dmats1[4][13] + coeff0_5*dmats1[5][13] + coeff0_6*dmats1[6][13] + coeff0_7*dmats1[7][13] + coeff0_8*dmats1[8][13] + coeff0_9*dmats1[9][13] + coeff0_10*dmats1[10][13] + coeff0_11*dmats1[11][13] + coeff0_12*dmats1[12][13] + coeff0_13*dmats1[13][13] + coeff0_14*dmats1[14][13] + coeff0_15*dmats1[15][13] + coeff0_16*dmats1[16][13] + coeff0_17*dmats1[17][13] + coeff0_18*dmats1[18][13] + coeff0_19*dmats1[19][13] + coeff0_20*dmats1[20][13] + coeff0_21*dmats1[21][13] + coeff0_22*dmats1[22][13] + coeff0_23*dmats1[23][13] + coeff0_24*dmats1[24][13] + coeff0_25*dmats1[25][13] + coeff0_26*dmats1[26][13] + coeff0_27*dmats1[27][13] + coeff0_28*dmats1[28][13] + coeff0_29*dmats1[29][13] + coeff0_30*dmats1[30][13] + coeff0_31*dmats1[31][13] + coeff0_32*dmats1[32][13] + coeff0_33*dmats1[33][13] + coeff0_34*dmats1[34][13] + coeff0_35*dmats1[35][13] + coeff0_36*dmats1[36][13] + coeff0_37*dmats1[37][13] + coeff0_38*dmats1[38][13] + coeff0_39*dmats1[39][13] + coeff0_40*dmats1[40][13] + coeff0_41*dmats1[41][13] + coeff0_42*dmats1[42][13] + coeff0_43*dmats1[43][13] + coeff0_44*dmats1[44][13] + coeff0_45*dmats1[45][13] + coeff0_46*dmats1[46][13] + coeff0_47*dmats1[47][13] + coeff0_48*dmats1[48][13] + coeff0_49*dmats1[49][13] + coeff0_50*dmats1[50][13] + coeff0_51*dmats1[51][13] + coeff0_52*dmats1[52][13] + coeff0_53*dmats1[53][13] + coeff0_54*dmats1[54][13] + coeff0_55*dmats1[55][13];
          new_coeff0_14 = coeff0_0*dmats1[0][14] + coeff0_1*dmats1[1][14] + coeff0_2*dmats1[2][14] + coeff0_3*dmats1[3][14] + coeff0_4*dmats1[4][14] + coeff0_5*dmats1[5][14] + coeff0_6*dmats1[6][14] + coeff0_7*dmats1[7][14] + coeff0_8*dmats1[8][14] + coeff0_9*dmats1[9][14] + coeff0_10*dmats1[10][14] + coeff0_11*dmats1[11][14] + coeff0_12*dmats1[12][14] + coeff0_13*dmats1[13][14] + coeff0_14*dmats1[14][14] + coeff0_15*dmats1[15][14] + coeff0_16*dmats1[16][14] + coeff0_17*dmats1[17][14] + coeff0_18*dmats1[18][14] + coeff0_19*dmats1[19][14] + coeff0_20*dmats1[20][14] + coeff0_21*dmats1[21][14] + coeff0_22*dmats1[22][14] + coeff0_23*dmats1[23][14] + coeff0_24*dmats1[24][14] + coeff0_25*dmats1[25][14] + coeff0_26*dmats1[26][14] + coeff0_27*dmats1[27][14] + coeff0_28*dmats1[28][14] + coeff0_29*dmats1[29][14] + coeff0_30*dmats1[30][14] + coeff0_31*dmats1[31][14] + coeff0_32*dmats1[32][14] + coeff0_33*dmats1[33][14] + coeff0_34*dmats1[34][14] + coeff0_35*dmats1[35][14] + coeff0_36*dmats1[36][14] + coeff0_37*dmats1[37][14] + coeff0_38*dmats1[38][14] + coeff0_39*dmats1[39][14] + coeff0_40*dmats1[40][14] + coeff0_41*dmats1[41][14] + coeff0_42*dmats1[42][14] + coeff0_43*dmats1[43][14] + coeff0_44*dmats1[44][14] + coeff0_45*dmats1[45][14] + coeff0_46*dmats1[46][14] + coeff0_47*dmats1[47][14] + coeff0_48*dmats1[48][14] + coeff0_49*dmats1[49][14] + coeff0_50*dmats1[50][14] + coeff0_51*dmats1[51][14] + coeff0_52*dmats1[52][14] + coeff0_53*dmats1[53][14] + coeff0_54*dmats1[54][14] + coeff0_55*dmats1[55][14];
          new_coeff0_15 = coeff0_0*dmats1[0][15] + coeff0_1*dmats1[1][15] + coeff0_2*dmats1[2][15] + coeff0_3*dmats1[3][15] + coeff0_4*dmats1[4][15] + coeff0_5*dmats1[5][15] + coeff0_6*dmats1[6][15] + coeff0_7*dmats1[7][15] + coeff0_8*dmats1[8][15] + coeff0_9*dmats1[9][15] + coeff0_10*dmats1[10][15] + coeff0_11*dmats1[11][15] + coeff0_12*dmats1[12][15] + coeff0_13*dmats1[13][15] + coeff0_14*dmats1[14][15] + coeff0_15*dmats1[15][15] + coeff0_16*dmats1[16][15] + coeff0_17*dmats1[17][15] + coeff0_18*dmats1[18][15] + coeff0_19*dmats1[19][15] + coeff0_20*dmats1[20][15] + coeff0_21*dmats1[21][15] + coeff0_22*dmats1[22][15] + coeff0_23*dmats1[23][15] + coeff0_24*dmats1[24][15] + coeff0_25*dmats1[25][15] + coeff0_26*dmats1[26][15] + coeff0_27*dmats1[27][15] + coeff0_28*dmats1[28][15] + coeff0_29*dmats1[29][15] + coeff0_30*dmats1[30][15] + coeff0_31*dmats1[31][15] + coeff0_32*dmats1[32][15] + coeff0_33*dmats1[33][15] + coeff0_34*dmats1[34][15] + coeff0_35*dmats1[35][15] + coeff0_36*dmats1[36][15] + coeff0_37*dmats1[37][15] + coeff0_38*dmats1[38][15] + coeff0_39*dmats1[39][15] + coeff0_40*dmats1[40][15] + coeff0_41*dmats1[41][15] + coeff0_42*dmats1[42][15] + coeff0_43*dmats1[43][15] + coeff0_44*dmats1[44][15] + coeff0_45*dmats1[45][15] + coeff0_46*dmats1[46][15] + coeff0_47*dmats1[47][15] + coeff0_48*dmats1[48][15] + coeff0_49*dmats1[49][15] + coeff0_50*dmats1[50][15] + coeff0_51*dmats1[51][15] + coeff0_52*dmats1[52][15] + coeff0_53*dmats1[53][15] + coeff0_54*dmats1[54][15] + coeff0_55*dmats1[55][15];
          new_coeff0_16 = coeff0_0*dmats1[0][16] + coeff0_1*dmats1[1][16] + coeff0_2*dmats1[2][16] + coeff0_3*dmats1[3][16] + coeff0_4*dmats1[4][16] + coeff0_5*dmats1[5][16] + coeff0_6*dmats1[6][16] + coeff0_7*dmats1[7][16] + coeff0_8*dmats1[8][16] + coeff0_9*dmats1[9][16] + coeff0_10*dmats1[10][16] + coeff0_11*dmats1[11][16] + coeff0_12*dmats1[12][16] + coeff0_13*dmats1[13][16] + coeff0_14*dmats1[14][16] + coeff0_15*dmats1[15][16] + coeff0_16*dmats1[16][16] + coeff0_17*dmats1[17][16] + coeff0_18*dmats1[18][16] + coeff0_19*dmats1[19][16] + coeff0_20*dmats1[20][16] + coeff0_21*dmats1[21][16] + coeff0_22*dmats1[22][16] + coeff0_23*dmats1[23][16] + coeff0_24*dmats1[24][16] + coeff0_25*dmats1[25][16] + coeff0_26*dmats1[26][16] + coeff0_27*dmats1[27][16] + coeff0_28*dmats1[28][16] + coeff0_29*dmats1[29][16] + coeff0_30*dmats1[30][16] + coeff0_31*dmats1[31][16] + coeff0_32*dmats1[32][16] + coeff0_33*dmats1[33][16] + coeff0_34*dmats1[34][16] + coeff0_35*dmats1[35][16] + coeff0_36*dmats1[36][16] + coeff0_37*dmats1[37][16] + coeff0_38*dmats1[38][16] + coeff0_39*dmats1[39][16] + coeff0_40*dmats1[40][16] + coeff0_41*dmats1[41][16] + coeff0_42*dmats1[42][16] + coeff0_43*dmats1[43][16] + coeff0_44*dmats1[44][16] + coeff0_45*dmats1[45][16] + coeff0_46*dmats1[46][16] + coeff0_47*dmats1[47][16] + coeff0_48*dmats1[48][16] + coeff0_49*dmats1[49][16] + coeff0_50*dmats1[50][16] + coeff0_51*dmats1[51][16] + coeff0_52*dmats1[52][16] + coeff0_53*dmats1[53][16] + coeff0_54*dmats1[54][16] + coeff0_55*dmats1[55][16];
          new_coeff0_17 = coeff0_0*dmats1[0][17] + coeff0_1*dmats1[1][17] + coeff0_2*dmats1[2][17] + coeff0_3*dmats1[3][17] + coeff0_4*dmats1[4][17] + coeff0_5*dmats1[5][17] + coeff0_6*dmats1[6][17] + coeff0_7*dmats1[7][17] + coeff0_8*dmats1[8][17] + coeff0_9*dmats1[9][17] + coeff0_10*dmats1[10][17] + coeff0_11*dmats1[11][17] + coeff0_12*dmats1[12][17] + coeff0_13*dmats1[13][17] + coeff0_14*dmats1[14][17] + coeff0_15*dmats1[15][17] + coeff0_16*dmats1[16][17] + coeff0_17*dmats1[17][17] + coeff0_18*dmats1[18][17] + coeff0_19*dmats1[19][17] + coeff0_20*dmats1[20][17] + coeff0_21*dmats1[21][17] + coeff0_22*dmats1[22][17] + coeff0_23*dmats1[23][17] + coeff0_24*dmats1[24][17] + coeff0_25*dmats1[25][17] + coeff0_26*dmats1[26][17] + coeff0_27*dmats1[27][17] + coeff0_28*dmats1[28][17] + coeff0_29*dmats1[29][17] + coeff0_30*dmats1[30][17] + coeff0_31*dmats1[31][17] + coeff0_32*dmats1[32][17] + coeff0_33*dmats1[33][17] + coeff0_34*dmats1[34][17] + coeff0_35*dmats1[35][17] + coeff0_36*dmats1[36][17] + coeff0_37*dmats1[37][17] + coeff0_38*dmats1[38][17] + coeff0_39*dmats1[39][17] + coeff0_40*dmats1[40][17] + coeff0_41*dmats1[41][17] + coeff0_42*dmats1[42][17] + coeff0_43*dmats1[43][17] + coeff0_44*dmats1[44][17] + coeff0_45*dmats1[45][17] + coeff0_46*dmats1[46][17] + coeff0_47*dmats1[47][17] + coeff0_48*dmats1[48][17] + coeff0_49*dmats1[49][17] + coeff0_50*dmats1[50][17] + coeff0_51*dmats1[51][17] + coeff0_52*dmats1[52][17] + coeff0_53*dmats1[53][17] + coeff0_54*dmats1[54][17] + coeff0_55*dmats1[55][17];
          new_coeff0_18 = coeff0_0*dmats1[0][18] + coeff0_1*dmats1[1][18] + coeff0_2*dmats1[2][18] + coeff0_3*dmats1[3][18] + coeff0_4*dmats1[4][18] + coeff0_5*dmats1[5][18] + coeff0_6*dmats1[6][18] + coeff0_7*dmats1[7][18] + coeff0_8*dmats1[8][18] + coeff0_9*dmats1[9][18] + coeff0_10*dmats1[10][18] + coeff0_11*dmats1[11][18] + coeff0_12*dmats1[12][18] + coeff0_13*dmats1[13][18] + coeff0_14*dmats1[14][18] + coeff0_15*dmats1[15][18] + coeff0_16*dmats1[16][18] + coeff0_17*dmats1[17][18] + coeff0_18*dmats1[18][18] + coeff0_19*dmats1[19][18] + coeff0_20*dmats1[20][18] + coeff0_21*dmats1[21][18] + coeff0_22*dmats1[22][18] + coeff0_23*dmats1[23][18] + coeff0_24*dmats1[24][18] + coeff0_25*dmats1[25][18] + coeff0_26*dmats1[26][18] + coeff0_27*dmats1[27][18] + coeff0_28*dmats1[28][18] + coeff0_29*dmats1[29][18] + coeff0_30*dmats1[30][18] + coeff0_31*dmats1[31][18] + coeff0_32*dmats1[32][18] + coeff0_33*dmats1[33][18] + coeff0_34*dmats1[34][18] + coeff0_35*dmats1[35][18] + coeff0_36*dmats1[36][18] + coeff0_37*dmats1[37][18] + coeff0_38*dmats1[38][18] + coeff0_39*dmats1[39][18] + coeff0_40*dmats1[40][18] + coeff0_41*dmats1[41][18] + coeff0_42*dmats1[42][18] + coeff0_43*dmats1[43][18] + coeff0_44*dmats1[44][18] + coeff0_45*dmats1[45][18] + coeff0_46*dmats1[46][18] + coeff0_47*dmats1[47][18] + coeff0_48*dmats1[48][18] + coeff0_49*dmats1[49][18] + coeff0_50*dmats1[50][18] + coeff0_51*dmats1[51][18] + coeff0_52*dmats1[52][18] + coeff0_53*dmats1[53][18] + coeff0_54*dmats1[54][18] + coeff0_55*dmats1[55][18];
          new_coeff0_19 = coeff0_0*dmats1[0][19] + coeff0_1*dmats1[1][19] + coeff0_2*dmats1[2][19] + coeff0_3*dmats1[3][19] + coeff0_4*dmats1[4][19] + coeff0_5*dmats1[5][19] + coeff0_6*dmats1[6][19] + coeff0_7*dmats1[7][19] + coeff0_8*dmats1[8][19] + coeff0_9*dmats1[9][19] + coeff0_10*dmats1[10][19] + coeff0_11*dmats1[11][19] + coeff0_12*dmats1[12][19] + coeff0_13*dmats1[13][19] + coeff0_14*dmats1[14][19] + coeff0_15*dmats1[15][19] + coeff0_16*dmats1[16][19] + coeff0_17*dmats1[17][19] + coeff0_18*dmats1[18][19] + coeff0_19*dmats1[19][19] + coeff0_20*dmats1[20][19] + coeff0_21*dmats1[21][19] + coeff0_22*dmats1[22][19] + coeff0_23*dmats1[23][19] + coeff0_24*dmats1[24][19] + coeff0_25*dmats1[25][19] + coeff0_26*dmats1[26][19] + coeff0_27*dmats1[27][19] + coeff0_28*dmats1[28][19] + coeff0_29*dmats1[29][19] + coeff0_30*dmats1[30][19] + coeff0_31*dmats1[31][19] + coeff0_32*dmats1[32][19] + coeff0_33*dmats1[33][19] + coeff0_34*dmats1[34][19] + coeff0_35*dmats1[35][19] + coeff0_36*dmats1[36][19] + coeff0_37*dmats1[37][19] + coeff0_38*dmats1[38][19] + coeff0_39*dmats1[39][19] + coeff0_40*dmats1[40][19] + coeff0_41*dmats1[41][19] + coeff0_42*dmats1[42][19] + coeff0_43*dmats1[43][19] + coeff0_44*dmats1[44][19] + coeff0_45*dmats1[45][19] + coeff0_46*dmats1[46][19] + coeff0_47*dmats1[47][19] + coeff0_48*dmats1[48][19] + coeff0_49*dmats1[49][19] + coeff0_50*dmats1[50][19] + coeff0_51*dmats1[51][19] + coeff0_52*dmats1[52][19] + coeff0_53*dmats1[53][19] + coeff0_54*dmats1[54][19] + coeff0_55*dmats1[55][19];
          new_coeff0_20 = coeff0_0*dmats1[0][20] + coeff0_1*dmats1[1][20] + coeff0_2*dmats1[2][20] + coeff0_3*dmats1[3][20] + coeff0_4*dmats1[4][20] + coeff0_5*dmats1[5][20] + coeff0_6*dmats1[6][20] + coeff0_7*dmats1[7][20] + coeff0_8*dmats1[8][20] + coeff0_9*dmats1[9][20] + coeff0_10*dmats1[10][20] + coeff0_11*dmats1[11][20] + coeff0_12*dmats1[12][20] + coeff0_13*dmats1[13][20] + coeff0_14*dmats1[14][20] + coeff0_15*dmats1[15][20] + coeff0_16*dmats1[16][20] + coeff0_17*dmats1[17][20] + coeff0_18*dmats1[18][20] + coeff0_19*dmats1[19][20] + coeff0_20*dmats1[20][20] + coeff0_21*dmats1[21][20] + coeff0_22*dmats1[22][20] + coeff0_23*dmats1[23][20] + coeff0_24*dmats1[24][20] + coeff0_25*dmats1[25][20] + coeff0_26*dmats1[26][20] + coeff0_27*dmats1[27][20] + coeff0_28*dmats1[28][20] + coeff0_29*dmats1[29][20] + coeff0_30*dmats1[30][20] + coeff0_31*dmats1[31][20] + coeff0_32*dmats1[32][20] + coeff0_33*dmats1[33][20] + coeff0_34*dmats1[34][20] + coeff0_35*dmats1[35][20] + coeff0_36*dmats1[36][20] + coeff0_37*dmats1[37][20] + coeff0_38*dmats1[38][20] + coeff0_39*dmats1[39][20] + coeff0_40*dmats1[40][20] + coeff0_41*dmats1[41][20] + coeff0_42*dmats1[42][20] + coeff0_43*dmats1[43][20] + coeff0_44*dmats1[44][20] + coeff0_45*dmats1[45][20] + coeff0_46*dmats1[46][20] + coeff0_47*dmats1[47][20] + coeff0_48*dmats1[48][20] + coeff0_49*dmats1[49][20] + coeff0_50*dmats1[50][20] + coeff0_51*dmats1[51][20] + coeff0_52*dmats1[52][20] + coeff0_53*dmats1[53][20] + coeff0_54*dmats1[54][20] + coeff0_55*dmats1[55][20];
          new_coeff0_21 = coeff0_0*dmats1[0][21] + coeff0_1*dmats1[1][21] + coeff0_2*dmats1[2][21] + coeff0_3*dmats1[3][21] + coeff0_4*dmats1[4][21] + coeff0_5*dmats1[5][21] + coeff0_6*dmats1[6][21] + coeff0_7*dmats1[7][21] + coeff0_8*dmats1[8][21] + coeff0_9*dmats1[9][21] + coeff0_10*dmats1[10][21] + coeff0_11*dmats1[11][21] + coeff0_12*dmats1[12][21] + coeff0_13*dmats1[13][21] + coeff0_14*dmats1[14][21] + coeff0_15*dmats1[15][21] + coeff0_16*dmats1[16][21] + coeff0_17*dmats1[17][21] + coeff0_18*dmats1[18][21] + coeff0_19*dmats1[19][21] + coeff0_20*dmats1[20][21] + coeff0_21*dmats1[21][21] + coeff0_22*dmats1[22][21] + coeff0_23*dmats1[23][21] + coeff0_24*dmats1[24][21] + coeff0_25*dmats1[25][21] + coeff0_26*dmats1[26][21] + coeff0_27*dmats1[27][21] + coeff0_28*dmats1[28][21] + coeff0_29*dmats1[29][21] + coeff0_30*dmats1[30][21] + coeff0_31*dmats1[31][21] + coeff0_32*dmats1[32][21] + coeff0_33*dmats1[33][21] + coeff0_34*dmats1[34][21] + coeff0_35*dmats1[35][21] + coeff0_36*dmats1[36][21] + coeff0_37*dmats1[37][21] + coeff0_38*dmats1[38][21] + coeff0_39*dmats1[39][21] + coeff0_40*dmats1[40][21] + coeff0_41*dmats1[41][21] + coeff0_42*dmats1[42][21] + coeff0_43*dmats1[43][21] + coeff0_44*dmats1[44][21] + coeff0_45*dmats1[45][21] + coeff0_46*dmats1[46][21] + coeff0_47*dmats1[47][21] + coeff0_48*dmats1[48][21] + coeff0_49*dmats1[49][21] + coeff0_50*dmats1[50][21] + coeff0_51*dmats1[51][21] + coeff0_52*dmats1[52][21] + coeff0_53*dmats1[53][21] + coeff0_54*dmats1[54][21] + coeff0_55*dmats1[55][21];
          new_coeff0_22 = coeff0_0*dmats1[0][22] + coeff0_1*dmats1[1][22] + coeff0_2*dmats1[2][22] + coeff0_3*dmats1[3][22] + coeff0_4*dmats1[4][22] + coeff0_5*dmats1[5][22] + coeff0_6*dmats1[6][22] + coeff0_7*dmats1[7][22] + coeff0_8*dmats1[8][22] + coeff0_9*dmats1[9][22] + coeff0_10*dmats1[10][22] + coeff0_11*dmats1[11][22] + coeff0_12*dmats1[12][22] + coeff0_13*dmats1[13][22] + coeff0_14*dmats1[14][22] + coeff0_15*dmats1[15][22] + coeff0_16*dmats1[16][22] + coeff0_17*dmats1[17][22] + coeff0_18*dmats1[18][22] + coeff0_19*dmats1[19][22] + coeff0_20*dmats1[20][22] + coeff0_21*dmats1[21][22] + coeff0_22*dmats1[22][22] + coeff0_23*dmats1[23][22] + coeff0_24*dmats1[24][22] + coeff0_25*dmats1[25][22] + coeff0_26*dmats1[26][22] + coeff0_27*dmats1[27][22] + coeff0_28*dmats1[28][22] + coeff0_29*dmats1[29][22] + coeff0_30*dmats1[30][22] + coeff0_31*dmats1[31][22] + coeff0_32*dmats1[32][22] + coeff0_33*dmats1[33][22] + coeff0_34*dmats1[34][22] + coeff0_35*dmats1[35][22] + coeff0_36*dmats1[36][22] + coeff0_37*dmats1[37][22] + coeff0_38*dmats1[38][22] + coeff0_39*dmats1[39][22] + coeff0_40*dmats1[40][22] + coeff0_41*dmats1[41][22] + coeff0_42*dmats1[42][22] + coeff0_43*dmats1[43][22] + coeff0_44*dmats1[44][22] + coeff0_45*dmats1[45][22] + coeff0_46*dmats1[46][22] + coeff0_47*dmats1[47][22] + coeff0_48*dmats1[48][22] + coeff0_49*dmats1[49][22] + coeff0_50*dmats1[50][22] + coeff0_51*dmats1[51][22] + coeff0_52*dmats1[52][22] + coeff0_53*dmats1[53][22] + coeff0_54*dmats1[54][22] + coeff0_55*dmats1[55][22];
          new_coeff0_23 = coeff0_0*dmats1[0][23] + coeff0_1*dmats1[1][23] + coeff0_2*dmats1[2][23] + coeff0_3*dmats1[3][23] + coeff0_4*dmats1[4][23] + coeff0_5*dmats1[5][23] + coeff0_6*dmats1[6][23] + coeff0_7*dmats1[7][23] + coeff0_8*dmats1[8][23] + coeff0_9*dmats1[9][23] + coeff0_10*dmats1[10][23] + coeff0_11*dmats1[11][23] + coeff0_12*dmats1[12][23] + coeff0_13*dmats1[13][23] + coeff0_14*dmats1[14][23] + coeff0_15*dmats1[15][23] + coeff0_16*dmats1[16][23] + coeff0_17*dmats1[17][23] + coeff0_18*dmats1[18][23] + coeff0_19*dmats1[19][23] + coeff0_20*dmats1[20][23] + coeff0_21*dmats1[21][23] + coeff0_22*dmats1[22][23] + coeff0_23*dmats1[23][23] + coeff0_24*dmats1[24][23] + coeff0_25*dmats1[25][23] + coeff0_26*dmats1[26][23] + coeff0_27*dmats1[27][23] + coeff0_28*dmats1[28][23] + coeff0_29*dmats1[29][23] + coeff0_30*dmats1[30][23] + coeff0_31*dmats1[31][23] + coeff0_32*dmats1[32][23] + coeff0_33*dmats1[33][23] + coeff0_34*dmats1[34][23] + coeff0_35*dmats1[35][23] + coeff0_36*dmats1[36][23] + coeff0_37*dmats1[37][23] + coeff0_38*dmats1[38][23] + coeff0_39*dmats1[39][23] + coeff0_40*dmats1[40][23] + coeff0_41*dmats1[41][23] + coeff0_42*dmats1[42][23] + coeff0_43*dmats1[43][23] + coeff0_44*dmats1[44][23] + coeff0_45*dmats1[45][23] + coeff0_46*dmats1[46][23] + coeff0_47*dmats1[47][23] + coeff0_48*dmats1[48][23] + coeff0_49*dmats1[49][23] + coeff0_50*dmats1[50][23] + coeff0_51*dmats1[51][23] + coeff0_52*dmats1[52][23] + coeff0_53*dmats1[53][23] + coeff0_54*dmats1[54][23] + coeff0_55*dmats1[55][23];
          new_coeff0_24 = coeff0_0*dmats1[0][24] + coeff0_1*dmats1[1][24] + coeff0_2*dmats1[2][24] + coeff0_3*dmats1[3][24] + coeff0_4*dmats1[4][24] + coeff0_5*dmats1[5][24] + coeff0_6*dmats1[6][24] + coeff0_7*dmats1[7][24] + coeff0_8*dmats1[8][24] + coeff0_9*dmats1[9][24] + coeff0_10*dmats1[10][24] + coeff0_11*dmats1[11][24] + coeff0_12*dmats1[12][24] + coeff0_13*dmats1[13][24] + coeff0_14*dmats1[14][24] + coeff0_15*dmats1[15][24] + coeff0_16*dmats1[16][24] + coeff0_17*dmats1[17][24] + coeff0_18*dmats1[18][24] + coeff0_19*dmats1[19][24] + coeff0_20*dmats1[20][24] + coeff0_21*dmats1[21][24] + coeff0_22*dmats1[22][24] + coeff0_23*dmats1[23][24] + coeff0_24*dmats1[24][24] + coeff0_25*dmats1[25][24] + coeff0_26*dmats1[26][24] + coeff0_27*dmats1[27][24] + coeff0_28*dmats1[28][24] + coeff0_29*dmats1[29][24] + coeff0_30*dmats1[30][24] + coeff0_31*dmats1[31][24] + coeff0_32*dmats1[32][24] + coeff0_33*dmats1[33][24] + coeff0_34*dmats1[34][24] + coeff0_35*dmats1[35][24] + coeff0_36*dmats1[36][24] + coeff0_37*dmats1[37][24] + coeff0_38*dmats1[38][24] + coeff0_39*dmats1[39][24] + coeff0_40*dmats1[40][24] + coeff0_41*dmats1[41][24] + coeff0_42*dmats1[42][24] + coeff0_43*dmats1[43][24] + coeff0_44*dmats1[44][24] + coeff0_45*dmats1[45][24] + coeff0_46*dmats1[46][24] + coeff0_47*dmats1[47][24] + coeff0_48*dmats1[48][24] + coeff0_49*dmats1[49][24] + coeff0_50*dmats1[50][24] + coeff0_51*dmats1[51][24] + coeff0_52*dmats1[52][24] + coeff0_53*dmats1[53][24] + coeff0_54*dmats1[54][24] + coeff0_55*dmats1[55][24];
          new_coeff0_25 = coeff0_0*dmats1[0][25] + coeff0_1*dmats1[1][25] + coeff0_2*dmats1[2][25] + coeff0_3*dmats1[3][25] + coeff0_4*dmats1[4][25] + coeff0_5*dmats1[5][25] + coeff0_6*dmats1[6][25] + coeff0_7*dmats1[7][25] + coeff0_8*dmats1[8][25] + coeff0_9*dmats1[9][25] + coeff0_10*dmats1[10][25] + coeff0_11*dmats1[11][25] + coeff0_12*dmats1[12][25] + coeff0_13*dmats1[13][25] + coeff0_14*dmats1[14][25] + coeff0_15*dmats1[15][25] + coeff0_16*dmats1[16][25] + coeff0_17*dmats1[17][25] + coeff0_18*dmats1[18][25] + coeff0_19*dmats1[19][25] + coeff0_20*dmats1[20][25] + coeff0_21*dmats1[21][25] + coeff0_22*dmats1[22][25] + coeff0_23*dmats1[23][25] + coeff0_24*dmats1[24][25] + coeff0_25*dmats1[25][25] + coeff0_26*dmats1[26][25] + coeff0_27*dmats1[27][25] + coeff0_28*dmats1[28][25] + coeff0_29*dmats1[29][25] + coeff0_30*dmats1[30][25] + coeff0_31*dmats1[31][25] + coeff0_32*dmats1[32][25] + coeff0_33*dmats1[33][25] + coeff0_34*dmats1[34][25] + coeff0_35*dmats1[35][25] + coeff0_36*dmats1[36][25] + coeff0_37*dmats1[37][25] + coeff0_38*dmats1[38][25] + coeff0_39*dmats1[39][25] + coeff0_40*dmats1[40][25] + coeff0_41*dmats1[41][25] + coeff0_42*dmats1[42][25] + coeff0_43*dmats1[43][25] + coeff0_44*dmats1[44][25] + coeff0_45*dmats1[45][25] + coeff0_46*dmats1[46][25] + coeff0_47*dmats1[47][25] + coeff0_48*dmats1[48][25] + coeff0_49*dmats1[49][25] + coeff0_50*dmats1[50][25] + coeff0_51*dmats1[51][25] + coeff0_52*dmats1[52][25] + coeff0_53*dmats1[53][25] + coeff0_54*dmats1[54][25] + coeff0_55*dmats1[55][25];
          new_coeff0_26 = coeff0_0*dmats1[0][26] + coeff0_1*dmats1[1][26] + coeff0_2*dmats1[2][26] + coeff0_3*dmats1[3][26] + coeff0_4*dmats1[4][26] + coeff0_5*dmats1[5][26] + coeff0_6*dmats1[6][26] + coeff0_7*dmats1[7][26] + coeff0_8*dmats1[8][26] + coeff0_9*dmats1[9][26] + coeff0_10*dmats1[10][26] + coeff0_11*dmats1[11][26] + coeff0_12*dmats1[12][26] + coeff0_13*dmats1[13][26] + coeff0_14*dmats1[14][26] + coeff0_15*dmats1[15][26] + coeff0_16*dmats1[16][26] + coeff0_17*dmats1[17][26] + coeff0_18*dmats1[18][26] + coeff0_19*dmats1[19][26] + coeff0_20*dmats1[20][26] + coeff0_21*dmats1[21][26] + coeff0_22*dmats1[22][26] + coeff0_23*dmats1[23][26] + coeff0_24*dmats1[24][26] + coeff0_25*dmats1[25][26] + coeff0_26*dmats1[26][26] + coeff0_27*dmats1[27][26] + coeff0_28*dmats1[28][26] + coeff0_29*dmats1[29][26] + coeff0_30*dmats1[30][26] + coeff0_31*dmats1[31][26] + coeff0_32*dmats1[32][26] + coeff0_33*dmats1[33][26] + coeff0_34*dmats1[34][26] + coeff0_35*dmats1[35][26] + coeff0_36*dmats1[36][26] + coeff0_37*dmats1[37][26] + coeff0_38*dmats1[38][26] + coeff0_39*dmats1[39][26] + coeff0_40*dmats1[40][26] + coeff0_41*dmats1[41][26] + coeff0_42*dmats1[42][26] + coeff0_43*dmats1[43][26] + coeff0_44*dmats1[44][26] + coeff0_45*dmats1[45][26] + coeff0_46*dmats1[46][26] + coeff0_47*dmats1[47][26] + coeff0_48*dmats1[48][26] + coeff0_49*dmats1[49][26] + coeff0_50*dmats1[50][26] + coeff0_51*dmats1[51][26] + coeff0_52*dmats1[52][26] + coeff0_53*dmats1[53][26] + coeff0_54*dmats1[54][26] + coeff0_55*dmats1[55][26];
          new_coeff0_27 = coeff0_0*dmats1[0][27] + coeff0_1*dmats1[1][27] + coeff0_2*dmats1[2][27] + coeff0_3*dmats1[3][27] + coeff0_4*dmats1[4][27] + coeff0_5*dmats1[5][27] + coeff0_6*dmats1[6][27] + coeff0_7*dmats1[7][27] + coeff0_8*dmats1[8][27] + coeff0_9*dmats1[9][27] + coeff0_10*dmats1[10][27] + coeff0_11*dmats1[11][27] + coeff0_12*dmats1[12][27] + coeff0_13*dmats1[13][27] + coeff0_14*dmats1[14][27] + coeff0_15*dmats1[15][27] + coeff0_16*dmats1[16][27] + coeff0_17*dmats1[17][27] + coeff0_18*dmats1[18][27] + coeff0_19*dmats1[19][27] + coeff0_20*dmats1[20][27] + coeff0_21*dmats1[21][27] + coeff0_22*dmats1[22][27] + coeff0_23*dmats1[23][27] + coeff0_24*dmats1[24][27] + coeff0_25*dmats1[25][27] + coeff0_26*dmats1[26][27] + coeff0_27*dmats1[27][27] + coeff0_28*dmats1[28][27] + coeff0_29*dmats1[29][27] + coeff0_30*dmats1[30][27] + coeff0_31*dmats1[31][27] + coeff0_32*dmats1[32][27] + coeff0_33*dmats1[33][27] + coeff0_34*dmats1[34][27] + coeff0_35*dmats1[35][27] + coeff0_36*dmats1[36][27] + coeff0_37*dmats1[37][27] + coeff0_38*dmats1[38][27] + coeff0_39*dmats1[39][27] + coeff0_40*dmats1[40][27] + coeff0_41*dmats1[41][27] + coeff0_42*dmats1[42][27] + coeff0_43*dmats1[43][27] + coeff0_44*dmats1[44][27] + coeff0_45*dmats1[45][27] + coeff0_46*dmats1[46][27] + coeff0_47*dmats1[47][27] + coeff0_48*dmats1[48][27] + coeff0_49*dmats1[49][27] + coeff0_50*dmats1[50][27] + coeff0_51*dmats1[51][27] + coeff0_52*dmats1[52][27] + coeff0_53*dmats1[53][27] + coeff0_54*dmats1[54][27] + coeff0_55*dmats1[55][27];
          new_coeff0_28 = coeff0_0*dmats1[0][28] + coeff0_1*dmats1[1][28] + coeff0_2*dmats1[2][28] + coeff0_3*dmats1[3][28] + coeff0_4*dmats1[4][28] + coeff0_5*dmats1[5][28] + coeff0_6*dmats1[6][28] + coeff0_7*dmats1[7][28] + coeff0_8*dmats1[8][28] + coeff0_9*dmats1[9][28] + coeff0_10*dmats1[10][28] + coeff0_11*dmats1[11][28] + coeff0_12*dmats1[12][28] + coeff0_13*dmats1[13][28] + coeff0_14*dmats1[14][28] + coeff0_15*dmats1[15][28] + coeff0_16*dmats1[16][28] + coeff0_17*dmats1[17][28] + coeff0_18*dmats1[18][28] + coeff0_19*dmats1[19][28] + coeff0_20*dmats1[20][28] + coeff0_21*dmats1[21][28] + coeff0_22*dmats1[22][28] + coeff0_23*dmats1[23][28] + coeff0_24*dmats1[24][28] + coeff0_25*dmats1[25][28] + coeff0_26*dmats1[26][28] + coeff0_27*dmats1[27][28] + coeff0_28*dmats1[28][28] + coeff0_29*dmats1[29][28] + coeff0_30*dmats1[30][28] + coeff0_31*dmats1[31][28] + coeff0_32*dmats1[32][28] + coeff0_33*dmats1[33][28] + coeff0_34*dmats1[34][28] + coeff0_35*dmats1[35][28] + coeff0_36*dmats1[36][28] + coeff0_37*dmats1[37][28] + coeff0_38*dmats1[38][28] + coeff0_39*dmats1[39][28] + coeff0_40*dmats1[40][28] + coeff0_41*dmats1[41][28] + coeff0_42*dmats1[42][28] + coeff0_43*dmats1[43][28] + coeff0_44*dmats1[44][28] + coeff0_45*dmats1[45][28] + coeff0_46*dmats1[46][28] + coeff0_47*dmats1[47][28] + coeff0_48*dmats1[48][28] + coeff0_49*dmats1[49][28] + coeff0_50*dmats1[50][28] + coeff0_51*dmats1[51][28] + coeff0_52*dmats1[52][28] + coeff0_53*dmats1[53][28] + coeff0_54*dmats1[54][28] + coeff0_55*dmats1[55][28];
          new_coeff0_29 = coeff0_0*dmats1[0][29] + coeff0_1*dmats1[1][29] + coeff0_2*dmats1[2][29] + coeff0_3*dmats1[3][29] + coeff0_4*dmats1[4][29] + coeff0_5*dmats1[5][29] + coeff0_6*dmats1[6][29] + coeff0_7*dmats1[7][29] + coeff0_8*dmats1[8][29] + coeff0_9*dmats1[9][29] + coeff0_10*dmats1[10][29] + coeff0_11*dmats1[11][29] + coeff0_12*dmats1[12][29] + coeff0_13*dmats1[13][29] + coeff0_14*dmats1[14][29] + coeff0_15*dmats1[15][29] + coeff0_16*dmats1[16][29] + coeff0_17*dmats1[17][29] + coeff0_18*dmats1[18][29] + coeff0_19*dmats1[19][29] + coeff0_20*dmats1[20][29] + coeff0_21*dmats1[21][29] + coeff0_22*dmats1[22][29] + coeff0_23*dmats1[23][29] + coeff0_24*dmats1[24][29] + coeff0_25*dmats1[25][29] + coeff0_26*dmats1[26][29] + coeff0_27*dmats1[27][29] + coeff0_28*dmats1[28][29] + coeff0_29*dmats1[29][29] + coeff0_30*dmats1[30][29] + coeff0_31*dmats1[31][29] + coeff0_32*dmats1[32][29] + coeff0_33*dmats1[33][29] + coeff0_34*dmats1[34][29] + coeff0_35*dmats1[35][29] + coeff0_36*dmats1[36][29] + coeff0_37*dmats1[37][29] + coeff0_38*dmats1[38][29] + coeff0_39*dmats1[39][29] + coeff0_40*dmats1[40][29] + coeff0_41*dmats1[41][29] + coeff0_42*dmats1[42][29] + coeff0_43*dmats1[43][29] + coeff0_44*dmats1[44][29] + coeff0_45*dmats1[45][29] + coeff0_46*dmats1[46][29] + coeff0_47*dmats1[47][29] + coeff0_48*dmats1[48][29] + coeff0_49*dmats1[49][29] + coeff0_50*dmats1[50][29] + coeff0_51*dmats1[51][29] + coeff0_52*dmats1[52][29] + coeff0_53*dmats1[53][29] + coeff0_54*dmats1[54][29] + coeff0_55*dmats1[55][29];
          new_coeff0_30 = coeff0_0*dmats1[0][30] + coeff0_1*dmats1[1][30] + coeff0_2*dmats1[2][30] + coeff0_3*dmats1[3][30] + coeff0_4*dmats1[4][30] + coeff0_5*dmats1[5][30] + coeff0_6*dmats1[6][30] + coeff0_7*dmats1[7][30] + coeff0_8*dmats1[8][30] + coeff0_9*dmats1[9][30] + coeff0_10*dmats1[10][30] + coeff0_11*dmats1[11][30] + coeff0_12*dmats1[12][30] + coeff0_13*dmats1[13][30] + coeff0_14*dmats1[14][30] + coeff0_15*dmats1[15][30] + coeff0_16*dmats1[16][30] + coeff0_17*dmats1[17][30] + coeff0_18*dmats1[18][30] + coeff0_19*dmats1[19][30] + coeff0_20*dmats1[20][30] + coeff0_21*dmats1[21][30] + coeff0_22*dmats1[22][30] + coeff0_23*dmats1[23][30] + coeff0_24*dmats1[24][30] + coeff0_25*dmats1[25][30] + coeff0_26*dmats1[26][30] + coeff0_27*dmats1[27][30] + coeff0_28*dmats1[28][30] + coeff0_29*dmats1[29][30] + coeff0_30*dmats1[30][30] + coeff0_31*dmats1[31][30] + coeff0_32*dmats1[32][30] + coeff0_33*dmats1[33][30] + coeff0_34*dmats1[34][30] + coeff0_35*dmats1[35][30] + coeff0_36*dmats1[36][30] + coeff0_37*dmats1[37][30] + coeff0_38*dmats1[38][30] + coeff0_39*dmats1[39][30] + coeff0_40*dmats1[40][30] + coeff0_41*dmats1[41][30] + coeff0_42*dmats1[42][30] + coeff0_43*dmats1[43][30] + coeff0_44*dmats1[44][30] + coeff0_45*dmats1[45][30] + coeff0_46*dmats1[46][30] + coeff0_47*dmats1[47][30] + coeff0_48*dmats1[48][30] + coeff0_49*dmats1[49][30] + coeff0_50*dmats1[50][30] + coeff0_51*dmats1[51][30] + coeff0_52*dmats1[52][30] + coeff0_53*dmats1[53][30] + coeff0_54*dmats1[54][30] + coeff0_55*dmats1[55][30];
          new_coeff0_31 = coeff0_0*dmats1[0][31] + coeff0_1*dmats1[1][31] + coeff0_2*dmats1[2][31] + coeff0_3*dmats1[3][31] + coeff0_4*dmats1[4][31] + coeff0_5*dmats1[5][31] + coeff0_6*dmats1[6][31] + coeff0_7*dmats1[7][31] + coeff0_8*dmats1[8][31] + coeff0_9*dmats1[9][31] + coeff0_10*dmats1[10][31] + coeff0_11*dmats1[11][31] + coeff0_12*dmats1[12][31] + coeff0_13*dmats1[13][31] + coeff0_14*dmats1[14][31] + coeff0_15*dmats1[15][31] + coeff0_16*dmats1[16][31] + coeff0_17*dmats1[17][31] + coeff0_18*dmats1[18][31] + coeff0_19*dmats1[19][31] + coeff0_20*dmats1[20][31] + coeff0_21*dmats1[21][31] + coeff0_22*dmats1[22][31] + coeff0_23*dmats1[23][31] + coeff0_24*dmats1[24][31] + coeff0_25*dmats1[25][31] + coeff0_26*dmats1[26][31] + coeff0_27*dmats1[27][31] + coeff0_28*dmats1[28][31] + coeff0_29*dmats1[29][31] + coeff0_30*dmats1[30][31] + coeff0_31*dmats1[31][31] + coeff0_32*dmats1[32][31] + coeff0_33*dmats1[33][31] + coeff0_34*dmats1[34][31] + coeff0_35*dmats1[35][31] + coeff0_36*dmats1[36][31] + coeff0_37*dmats1[37][31] + coeff0_38*dmats1[38][31] + coeff0_39*dmats1[39][31] + coeff0_40*dmats1[40][31] + coeff0_41*dmats1[41][31] + coeff0_42*dmats1[42][31] + coeff0_43*dmats1[43][31] + coeff0_44*dmats1[44][31] + coeff0_45*dmats1[45][31] + coeff0_46*dmats1[46][31] + coeff0_47*dmats1[47][31] + coeff0_48*dmats1[48][31] + coeff0_49*dmats1[49][31] + coeff0_50*dmats1[50][31] + coeff0_51*dmats1[51][31] + coeff0_52*dmats1[52][31] + coeff0_53*dmats1[53][31] + coeff0_54*dmats1[54][31] + coeff0_55*dmats1[55][31];
          new_coeff0_32 = coeff0_0*dmats1[0][32] + coeff0_1*dmats1[1][32] + coeff0_2*dmats1[2][32] + coeff0_3*dmats1[3][32] + coeff0_4*dmats1[4][32] + coeff0_5*dmats1[5][32] + coeff0_6*dmats1[6][32] + coeff0_7*dmats1[7][32] + coeff0_8*dmats1[8][32] + coeff0_9*dmats1[9][32] + coeff0_10*dmats1[10][32] + coeff0_11*dmats1[11][32] + coeff0_12*dmats1[12][32] + coeff0_13*dmats1[13][32] + coeff0_14*dmats1[14][32] + coeff0_15*dmats1[15][32] + coeff0_16*dmats1[16][32] + coeff0_17*dmats1[17][32] + coeff0_18*dmats1[18][32] + coeff0_19*dmats1[19][32] + coeff0_20*dmats1[20][32] + coeff0_21*dmats1[21][32] + coeff0_22*dmats1[22][32] + coeff0_23*dmats1[23][32] + coeff0_24*dmats1[24][32] + coeff0_25*dmats1[25][32] + coeff0_26*dmats1[26][32] + coeff0_27*dmats1[27][32] + coeff0_28*dmats1[28][32] + coeff0_29*dmats1[29][32] + coeff0_30*dmats1[30][32] + coeff0_31*dmats1[31][32] + coeff0_32*dmats1[32][32] + coeff0_33*dmats1[33][32] + coeff0_34*dmats1[34][32] + coeff0_35*dmats1[35][32] + coeff0_36*dmats1[36][32] + coeff0_37*dmats1[37][32] + coeff0_38*dmats1[38][32] + coeff0_39*dmats1[39][32] + coeff0_40*dmats1[40][32] + coeff0_41*dmats1[41][32] + coeff0_42*dmats1[42][32] + coeff0_43*dmats1[43][32] + coeff0_44*dmats1[44][32] + coeff0_45*dmats1[45][32] + coeff0_46*dmats1[46][32] + coeff0_47*dmats1[47][32] + coeff0_48*dmats1[48][32] + coeff0_49*dmats1[49][32] + coeff0_50*dmats1[50][32] + coeff0_51*dmats1[51][32] + coeff0_52*dmats1[52][32] + coeff0_53*dmats1[53][32] + coeff0_54*dmats1[54][32] + coeff0_55*dmats1[55][32];
          new_coeff0_33 = coeff0_0*dmats1[0][33] + coeff0_1*dmats1[1][33] + coeff0_2*dmats1[2][33] + coeff0_3*dmats1[3][33] + coeff0_4*dmats1[4][33] + coeff0_5*dmats1[5][33] + coeff0_6*dmats1[6][33] + coeff0_7*dmats1[7][33] + coeff0_8*dmats1[8][33] + coeff0_9*dmats1[9][33] + coeff0_10*dmats1[10][33] + coeff0_11*dmats1[11][33] + coeff0_12*dmats1[12][33] + coeff0_13*dmats1[13][33] + coeff0_14*dmats1[14][33] + coeff0_15*dmats1[15][33] + coeff0_16*dmats1[16][33] + coeff0_17*dmats1[17][33] + coeff0_18*dmats1[18][33] + coeff0_19*dmats1[19][33] + coeff0_20*dmats1[20][33] + coeff0_21*dmats1[21][33] + coeff0_22*dmats1[22][33] + coeff0_23*dmats1[23][33] + coeff0_24*dmats1[24][33] + coeff0_25*dmats1[25][33] + coeff0_26*dmats1[26][33] + coeff0_27*dmats1[27][33] + coeff0_28*dmats1[28][33] + coeff0_29*dmats1[29][33] + coeff0_30*dmats1[30][33] + coeff0_31*dmats1[31][33] + coeff0_32*dmats1[32][33] + coeff0_33*dmats1[33][33] + coeff0_34*dmats1[34][33] + coeff0_35*dmats1[35][33] + coeff0_36*dmats1[36][33] + coeff0_37*dmats1[37][33] + coeff0_38*dmats1[38][33] + coeff0_39*dmats1[39][33] + coeff0_40*dmats1[40][33] + coeff0_41*dmats1[41][33] + coeff0_42*dmats1[42][33] + coeff0_43*dmats1[43][33] + coeff0_44*dmats1[44][33] + coeff0_45*dmats1[45][33] + coeff0_46*dmats1[46][33] + coeff0_47*dmats1[47][33] + coeff0_48*dmats1[48][33] + coeff0_49*dmats1[49][33] + coeff0_50*dmats1[50][33] + coeff0_51*dmats1[51][33] + coeff0_52*dmats1[52][33] + coeff0_53*dmats1[53][33] + coeff0_54*dmats1[54][33] + coeff0_55*dmats1[55][33];
          new_coeff0_34 = coeff0_0*dmats1[0][34] + coeff0_1*dmats1[1][34] + coeff0_2*dmats1[2][34] + coeff0_3*dmats1[3][34] + coeff0_4*dmats1[4][34] + coeff0_5*dmats1[5][34] + coeff0_6*dmats1[6][34] + coeff0_7*dmats1[7][34] + coeff0_8*dmats1[8][34] + coeff0_9*dmats1[9][34] + coeff0_10*dmats1[10][34] + coeff0_11*dmats1[11][34] + coeff0_12*dmats1[12][34] + coeff0_13*dmats1[13][34] + coeff0_14*dmats1[14][34] + coeff0_15*dmats1[15][34] + coeff0_16*dmats1[16][34] + coeff0_17*dmats1[17][34] + coeff0_18*dmats1[18][34] + coeff0_19*dmats1[19][34] + coeff0_20*dmats1[20][34] + coeff0_21*dmats1[21][34] + coeff0_22*dmats1[22][34] + coeff0_23*dmats1[23][34] + coeff0_24*dmats1[24][34] + coeff0_25*dmats1[25][34] + coeff0_26*dmats1[26][34] + coeff0_27*dmats1[27][34] + coeff0_28*dmats1[28][34] + coeff0_29*dmats1[29][34] + coeff0_30*dmats1[30][34] + coeff0_31*dmats1[31][34] + coeff0_32*dmats1[32][34] + coeff0_33*dmats1[33][34] + coeff0_34*dmats1[34][34] + coeff0_35*dmats1[35][34] + coeff0_36*dmats1[36][34] + coeff0_37*dmats1[37][34] + coeff0_38*dmats1[38][34] + coeff0_39*dmats1[39][34] + coeff0_40*dmats1[40][34] + coeff0_41*dmats1[41][34] + coeff0_42*dmats1[42][34] + coeff0_43*dmats1[43][34] + coeff0_44*dmats1[44][34] + coeff0_45*dmats1[45][34] + coeff0_46*dmats1[46][34] + coeff0_47*dmats1[47][34] + coeff0_48*dmats1[48][34] + coeff0_49*dmats1[49][34] + coeff0_50*dmats1[50][34] + coeff0_51*dmats1[51][34] + coeff0_52*dmats1[52][34] + coeff0_53*dmats1[53][34] + coeff0_54*dmats1[54][34] + coeff0_55*dmats1[55][34];
          new_coeff0_35 = coeff0_0*dmats1[0][35] + coeff0_1*dmats1[1][35] + coeff0_2*dmats1[2][35] + coeff0_3*dmats1[3][35] + coeff0_4*dmats1[4][35] + coeff0_5*dmats1[5][35] + coeff0_6*dmats1[6][35] + coeff0_7*dmats1[7][35] + coeff0_8*dmats1[8][35] + coeff0_9*dmats1[9][35] + coeff0_10*dmats1[10][35] + coeff0_11*dmats1[11][35] + coeff0_12*dmats1[12][35] + coeff0_13*dmats1[13][35] + coeff0_14*dmats1[14][35] + coeff0_15*dmats1[15][35] + coeff0_16*dmats1[16][35] + coeff0_17*dmats1[17][35] + coeff0_18*dmats1[18][35] + coeff0_19*dmats1[19][35] + coeff0_20*dmats1[20][35] + coeff0_21*dmats1[21][35] + coeff0_22*dmats1[22][35] + coeff0_23*dmats1[23][35] + coeff0_24*dmats1[24][35] + coeff0_25*dmats1[25][35] + coeff0_26*dmats1[26][35] + coeff0_27*dmats1[27][35] + coeff0_28*dmats1[28][35] + coeff0_29*dmats1[29][35] + coeff0_30*dmats1[30][35] + coeff0_31*dmats1[31][35] + coeff0_32*dmats1[32][35] + coeff0_33*dmats1[33][35] + coeff0_34*dmats1[34][35] + coeff0_35*dmats1[35][35] + coeff0_36*dmats1[36][35] + coeff0_37*dmats1[37][35] + coeff0_38*dmats1[38][35] + coeff0_39*dmats1[39][35] + coeff0_40*dmats1[40][35] + coeff0_41*dmats1[41][35] + coeff0_42*dmats1[42][35] + coeff0_43*dmats1[43][35] + coeff0_44*dmats1[44][35] + coeff0_45*dmats1[45][35] + coeff0_46*dmats1[46][35] + coeff0_47*dmats1[47][35] + coeff0_48*dmats1[48][35] + coeff0_49*dmats1[49][35] + coeff0_50*dmats1[50][35] + coeff0_51*dmats1[51][35] + coeff0_52*dmats1[52][35] + coeff0_53*dmats1[53][35] + coeff0_54*dmats1[54][35] + coeff0_55*dmats1[55][35];
          new_coeff0_36 = coeff0_0*dmats1[0][36] + coeff0_1*dmats1[1][36] + coeff0_2*dmats1[2][36] + coeff0_3*dmats1[3][36] + coeff0_4*dmats1[4][36] + coeff0_5*dmats1[5][36] + coeff0_6*dmats1[6][36] + coeff0_7*dmats1[7][36] + coeff0_8*dmats1[8][36] + coeff0_9*dmats1[9][36] + coeff0_10*dmats1[10][36] + coeff0_11*dmats1[11][36] + coeff0_12*dmats1[12][36] + coeff0_13*dmats1[13][36] + coeff0_14*dmats1[14][36] + coeff0_15*dmats1[15][36] + coeff0_16*dmats1[16][36] + coeff0_17*dmats1[17][36] + coeff0_18*dmats1[18][36] + coeff0_19*dmats1[19][36] + coeff0_20*dmats1[20][36] + coeff0_21*dmats1[21][36] + coeff0_22*dmats1[22][36] + coeff0_23*dmats1[23][36] + coeff0_24*dmats1[24][36] + coeff0_25*dmats1[25][36] + coeff0_26*dmats1[26][36] + coeff0_27*dmats1[27][36] + coeff0_28*dmats1[28][36] + coeff0_29*dmats1[29][36] + coeff0_30*dmats1[30][36] + coeff0_31*dmats1[31][36] + coeff0_32*dmats1[32][36] + coeff0_33*dmats1[33][36] + coeff0_34*dmats1[34][36] + coeff0_35*dmats1[35][36] + coeff0_36*dmats1[36][36] + coeff0_37*dmats1[37][36] + coeff0_38*dmats1[38][36] + coeff0_39*dmats1[39][36] + coeff0_40*dmats1[40][36] + coeff0_41*dmats1[41][36] + coeff0_42*dmats1[42][36] + coeff0_43*dmats1[43][36] + coeff0_44*dmats1[44][36] + coeff0_45*dmats1[45][36] + coeff0_46*dmats1[46][36] + coeff0_47*dmats1[47][36] + coeff0_48*dmats1[48][36] + coeff0_49*dmats1[49][36] + coeff0_50*dmats1[50][36] + coeff0_51*dmats1[51][36] + coeff0_52*dmats1[52][36] + coeff0_53*dmats1[53][36] + coeff0_54*dmats1[54][36] + coeff0_55*dmats1[55][36];
          new_coeff0_37 = coeff0_0*dmats1[0][37] + coeff0_1*dmats1[1][37] + coeff0_2*dmats1[2][37] + coeff0_3*dmats1[3][37] + coeff0_4*dmats1[4][37] + coeff0_5*dmats1[5][37] + coeff0_6*dmats1[6][37] + coeff0_7*dmats1[7][37] + coeff0_8*dmats1[8][37] + coeff0_9*dmats1[9][37] + coeff0_10*dmats1[10][37] + coeff0_11*dmats1[11][37] + coeff0_12*dmats1[12][37] + coeff0_13*dmats1[13][37] + coeff0_14*dmats1[14][37] + coeff0_15*dmats1[15][37] + coeff0_16*dmats1[16][37] + coeff0_17*dmats1[17][37] + coeff0_18*dmats1[18][37] + coeff0_19*dmats1[19][37] + coeff0_20*dmats1[20][37] + coeff0_21*dmats1[21][37] + coeff0_22*dmats1[22][37] + coeff0_23*dmats1[23][37] + coeff0_24*dmats1[24][37] + coeff0_25*dmats1[25][37] + coeff0_26*dmats1[26][37] + coeff0_27*dmats1[27][37] + coeff0_28*dmats1[28][37] + coeff0_29*dmats1[29][37] + coeff0_30*dmats1[30][37] + coeff0_31*dmats1[31][37] + coeff0_32*dmats1[32][37] + coeff0_33*dmats1[33][37] + coeff0_34*dmats1[34][37] + coeff0_35*dmats1[35][37] + coeff0_36*dmats1[36][37] + coeff0_37*dmats1[37][37] + coeff0_38*dmats1[38][37] + coeff0_39*dmats1[39][37] + coeff0_40*dmats1[40][37] + coeff0_41*dmats1[41][37] + coeff0_42*dmats1[42][37] + coeff0_43*dmats1[43][37] + coeff0_44*dmats1[44][37] + coeff0_45*dmats1[45][37] + coeff0_46*dmats1[46][37] + coeff0_47*dmats1[47][37] + coeff0_48*dmats1[48][37] + coeff0_49*dmats1[49][37] + coeff0_50*dmats1[50][37] + coeff0_51*dmats1[51][37] + coeff0_52*dmats1[52][37] + coeff0_53*dmats1[53][37] + coeff0_54*dmats1[54][37] + coeff0_55*dmats1[55][37];
          new_coeff0_38 = coeff0_0*dmats1[0][38] + coeff0_1*dmats1[1][38] + coeff0_2*dmats1[2][38] + coeff0_3*dmats1[3][38] + coeff0_4*dmats1[4][38] + coeff0_5*dmats1[5][38] + coeff0_6*dmats1[6][38] + coeff0_7*dmats1[7][38] + coeff0_8*dmats1[8][38] + coeff0_9*dmats1[9][38] + coeff0_10*dmats1[10][38] + coeff0_11*dmats1[11][38] + coeff0_12*dmats1[12][38] + coeff0_13*dmats1[13][38] + coeff0_14*dmats1[14][38] + coeff0_15*dmats1[15][38] + coeff0_16*dmats1[16][38] + coeff0_17*dmats1[17][38] + coeff0_18*dmats1[18][38] + coeff0_19*dmats1[19][38] + coeff0_20*dmats1[20][38] + coeff0_21*dmats1[21][38] + coeff0_22*dmats1[22][38] + coeff0_23*dmats1[23][38] + coeff0_24*dmats1[24][38] + coeff0_25*dmats1[25][38] + coeff0_26*dmats1[26][38] + coeff0_27*dmats1[27][38] + coeff0_28*dmats1[28][38] + coeff0_29*dmats1[29][38] + coeff0_30*dmats1[30][38] + coeff0_31*dmats1[31][38] + coeff0_32*dmats1[32][38] + coeff0_33*dmats1[33][38] + coeff0_34*dmats1[34][38] + coeff0_35*dmats1[35][38] + coeff0_36*dmats1[36][38] + coeff0_37*dmats1[37][38] + coeff0_38*dmats1[38][38] + coeff0_39*dmats1[39][38] + coeff0_40*dmats1[40][38] + coeff0_41*dmats1[41][38] + coeff0_42*dmats1[42][38] + coeff0_43*dmats1[43][38] + coeff0_44*dmats1[44][38] + coeff0_45*dmats1[45][38] + coeff0_46*dmats1[46][38] + coeff0_47*dmats1[47][38] + coeff0_48*dmats1[48][38] + coeff0_49*dmats1[49][38] + coeff0_50*dmats1[50][38] + coeff0_51*dmats1[51][38] + coeff0_52*dmats1[52][38] + coeff0_53*dmats1[53][38] + coeff0_54*dmats1[54][38] + coeff0_55*dmats1[55][38];
          new_coeff0_39 = coeff0_0*dmats1[0][39] + coeff0_1*dmats1[1][39] + coeff0_2*dmats1[2][39] + coeff0_3*dmats1[3][39] + coeff0_4*dmats1[4][39] + coeff0_5*dmats1[5][39] + coeff0_6*dmats1[6][39] + coeff0_7*dmats1[7][39] + coeff0_8*dmats1[8][39] + coeff0_9*dmats1[9][39] + coeff0_10*dmats1[10][39] + coeff0_11*dmats1[11][39] + coeff0_12*dmats1[12][39] + coeff0_13*dmats1[13][39] + coeff0_14*dmats1[14][39] + coeff0_15*dmats1[15][39] + coeff0_16*dmats1[16][39] + coeff0_17*dmats1[17][39] + coeff0_18*dmats1[18][39] + coeff0_19*dmats1[19][39] + coeff0_20*dmats1[20][39] + coeff0_21*dmats1[21][39] + coeff0_22*dmats1[22][39] + coeff0_23*dmats1[23][39] + coeff0_24*dmats1[24][39] + coeff0_25*dmats1[25][39] + coeff0_26*dmats1[26][39] + coeff0_27*dmats1[27][39] + coeff0_28*dmats1[28][39] + coeff0_29*dmats1[29][39] + coeff0_30*dmats1[30][39] + coeff0_31*dmats1[31][39] + coeff0_32*dmats1[32][39] + coeff0_33*dmats1[33][39] + coeff0_34*dmats1[34][39] + coeff0_35*dmats1[35][39] + coeff0_36*dmats1[36][39] + coeff0_37*dmats1[37][39] + coeff0_38*dmats1[38][39] + coeff0_39*dmats1[39][39] + coeff0_40*dmats1[40][39] + coeff0_41*dmats1[41][39] + coeff0_42*dmats1[42][39] + coeff0_43*dmats1[43][39] + coeff0_44*dmats1[44][39] + coeff0_45*dmats1[45][39] + coeff0_46*dmats1[46][39] + coeff0_47*dmats1[47][39] + coeff0_48*dmats1[48][39] + coeff0_49*dmats1[49][39] + coeff0_50*dmats1[50][39] + coeff0_51*dmats1[51][39] + coeff0_52*dmats1[52][39] + coeff0_53*dmats1[53][39] + coeff0_54*dmats1[54][39] + coeff0_55*dmats1[55][39];
          new_coeff0_40 = coeff0_0*dmats1[0][40] + coeff0_1*dmats1[1][40] + coeff0_2*dmats1[2][40] + coeff0_3*dmats1[3][40] + coeff0_4*dmats1[4][40] + coeff0_5*dmats1[5][40] + coeff0_6*dmats1[6][40] + coeff0_7*dmats1[7][40] + coeff0_8*dmats1[8][40] + coeff0_9*dmats1[9][40] + coeff0_10*dmats1[10][40] + coeff0_11*dmats1[11][40] + coeff0_12*dmats1[12][40] + coeff0_13*dmats1[13][40] + coeff0_14*dmats1[14][40] + coeff0_15*dmats1[15][40] + coeff0_16*dmats1[16][40] + coeff0_17*dmats1[17][40] + coeff0_18*dmats1[18][40] + coeff0_19*dmats1[19][40] + coeff0_20*dmats1[20][40] + coeff0_21*dmats1[21][40] + coeff0_22*dmats1[22][40] + coeff0_23*dmats1[23][40] + coeff0_24*dmats1[24][40] + coeff0_25*dmats1[25][40] + coeff0_26*dmats1[26][40] + coeff0_27*dmats1[27][40] + coeff0_28*dmats1[28][40] + coeff0_29*dmats1[29][40] + coeff0_30*dmats1[30][40] + coeff0_31*dmats1[31][40] + coeff0_32*dmats1[32][40] + coeff0_33*dmats1[33][40] + coeff0_34*dmats1[34][40] + coeff0_35*dmats1[35][40] + coeff0_36*dmats1[36][40] + coeff0_37*dmats1[37][40] + coeff0_38*dmats1[38][40] + coeff0_39*dmats1[39][40] + coeff0_40*dmats1[40][40] + coeff0_41*dmats1[41][40] + coeff0_42*dmats1[42][40] + coeff0_43*dmats1[43][40] + coeff0_44*dmats1[44][40] + coeff0_45*dmats1[45][40] + coeff0_46*dmats1[46][40] + coeff0_47*dmats1[47][40] + coeff0_48*dmats1[48][40] + coeff0_49*dmats1[49][40] + coeff0_50*dmats1[50][40] + coeff0_51*dmats1[51][40] + coeff0_52*dmats1[52][40] + coeff0_53*dmats1[53][40] + coeff0_54*dmats1[54][40] + coeff0_55*dmats1[55][40];
          new_coeff0_41 = coeff0_0*dmats1[0][41] + coeff0_1*dmats1[1][41] + coeff0_2*dmats1[2][41] + coeff0_3*dmats1[3][41] + coeff0_4*dmats1[4][41] + coeff0_5*dmats1[5][41] + coeff0_6*dmats1[6][41] + coeff0_7*dmats1[7][41] + coeff0_8*dmats1[8][41] + coeff0_9*dmats1[9][41] + coeff0_10*dmats1[10][41] + coeff0_11*dmats1[11][41] + coeff0_12*dmats1[12][41] + coeff0_13*dmats1[13][41] + coeff0_14*dmats1[14][41] + coeff0_15*dmats1[15][41] + coeff0_16*dmats1[16][41] + coeff0_17*dmats1[17][41] + coeff0_18*dmats1[18][41] + coeff0_19*dmats1[19][41] + coeff0_20*dmats1[20][41] + coeff0_21*dmats1[21][41] + coeff0_22*dmats1[22][41] + coeff0_23*dmats1[23][41] + coeff0_24*dmats1[24][41] + coeff0_25*dmats1[25][41] + coeff0_26*dmats1[26][41] + coeff0_27*dmats1[27][41] + coeff0_28*dmats1[28][41] + coeff0_29*dmats1[29][41] + coeff0_30*dmats1[30][41] + coeff0_31*dmats1[31][41] + coeff0_32*dmats1[32][41] + coeff0_33*dmats1[33][41] + coeff0_34*dmats1[34][41] + coeff0_35*dmats1[35][41] + coeff0_36*dmats1[36][41] + coeff0_37*dmats1[37][41] + coeff0_38*dmats1[38][41] + coeff0_39*dmats1[39][41] + coeff0_40*dmats1[40][41] + coeff0_41*dmats1[41][41] + coeff0_42*dmats1[42][41] + coeff0_43*dmats1[43][41] + coeff0_44*dmats1[44][41] + coeff0_45*dmats1[45][41] + coeff0_46*dmats1[46][41] + coeff0_47*dmats1[47][41] + coeff0_48*dmats1[48][41] + coeff0_49*dmats1[49][41] + coeff0_50*dmats1[50][41] + coeff0_51*dmats1[51][41] + coeff0_52*dmats1[52][41] + coeff0_53*dmats1[53][41] + coeff0_54*dmats1[54][41] + coeff0_55*dmats1[55][41];
          new_coeff0_42 = coeff0_0*dmats1[0][42] + coeff0_1*dmats1[1][42] + coeff0_2*dmats1[2][42] + coeff0_3*dmats1[3][42] + coeff0_4*dmats1[4][42] + coeff0_5*dmats1[5][42] + coeff0_6*dmats1[6][42] + coeff0_7*dmats1[7][42] + coeff0_8*dmats1[8][42] + coeff0_9*dmats1[9][42] + coeff0_10*dmats1[10][42] + coeff0_11*dmats1[11][42] + coeff0_12*dmats1[12][42] + coeff0_13*dmats1[13][42] + coeff0_14*dmats1[14][42] + coeff0_15*dmats1[15][42] + coeff0_16*dmats1[16][42] + coeff0_17*dmats1[17][42] + coeff0_18*dmats1[18][42] + coeff0_19*dmats1[19][42] + coeff0_20*dmats1[20][42] + coeff0_21*dmats1[21][42] + coeff0_22*dmats1[22][42] + coeff0_23*dmats1[23][42] + coeff0_24*dmats1[24][42] + coeff0_25*dmats1[25][42] + coeff0_26*dmats1[26][42] + coeff0_27*dmats1[27][42] + coeff0_28*dmats1[28][42] + coeff0_29*dmats1[29][42] + coeff0_30*dmats1[30][42] + coeff0_31*dmats1[31][42] + coeff0_32*dmats1[32][42] + coeff0_33*dmats1[33][42] + coeff0_34*dmats1[34][42] + coeff0_35*dmats1[35][42] + coeff0_36*dmats1[36][42] + coeff0_37*dmats1[37][42] + coeff0_38*dmats1[38][42] + coeff0_39*dmats1[39][42] + coeff0_40*dmats1[40][42] + coeff0_41*dmats1[41][42] + coeff0_42*dmats1[42][42] + coeff0_43*dmats1[43][42] + coeff0_44*dmats1[44][42] + coeff0_45*dmats1[45][42] + coeff0_46*dmats1[46][42] + coeff0_47*dmats1[47][42] + coeff0_48*dmats1[48][42] + coeff0_49*dmats1[49][42] + coeff0_50*dmats1[50][42] + coeff0_51*dmats1[51][42] + coeff0_52*dmats1[52][42] + coeff0_53*dmats1[53][42] + coeff0_54*dmats1[54][42] + coeff0_55*dmats1[55][42];
          new_coeff0_43 = coeff0_0*dmats1[0][43] + coeff0_1*dmats1[1][43] + coeff0_2*dmats1[2][43] + coeff0_3*dmats1[3][43] + coeff0_4*dmats1[4][43] + coeff0_5*dmats1[5][43] + coeff0_6*dmats1[6][43] + coeff0_7*dmats1[7][43] + coeff0_8*dmats1[8][43] + coeff0_9*dmats1[9][43] + coeff0_10*dmats1[10][43] + coeff0_11*dmats1[11][43] + coeff0_12*dmats1[12][43] + coeff0_13*dmats1[13][43] + coeff0_14*dmats1[14][43] + coeff0_15*dmats1[15][43] + coeff0_16*dmats1[16][43] + coeff0_17*dmats1[17][43] + coeff0_18*dmats1[18][43] + coeff0_19*dmats1[19][43] + coeff0_20*dmats1[20][43] + coeff0_21*dmats1[21][43] + coeff0_22*dmats1[22][43] + coeff0_23*dmats1[23][43] + coeff0_24*dmats1[24][43] + coeff0_25*dmats1[25][43] + coeff0_26*dmats1[26][43] + coeff0_27*dmats1[27][43] + coeff0_28*dmats1[28][43] + coeff0_29*dmats1[29][43] + coeff0_30*dmats1[30][43] + coeff0_31*dmats1[31][43] + coeff0_32*dmats1[32][43] + coeff0_33*dmats1[33][43] + coeff0_34*dmats1[34][43] + coeff0_35*dmats1[35][43] + coeff0_36*dmats1[36][43] + coeff0_37*dmats1[37][43] + coeff0_38*dmats1[38][43] + coeff0_39*dmats1[39][43] + coeff0_40*dmats1[40][43] + coeff0_41*dmats1[41][43] + coeff0_42*dmats1[42][43] + coeff0_43*dmats1[43][43] + coeff0_44*dmats1[44][43] + coeff0_45*dmats1[45][43] + coeff0_46*dmats1[46][43] + coeff0_47*dmats1[47][43] + coeff0_48*dmats1[48][43] + coeff0_49*dmats1[49][43] + coeff0_50*dmats1[50][43] + coeff0_51*dmats1[51][43] + coeff0_52*dmats1[52][43] + coeff0_53*dmats1[53][43] + coeff0_54*dmats1[54][43] + coeff0_55*dmats1[55][43];
          new_coeff0_44 = coeff0_0*dmats1[0][44] + coeff0_1*dmats1[1][44] + coeff0_2*dmats1[2][44] + coeff0_3*dmats1[3][44] + coeff0_4*dmats1[4][44] + coeff0_5*dmats1[5][44] + coeff0_6*dmats1[6][44] + coeff0_7*dmats1[7][44] + coeff0_8*dmats1[8][44] + coeff0_9*dmats1[9][44] + coeff0_10*dmats1[10][44] + coeff0_11*dmats1[11][44] + coeff0_12*dmats1[12][44] + coeff0_13*dmats1[13][44] + coeff0_14*dmats1[14][44] + coeff0_15*dmats1[15][44] + coeff0_16*dmats1[16][44] + coeff0_17*dmats1[17][44] + coeff0_18*dmats1[18][44] + coeff0_19*dmats1[19][44] + coeff0_20*dmats1[20][44] + coeff0_21*dmats1[21][44] + coeff0_22*dmats1[22][44] + coeff0_23*dmats1[23][44] + coeff0_24*dmats1[24][44] + coeff0_25*dmats1[25][44] + coeff0_26*dmats1[26][44] + coeff0_27*dmats1[27][44] + coeff0_28*dmats1[28][44] + coeff0_29*dmats1[29][44] + coeff0_30*dmats1[30][44] + coeff0_31*dmats1[31][44] + coeff0_32*dmats1[32][44] + coeff0_33*dmats1[33][44] + coeff0_34*dmats1[34][44] + coeff0_35*dmats1[35][44] + coeff0_36*dmats1[36][44] + coeff0_37*dmats1[37][44] + coeff0_38*dmats1[38][44] + coeff0_39*dmats1[39][44] + coeff0_40*dmats1[40][44] + coeff0_41*dmats1[41][44] + coeff0_42*dmats1[42][44] + coeff0_43*dmats1[43][44] + coeff0_44*dmats1[44][44] + coeff0_45*dmats1[45][44] + coeff0_46*dmats1[46][44] + coeff0_47*dmats1[47][44] + coeff0_48*dmats1[48][44] + coeff0_49*dmats1[49][44] + coeff0_50*dmats1[50][44] + coeff0_51*dmats1[51][44] + coeff0_52*dmats1[52][44] + coeff0_53*dmats1[53][44] + coeff0_54*dmats1[54][44] + coeff0_55*dmats1[55][44];
          new_coeff0_45 = coeff0_0*dmats1[0][45] + coeff0_1*dmats1[1][45] + coeff0_2*dmats1[2][45] + coeff0_3*dmats1[3][45] + coeff0_4*dmats1[4][45] + coeff0_5*dmats1[5][45] + coeff0_6*dmats1[6][45] + coeff0_7*dmats1[7][45] + coeff0_8*dmats1[8][45] + coeff0_9*dmats1[9][45] + coeff0_10*dmats1[10][45] + coeff0_11*dmats1[11][45] + coeff0_12*dmats1[12][45] + coeff0_13*dmats1[13][45] + coeff0_14*dmats1[14][45] + coeff0_15*dmats1[15][45] + coeff0_16*dmats1[16][45] + coeff0_17*dmats1[17][45] + coeff0_18*dmats1[18][45] + coeff0_19*dmats1[19][45] + coeff0_20*dmats1[20][45] + coeff0_21*dmats1[21][45] + coeff0_22*dmats1[22][45] + coeff0_23*dmats1[23][45] + coeff0_24*dmats1[24][45] + coeff0_25*dmats1[25][45] + coeff0_26*dmats1[26][45] + coeff0_27*dmats1[27][45] + coeff0_28*dmats1[28][45] + coeff0_29*dmats1[29][45] + coeff0_30*dmats1[30][45] + coeff0_31*dmats1[31][45] + coeff0_32*dmats1[32][45] + coeff0_33*dmats1[33][45] + coeff0_34*dmats1[34][45] + coeff0_35*dmats1[35][45] + coeff0_36*dmats1[36][45] + coeff0_37*dmats1[37][45] + coeff0_38*dmats1[38][45] + coeff0_39*dmats1[39][45] + coeff0_40*dmats1[40][45] + coeff0_41*dmats1[41][45] + coeff0_42*dmats1[42][45] + coeff0_43*dmats1[43][45] + coeff0_44*dmats1[44][45] + coeff0_45*dmats1[45][45] + coeff0_46*dmats1[46][45] + coeff0_47*dmats1[47][45] + coeff0_48*dmats1[48][45] + coeff0_49*dmats1[49][45] + coeff0_50*dmats1[50][45] + coeff0_51*dmats1[51][45] + coeff0_52*dmats1[52][45] + coeff0_53*dmats1[53][45] + coeff0_54*dmats1[54][45] + coeff0_55*dmats1[55][45];
          new_coeff0_46 = coeff0_0*dmats1[0][46] + coeff0_1*dmats1[1][46] + coeff0_2*dmats1[2][46] + coeff0_3*dmats1[3][46] + coeff0_4*dmats1[4][46] + coeff0_5*dmats1[5][46] + coeff0_6*dmats1[6][46] + coeff0_7*dmats1[7][46] + coeff0_8*dmats1[8][46] + coeff0_9*dmats1[9][46] + coeff0_10*dmats1[10][46] + coeff0_11*dmats1[11][46] + coeff0_12*dmats1[12][46] + coeff0_13*dmats1[13][46] + coeff0_14*dmats1[14][46] + coeff0_15*dmats1[15][46] + coeff0_16*dmats1[16][46] + coeff0_17*dmats1[17][46] + coeff0_18*dmats1[18][46] + coeff0_19*dmats1[19][46] + coeff0_20*dmats1[20][46] + coeff0_21*dmats1[21][46] + coeff0_22*dmats1[22][46] + coeff0_23*dmats1[23][46] + coeff0_24*dmats1[24][46] + coeff0_25*dmats1[25][46] + coeff0_26*dmats1[26][46] + coeff0_27*dmats1[27][46] + coeff0_28*dmats1[28][46] + coeff0_29*dmats1[29][46] + coeff0_30*dmats1[30][46] + coeff0_31*dmats1[31][46] + coeff0_32*dmats1[32][46] + coeff0_33*dmats1[33][46] + coeff0_34*dmats1[34][46] + coeff0_35*dmats1[35][46] + coeff0_36*dmats1[36][46] + coeff0_37*dmats1[37][46] + coeff0_38*dmats1[38][46] + coeff0_39*dmats1[39][46] + coeff0_40*dmats1[40][46] + coeff0_41*dmats1[41][46] + coeff0_42*dmats1[42][46] + coeff0_43*dmats1[43][46] + coeff0_44*dmats1[44][46] + coeff0_45*dmats1[45][46] + coeff0_46*dmats1[46][46] + coeff0_47*dmats1[47][46] + coeff0_48*dmats1[48][46] + coeff0_49*dmats1[49][46] + coeff0_50*dmats1[50][46] + coeff0_51*dmats1[51][46] + coeff0_52*dmats1[52][46] + coeff0_53*dmats1[53][46] + coeff0_54*dmats1[54][46] + coeff0_55*dmats1[55][46];
          new_coeff0_47 = coeff0_0*dmats1[0][47] + coeff0_1*dmats1[1][47] + coeff0_2*dmats1[2][47] + coeff0_3*dmats1[3][47] + coeff0_4*dmats1[4][47] + coeff0_5*dmats1[5][47] + coeff0_6*dmats1[6][47] + coeff0_7*dmats1[7][47] + coeff0_8*dmats1[8][47] + coeff0_9*dmats1[9][47] + coeff0_10*dmats1[10][47] + coeff0_11*dmats1[11][47] + coeff0_12*dmats1[12][47] + coeff0_13*dmats1[13][47] + coeff0_14*dmats1[14][47] + coeff0_15*dmats1[15][47] + coeff0_16*dmats1[16][47] + coeff0_17*dmats1[17][47] + coeff0_18*dmats1[18][47] + coeff0_19*dmats1[19][47] + coeff0_20*dmats1[20][47] + coeff0_21*dmats1[21][47] + coeff0_22*dmats1[22][47] + coeff0_23*dmats1[23][47] + coeff0_24*dmats1[24][47] + coeff0_25*dmats1[25][47] + coeff0_26*dmats1[26][47] + coeff0_27*dmats1[27][47] + coeff0_28*dmats1[28][47] + coeff0_29*dmats1[29][47] + coeff0_30*dmats1[30][47] + coeff0_31*dmats1[31][47] + coeff0_32*dmats1[32][47] + coeff0_33*dmats1[33][47] + coeff0_34*dmats1[34][47] + coeff0_35*dmats1[35][47] + coeff0_36*dmats1[36][47] + coeff0_37*dmats1[37][47] + coeff0_38*dmats1[38][47] + coeff0_39*dmats1[39][47] + coeff0_40*dmats1[40][47] + coeff0_41*dmats1[41][47] + coeff0_42*dmats1[42][47] + coeff0_43*dmats1[43][47] + coeff0_44*dmats1[44][47] + coeff0_45*dmats1[45][47] + coeff0_46*dmats1[46][47] + coeff0_47*dmats1[47][47] + coeff0_48*dmats1[48][47] + coeff0_49*dmats1[49][47] + coeff0_50*dmats1[50][47] + coeff0_51*dmats1[51][47] + coeff0_52*dmats1[52][47] + coeff0_53*dmats1[53][47] + coeff0_54*dmats1[54][47] + coeff0_55*dmats1[55][47];
          new_coeff0_48 = coeff0_0*dmats1[0][48] + coeff0_1*dmats1[1][48] + coeff0_2*dmats1[2][48] + coeff0_3*dmats1[3][48] + coeff0_4*dmats1[4][48] + coeff0_5*dmats1[5][48] + coeff0_6*dmats1[6][48] + coeff0_7*dmats1[7][48] + coeff0_8*dmats1[8][48] + coeff0_9*dmats1[9][48] + coeff0_10*dmats1[10][48] + coeff0_11*dmats1[11][48] + coeff0_12*dmats1[12][48] + coeff0_13*dmats1[13][48] + coeff0_14*dmats1[14][48] + coeff0_15*dmats1[15][48] + coeff0_16*dmats1[16][48] + coeff0_17*dmats1[17][48] + coeff0_18*dmats1[18][48] + coeff0_19*dmats1[19][48] + coeff0_20*dmats1[20][48] + coeff0_21*dmats1[21][48] + coeff0_22*dmats1[22][48] + coeff0_23*dmats1[23][48] + coeff0_24*dmats1[24][48] + coeff0_25*dmats1[25][48] + coeff0_26*dmats1[26][48] + coeff0_27*dmats1[27][48] + coeff0_28*dmats1[28][48] + coeff0_29*dmats1[29][48] + coeff0_30*dmats1[30][48] + coeff0_31*dmats1[31][48] + coeff0_32*dmats1[32][48] + coeff0_33*dmats1[33][48] + coeff0_34*dmats1[34][48] + coeff0_35*dmats1[35][48] + coeff0_36*dmats1[36][48] + coeff0_37*dmats1[37][48] + coeff0_38*dmats1[38][48] + coeff0_39*dmats1[39][48] + coeff0_40*dmats1[40][48] + coeff0_41*dmats1[41][48] + coeff0_42*dmats1[42][48] + coeff0_43*dmats1[43][48] + coeff0_44*dmats1[44][48] + coeff0_45*dmats1[45][48] + coeff0_46*dmats1[46][48] + coeff0_47*dmats1[47][48] + coeff0_48*dmats1[48][48] + coeff0_49*dmats1[49][48] + coeff0_50*dmats1[50][48] + coeff0_51*dmats1[51][48] + coeff0_52*dmats1[52][48] + coeff0_53*dmats1[53][48] + coeff0_54*dmats1[54][48] + coeff0_55*dmats1[55][48];
          new_coeff0_49 = coeff0_0*dmats1[0][49] + coeff0_1*dmats1[1][49] + coeff0_2*dmats1[2][49] + coeff0_3*dmats1[3][49] + coeff0_4*dmats1[4][49] + coeff0_5*dmats1[5][49] + coeff0_6*dmats1[6][49] + coeff0_7*dmats1[7][49] + coeff0_8*dmats1[8][49] + coeff0_9*dmats1[9][49] + coeff0_10*dmats1[10][49] + coeff0_11*dmats1[11][49] + coeff0_12*dmats1[12][49] + coeff0_13*dmats1[13][49] + coeff0_14*dmats1[14][49] + coeff0_15*dmats1[15][49] + coeff0_16*dmats1[16][49] + coeff0_17*dmats1[17][49] + coeff0_18*dmats1[18][49] + coeff0_19*dmats1[19][49] + coeff0_20*dmats1[20][49] + coeff0_21*dmats1[21][49] + coeff0_22*dmats1[22][49] + coeff0_23*dmats1[23][49] + coeff0_24*dmats1[24][49] + coeff0_25*dmats1[25][49] + coeff0_26*dmats1[26][49] + coeff0_27*dmats1[27][49] + coeff0_28*dmats1[28][49] + coeff0_29*dmats1[29][49] + coeff0_30*dmats1[30][49] + coeff0_31*dmats1[31][49] + coeff0_32*dmats1[32][49] + coeff0_33*dmats1[33][49] + coeff0_34*dmats1[34][49] + coeff0_35*dmats1[35][49] + coeff0_36*dmats1[36][49] + coeff0_37*dmats1[37][49] + coeff0_38*dmats1[38][49] + coeff0_39*dmats1[39][49] + coeff0_40*dmats1[40][49] + coeff0_41*dmats1[41][49] + coeff0_42*dmats1[42][49] + coeff0_43*dmats1[43][49] + coeff0_44*dmats1[44][49] + coeff0_45*dmats1[45][49] + coeff0_46*dmats1[46][49] + coeff0_47*dmats1[47][49] + coeff0_48*dmats1[48][49] + coeff0_49*dmats1[49][49] + coeff0_50*dmats1[50][49] + coeff0_51*dmats1[51][49] + coeff0_52*dmats1[52][49] + coeff0_53*dmats1[53][49] + coeff0_54*dmats1[54][49] + coeff0_55*dmats1[55][49];
          new_coeff0_50 = coeff0_0*dmats1[0][50] + coeff0_1*dmats1[1][50] + coeff0_2*dmats1[2][50] + coeff0_3*dmats1[3][50] + coeff0_4*dmats1[4][50] + coeff0_5*dmats1[5][50] + coeff0_6*dmats1[6][50] + coeff0_7*dmats1[7][50] + coeff0_8*dmats1[8][50] + coeff0_9*dmats1[9][50] + coeff0_10*dmats1[10][50] + coeff0_11*dmats1[11][50] + coeff0_12*dmats1[12][50] + coeff0_13*dmats1[13][50] + coeff0_14*dmats1[14][50] + coeff0_15*dmats1[15][50] + coeff0_16*dmats1[16][50] + coeff0_17*dmats1[17][50] + coeff0_18*dmats1[18][50] + coeff0_19*dmats1[19][50] + coeff0_20*dmats1[20][50] + coeff0_21*dmats1[21][50] + coeff0_22*dmats1[22][50] + coeff0_23*dmats1[23][50] + coeff0_24*dmats1[24][50] + coeff0_25*dmats1[25][50] + coeff0_26*dmats1[26][50] + coeff0_27*dmats1[27][50] + coeff0_28*dmats1[28][50] + coeff0_29*dmats1[29][50] + coeff0_30*dmats1[30][50] + coeff0_31*dmats1[31][50] + coeff0_32*dmats1[32][50] + coeff0_33*dmats1[33][50] + coeff0_34*dmats1[34][50] + coeff0_35*dmats1[35][50] + coeff0_36*dmats1[36][50] + coeff0_37*dmats1[37][50] + coeff0_38*dmats1[38][50] + coeff0_39*dmats1[39][50] + coeff0_40*dmats1[40][50] + coeff0_41*dmats1[41][50] + coeff0_42*dmats1[42][50] + coeff0_43*dmats1[43][50] + coeff0_44*dmats1[44][50] + coeff0_45*dmats1[45][50] + coeff0_46*dmats1[46][50] + coeff0_47*dmats1[47][50] + coeff0_48*dmats1[48][50] + coeff0_49*dmats1[49][50] + coeff0_50*dmats1[50][50] + coeff0_51*dmats1[51][50] + coeff0_52*dmats1[52][50] + coeff0_53*dmats1[53][50] + coeff0_54*dmats1[54][50] + coeff0_55*dmats1[55][50];
          new_coeff0_51 = coeff0_0*dmats1[0][51] + coeff0_1*dmats1[1][51] + coeff0_2*dmats1[2][51] + coeff0_3*dmats1[3][51] + coeff0_4*dmats1[4][51] + coeff0_5*dmats1[5][51] + coeff0_6*dmats1[6][51] + coeff0_7*dmats1[7][51] + coeff0_8*dmats1[8][51] + coeff0_9*dmats1[9][51] + coeff0_10*dmats1[10][51] + coeff0_11*dmats1[11][51] + coeff0_12*dmats1[12][51] + coeff0_13*dmats1[13][51] + coeff0_14*dmats1[14][51] + coeff0_15*dmats1[15][51] + coeff0_16*dmats1[16][51] + coeff0_17*dmats1[17][51] + coeff0_18*dmats1[18][51] + coeff0_19*dmats1[19][51] + coeff0_20*dmats1[20][51] + coeff0_21*dmats1[21][51] + coeff0_22*dmats1[22][51] + coeff0_23*dmats1[23][51] + coeff0_24*dmats1[24][51] + coeff0_25*dmats1[25][51] + coeff0_26*dmats1[26][51] + coeff0_27*dmats1[27][51] + coeff0_28*dmats1[28][51] + coeff0_29*dmats1[29][51] + coeff0_30*dmats1[30][51] + coeff0_31*dmats1[31][51] + coeff0_32*dmats1[32][51] + coeff0_33*dmats1[33][51] + coeff0_34*dmats1[34][51] + coeff0_35*dmats1[35][51] + coeff0_36*dmats1[36][51] + coeff0_37*dmats1[37][51] + coeff0_38*dmats1[38][51] + coeff0_39*dmats1[39][51] + coeff0_40*dmats1[40][51] + coeff0_41*dmats1[41][51] + coeff0_42*dmats1[42][51] + coeff0_43*dmats1[43][51] + coeff0_44*dmats1[44][51] + coeff0_45*dmats1[45][51] + coeff0_46*dmats1[46][51] + coeff0_47*dmats1[47][51] + coeff0_48*dmats1[48][51] + coeff0_49*dmats1[49][51] + coeff0_50*dmats1[50][51] + coeff0_51*dmats1[51][51] + coeff0_52*dmats1[52][51] + coeff0_53*dmats1[53][51] + coeff0_54*dmats1[54][51] + coeff0_55*dmats1[55][51];
          new_coeff0_52 = coeff0_0*dmats1[0][52] + coeff0_1*dmats1[1][52] + coeff0_2*dmats1[2][52] + coeff0_3*dmats1[3][52] + coeff0_4*dmats1[4][52] + coeff0_5*dmats1[5][52] + coeff0_6*dmats1[6][52] + coeff0_7*dmats1[7][52] + coeff0_8*dmats1[8][52] + coeff0_9*dmats1[9][52] + coeff0_10*dmats1[10][52] + coeff0_11*dmats1[11][52] + coeff0_12*dmats1[12][52] + coeff0_13*dmats1[13][52] + coeff0_14*dmats1[14][52] + coeff0_15*dmats1[15][52] + coeff0_16*dmats1[16][52] + coeff0_17*dmats1[17][52] + coeff0_18*dmats1[18][52] + coeff0_19*dmats1[19][52] + coeff0_20*dmats1[20][52] + coeff0_21*dmats1[21][52] + coeff0_22*dmats1[22][52] + coeff0_23*dmats1[23][52] + coeff0_24*dmats1[24][52] + coeff0_25*dmats1[25][52] + coeff0_26*dmats1[26][52] + coeff0_27*dmats1[27][52] + coeff0_28*dmats1[28][52] + coeff0_29*dmats1[29][52] + coeff0_30*dmats1[30][52] + coeff0_31*dmats1[31][52] + coeff0_32*dmats1[32][52] + coeff0_33*dmats1[33][52] + coeff0_34*dmats1[34][52] + coeff0_35*dmats1[35][52] + coeff0_36*dmats1[36][52] + coeff0_37*dmats1[37][52] + coeff0_38*dmats1[38][52] + coeff0_39*dmats1[39][52] + coeff0_40*dmats1[40][52] + coeff0_41*dmats1[41][52] + coeff0_42*dmats1[42][52] + coeff0_43*dmats1[43][52] + coeff0_44*dmats1[44][52] + coeff0_45*dmats1[45][52] + coeff0_46*dmats1[46][52] + coeff0_47*dmats1[47][52] + coeff0_48*dmats1[48][52] + coeff0_49*dmats1[49][52] + coeff0_50*dmats1[50][52] + coeff0_51*dmats1[51][52] + coeff0_52*dmats1[52][52] + coeff0_53*dmats1[53][52] + coeff0_54*dmats1[54][52] + coeff0_55*dmats1[55][52];
          new_coeff0_53 = coeff0_0*dmats1[0][53] + coeff0_1*dmats1[1][53] + coeff0_2*dmats1[2][53] + coeff0_3*dmats1[3][53] + coeff0_4*dmats1[4][53] + coeff0_5*dmats1[5][53] + coeff0_6*dmats1[6][53] + coeff0_7*dmats1[7][53] + coeff0_8*dmats1[8][53] + coeff0_9*dmats1[9][53] + coeff0_10*dmats1[10][53] + coeff0_11*dmats1[11][53] + coeff0_12*dmats1[12][53] + coeff0_13*dmats1[13][53] + coeff0_14*dmats1[14][53] + coeff0_15*dmats1[15][53] + coeff0_16*dmats1[16][53] + coeff0_17*dmats1[17][53] + coeff0_18*dmats1[18][53] + coeff0_19*dmats1[19][53] + coeff0_20*dmats1[20][53] + coeff0_21*dmats1[21][53] + coeff0_22*dmats1[22][53] + coeff0_23*dmats1[23][53] + coeff0_24*dmats1[24][53] + coeff0_25*dmats1[25][53] + coeff0_26*dmats1[26][53] + coeff0_27*dmats1[27][53] + coeff0_28*dmats1[28][53] + coeff0_29*dmats1[29][53] + coeff0_30*dmats1[30][53] + coeff0_31*dmats1[31][53] + coeff0_32*dmats1[32][53] + coeff0_33*dmats1[33][53] + coeff0_34*dmats1[34][53] + coeff0_35*dmats1[35][53] + coeff0_36*dmats1[36][53] + coeff0_37*dmats1[37][53] + coeff0_38*dmats1[38][53] + coeff0_39*dmats1[39][53] + coeff0_40*dmats1[40][53] + coeff0_41*dmats1[41][53] + coeff0_42*dmats1[42][53] + coeff0_43*dmats1[43][53] + coeff0_44*dmats1[44][53] + coeff0_45*dmats1[45][53] + coeff0_46*dmats1[46][53] + coeff0_47*dmats1[47][53] + coeff0_48*dmats1[48][53] + coeff0_49*dmats1[49][53] + coeff0_50*dmats1[50][53] + coeff0_51*dmats1[51][53] + coeff0_52*dmats1[52][53] + coeff0_53*dmats1[53][53] + coeff0_54*dmats1[54][53] + coeff0_55*dmats1[55][53];
          new_coeff0_54 = coeff0_0*dmats1[0][54] + coeff0_1*dmats1[1][54] + coeff0_2*dmats1[2][54] + coeff0_3*dmats1[3][54] + coeff0_4*dmats1[4][54] + coeff0_5*dmats1[5][54] + coeff0_6*dmats1[6][54] + coeff0_7*dmats1[7][54] + coeff0_8*dmats1[8][54] + coeff0_9*dmats1[9][54] + coeff0_10*dmats1[10][54] + coeff0_11*dmats1[11][54] + coeff0_12*dmats1[12][54] + coeff0_13*dmats1[13][54] + coeff0_14*dmats1[14][54] + coeff0_15*dmats1[15][54] + coeff0_16*dmats1[16][54] + coeff0_17*dmats1[17][54] + coeff0_18*dmats1[18][54] + coeff0_19*dmats1[19][54] + coeff0_20*dmats1[20][54] + coeff0_21*dmats1[21][54] + coeff0_22*dmats1[22][54] + coeff0_23*dmats1[23][54] + coeff0_24*dmats1[24][54] + coeff0_25*dmats1[25][54] + coeff0_26*dmats1[26][54] + coeff0_27*dmats1[27][54] + coeff0_28*dmats1[28][54] + coeff0_29*dmats1[29][54] + coeff0_30*dmats1[30][54] + coeff0_31*dmats1[31][54] + coeff0_32*dmats1[32][54] + coeff0_33*dmats1[33][54] + coeff0_34*dmats1[34][54] + coeff0_35*dmats1[35][54] + coeff0_36*dmats1[36][54] + coeff0_37*dmats1[37][54] + coeff0_38*dmats1[38][54] + coeff0_39*dmats1[39][54] + coeff0_40*dmats1[40][54] + coeff0_41*dmats1[41][54] + coeff0_42*dmats1[42][54] + coeff0_43*dmats1[43][54] + coeff0_44*dmats1[44][54] + coeff0_45*dmats1[45][54] + coeff0_46*dmats1[46][54] + coeff0_47*dmats1[47][54] + coeff0_48*dmats1[48][54] + coeff0_49*dmats1[49][54] + coeff0_50*dmats1[50][54] + coeff0_51*dmats1[51][54] + coeff0_52*dmats1[52][54] + coeff0_53*dmats1[53][54] + coeff0_54*dmats1[54][54] + coeff0_55*dmats1[55][54];
          new_coeff0_55 = coeff0_0*dmats1[0][55] + coeff0_1*dmats1[1][55] + coeff0_2*dmats1[2][55] + coeff0_3*dmats1[3][55] + coeff0_4*dmats1[4][55] + coeff0_5*dmats1[5][55] + coeff0_6*dmats1[6][55] + coeff0_7*dmats1[7][55] + coeff0_8*dmats1[8][55] + coeff0_9*dmats1[9][55] + coeff0_10*dmats1[10][55] + coeff0_11*dmats1[11][55] + coeff0_12*dmats1[12][55] + coeff0_13*dmats1[13][55] + coeff0_14*dmats1[14][55] + coeff0_15*dmats1[15][55] + coeff0_16*dmats1[16][55] + coeff0_17*dmats1[17][55] + coeff0_18*dmats1[18][55] + coeff0_19*dmats1[19][55] + coeff0_20*dmats1[20][55] + coeff0_21*dmats1[21][55] + coeff0_22*dmats1[22][55] + coeff0_23*dmats1[23][55] + coeff0_24*dmats1[24][55] + coeff0_25*dmats1[25][55] + coeff0_26*dmats1[26][55] + coeff0_27*dmats1[27][55] + coeff0_28*dmats1[28][55] + coeff0_29*dmats1[29][55] + coeff0_30*dmats1[30][55] + coeff0_31*dmats1[31][55] + coeff0_32*dmats1[32][55] + coeff0_33*dmats1[33][55] + coeff0_34*dmats1[34][55] + coeff0_35*dmats1[35][55] + coeff0_36*dmats1[36][55] + coeff0_37*dmats1[37][55] + coeff0_38*dmats1[38][55] + coeff0_39*dmats1[39][55] + coeff0_40*dmats1[40][55] + coeff0_41*dmats1[41][55] + coeff0_42*dmats1[42][55] + coeff0_43*dmats1[43][55] + coeff0_44*dmats1[44][55] + coeff0_45*dmats1[45][55] + coeff0_46*dmats1[46][55] + coeff0_47*dmats1[47][55] + coeff0_48*dmats1[48][55] + coeff0_49*dmats1[49][55] + coeff0_50*dmats1[50][55] + coeff0_51*dmats1[51][55] + coeff0_52*dmats1[52][55] + coeff0_53*dmats1[53][55] + coeff0_54*dmats1[54][55] + coeff0_55*dmats1[55][55];
        }
        if(combinations[deriv_num][j] == 2)
        {
          new_coeff0_0 = coeff0_0*dmats2[0][0] + coeff0_1*dmats2[1][0] + coeff0_2*dmats2[2][0] + coeff0_3*dmats2[3][0] + coeff0_4*dmats2[4][0] + coeff0_5*dmats2[5][0] + coeff0_6*dmats2[6][0] + coeff0_7*dmats2[7][0] + coeff0_8*dmats2[8][0] + coeff0_9*dmats2[9][0] + coeff0_10*dmats2[10][0] + coeff0_11*dmats2[11][0] + coeff0_12*dmats2[12][0] + coeff0_13*dmats2[13][0] + coeff0_14*dmats2[14][0] + coeff0_15*dmats2[15][0] + coeff0_16*dmats2[16][0] + coeff0_17*dmats2[17][0] + coeff0_18*dmats2[18][0] + coeff0_19*dmats2[19][0] + coeff0_20*dmats2[20][0] + coeff0_21*dmats2[21][0] + coeff0_22*dmats2[22][0] + coeff0_23*dmats2[23][0] + coeff0_24*dmats2[24][0] + coeff0_25*dmats2[25][0] + coeff0_26*dmats2[26][0] + coeff0_27*dmats2[27][0] + coeff0_28*dmats2[28][0] + coeff0_29*dmats2[29][0] + coeff0_30*dmats2[30][0] + coeff0_31*dmats2[31][0] + coeff0_32*dmats2[32][0] + coeff0_33*dmats2[33][0] + coeff0_34*dmats2[34][0] + coeff0_35*dmats2[35][0] + coeff0_36*dmats2[36][0] + coeff0_37*dmats2[37][0] + coeff0_38*dmats2[38][0] + coeff0_39*dmats2[39][0] + coeff0_40*dmats2[40][0] + coeff0_41*dmats2[41][0] + coeff0_42*dmats2[42][0] + coeff0_43*dmats2[43][0] + coeff0_44*dmats2[44][0] + coeff0_45*dmats2[45][0] + coeff0_46*dmats2[46][0] + coeff0_47*dmats2[47][0] + coeff0_48*dmats2[48][0] + coeff0_49*dmats2[49][0] + coeff0_50*dmats2[50][0] + coeff0_51*dmats2[51][0] + coeff0_52*dmats2[52][0] + coeff0_53*dmats2[53][0] + coeff0_54*dmats2[54][0] + coeff0_55*dmats2[55][0];
          new_coeff0_1 = coeff0_0*dmats2[0][1] + coeff0_1*dmats2[1][1] + coeff0_2*dmats2[2][1] + coeff0_3*dmats2[3][1] + coeff0_4*dmats2[4][1] + coeff0_5*dmats2[5][1] + coeff0_6*dmats2[6][1] + coeff0_7*dmats2[7][1] + coeff0_8*dmats2[8][1] + coeff0_9*dmats2[9][1] + coeff0_10*dmats2[10][1] + coeff0_11*dmats2[11][1] + coeff0_12*dmats2[12][1] + coeff0_13*dmats2[13][1] + coeff0_14*dmats2[14][1] + coeff0_15*dmats2[15][1] + coeff0_16*dmats2[16][1] + coeff0_17*dmats2[17][1] + coeff0_18*dmats2[18][1] + coeff0_19*dmats2[19][1] + coeff0_20*dmats2[20][1] + coeff0_21*dmats2[21][1] + coeff0_22*dmats2[22][1] + coeff0_23*dmats2[23][1] + coeff0_24*dmats2[24][1] + coeff0_25*dmats2[25][1] + coeff0_26*dmats2[26][1] + coeff0_27*dmats2[27][1] + coeff0_28*dmats2[28][1] + coeff0_29*dmats2[29][1] + coeff0_30*dmats2[30][1] + coeff0_31*dmats2[31][1] + coeff0_32*dmats2[32][1] + coeff0_33*dmats2[33][1] + coeff0_34*dmats2[34][1] + coeff0_35*dmats2[35][1] + coeff0_36*dmats2[36][1] + coeff0_37*dmats2[37][1] + coeff0_38*dmats2[38][1] + coeff0_39*dmats2[39][1] + coeff0_40*dmats2[40][1] + coeff0_41*dmats2[41][1] + coeff0_42*dmats2[42][1] + coeff0_43*dmats2[43][1] + coeff0_44*dmats2[44][1] + coeff0_45*dmats2[45][1] + coeff0_46*dmats2[46][1] + coeff0_47*dmats2[47][1] + coeff0_48*dmats2[48][1] + coeff0_49*dmats2[49][1] + coeff0_50*dmats2[50][1] + coeff0_51*dmats2[51][1] + coeff0_52*dmats2[52][1] + coeff0_53*dmats2[53][1] + coeff0_54*dmats2[54][1] + coeff0_55*dmats2[55][1];
          new_coeff0_2 = coeff0_0*dmats2[0][2] + coeff0_1*dmats2[1][2] + coeff0_2*dmats2[2][2] + coeff0_3*dmats2[3][2] + coeff0_4*dmats2[4][2] + coeff0_5*dmats2[5][2] + coeff0_6*dmats2[6][2] + coeff0_7*dmats2[7][2] + coeff0_8*dmats2[8][2] + coeff0_9*dmats2[9][2] + coeff0_10*dmats2[10][2] + coeff0_11*dmats2[11][2] + coeff0_12*dmats2[12][2] + coeff0_13*dmats2[13][2] + coeff0_14*dmats2[14][2] + coeff0_15*dmats2[15][2] + coeff0_16*dmats2[16][2] + coeff0_17*dmats2[17][2] + coeff0_18*dmats2[18][2] + coeff0_19*dmats2[19][2] + coeff0_20*dmats2[20][2] + coeff0_21*dmats2[21][2] + coeff0_22*dmats2[22][2] + coeff0_23*dmats2[23][2] + coeff0_24*dmats2[24][2] + coeff0_25*dmats2[25][2] + coeff0_26*dmats2[26][2] + coeff0_27*dmats2[27][2] + coeff0_28*dmats2[28][2] + coeff0_29*dmats2[29][2] + coeff0_30*dmats2[30][2] + coeff0_31*dmats2[31][2] + coeff0_32*dmats2[32][2] + coeff0_33*dmats2[33][2] + coeff0_34*dmats2[34][2] + coeff0_35*dmats2[35][2] + coeff0_36*dmats2[36][2] + coeff0_37*dmats2[37][2] + coeff0_38*dmats2[38][2] + coeff0_39*dmats2[39][2] + coeff0_40*dmats2[40][2] + coeff0_41*dmats2[41][2] + coeff0_42*dmats2[42][2] + coeff0_43*dmats2[43][2] + coeff0_44*dmats2[44][2] + coeff0_45*dmats2[45][2] + coeff0_46*dmats2[46][2] + coeff0_47*dmats2[47][2] + coeff0_48*dmats2[48][2] + coeff0_49*dmats2[49][2] + coeff0_50*dmats2[50][2] + coeff0_51*dmats2[51][2] + coeff0_52*dmats2[52][2] + coeff0_53*dmats2[53][2] + coeff0_54*dmats2[54][2] + coeff0_55*dmats2[55][2];
          new_coeff0_3 = coeff0_0*dmats2[0][3] + coeff0_1*dmats2[1][3] + coeff0_2*dmats2[2][3] + coeff0_3*dmats2[3][3] + coeff0_4*dmats2[4][3] + coeff0_5*dmats2[5][3] + coeff0_6*dmats2[6][3] + coeff0_7*dmats2[7][3] + coeff0_8*dmats2[8][3] + coeff0_9*dmats2[9][3] + coeff0_10*dmats2[10][3] + coeff0_11*dmats2[11][3] + coeff0_12*dmats2[12][3] + coeff0_13*dmats2[13][3] + coeff0_14*dmats2[14][3] + coeff0_15*dmats2[15][3] + coeff0_16*dmats2[16][3] + coeff0_17*dmats2[17][3] + coeff0_18*dmats2[18][3] + coeff0_19*dmats2[19][3] + coeff0_20*dmats2[20][3] + coeff0_21*dmats2[21][3] + coeff0_22*dmats2[22][3] + coeff0_23*dmats2[23][3] + coeff0_24*dmats2[24][3] + coeff0_25*dmats2[25][3] + coeff0_26*dmats2[26][3] + coeff0_27*dmats2[27][3] + coeff0_28*dmats2[28][3] + coeff0_29*dmats2[29][3] + coeff0_30*dmats2[30][3] + coeff0_31*dmats2[31][3] + coeff0_32*dmats2[32][3] + coeff0_33*dmats2[33][3] + coeff0_34*dmats2[34][3] + coeff0_35*dmats2[35][3] + coeff0_36*dmats2[36][3] + coeff0_37*dmats2[37][3] + coeff0_38*dmats2[38][3] + coeff0_39*dmats2[39][3] + coeff0_40*dmats2[40][3] + coeff0_41*dmats2[41][3] + coeff0_42*dmats2[42][3] + coeff0_43*dmats2[43][3] + coeff0_44*dmats2[44][3] + coeff0_45*dmats2[45][3] + coeff0_46*dmats2[46][3] + coeff0_47*dmats2[47][3] + coeff0_48*dmats2[48][3] + coeff0_49*dmats2[49][3] + coeff0_50*dmats2[50][3] + coeff0_51*dmats2[51][3] + coeff0_52*dmats2[52][3] + coeff0_53*dmats2[53][3] + coeff0_54*dmats2[54][3] + coeff0_55*dmats2[55][3];
          new_coeff0_4 = coeff0_0*dmats2[0][4] + coeff0_1*dmats2[1][4] + coeff0_2*dmats2[2][4] + coeff0_3*dmats2[3][4] + coeff0_4*dmats2[4][4] + coeff0_5*dmats2[5][4] + coeff0_6*dmats2[6][4] + coeff0_7*dmats2[7][4] + coeff0_8*dmats2[8][4] + coeff0_9*dmats2[9][4] + coeff0_10*dmats2[10][4] + coeff0_11*dmats2[11][4] + coeff0_12*dmats2[12][4] + coeff0_13*dmats2[13][4] + coeff0_14*dmats2[14][4] + coeff0_15*dmats2[15][4] + coeff0_16*dmats2[16][4] + coeff0_17*dmats2[17][4] + coeff0_18*dmats2[18][4] + coeff0_19*dmats2[19][4] + coeff0_20*dmats2[20][4] + coeff0_21*dmats2[21][4] + coeff0_22*dmats2[22][4] + coeff0_23*dmats2[23][4] + coeff0_24*dmats2[24][4] + coeff0_25*dmats2[25][4] + coeff0_26*dmats2[26][4] + coeff0_27*dmats2[27][4] + coeff0_28*dmats2[28][4] + coeff0_29*dmats2[29][4] + coeff0_30*dmats2[30][4] + coeff0_31*dmats2[31][4] + coeff0_32*dmats2[32][4] + coeff0_33*dmats2[33][4] + coeff0_34*dmats2[34][4] + coeff0_35*dmats2[35][4] + coeff0_36*dmats2[36][4] + coeff0_37*dmats2[37][4] + coeff0_38*dmats2[38][4] + coeff0_39*dmats2[39][4] + coeff0_40*dmats2[40][4] + coeff0_41*dmats2[41][4] + coeff0_42*dmats2[42][4] + coeff0_43*dmats2[43][4] + coeff0_44*dmats2[44][4] + coeff0_45*dmats2[45][4] + coeff0_46*dmats2[46][4] + coeff0_47*dmats2[47][4] + coeff0_48*dmats2[48][4] + coeff0_49*dmats2[49][4] + coeff0_50*dmats2[50][4] + coeff0_51*dmats2[51][4] + coeff0_52*dmats2[52][4] + coeff0_53*dmats2[53][4] + coeff0_54*dmats2[54][4] + coeff0_55*dmats2[55][4];
          new_coeff0_5 = coeff0_0*dmats2[0][5] + coeff0_1*dmats2[1][5] + coeff0_2*dmats2[2][5] + coeff0_3*dmats2[3][5] + coeff0_4*dmats2[4][5] + coeff0_5*dmats2[5][5] + coeff0_6*dmats2[6][5] + coeff0_7*dmats2[7][5] + coeff0_8*dmats2[8][5] + coeff0_9*dmats2[9][5] + coeff0_10*dmats2[10][5] + coeff0_11*dmats2[11][5] + coeff0_12*dmats2[12][5] + coeff0_13*dmats2[13][5] + coeff0_14*dmats2[14][5] + coeff0_15*dmats2[15][5] + coeff0_16*dmats2[16][5] + coeff0_17*dmats2[17][5] + coeff0_18*dmats2[18][5] + coeff0_19*dmats2[19][5] + coeff0_20*dmats2[20][5] + coeff0_21*dmats2[21][5] + coeff0_22*dmats2[22][5] + coeff0_23*dmats2[23][5] + coeff0_24*dmats2[24][5] + coeff0_25*dmats2[25][5] + coeff0_26*dmats2[26][5] + coeff0_27*dmats2[27][5] + coeff0_28*dmats2[28][5] + coeff0_29*dmats2[29][5] + coeff0_30*dmats2[30][5] + coeff0_31*dmats2[31][5] + coeff0_32*dmats2[32][5] + coeff0_33*dmats2[33][5] + coeff0_34*dmats2[34][5] + coeff0_35*dmats2[35][5] + coeff0_36*dmats2[36][5] + coeff0_37*dmats2[37][5] + coeff0_38*dmats2[38][5] + coeff0_39*dmats2[39][5] + coeff0_40*dmats2[40][5] + coeff0_41*dmats2[41][5] + coeff0_42*dmats2[42][5] + coeff0_43*dmats2[43][5] + coeff0_44*dmats2[44][5] + coeff0_45*dmats2[45][5] + coeff0_46*dmats2[46][5] + coeff0_47*dmats2[47][5] + coeff0_48*dmats2[48][5] + coeff0_49*dmats2[49][5] + coeff0_50*dmats2[50][5] + coeff0_51*dmats2[51][5] + coeff0_52*dmats2[52][5] + coeff0_53*dmats2[53][5] + coeff0_54*dmats2[54][5] + coeff0_55*dmats2[55][5];
          new_coeff0_6 = coeff0_0*dmats2[0][6] + coeff0_1*dmats2[1][6] + coeff0_2*dmats2[2][6] + coeff0_3*dmats2[3][6] + coeff0_4*dmats2[4][6] + coeff0_5*dmats2[5][6] + coeff0_6*dmats2[6][6] + coeff0_7*dmats2[7][6] + coeff0_8*dmats2[8][6] + coeff0_9*dmats2[9][6] + coeff0_10*dmats2[10][6] + coeff0_11*dmats2[11][6] + coeff0_12*dmats2[12][6] + coeff0_13*dmats2[13][6] + coeff0_14*dmats2[14][6] + coeff0_15*dmats2[15][6] + coeff0_16*dmats2[16][6] + coeff0_17*dmats2[17][6] + coeff0_18*dmats2[18][6] + coeff0_19*dmats2[19][6] + coeff0_20*dmats2[20][6] + coeff0_21*dmats2[21][6] + coeff0_22*dmats2[22][6] + coeff0_23*dmats2[23][6] + coeff0_24*dmats2[24][6] + coeff0_25*dmats2[25][6] + coeff0_26*dmats2[26][6] + coeff0_27*dmats2[27][6] + coeff0_28*dmats2[28][6] + coeff0_29*dmats2[29][6] + coeff0_30*dmats2[30][6] + coeff0_31*dmats2[31][6] + coeff0_32*dmats2[32][6] + coeff0_33*dmats2[33][6] + coeff0_34*dmats2[34][6] + coeff0_35*dmats2[35][6] + coeff0_36*dmats2[36][6] + coeff0_37*dmats2[37][6] + coeff0_38*dmats2[38][6] + coeff0_39*dmats2[39][6] + coeff0_40*dmats2[40][6] + coeff0_41*dmats2[41][6] + coeff0_42*dmats2[42][6] + coeff0_43*dmats2[43][6] + coeff0_44*dmats2[44][6] + coeff0_45*dmats2[45][6] + coeff0_46*dmats2[46][6] + coeff0_47*dmats2[47][6] + coeff0_48*dmats2[48][6] + coeff0_49*dmats2[49][6] + coeff0_50*dmats2[50][6] + coeff0_51*dmats2[51][6] + coeff0_52*dmats2[52][6] + coeff0_53*dmats2[53][6] + coeff0_54*dmats2[54][6] + coeff0_55*dmats2[55][6];
          new_coeff0_7 = coeff0_0*dmats2[0][7] + coeff0_1*dmats2[1][7] + coeff0_2*dmats2[2][7] + coeff0_3*dmats2[3][7] + coeff0_4*dmats2[4][7] + coeff0_5*dmats2[5][7] + coeff0_6*dmats2[6][7] + coeff0_7*dmats2[7][7] + coeff0_8*dmats2[8][7] + coeff0_9*dmats2[9][7] + coeff0_10*dmats2[10][7] + coeff0_11*dmats2[11][7] + coeff0_12*dmats2[12][7] + coeff0_13*dmats2[13][7] + coeff0_14*dmats2[14][7] + coeff0_15*dmats2[15][7] + coeff0_16*dmats2[16][7] + coeff0_17*dmats2[17][7] + coeff0_18*dmats2[18][7] + coeff0_19*dmats2[19][7] + coeff0_20*dmats2[20][7] + coeff0_21*dmats2[21][7] + coeff0_22*dmats2[22][7] + coeff0_23*dmats2[23][7] + coeff0_24*dmats2[24][7] + coeff0_25*dmats2[25][7] + coeff0_26*dmats2[26][7] + coeff0_27*dmats2[27][7] + coeff0_28*dmats2[28][7] + coeff0_29*dmats2[29][7] + coeff0_30*dmats2[30][7] + coeff0_31*dmats2[31][7] + coeff0_32*dmats2[32][7] + coeff0_33*dmats2[33][7] + coeff0_34*dmats2[34][7] + coeff0_35*dmats2[35][7] + coeff0_36*dmats2[36][7] + coeff0_37*dmats2[37][7] + coeff0_38*dmats2[38][7] + coeff0_39*dmats2[39][7] + coeff0_40*dmats2[40][7] + coeff0_41*dmats2[41][7] + coeff0_42*dmats2[42][7] + coeff0_43*dmats2[43][7] + coeff0_44*dmats2[44][7] + coeff0_45*dmats2[45][7] + coeff0_46*dmats2[46][7] + coeff0_47*dmats2[47][7] + coeff0_48*dmats2[48][7] + coeff0_49*dmats2[49][7] + coeff0_50*dmats2[50][7] + coeff0_51*dmats2[51][7] + coeff0_52*dmats2[52][7] + coeff0_53*dmats2[53][7] + coeff0_54*dmats2[54][7] + coeff0_55*dmats2[55][7];
          new_coeff0_8 = coeff0_0*dmats2[0][8] + coeff0_1*dmats2[1][8] + coeff0_2*dmats2[2][8] + coeff0_3*dmats2[3][8] + coeff0_4*dmats2[4][8] + coeff0_5*dmats2[5][8] + coeff0_6*dmats2[6][8] + coeff0_7*dmats2[7][8] + coeff0_8*dmats2[8][8] + coeff0_9*dmats2[9][8] + coeff0_10*dmats2[10][8] + coeff0_11*dmats2[11][8] + coeff0_12*dmats2[12][8] + coeff0_13*dmats2[13][8] + coeff0_14*dmats2[14][8] + coeff0_15*dmats2[15][8] + coeff0_16*dmats2[16][8] + coeff0_17*dmats2[17][8] + coeff0_18*dmats2[18][8] + coeff0_19*dmats2[19][8] + coeff0_20*dmats2[20][8] + coeff0_21*dmats2[21][8] + coeff0_22*dmats2[22][8] + coeff0_23*dmats2[23][8] + coeff0_24*dmats2[24][8] + coeff0_25*dmats2[25][8] + coeff0_26*dmats2[26][8] + coeff0_27*dmats2[27][8] + coeff0_28*dmats2[28][8] + coeff0_29*dmats2[29][8] + coeff0_30*dmats2[30][8] + coeff0_31*dmats2[31][8] + coeff0_32*dmats2[32][8] + coeff0_33*dmats2[33][8] + coeff0_34*dmats2[34][8] + coeff0_35*dmats2[35][8] + coeff0_36*dmats2[36][8] + coeff0_37*dmats2[37][8] + coeff0_38*dmats2[38][8] + coeff0_39*dmats2[39][8] + coeff0_40*dmats2[40][8] + coeff0_41*dmats2[41][8] + coeff0_42*dmats2[42][8] + coeff0_43*dmats2[43][8] + coeff0_44*dmats2[44][8] + coeff0_45*dmats2[45][8] + coeff0_46*dmats2[46][8] + coeff0_47*dmats2[47][8] + coeff0_48*dmats2[48][8] + coeff0_49*dmats2[49][8] + coeff0_50*dmats2[50][8] + coeff0_51*dmats2[51][8] + coeff0_52*dmats2[52][8] + coeff0_53*dmats2[53][8] + coeff0_54*dmats2[54][8] + coeff0_55*dmats2[55][8];
          new_coeff0_9 = coeff0_0*dmats2[0][9] + coeff0_1*dmats2[1][9] + coeff0_2*dmats2[2][9] + coeff0_3*dmats2[3][9] + coeff0_4*dmats2[4][9] + coeff0_5*dmats2[5][9] + coeff0_6*dmats2[6][9] + coeff0_7*dmats2[7][9] + coeff0_8*dmats2[8][9] + coeff0_9*dmats2[9][9] + coeff0_10*dmats2[10][9] + coeff0_11*dmats2[11][9] + coeff0_12*dmats2[12][9] + coeff0_13*dmats2[13][9] + coeff0_14*dmats2[14][9] + coeff0_15*dmats2[15][9] + coeff0_16*dmats2[16][9] + coeff0_17*dmats2[17][9] + coeff0_18*dmats2[18][9] + coeff0_19*dmats2[19][9] + coeff0_20*dmats2[20][9] + coeff0_21*dmats2[21][9] + coeff0_22*dmats2[22][9] + coeff0_23*dmats2[23][9] + coeff0_24*dmats2[24][9] + coeff0_25*dmats2[25][9] + coeff0_26*dmats2[26][9] + coeff0_27*dmats2[27][9] + coeff0_28*dmats2[28][9] + coeff0_29*dmats2[29][9] + coeff0_30*dmats2[30][9] + coeff0_31*dmats2[31][9] + coeff0_32*dmats2[32][9] + coeff0_33*dmats2[33][9] + coeff0_34*dmats2[34][9] + coeff0_35*dmats2[35][9] + coeff0_36*dmats2[36][9] + coeff0_37*dmats2[37][9] + coeff0_38*dmats2[38][9] + coeff0_39*dmats2[39][9] + coeff0_40*dmats2[40][9] + coeff0_41*dmats2[41][9] + coeff0_42*dmats2[42][9] + coeff0_43*dmats2[43][9] + coeff0_44*dmats2[44][9] + coeff0_45*dmats2[45][9] + coeff0_46*dmats2[46][9] + coeff0_47*dmats2[47][9] + coeff0_48*dmats2[48][9] + coeff0_49*dmats2[49][9] + coeff0_50*dmats2[50][9] + coeff0_51*dmats2[51][9] + coeff0_52*dmats2[52][9] + coeff0_53*dmats2[53][9] + coeff0_54*dmats2[54][9] + coeff0_55*dmats2[55][9];
          new_coeff0_10 = coeff0_0*dmats2[0][10] + coeff0_1*dmats2[1][10] + coeff0_2*dmats2[2][10] + coeff0_3*dmats2[3][10] + coeff0_4*dmats2[4][10] + coeff0_5*dmats2[5][10] + coeff0_6*dmats2[6][10] + coeff0_7*dmats2[7][10] + coeff0_8*dmats2[8][10] + coeff0_9*dmats2[9][10] + coeff0_10*dmats2[10][10] + coeff0_11*dmats2[11][10] + coeff0_12*dmats2[12][10] + coeff0_13*dmats2[13][10] + coeff0_14*dmats2[14][10] + coeff0_15*dmats2[15][10] + coeff0_16*dmats2[16][10] + coeff0_17*dmats2[17][10] + coeff0_18*dmats2[18][10] + coeff0_19*dmats2[19][10] + coeff0_20*dmats2[20][10] + coeff0_21*dmats2[21][10] + coeff0_22*dmats2[22][10] + coeff0_23*dmats2[23][10] + coeff0_24*dmats2[24][10] + coeff0_25*dmats2[25][10] + coeff0_26*dmats2[26][10] + coeff0_27*dmats2[27][10] + coeff0_28*dmats2[28][10] + coeff0_29*dmats2[29][10] + coeff0_30*dmats2[30][10] + coeff0_31*dmats2[31][10] + coeff0_32*dmats2[32][10] + coeff0_33*dmats2[33][10] + coeff0_34*dmats2[34][10] + coeff0_35*dmats2[35][10] + coeff0_36*dmats2[36][10] + coeff0_37*dmats2[37][10] + coeff0_38*dmats2[38][10] + coeff0_39*dmats2[39][10] + coeff0_40*dmats2[40][10] + coeff0_41*dmats2[41][10] + coeff0_42*dmats2[42][10] + coeff0_43*dmats2[43][10] + coeff0_44*dmats2[44][10] + coeff0_45*dmats2[45][10] + coeff0_46*dmats2[46][10] + coeff0_47*dmats2[47][10] + coeff0_48*dmats2[48][10] + coeff0_49*dmats2[49][10] + coeff0_50*dmats2[50][10] + coeff0_51*dmats2[51][10] + coeff0_52*dmats2[52][10] + coeff0_53*dmats2[53][10] + coeff0_54*dmats2[54][10] + coeff0_55*dmats2[55][10];
          new_coeff0_11 = coeff0_0*dmats2[0][11] + coeff0_1*dmats2[1][11] + coeff0_2*dmats2[2][11] + coeff0_3*dmats2[3][11] + coeff0_4*dmats2[4][11] + coeff0_5*dmats2[5][11] + coeff0_6*dmats2[6][11] + coeff0_7*dmats2[7][11] + coeff0_8*dmats2[8][11] + coeff0_9*dmats2[9][11] + coeff0_10*dmats2[10][11] + coeff0_11*dmats2[11][11] + coeff0_12*dmats2[12][11] + coeff0_13*dmats2[13][11] + coeff0_14*dmats2[14][11] + coeff0_15*dmats2[15][11] + coeff0_16*dmats2[16][11] + coeff0_17*dmats2[17][11] + coeff0_18*dmats2[18][11] + coeff0_19*dmats2[19][11] + coeff0_20*dmats2[20][11] + coeff0_21*dmats2[21][11] + coeff0_22*dmats2[22][11] + coeff0_23*dmats2[23][11] + coeff0_24*dmats2[24][11] + coeff0_25*dmats2[25][11] + coeff0_26*dmats2[26][11] + coeff0_27*dmats2[27][11] + coeff0_28*dmats2[28][11] + coeff0_29*dmats2[29][11] + coeff0_30*dmats2[30][11] + coeff0_31*dmats2[31][11] + coeff0_32*dmats2[32][11] + coeff0_33*dmats2[33][11] + coeff0_34*dmats2[34][11] + coeff0_35*dmats2[35][11] + coeff0_36*dmats2[36][11] + coeff0_37*dmats2[37][11] + coeff0_38*dmats2[38][11] + coeff0_39*dmats2[39][11] + coeff0_40*dmats2[40][11] + coeff0_41*dmats2[41][11] + coeff0_42*dmats2[42][11] + coeff0_43*dmats2[43][11] + coeff0_44*dmats2[44][11] + coeff0_45*dmats2[45][11] + coeff0_46*dmats2[46][11] + coeff0_47*dmats2[47][11] + coeff0_48*dmats2[48][11] + coeff0_49*dmats2[49][11] + coeff0_50*dmats2[50][11] + coeff0_51*dmats2[51][11] + coeff0_52*dmats2[52][11] + coeff0_53*dmats2[53][11] + coeff0_54*dmats2[54][11] + coeff0_55*dmats2[55][11];
          new_coeff0_12 = coeff0_0*dmats2[0][12] + coeff0_1*dmats2[1][12] + coeff0_2*dmats2[2][12] + coeff0_3*dmats2[3][12] + coeff0_4*dmats2[4][12] + coeff0_5*dmats2[5][12] + coeff0_6*dmats2[6][12] + coeff0_7*dmats2[7][12] + coeff0_8*dmats2[8][12] + coeff0_9*dmats2[9][12] + coeff0_10*dmats2[10][12] + coeff0_11*dmats2[11][12] + coeff0_12*dmats2[12][12] + coeff0_13*dmats2[13][12] + coeff0_14*dmats2[14][12] + coeff0_15*dmats2[15][12] + coeff0_16*dmats2[16][12] + coeff0_17*dmats2[17][12] + coeff0_18*dmats2[18][12] + coeff0_19*dmats2[19][12] + coeff0_20*dmats2[20][12] + coeff0_21*dmats2[21][12] + coeff0_22*dmats2[22][12] + coeff0_23*dmats2[23][12] + coeff0_24*dmats2[24][12] + coeff0_25*dmats2[25][12] + coeff0_26*dmats2[26][12] + coeff0_27*dmats2[27][12] + coeff0_28*dmats2[28][12] + coeff0_29*dmats2[29][12] + coeff0_30*dmats2[30][12] + coeff0_31*dmats2[31][12] + coeff0_32*dmats2[32][12] + coeff0_33*dmats2[33][12] + coeff0_34*dmats2[34][12] + coeff0_35*dmats2[35][12] + coeff0_36*dmats2[36][12] + coeff0_37*dmats2[37][12] + coeff0_38*dmats2[38][12] + coeff0_39*dmats2[39][12] + coeff0_40*dmats2[40][12] + coeff0_41*dmats2[41][12] + coeff0_42*dmats2[42][12] + coeff0_43*dmats2[43][12] + coeff0_44*dmats2[44][12] + coeff0_45*dmats2[45][12] + coeff0_46*dmats2[46][12] + coeff0_47*dmats2[47][12] + coeff0_48*dmats2[48][12] + coeff0_49*dmats2[49][12] + coeff0_50*dmats2[50][12] + coeff0_51*dmats2[51][12] + coeff0_52*dmats2[52][12] + coeff0_53*dmats2[53][12] + coeff0_54*dmats2[54][12] + coeff0_55*dmats2[55][12];
          new_coeff0_13 = coeff0_0*dmats2[0][13] + coeff0_1*dmats2[1][13] + coeff0_2*dmats2[2][13] + coeff0_3*dmats2[3][13] + coeff0_4*dmats2[4][13] + coeff0_5*dmats2[5][13] + coeff0_6*dmats2[6][13] + coeff0_7*dmats2[7][13] + coeff0_8*dmats2[8][13] + coeff0_9*dmats2[9][13] + coeff0_10*dmats2[10][13] + coeff0_11*dmats2[11][13] + coeff0_12*dmats2[12][13] + coeff0_13*dmats2[13][13] + coeff0_14*dmats2[14][13] + coeff0_15*dmats2[15][13] + coeff0_16*dmats2[16][13] + coeff0_17*dmats2[17][13] + coeff0_18*dmats2[18][13] + coeff0_19*dmats2[19][13] + coeff0_20*dmats2[20][13] + coeff0_21*dmats2[21][13] + coeff0_22*dmats2[22][13] + coeff0_23*dmats2[23][13] + coeff0_24*dmats2[24][13] + coeff0_25*dmats2[25][13] + coeff0_26*dmats2[26][13] + coeff0_27*dmats2[27][13] + coeff0_28*dmats2[28][13] + coeff0_29*dmats2[29][13] + coeff0_30*dmats2[30][13] + coeff0_31*dmats2[31][13] + coeff0_32*dmats2[32][13] + coeff0_33*dmats2[33][13] + coeff0_34*dmats2[34][13] + coeff0_35*dmats2[35][13] + coeff0_36*dmats2[36][13] + coeff0_37*dmats2[37][13] + coeff0_38*dmats2[38][13] + coeff0_39*dmats2[39][13] + coeff0_40*dmats2[40][13] + coeff0_41*dmats2[41][13] + coeff0_42*dmats2[42][13] + coeff0_43*dmats2[43][13] + coeff0_44*dmats2[44][13] + coeff0_45*dmats2[45][13] + coeff0_46*dmats2[46][13] + coeff0_47*dmats2[47][13] + coeff0_48*dmats2[48][13] + coeff0_49*dmats2[49][13] + coeff0_50*dmats2[50][13] + coeff0_51*dmats2[51][13] + coeff0_52*dmats2[52][13] + coeff0_53*dmats2[53][13] + coeff0_54*dmats2[54][13] + coeff0_55*dmats2[55][13];
          new_coeff0_14 = coeff0_0*dmats2[0][14] + coeff0_1*dmats2[1][14] + coeff0_2*dmats2[2][14] + coeff0_3*dmats2[3][14] + coeff0_4*dmats2[4][14] + coeff0_5*dmats2[5][14] + coeff0_6*dmats2[6][14] + coeff0_7*dmats2[7][14] + coeff0_8*dmats2[8][14] + coeff0_9*dmats2[9][14] + coeff0_10*dmats2[10][14] + coeff0_11*dmats2[11][14] + coeff0_12*dmats2[12][14] + coeff0_13*dmats2[13][14] + coeff0_14*dmats2[14][14] + coeff0_15*dmats2[15][14] + coeff0_16*dmats2[16][14] + coeff0_17*dmats2[17][14] + coeff0_18*dmats2[18][14] + coeff0_19*dmats2[19][14] + coeff0_20*dmats2[20][14] + coeff0_21*dmats2[21][14] + coeff0_22*dmats2[22][14] + coeff0_23*dmats2[23][14] + coeff0_24*dmats2[24][14] + coeff0_25*dmats2[25][14] + coeff0_26*dmats2[26][14] + coeff0_27*dmats2[27][14] + coeff0_28*dmats2[28][14] + coeff0_29*dmats2[29][14] + coeff0_30*dmats2[30][14] + coeff0_31*dmats2[31][14] + coeff0_32*dmats2[32][14] + coeff0_33*dmats2[33][14] + coeff0_34*dmats2[34][14] + coeff0_35*dmats2[35][14] + coeff0_36*dmats2[36][14] + coeff0_37*dmats2[37][14] + coeff0_38*dmats2[38][14] + coeff0_39*dmats2[39][14] + coeff0_40*dmats2[40][14] + coeff0_41*dmats2[41][14] + coeff0_42*dmats2[42][14] + coeff0_43*dmats2[43][14] + coeff0_44*dmats2[44][14] + coeff0_45*dmats2[45][14] + coeff0_46*dmats2[46][14] + coeff0_47*dmats2[47][14] + coeff0_48*dmats2[48][14] + coeff0_49*dmats2[49][14] + coeff0_50*dmats2[50][14] + coeff0_51*dmats2[51][14] + coeff0_52*dmats2[52][14] + coeff0_53*dmats2[53][14] + coeff0_54*dmats2[54][14] + coeff0_55*dmats2[55][14];
          new_coeff0_15 = coeff0_0*dmats2[0][15] + coeff0_1*dmats2[1][15] + coeff0_2*dmats2[2][15] + coeff0_3*dmats2[3][15] + coeff0_4*dmats2[4][15] + coeff0_5*dmats2[5][15] + coeff0_6*dmats2[6][15] + coeff0_7*dmats2[7][15] + coeff0_8*dmats2[8][15] + coeff0_9*dmats2[9][15] + coeff0_10*dmats2[10][15] + coeff0_11*dmats2[11][15] + coeff0_12*dmats2[12][15] + coeff0_13*dmats2[13][15] + coeff0_14*dmats2[14][15] + coeff0_15*dmats2[15][15] + coeff0_16*dmats2[16][15] + coeff0_17*dmats2[17][15] + coeff0_18*dmats2[18][15] + coeff0_19*dmats2[19][15] + coeff0_20*dmats2[20][15] + coeff0_21*dmats2[21][15] + coeff0_22*dmats2[22][15] + coeff0_23*dmats2[23][15] + coeff0_24*dmats2[24][15] + coeff0_25*dmats2[25][15] + coeff0_26*dmats2[26][15] + coeff0_27*dmats2[27][15] + coeff0_28*dmats2[28][15] + coeff0_29*dmats2[29][15] + coeff0_30*dmats2[30][15] + coeff0_31*dmats2[31][15] + coeff0_32*dmats2[32][15] + coeff0_33*dmats2[33][15] + coeff0_34*dmats2[34][15] + coeff0_35*dmats2[35][15] + coeff0_36*dmats2[36][15] + coeff0_37*dmats2[37][15] + coeff0_38*dmats2[38][15] + coeff0_39*dmats2[39][15] + coeff0_40*dmats2[40][15] + coeff0_41*dmats2[41][15] + coeff0_42*dmats2[42][15] + coeff0_43*dmats2[43][15] + coeff0_44*dmats2[44][15] + coeff0_45*dmats2[45][15] + coeff0_46*dmats2[46][15] + coeff0_47*dmats2[47][15] + coeff0_48*dmats2[48][15] + coeff0_49*dmats2[49][15] + coeff0_50*dmats2[50][15] + coeff0_51*dmats2[51][15] + coeff0_52*dmats2[52][15] + coeff0_53*dmats2[53][15] + coeff0_54*dmats2[54][15] + coeff0_55*dmats2[55][15];
          new_coeff0_16 = coeff0_0*dmats2[0][16] + coeff0_1*dmats2[1][16] + coeff0_2*dmats2[2][16] + coeff0_3*dmats2[3][16] + coeff0_4*dmats2[4][16] + coeff0_5*dmats2[5][16] + coeff0_6*dmats2[6][16] + coeff0_7*dmats2[7][16] + coeff0_8*dmats2[8][16] + coeff0_9*dmats2[9][16] + coeff0_10*dmats2[10][16] + coeff0_11*dmats2[11][16] + coeff0_12*dmats2[12][16] + coeff0_13*dmats2[13][16] + coeff0_14*dmats2[14][16] + coeff0_15*dmats2[15][16] + coeff0_16*dmats2[16][16] + coeff0_17*dmats2[17][16] + coeff0_18*dmats2[18][16] + coeff0_19*dmats2[19][16] + coeff0_20*dmats2[20][16] + coeff0_21*dmats2[21][16] + coeff0_22*dmats2[22][16] + coeff0_23*dmats2[23][16] + coeff0_24*dmats2[24][16] + coeff0_25*dmats2[25][16] + coeff0_26*dmats2[26][16] + coeff0_27*dmats2[27][16] + coeff0_28*dmats2[28][16] + coeff0_29*dmats2[29][16] + coeff0_30*dmats2[30][16] + coeff0_31*dmats2[31][16] + coeff0_32*dmats2[32][16] + coeff0_33*dmats2[33][16] + coeff0_34*dmats2[34][16] + coeff0_35*dmats2[35][16] + coeff0_36*dmats2[36][16] + coeff0_37*dmats2[37][16] + coeff0_38*dmats2[38][16] + coeff0_39*dmats2[39][16] + coeff0_40*dmats2[40][16] + coeff0_41*dmats2[41][16] + coeff0_42*dmats2[42][16] + coeff0_43*dmats2[43][16] + coeff0_44*dmats2[44][16] + coeff0_45*dmats2[45][16] + coeff0_46*dmats2[46][16] + coeff0_47*dmats2[47][16] + coeff0_48*dmats2[48][16] + coeff0_49*dmats2[49][16] + coeff0_50*dmats2[50][16] + coeff0_51*dmats2[51][16] + coeff0_52*dmats2[52][16] + coeff0_53*dmats2[53][16] + coeff0_54*dmats2[54][16] + coeff0_55*dmats2[55][16];
          new_coeff0_17 = coeff0_0*dmats2[0][17] + coeff0_1*dmats2[1][17] + coeff0_2*dmats2[2][17] + coeff0_3*dmats2[3][17] + coeff0_4*dmats2[4][17] + coeff0_5*dmats2[5][17] + coeff0_6*dmats2[6][17] + coeff0_7*dmats2[7][17] + coeff0_8*dmats2[8][17] + coeff0_9*dmats2[9][17] + coeff0_10*dmats2[10][17] + coeff0_11*dmats2[11][17] + coeff0_12*dmats2[12][17] + coeff0_13*dmats2[13][17] + coeff0_14*dmats2[14][17] + coeff0_15*dmats2[15][17] + coeff0_16*dmats2[16][17] + coeff0_17*dmats2[17][17] + coeff0_18*dmats2[18][17] + coeff0_19*dmats2[19][17] + coeff0_20*dmats2[20][17] + coeff0_21*dmats2[21][17] + coeff0_22*dmats2[22][17] + coeff0_23*dmats2[23][17] + coeff0_24*dmats2[24][17] + coeff0_25*dmats2[25][17] + coeff0_26*dmats2[26][17] + coeff0_27*dmats2[27][17] + coeff0_28*dmats2[28][17] + coeff0_29*dmats2[29][17] + coeff0_30*dmats2[30][17] + coeff0_31*dmats2[31][17] + coeff0_32*dmats2[32][17] + coeff0_33*dmats2[33][17] + coeff0_34*dmats2[34][17] + coeff0_35*dmats2[35][17] + coeff0_36*dmats2[36][17] + coeff0_37*dmats2[37][17] + coeff0_38*dmats2[38][17] + coeff0_39*dmats2[39][17] + coeff0_40*dmats2[40][17] + coeff0_41*dmats2[41][17] + coeff0_42*dmats2[42][17] + coeff0_43*dmats2[43][17] + coeff0_44*dmats2[44][17] + coeff0_45*dmats2[45][17] + coeff0_46*dmats2[46][17] + coeff0_47*dmats2[47][17] + coeff0_48*dmats2[48][17] + coeff0_49*dmats2[49][17] + coeff0_50*dmats2[50][17] + coeff0_51*dmats2[51][17] + coeff0_52*dmats2[52][17] + coeff0_53*dmats2[53][17] + coeff0_54*dmats2[54][17] + coeff0_55*dmats2[55][17];
          new_coeff0_18 = coeff0_0*dmats2[0][18] + coeff0_1*dmats2[1][18] + coeff0_2*dmats2[2][18] + coeff0_3*dmats2[3][18] + coeff0_4*dmats2[4][18] + coeff0_5*dmats2[5][18] + coeff0_6*dmats2[6][18] + coeff0_7*dmats2[7][18] + coeff0_8*dmats2[8][18] + coeff0_9*dmats2[9][18] + coeff0_10*dmats2[10][18] + coeff0_11*dmats2[11][18] + coeff0_12*dmats2[12][18] + coeff0_13*dmats2[13][18] + coeff0_14*dmats2[14][18] + coeff0_15*dmats2[15][18] + coeff0_16*dmats2[16][18] + coeff0_17*dmats2[17][18] + coeff0_18*dmats2[18][18] + coeff0_19*dmats2[19][18] + coeff0_20*dmats2[20][18] + coeff0_21*dmats2[21][18] + coeff0_22*dmats2[22][18] + coeff0_23*dmats2[23][18] + coeff0_24*dmats2[24][18] + coeff0_25*dmats2[25][18] + coeff0_26*dmats2[26][18] + coeff0_27*dmats2[27][18] + coeff0_28*dmats2[28][18] + coeff0_29*dmats2[29][18] + coeff0_30*dmats2[30][18] + coeff0_31*dmats2[31][18] + coeff0_32*dmats2[32][18] + coeff0_33*dmats2[33][18] + coeff0_34*dmats2[34][18] + coeff0_35*dmats2[35][18] + coeff0_36*dmats2[36][18] + coeff0_37*dmats2[37][18] + coeff0_38*dmats2[38][18] + coeff0_39*dmats2[39][18] + coeff0_40*dmats2[40][18] + coeff0_41*dmats2[41][18] + coeff0_42*dmats2[42][18] + coeff0_43*dmats2[43][18] + coeff0_44*dmats2[44][18] + coeff0_45*dmats2[45][18] + coeff0_46*dmats2[46][18] + coeff0_47*dmats2[47][18] + coeff0_48*dmats2[48][18] + coeff0_49*dmats2[49][18] + coeff0_50*dmats2[50][18] + coeff0_51*dmats2[51][18] + coeff0_52*dmats2[52][18] + coeff0_53*dmats2[53][18] + coeff0_54*dmats2[54][18] + coeff0_55*dmats2[55][18];
          new_coeff0_19 = coeff0_0*dmats2[0][19] + coeff0_1*dmats2[1][19] + coeff0_2*dmats2[2][19] + coeff0_3*dmats2[3][19] + coeff0_4*dmats2[4][19] + coeff0_5*dmats2[5][19] + coeff0_6*dmats2[6][19] + coeff0_7*dmats2[7][19] + coeff0_8*dmats2[8][19] + coeff0_9*dmats2[9][19] + coeff0_10*dmats2[10][19] + coeff0_11*dmats2[11][19] + coeff0_12*dmats2[12][19] + coeff0_13*dmats2[13][19] + coeff0_14*dmats2[14][19] + coeff0_15*dmats2[15][19] + coeff0_16*dmats2[16][19] + coeff0_17*dmats2[17][19] + coeff0_18*dmats2[18][19] + coeff0_19*dmats2[19][19] + coeff0_20*dmats2[20][19] + coeff0_21*dmats2[21][19] + coeff0_22*dmats2[22][19] + coeff0_23*dmats2[23][19] + coeff0_24*dmats2[24][19] + coeff0_25*dmats2[25][19] + coeff0_26*dmats2[26][19] + coeff0_27*dmats2[27][19] + coeff0_28*dmats2[28][19] + coeff0_29*dmats2[29][19] + coeff0_30*dmats2[30][19] + coeff0_31*dmats2[31][19] + coeff0_32*dmats2[32][19] + coeff0_33*dmats2[33][19] + coeff0_34*dmats2[34][19] + coeff0_35*dmats2[35][19] + coeff0_36*dmats2[36][19] + coeff0_37*dmats2[37][19] + coeff0_38*dmats2[38][19] + coeff0_39*dmats2[39][19] + coeff0_40*dmats2[40][19] + coeff0_41*dmats2[41][19] + coeff0_42*dmats2[42][19] + coeff0_43*dmats2[43][19] + coeff0_44*dmats2[44][19] + coeff0_45*dmats2[45][19] + coeff0_46*dmats2[46][19] + coeff0_47*dmats2[47][19] + coeff0_48*dmats2[48][19] + coeff0_49*dmats2[49][19] + coeff0_50*dmats2[50][19] + coeff0_51*dmats2[51][19] + coeff0_52*dmats2[52][19] + coeff0_53*dmats2[53][19] + coeff0_54*dmats2[54][19] + coeff0_55*dmats2[55][19];
          new_coeff0_20 = coeff0_0*dmats2[0][20] + coeff0_1*dmats2[1][20] + coeff0_2*dmats2[2][20] + coeff0_3*dmats2[3][20] + coeff0_4*dmats2[4][20] + coeff0_5*dmats2[5][20] + coeff0_6*dmats2[6][20] + coeff0_7*dmats2[7][20] + coeff0_8*dmats2[8][20] + coeff0_9*dmats2[9][20] + coeff0_10*dmats2[10][20] + coeff0_11*dmats2[11][20] + coeff0_12*dmats2[12][20] + coeff0_13*dmats2[13][20] + coeff0_14*dmats2[14][20] + coeff0_15*dmats2[15][20] + coeff0_16*dmats2[16][20] + coeff0_17*dmats2[17][20] + coeff0_18*dmats2[18][20] + coeff0_19*dmats2[19][20] + coeff0_20*dmats2[20][20] + coeff0_21*dmats2[21][20] + coeff0_22*dmats2[22][20] + coeff0_23*dmats2[23][20] + coeff0_24*dmats2[24][20] + coeff0_25*dmats2[25][20] + coeff0_26*dmats2[26][20] + coeff0_27*dmats2[27][20] + coeff0_28*dmats2[28][20] + coeff0_29*dmats2[29][20] + coeff0_30*dmats2[30][20] + coeff0_31*dmats2[31][20] + coeff0_32*dmats2[32][20] + coeff0_33*dmats2[33][20] + coeff0_34*dmats2[34][20] + coeff0_35*dmats2[35][20] + coeff0_36*dmats2[36][20] + coeff0_37*dmats2[37][20] + coeff0_38*dmats2[38][20] + coeff0_39*dmats2[39][20] + coeff0_40*dmats2[40][20] + coeff0_41*dmats2[41][20] + coeff0_42*dmats2[42][20] + coeff0_43*dmats2[43][20] + coeff0_44*dmats2[44][20] + coeff0_45*dmats2[45][20] + coeff0_46*dmats2[46][20] + coeff0_47*dmats2[47][20] + coeff0_48*dmats2[48][20] + coeff0_49*dmats2[49][20] + coeff0_50*dmats2[50][20] + coeff0_51*dmats2[51][20] + coeff0_52*dmats2[52][20] + coeff0_53*dmats2[53][20] + coeff0_54*dmats2[54][20] + coeff0_55*dmats2[55][20];
          new_coeff0_21 = coeff0_0*dmats2[0][21] + coeff0_1*dmats2[1][21] + coeff0_2*dmats2[2][21] + coeff0_3*dmats2[3][21] + coeff0_4*dmats2[4][21] + coeff0_5*dmats2[5][21] + coeff0_6*dmats2[6][21] + coeff0_7*dmats2[7][21] + coeff0_8*dmats2[8][21] + coeff0_9*dmats2[9][21] + coeff0_10*dmats2[10][21] + coeff0_11*dmats2[11][21] + coeff0_12*dmats2[12][21] + coeff0_13*dmats2[13][21] + coeff0_14*dmats2[14][21] + coeff0_15*dmats2[15][21] + coeff0_16*dmats2[16][21] + coeff0_17*dmats2[17][21] + coeff0_18*dmats2[18][21] + coeff0_19*dmats2[19][21] + coeff0_20*dmats2[20][21] + coeff0_21*dmats2[21][21] + coeff0_22*dmats2[22][21] + coeff0_23*dmats2[23][21] + coeff0_24*dmats2[24][21] + coeff0_25*dmats2[25][21] + coeff0_26*dmats2[26][21] + coeff0_27*dmats2[27][21] + coeff0_28*dmats2[28][21] + coeff0_29*dmats2[29][21] + coeff0_30*dmats2[30][21] + coeff0_31*dmats2[31][21] + coeff0_32*dmats2[32][21] + coeff0_33*dmats2[33][21] + coeff0_34*dmats2[34][21] + coeff0_35*dmats2[35][21] + coeff0_36*dmats2[36][21] + coeff0_37*dmats2[37][21] + coeff0_38*dmats2[38][21] + coeff0_39*dmats2[39][21] + coeff0_40*dmats2[40][21] + coeff0_41*dmats2[41][21] + coeff0_42*dmats2[42][21] + coeff0_43*dmats2[43][21] + coeff0_44*dmats2[44][21] + coeff0_45*dmats2[45][21] + coeff0_46*dmats2[46][21] + coeff0_47*dmats2[47][21] + coeff0_48*dmats2[48][21] + coeff0_49*dmats2[49][21] + coeff0_50*dmats2[50][21] + coeff0_51*dmats2[51][21] + coeff0_52*dmats2[52][21] + coeff0_53*dmats2[53][21] + coeff0_54*dmats2[54][21] + coeff0_55*dmats2[55][21];
          new_coeff0_22 = coeff0_0*dmats2[0][22] + coeff0_1*dmats2[1][22] + coeff0_2*dmats2[2][22] + coeff0_3*dmats2[3][22] + coeff0_4*dmats2[4][22] + coeff0_5*dmats2[5][22] + coeff0_6*dmats2[6][22] + coeff0_7*dmats2[7][22] + coeff0_8*dmats2[8][22] + coeff0_9*dmats2[9][22] + coeff0_10*dmats2[10][22] + coeff0_11*dmats2[11][22] + coeff0_12*dmats2[12][22] + coeff0_13*dmats2[13][22] + coeff0_14*dmats2[14][22] + coeff0_15*dmats2[15][22] + coeff0_16*dmats2[16][22] + coeff0_17*dmats2[17][22] + coeff0_18*dmats2[18][22] + coeff0_19*dmats2[19][22] + coeff0_20*dmats2[20][22] + coeff0_21*dmats2[21][22] + coeff0_22*dmats2[22][22] + coeff0_23*dmats2[23][22] + coeff0_24*dmats2[24][22] + coeff0_25*dmats2[25][22] + coeff0_26*dmats2[26][22] + coeff0_27*dmats2[27][22] + coeff0_28*dmats2[28][22] + coeff0_29*dmats2[29][22] + coeff0_30*dmats2[30][22] + coeff0_31*dmats2[31][22] + coeff0_32*dmats2[32][22] + coeff0_33*dmats2[33][22] + coeff0_34*dmats2[34][22] + coeff0_35*dmats2[35][22] + coeff0_36*dmats2[36][22] + coeff0_37*dmats2[37][22] + coeff0_38*dmats2[38][22] + coeff0_39*dmats2[39][22] + coeff0_40*dmats2[40][22] + coeff0_41*dmats2[41][22] + coeff0_42*dmats2[42][22] + coeff0_43*dmats2[43][22] + coeff0_44*dmats2[44][22] + coeff0_45*dmats2[45][22] + coeff0_46*dmats2[46][22] + coeff0_47*dmats2[47][22] + coeff0_48*dmats2[48][22] + coeff0_49*dmats2[49][22] + coeff0_50*dmats2[50][22] + coeff0_51*dmats2[51][22] + coeff0_52*dmats2[52][22] + coeff0_53*dmats2[53][22] + coeff0_54*dmats2[54][22] + coeff0_55*dmats2[55][22];
          new_coeff0_23 = coeff0_0*dmats2[0][23] + coeff0_1*dmats2[1][23] + coeff0_2*dmats2[2][23] + coeff0_3*dmats2[3][23] + coeff0_4*dmats2[4][23] + coeff0_5*dmats2[5][23] + coeff0_6*dmats2[6][23] + coeff0_7*dmats2[7][23] + coeff0_8*dmats2[8][23] + coeff0_9*dmats2[9][23] + coeff0_10*dmats2[10][23] + coeff0_11*dmats2[11][23] + coeff0_12*dmats2[12][23] + coeff0_13*dmats2[13][23] + coeff0_14*dmats2[14][23] + coeff0_15*dmats2[15][23] + coeff0_16*dmats2[16][23] + coeff0_17*dmats2[17][23] + coeff0_18*dmats2[18][23] + coeff0_19*dmats2[19][23] + coeff0_20*dmats2[20][23] + coeff0_21*dmats2[21][23] + coeff0_22*dmats2[22][23] + coeff0_23*dmats2[23][23] + coeff0_24*dmats2[24][23] + coeff0_25*dmats2[25][23] + coeff0_26*dmats2[26][23] + coeff0_27*dmats2[27][23] + coeff0_28*dmats2[28][23] + coeff0_29*dmats2[29][23] + coeff0_30*dmats2[30][23] + coeff0_31*dmats2[31][23] + coeff0_32*dmats2[32][23] + coeff0_33*dmats2[33][23] + coeff0_34*dmats2[34][23] + coeff0_35*dmats2[35][23] + coeff0_36*dmats2[36][23] + coeff0_37*dmats2[37][23] + coeff0_38*dmats2[38][23] + coeff0_39*dmats2[39][23] + coeff0_40*dmats2[40][23] + coeff0_41*dmats2[41][23] + coeff0_42*dmats2[42][23] + coeff0_43*dmats2[43][23] + coeff0_44*dmats2[44][23] + coeff0_45*dmats2[45][23] + coeff0_46*dmats2[46][23] + coeff0_47*dmats2[47][23] + coeff0_48*dmats2[48][23] + coeff0_49*dmats2[49][23] + coeff0_50*dmats2[50][23] + coeff0_51*dmats2[51][23] + coeff0_52*dmats2[52][23] + coeff0_53*dmats2[53][23] + coeff0_54*dmats2[54][23] + coeff0_55*dmats2[55][23];
          new_coeff0_24 = coeff0_0*dmats2[0][24] + coeff0_1*dmats2[1][24] + coeff0_2*dmats2[2][24] + coeff0_3*dmats2[3][24] + coeff0_4*dmats2[4][24] + coeff0_5*dmats2[5][24] + coeff0_6*dmats2[6][24] + coeff0_7*dmats2[7][24] + coeff0_8*dmats2[8][24] + coeff0_9*dmats2[9][24] + coeff0_10*dmats2[10][24] + coeff0_11*dmats2[11][24] + coeff0_12*dmats2[12][24] + coeff0_13*dmats2[13][24] + coeff0_14*dmats2[14][24] + coeff0_15*dmats2[15][24] + coeff0_16*dmats2[16][24] + coeff0_17*dmats2[17][24] + coeff0_18*dmats2[18][24] + coeff0_19*dmats2[19][24] + coeff0_20*dmats2[20][24] + coeff0_21*dmats2[21][24] + coeff0_22*dmats2[22][24] + coeff0_23*dmats2[23][24] + coeff0_24*dmats2[24][24] + coeff0_25*dmats2[25][24] + coeff0_26*dmats2[26][24] + coeff0_27*dmats2[27][24] + coeff0_28*dmats2[28][24] + coeff0_29*dmats2[29][24] + coeff0_30*dmats2[30][24] + coeff0_31*dmats2[31][24] + coeff0_32*dmats2[32][24] + coeff0_33*dmats2[33][24] + coeff0_34*dmats2[34][24] + coeff0_35*dmats2[35][24] + coeff0_36*dmats2[36][24] + coeff0_37*dmats2[37][24] + coeff0_38*dmats2[38][24] + coeff0_39*dmats2[39][24] + coeff0_40*dmats2[40][24] + coeff0_41*dmats2[41][24] + coeff0_42*dmats2[42][24] + coeff0_43*dmats2[43][24] + coeff0_44*dmats2[44][24] + coeff0_45*dmats2[45][24] + coeff0_46*dmats2[46][24] + coeff0_47*dmats2[47][24] + coeff0_48*dmats2[48][24] + coeff0_49*dmats2[49][24] + coeff0_50*dmats2[50][24] + coeff0_51*dmats2[51][24] + coeff0_52*dmats2[52][24] + coeff0_53*dmats2[53][24] + coeff0_54*dmats2[54][24] + coeff0_55*dmats2[55][24];
          new_coeff0_25 = coeff0_0*dmats2[0][25] + coeff0_1*dmats2[1][25] + coeff0_2*dmats2[2][25] + coeff0_3*dmats2[3][25] + coeff0_4*dmats2[4][25] + coeff0_5*dmats2[5][25] + coeff0_6*dmats2[6][25] + coeff0_7*dmats2[7][25] + coeff0_8*dmats2[8][25] + coeff0_9*dmats2[9][25] + coeff0_10*dmats2[10][25] + coeff0_11*dmats2[11][25] + coeff0_12*dmats2[12][25] + coeff0_13*dmats2[13][25] + coeff0_14*dmats2[14][25] + coeff0_15*dmats2[15][25] + coeff0_16*dmats2[16][25] + coeff0_17*dmats2[17][25] + coeff0_18*dmats2[18][25] + coeff0_19*dmats2[19][25] + coeff0_20*dmats2[20][25] + coeff0_21*dmats2[21][25] + coeff0_22*dmats2[22][25] + coeff0_23*dmats2[23][25] + coeff0_24*dmats2[24][25] + coeff0_25*dmats2[25][25] + coeff0_26*dmats2[26][25] + coeff0_27*dmats2[27][25] + coeff0_28*dmats2[28][25] + coeff0_29*dmats2[29][25] + coeff0_30*dmats2[30][25] + coeff0_31*dmats2[31][25] + coeff0_32*dmats2[32][25] + coeff0_33*dmats2[33][25] + coeff0_34*dmats2[34][25] + coeff0_35*dmats2[35][25] + coeff0_36*dmats2[36][25] + coeff0_37*dmats2[37][25] + coeff0_38*dmats2[38][25] + coeff0_39*dmats2[39][25] + coeff0_40*dmats2[40][25] + coeff0_41*dmats2[41][25] + coeff0_42*dmats2[42][25] + coeff0_43*dmats2[43][25] + coeff0_44*dmats2[44][25] + coeff0_45*dmats2[45][25] + coeff0_46*dmats2[46][25] + coeff0_47*dmats2[47][25] + coeff0_48*dmats2[48][25] + coeff0_49*dmats2[49][25] + coeff0_50*dmats2[50][25] + coeff0_51*dmats2[51][25] + coeff0_52*dmats2[52][25] + coeff0_53*dmats2[53][25] + coeff0_54*dmats2[54][25] + coeff0_55*dmats2[55][25];
          new_coeff0_26 = coeff0_0*dmats2[0][26] + coeff0_1*dmats2[1][26] + coeff0_2*dmats2[2][26] + coeff0_3*dmats2[3][26] + coeff0_4*dmats2[4][26] + coeff0_5*dmats2[5][26] + coeff0_6*dmats2[6][26] + coeff0_7*dmats2[7][26] + coeff0_8*dmats2[8][26] + coeff0_9*dmats2[9][26] + coeff0_10*dmats2[10][26] + coeff0_11*dmats2[11][26] + coeff0_12*dmats2[12][26] + coeff0_13*dmats2[13][26] + coeff0_14*dmats2[14][26] + coeff0_15*dmats2[15][26] + coeff0_16*dmats2[16][26] + coeff0_17*dmats2[17][26] + coeff0_18*dmats2[18][26] + coeff0_19*dmats2[19][26] + coeff0_20*dmats2[20][26] + coeff0_21*dmats2[21][26] + coeff0_22*dmats2[22][26] + coeff0_23*dmats2[23][26] + coeff0_24*dmats2[24][26] + coeff0_25*dmats2[25][26] + coeff0_26*dmats2[26][26] + coeff0_27*dmats2[27][26] + coeff0_28*dmats2[28][26] + coeff0_29*dmats2[29][26] + coeff0_30*dmats2[30][26] + coeff0_31*dmats2[31][26] + coeff0_32*dmats2[32][26] + coeff0_33*dmats2[33][26] + coeff0_34*dmats2[34][26] + coeff0_35*dmats2[35][26] + coeff0_36*dmats2[36][26] + coeff0_37*dmats2[37][26] + coeff0_38*dmats2[38][26] + coeff0_39*dmats2[39][26] + coeff0_40*dmats2[40][26] + coeff0_41*dmats2[41][26] + coeff0_42*dmats2[42][26] + coeff0_43*dmats2[43][26] + coeff0_44*dmats2[44][26] + coeff0_45*dmats2[45][26] + coeff0_46*dmats2[46][26] + coeff0_47*dmats2[47][26] + coeff0_48*dmats2[48][26] + coeff0_49*dmats2[49][26] + coeff0_50*dmats2[50][26] + coeff0_51*dmats2[51][26] + coeff0_52*dmats2[52][26] + coeff0_53*dmats2[53][26] + coeff0_54*dmats2[54][26] + coeff0_55*dmats2[55][26];
          new_coeff0_27 = coeff0_0*dmats2[0][27] + coeff0_1*dmats2[1][27] + coeff0_2*dmats2[2][27] + coeff0_3*dmats2[3][27] + coeff0_4*dmats2[4][27] + coeff0_5*dmats2[5][27] + coeff0_6*dmats2[6][27] + coeff0_7*dmats2[7][27] + coeff0_8*dmats2[8][27] + coeff0_9*dmats2[9][27] + coeff0_10*dmats2[10][27] + coeff0_11*dmats2[11][27] + coeff0_12*dmats2[12][27] + coeff0_13*dmats2[13][27] + coeff0_14*dmats2[14][27] + coeff0_15*dmats2[15][27] + coeff0_16*dmats2[16][27] + coeff0_17*dmats2[17][27] + coeff0_18*dmats2[18][27] + coeff0_19*dmats2[19][27] + coeff0_20*dmats2[20][27] + coeff0_21*dmats2[21][27] + coeff0_22*dmats2[22][27] + coeff0_23*dmats2[23][27] + coeff0_24*dmats2[24][27] + coeff0_25*dmats2[25][27] + coeff0_26*dmats2[26][27] + coeff0_27*dmats2[27][27] + coeff0_28*dmats2[28][27] + coeff0_29*dmats2[29][27] + coeff0_30*dmats2[30][27] + coeff0_31*dmats2[31][27] + coeff0_32*dmats2[32][27] + coeff0_33*dmats2[33][27] + coeff0_34*dmats2[34][27] + coeff0_35*dmats2[35][27] + coeff0_36*dmats2[36][27] + coeff0_37*dmats2[37][27] + coeff0_38*dmats2[38][27] + coeff0_39*dmats2[39][27] + coeff0_40*dmats2[40][27] + coeff0_41*dmats2[41][27] + coeff0_42*dmats2[42][27] + coeff0_43*dmats2[43][27] + coeff0_44*dmats2[44][27] + coeff0_45*dmats2[45][27] + coeff0_46*dmats2[46][27] + coeff0_47*dmats2[47][27] + coeff0_48*dmats2[48][27] + coeff0_49*dmats2[49][27] + coeff0_50*dmats2[50][27] + coeff0_51*dmats2[51][27] + coeff0_52*dmats2[52][27] + coeff0_53*dmats2[53][27] + coeff0_54*dmats2[54][27] + coeff0_55*dmats2[55][27];
          new_coeff0_28 = coeff0_0*dmats2[0][28] + coeff0_1*dmats2[1][28] + coeff0_2*dmats2[2][28] + coeff0_3*dmats2[3][28] + coeff0_4*dmats2[4][28] + coeff0_5*dmats2[5][28] + coeff0_6*dmats2[6][28] + coeff0_7*dmats2[7][28] + coeff0_8*dmats2[8][28] + coeff0_9*dmats2[9][28] + coeff0_10*dmats2[10][28] + coeff0_11*dmats2[11][28] + coeff0_12*dmats2[12][28] + coeff0_13*dmats2[13][28] + coeff0_14*dmats2[14][28] + coeff0_15*dmats2[15][28] + coeff0_16*dmats2[16][28] + coeff0_17*dmats2[17][28] + coeff0_18*dmats2[18][28] + coeff0_19*dmats2[19][28] + coeff0_20*dmats2[20][28] + coeff0_21*dmats2[21][28] + coeff0_22*dmats2[22][28] + coeff0_23*dmats2[23][28] + coeff0_24*dmats2[24][28] + coeff0_25*dmats2[25][28] + coeff0_26*dmats2[26][28] + coeff0_27*dmats2[27][28] + coeff0_28*dmats2[28][28] + coeff0_29*dmats2[29][28] + coeff0_30*dmats2[30][28] + coeff0_31*dmats2[31][28] + coeff0_32*dmats2[32][28] + coeff0_33*dmats2[33][28] + coeff0_34*dmats2[34][28] + coeff0_35*dmats2[35][28] + coeff0_36*dmats2[36][28] + coeff0_37*dmats2[37][28] + coeff0_38*dmats2[38][28] + coeff0_39*dmats2[39][28] + coeff0_40*dmats2[40][28] + coeff0_41*dmats2[41][28] + coeff0_42*dmats2[42][28] + coeff0_43*dmats2[43][28] + coeff0_44*dmats2[44][28] + coeff0_45*dmats2[45][28] + coeff0_46*dmats2[46][28] + coeff0_47*dmats2[47][28] + coeff0_48*dmats2[48][28] + coeff0_49*dmats2[49][28] + coeff0_50*dmats2[50][28] + coeff0_51*dmats2[51][28] + coeff0_52*dmats2[52][28] + coeff0_53*dmats2[53][28] + coeff0_54*dmats2[54][28] + coeff0_55*dmats2[55][28];
          new_coeff0_29 = coeff0_0*dmats2[0][29] + coeff0_1*dmats2[1][29] + coeff0_2*dmats2[2][29] + coeff0_3*dmats2[3][29] + coeff0_4*dmats2[4][29] + coeff0_5*dmats2[5][29] + coeff0_6*dmats2[6][29] + coeff0_7*dmats2[7][29] + coeff0_8*dmats2[8][29] + coeff0_9*dmats2[9][29] + coeff0_10*dmats2[10][29] + coeff0_11*dmats2[11][29] + coeff0_12*dmats2[12][29] + coeff0_13*dmats2[13][29] + coeff0_14*dmats2[14][29] + coeff0_15*dmats2[15][29] + coeff0_16*dmats2[16][29] + coeff0_17*dmats2[17][29] + coeff0_18*dmats2[18][29] + coeff0_19*dmats2[19][29] + coeff0_20*dmats2[20][29] + coeff0_21*dmats2[21][29] + coeff0_22*dmats2[22][29] + coeff0_23*dmats2[23][29] + coeff0_24*dmats2[24][29] + coeff0_25*dmats2[25][29] + coeff0_26*dmats2[26][29] + coeff0_27*dmats2[27][29] + coeff0_28*dmats2[28][29] + coeff0_29*dmats2[29][29] + coeff0_30*dmats2[30][29] + coeff0_31*dmats2[31][29] + coeff0_32*dmats2[32][29] + coeff0_33*dmats2[33][29] + coeff0_34*dmats2[34][29] + coeff0_35*dmats2[35][29] + coeff0_36*dmats2[36][29] + coeff0_37*dmats2[37][29] + coeff0_38*dmats2[38][29] + coeff0_39*dmats2[39][29] + coeff0_40*dmats2[40][29] + coeff0_41*dmats2[41][29] + coeff0_42*dmats2[42][29] + coeff0_43*dmats2[43][29] + coeff0_44*dmats2[44][29] + coeff0_45*dmats2[45][29] + coeff0_46*dmats2[46][29] + coeff0_47*dmats2[47][29] + coeff0_48*dmats2[48][29] + coeff0_49*dmats2[49][29] + coeff0_50*dmats2[50][29] + coeff0_51*dmats2[51][29] + coeff0_52*dmats2[52][29] + coeff0_53*dmats2[53][29] + coeff0_54*dmats2[54][29] + coeff0_55*dmats2[55][29];
          new_coeff0_30 = coeff0_0*dmats2[0][30] + coeff0_1*dmats2[1][30] + coeff0_2*dmats2[2][30] + coeff0_3*dmats2[3][30] + coeff0_4*dmats2[4][30] + coeff0_5*dmats2[5][30] + coeff0_6*dmats2[6][30] + coeff0_7*dmats2[7][30] + coeff0_8*dmats2[8][30] + coeff0_9*dmats2[9][30] + coeff0_10*dmats2[10][30] + coeff0_11*dmats2[11][30] + coeff0_12*dmats2[12][30] + coeff0_13*dmats2[13][30] + coeff0_14*dmats2[14][30] + coeff0_15*dmats2[15][30] + coeff0_16*dmats2[16][30] + coeff0_17*dmats2[17][30] + coeff0_18*dmats2[18][30] + coeff0_19*dmats2[19][30] + coeff0_20*dmats2[20][30] + coeff0_21*dmats2[21][30] + coeff0_22*dmats2[22][30] + coeff0_23*dmats2[23][30] + coeff0_24*dmats2[24][30] + coeff0_25*dmats2[25][30] + coeff0_26*dmats2[26][30] + coeff0_27*dmats2[27][30] + coeff0_28*dmats2[28][30] + coeff0_29*dmats2[29][30] + coeff0_30*dmats2[30][30] + coeff0_31*dmats2[31][30] + coeff0_32*dmats2[32][30] + coeff0_33*dmats2[33][30] + coeff0_34*dmats2[34][30] + coeff0_35*dmats2[35][30] + coeff0_36*dmats2[36][30] + coeff0_37*dmats2[37][30] + coeff0_38*dmats2[38][30] + coeff0_39*dmats2[39][30] + coeff0_40*dmats2[40][30] + coeff0_41*dmats2[41][30] + coeff0_42*dmats2[42][30] + coeff0_43*dmats2[43][30] + coeff0_44*dmats2[44][30] + coeff0_45*dmats2[45][30] + coeff0_46*dmats2[46][30] + coeff0_47*dmats2[47][30] + coeff0_48*dmats2[48][30] + coeff0_49*dmats2[49][30] + coeff0_50*dmats2[50][30] + coeff0_51*dmats2[51][30] + coeff0_52*dmats2[52][30] + coeff0_53*dmats2[53][30] + coeff0_54*dmats2[54][30] + coeff0_55*dmats2[55][30];
          new_coeff0_31 = coeff0_0*dmats2[0][31] + coeff0_1*dmats2[1][31] + coeff0_2*dmats2[2][31] + coeff0_3*dmats2[3][31] + coeff0_4*dmats2[4][31] + coeff0_5*dmats2[5][31] + coeff0_6*dmats2[6][31] + coeff0_7*dmats2[7][31] + coeff0_8*dmats2[8][31] + coeff0_9*dmats2[9][31] + coeff0_10*dmats2[10][31] + coeff0_11*dmats2[11][31] + coeff0_12*dmats2[12][31] + coeff0_13*dmats2[13][31] + coeff0_14*dmats2[14][31] + coeff0_15*dmats2[15][31] + coeff0_16*dmats2[16][31] + coeff0_17*dmats2[17][31] + coeff0_18*dmats2[18][31] + coeff0_19*dmats2[19][31] + coeff0_20*dmats2[20][31] + coeff0_21*dmats2[21][31] + coeff0_22*dmats2[22][31] + coeff0_23*dmats2[23][31] + coeff0_24*dmats2[24][31] + coeff0_25*dmats2[25][31] + coeff0_26*dmats2[26][31] + coeff0_27*dmats2[27][31] + coeff0_28*dmats2[28][31] + coeff0_29*dmats2[29][31] + coeff0_30*dmats2[30][31] + coeff0_31*dmats2[31][31] + coeff0_32*dmats2[32][31] + coeff0_33*dmats2[33][31] + coeff0_34*dmats2[34][31] + coeff0_35*dmats2[35][31] + coeff0_36*dmats2[36][31] + coeff0_37*dmats2[37][31] + coeff0_38*dmats2[38][31] + coeff0_39*dmats2[39][31] + coeff0_40*dmats2[40][31] + coeff0_41*dmats2[41][31] + coeff0_42*dmats2[42][31] + coeff0_43*dmats2[43][31] + coeff0_44*dmats2[44][31] + coeff0_45*dmats2[45][31] + coeff0_46*dmats2[46][31] + coeff0_47*dmats2[47][31] + coeff0_48*dmats2[48][31] + coeff0_49*dmats2[49][31] + coeff0_50*dmats2[50][31] + coeff0_51*dmats2[51][31] + coeff0_52*dmats2[52][31] + coeff0_53*dmats2[53][31] + coeff0_54*dmats2[54][31] + coeff0_55*dmats2[55][31];
          new_coeff0_32 = coeff0_0*dmats2[0][32] + coeff0_1*dmats2[1][32] + coeff0_2*dmats2[2][32] + coeff0_3*dmats2[3][32] + coeff0_4*dmats2[4][32] + coeff0_5*dmats2[5][32] + coeff0_6*dmats2[6][32] + coeff0_7*dmats2[7][32] + coeff0_8*dmats2[8][32] + coeff0_9*dmats2[9][32] + coeff0_10*dmats2[10][32] + coeff0_11*dmats2[11][32] + coeff0_12*dmats2[12][32] + coeff0_13*dmats2[13][32] + coeff0_14*dmats2[14][32] + coeff0_15*dmats2[15][32] + coeff0_16*dmats2[16][32] + coeff0_17*dmats2[17][32] + coeff0_18*dmats2[18][32] + coeff0_19*dmats2[19][32] + coeff0_20*dmats2[20][32] + coeff0_21*dmats2[21][32] + coeff0_22*dmats2[22][32] + coeff0_23*dmats2[23][32] + coeff0_24*dmats2[24][32] + coeff0_25*dmats2[25][32] + coeff0_26*dmats2[26][32] + coeff0_27*dmats2[27][32] + coeff0_28*dmats2[28][32] + coeff0_29*dmats2[29][32] + coeff0_30*dmats2[30][32] + coeff0_31*dmats2[31][32] + coeff0_32*dmats2[32][32] + coeff0_33*dmats2[33][32] + coeff0_34*dmats2[34][32] + coeff0_35*dmats2[35][32] + coeff0_36*dmats2[36][32] + coeff0_37*dmats2[37][32] + coeff0_38*dmats2[38][32] + coeff0_39*dmats2[39][32] + coeff0_40*dmats2[40][32] + coeff0_41*dmats2[41][32] + coeff0_42*dmats2[42][32] + coeff0_43*dmats2[43][32] + coeff0_44*dmats2[44][32] + coeff0_45*dmats2[45][32] + coeff0_46*dmats2[46][32] + coeff0_47*dmats2[47][32] + coeff0_48*dmats2[48][32] + coeff0_49*dmats2[49][32] + coeff0_50*dmats2[50][32] + coeff0_51*dmats2[51][32] + coeff0_52*dmats2[52][32] + coeff0_53*dmats2[53][32] + coeff0_54*dmats2[54][32] + coeff0_55*dmats2[55][32];
          new_coeff0_33 = coeff0_0*dmats2[0][33] + coeff0_1*dmats2[1][33] + coeff0_2*dmats2[2][33] + coeff0_3*dmats2[3][33] + coeff0_4*dmats2[4][33] + coeff0_5*dmats2[5][33] + coeff0_6*dmats2[6][33] + coeff0_7*dmats2[7][33] + coeff0_8*dmats2[8][33] + coeff0_9*dmats2[9][33] + coeff0_10*dmats2[10][33] + coeff0_11*dmats2[11][33] + coeff0_12*dmats2[12][33] + coeff0_13*dmats2[13][33] + coeff0_14*dmats2[14][33] + coeff0_15*dmats2[15][33] + coeff0_16*dmats2[16][33] + coeff0_17*dmats2[17][33] + coeff0_18*dmats2[18][33] + coeff0_19*dmats2[19][33] + coeff0_20*dmats2[20][33] + coeff0_21*dmats2[21][33] + coeff0_22*dmats2[22][33] + coeff0_23*dmats2[23][33] + coeff0_24*dmats2[24][33] + coeff0_25*dmats2[25][33] + coeff0_26*dmats2[26][33] + coeff0_27*dmats2[27][33] + coeff0_28*dmats2[28][33] + coeff0_29*dmats2[29][33] + coeff0_30*dmats2[30][33] + coeff0_31*dmats2[31][33] + coeff0_32*dmats2[32][33] + coeff0_33*dmats2[33][33] + coeff0_34*dmats2[34][33] + coeff0_35*dmats2[35][33] + coeff0_36*dmats2[36][33] + coeff0_37*dmats2[37][33] + coeff0_38*dmats2[38][33] + coeff0_39*dmats2[39][33] + coeff0_40*dmats2[40][33] + coeff0_41*dmats2[41][33] + coeff0_42*dmats2[42][33] + coeff0_43*dmats2[43][33] + coeff0_44*dmats2[44][33] + coeff0_45*dmats2[45][33] + coeff0_46*dmats2[46][33] + coeff0_47*dmats2[47][33] + coeff0_48*dmats2[48][33] + coeff0_49*dmats2[49][33] + coeff0_50*dmats2[50][33] + coeff0_51*dmats2[51][33] + coeff0_52*dmats2[52][33] + coeff0_53*dmats2[53][33] + coeff0_54*dmats2[54][33] + coeff0_55*dmats2[55][33];
          new_coeff0_34 = coeff0_0*dmats2[0][34] + coeff0_1*dmats2[1][34] + coeff0_2*dmats2[2][34] + coeff0_3*dmats2[3][34] + coeff0_4*dmats2[4][34] + coeff0_5*dmats2[5][34] + coeff0_6*dmats2[6][34] + coeff0_7*dmats2[7][34] + coeff0_8*dmats2[8][34] + coeff0_9*dmats2[9][34] + coeff0_10*dmats2[10][34] + coeff0_11*dmats2[11][34] + coeff0_12*dmats2[12][34] + coeff0_13*dmats2[13][34] + coeff0_14*dmats2[14][34] + coeff0_15*dmats2[15][34] + coeff0_16*dmats2[16][34] + coeff0_17*dmats2[17][34] + coeff0_18*dmats2[18][34] + coeff0_19*dmats2[19][34] + coeff0_20*dmats2[20][34] + coeff0_21*dmats2[21][34] + coeff0_22*dmats2[22][34] + coeff0_23*dmats2[23][34] + coeff0_24*dmats2[24][34] + coeff0_25*dmats2[25][34] + coeff0_26*dmats2[26][34] + coeff0_27*dmats2[27][34] + coeff0_28*dmats2[28][34] + coeff0_29*dmats2[29][34] + coeff0_30*dmats2[30][34] + coeff0_31*dmats2[31][34] + coeff0_32*dmats2[32][34] + coeff0_33*dmats2[33][34] + coeff0_34*dmats2[34][34] + coeff0_35*dmats2[35][34] + coeff0_36*dmats2[36][34] + coeff0_37*dmats2[37][34] + coeff0_38*dmats2[38][34] + coeff0_39*dmats2[39][34] + coeff0_40*dmats2[40][34] + coeff0_41*dmats2[41][34] + coeff0_42*dmats2[42][34] + coeff0_43*dmats2[43][34] + coeff0_44*dmats2[44][34] + coeff0_45*dmats2[45][34] + coeff0_46*dmats2[46][34] + coeff0_47*dmats2[47][34] + coeff0_48*dmats2[48][34] + coeff0_49*dmats2[49][34] + coeff0_50*dmats2[50][34] + coeff0_51*dmats2[51][34] + coeff0_52*dmats2[52][34] + coeff0_53*dmats2[53][34] + coeff0_54*dmats2[54][34] + coeff0_55*dmats2[55][34];
          new_coeff0_35 = coeff0_0*dmats2[0][35] + coeff0_1*dmats2[1][35] + coeff0_2*dmats2[2][35] + coeff0_3*dmats2[3][35] + coeff0_4*dmats2[4][35] + coeff0_5*dmats2[5][35] + coeff0_6*dmats2[6][35] + coeff0_7*dmats2[7][35] + coeff0_8*dmats2[8][35] + coeff0_9*dmats2[9][35] + coeff0_10*dmats2[10][35] + coeff0_11*dmats2[11][35] + coeff0_12*dmats2[12][35] + coeff0_13*dmats2[13][35] + coeff0_14*dmats2[14][35] + coeff0_15*dmats2[15][35] + coeff0_16*dmats2[16][35] + coeff0_17*dmats2[17][35] + coeff0_18*dmats2[18][35] + coeff0_19*dmats2[19][35] + coeff0_20*dmats2[20][35] + coeff0_21*dmats2[21][35] + coeff0_22*dmats2[22][35] + coeff0_23*dmats2[23][35] + coeff0_24*dmats2[24][35] + coeff0_25*dmats2[25][35] + coeff0_26*dmats2[26][35] + coeff0_27*dmats2[27][35] + coeff0_28*dmats2[28][35] + coeff0_29*dmats2[29][35] + coeff0_30*dmats2[30][35] + coeff0_31*dmats2[31][35] + coeff0_32*dmats2[32][35] + coeff0_33*dmats2[33][35] + coeff0_34*dmats2[34][35] + coeff0_35*dmats2[35][35] + coeff0_36*dmats2[36][35] + coeff0_37*dmats2[37][35] + coeff0_38*dmats2[38][35] + coeff0_39*dmats2[39][35] + coeff0_40*dmats2[40][35] + coeff0_41*dmats2[41][35] + coeff0_42*dmats2[42][35] + coeff0_43*dmats2[43][35] + coeff0_44*dmats2[44][35] + coeff0_45*dmats2[45][35] + coeff0_46*dmats2[46][35] + coeff0_47*dmats2[47][35] + coeff0_48*dmats2[48][35] + coeff0_49*dmats2[49][35] + coeff0_50*dmats2[50][35] + coeff0_51*dmats2[51][35] + coeff0_52*dmats2[52][35] + coeff0_53*dmats2[53][35] + coeff0_54*dmats2[54][35] + coeff0_55*dmats2[55][35];
          new_coeff0_36 = coeff0_0*dmats2[0][36] + coeff0_1*dmats2[1][36] + coeff0_2*dmats2[2][36] + coeff0_3*dmats2[3][36] + coeff0_4*dmats2[4][36] + coeff0_5*dmats2[5][36] + coeff0_6*dmats2[6][36] + coeff0_7*dmats2[7][36] + coeff0_8*dmats2[8][36] + coeff0_9*dmats2[9][36] + coeff0_10*dmats2[10][36] + coeff0_11*dmats2[11][36] + coeff0_12*dmats2[12][36] + coeff0_13*dmats2[13][36] + coeff0_14*dmats2[14][36] + coeff0_15*dmats2[15][36] + coeff0_16*dmats2[16][36] + coeff0_17*dmats2[17][36] + coeff0_18*dmats2[18][36] + coeff0_19*dmats2[19][36] + coeff0_20*dmats2[20][36] + coeff0_21*dmats2[21][36] + coeff0_22*dmats2[22][36] + coeff0_23*dmats2[23][36] + coeff0_24*dmats2[24][36] + coeff0_25*dmats2[25][36] + coeff0_26*dmats2[26][36] + coeff0_27*dmats2[27][36] + coeff0_28*dmats2[28][36] + coeff0_29*dmats2[29][36] + coeff0_30*dmats2[30][36] + coeff0_31*dmats2[31][36] + coeff0_32*dmats2[32][36] + coeff0_33*dmats2[33][36] + coeff0_34*dmats2[34][36] + coeff0_35*dmats2[35][36] + coeff0_36*dmats2[36][36] + coeff0_37*dmats2[37][36] + coeff0_38*dmats2[38][36] + coeff0_39*dmats2[39][36] + coeff0_40*dmats2[40][36] + coeff0_41*dmats2[41][36] + coeff0_42*dmats2[42][36] + coeff0_43*dmats2[43][36] + coeff0_44*dmats2[44][36] + coeff0_45*dmats2[45][36] + coeff0_46*dmats2[46][36] + coeff0_47*dmats2[47][36] + coeff0_48*dmats2[48][36] + coeff0_49*dmats2[49][36] + coeff0_50*dmats2[50][36] + coeff0_51*dmats2[51][36] + coeff0_52*dmats2[52][36] + coeff0_53*dmats2[53][36] + coeff0_54*dmats2[54][36] + coeff0_55*dmats2[55][36];
          new_coeff0_37 = coeff0_0*dmats2[0][37] + coeff0_1*dmats2[1][37] + coeff0_2*dmats2[2][37] + coeff0_3*dmats2[3][37] + coeff0_4*dmats2[4][37] + coeff0_5*dmats2[5][37] + coeff0_6*dmats2[6][37] + coeff0_7*dmats2[7][37] + coeff0_8*dmats2[8][37] + coeff0_9*dmats2[9][37] + coeff0_10*dmats2[10][37] + coeff0_11*dmats2[11][37] + coeff0_12*dmats2[12][37] + coeff0_13*dmats2[13][37] + coeff0_14*dmats2[14][37] + coeff0_15*dmats2[15][37] + coeff0_16*dmats2[16][37] + coeff0_17*dmats2[17][37] + coeff0_18*dmats2[18][37] + coeff0_19*dmats2[19][37] + coeff0_20*dmats2[20][37] + coeff0_21*dmats2[21][37] + coeff0_22*dmats2[22][37] + coeff0_23*dmats2[23][37] + coeff0_24*dmats2[24][37] + coeff0_25*dmats2[25][37] + coeff0_26*dmats2[26][37] + coeff0_27*dmats2[27][37] + coeff0_28*dmats2[28][37] + coeff0_29*dmats2[29][37] + coeff0_30*dmats2[30][37] + coeff0_31*dmats2[31][37] + coeff0_32*dmats2[32][37] + coeff0_33*dmats2[33][37] + coeff0_34*dmats2[34][37] + coeff0_35*dmats2[35][37] + coeff0_36*dmats2[36][37] + coeff0_37*dmats2[37][37] + coeff0_38*dmats2[38][37] + coeff0_39*dmats2[39][37] + coeff0_40*dmats2[40][37] + coeff0_41*dmats2[41][37] + coeff0_42*dmats2[42][37] + coeff0_43*dmats2[43][37] + coeff0_44*dmats2[44][37] + coeff0_45*dmats2[45][37] + coeff0_46*dmats2[46][37] + coeff0_47*dmats2[47][37] + coeff0_48*dmats2[48][37] + coeff0_49*dmats2[49][37] + coeff0_50*dmats2[50][37] + coeff0_51*dmats2[51][37] + coeff0_52*dmats2[52][37] + coeff0_53*dmats2[53][37] + coeff0_54*dmats2[54][37] + coeff0_55*dmats2[55][37];
          new_coeff0_38 = coeff0_0*dmats2[0][38] + coeff0_1*dmats2[1][38] + coeff0_2*dmats2[2][38] + coeff0_3*dmats2[3][38] + coeff0_4*dmats2[4][38] + coeff0_5*dmats2[5][38] + coeff0_6*dmats2[6][38] + coeff0_7*dmats2[7][38] + coeff0_8*dmats2[8][38] + coeff0_9*dmats2[9][38] + coeff0_10*dmats2[10][38] + coeff0_11*dmats2[11][38] + coeff0_12*dmats2[12][38] + coeff0_13*dmats2[13][38] + coeff0_14*dmats2[14][38] + coeff0_15*dmats2[15][38] + coeff0_16*dmats2[16][38] + coeff0_17*dmats2[17][38] + coeff0_18*dmats2[18][38] + coeff0_19*dmats2[19][38] + coeff0_20*dmats2[20][38] + coeff0_21*dmats2[21][38] + coeff0_22*dmats2[22][38] + coeff0_23*dmats2[23][38] + coeff0_24*dmats2[24][38] + coeff0_25*dmats2[25][38] + coeff0_26*dmats2[26][38] + coeff0_27*dmats2[27][38] + coeff0_28*dmats2[28][38] + coeff0_29*dmats2[29][38] + coeff0_30*dmats2[30][38] + coeff0_31*dmats2[31][38] + coeff0_32*dmats2[32][38] + coeff0_33*dmats2[33][38] + coeff0_34*dmats2[34][38] + coeff0_35*dmats2[35][38] + coeff0_36*dmats2[36][38] + coeff0_37*dmats2[37][38] + coeff0_38*dmats2[38][38] + coeff0_39*dmats2[39][38] + coeff0_40*dmats2[40][38] + coeff0_41*dmats2[41][38] + coeff0_42*dmats2[42][38] + coeff0_43*dmats2[43][38] + coeff0_44*dmats2[44][38] + coeff0_45*dmats2[45][38] + coeff0_46*dmats2[46][38] + coeff0_47*dmats2[47][38] + coeff0_48*dmats2[48][38] + coeff0_49*dmats2[49][38] + coeff0_50*dmats2[50][38] + coeff0_51*dmats2[51][38] + coeff0_52*dmats2[52][38] + coeff0_53*dmats2[53][38] + coeff0_54*dmats2[54][38] + coeff0_55*dmats2[55][38];
          new_coeff0_39 = coeff0_0*dmats2[0][39] + coeff0_1*dmats2[1][39] + coeff0_2*dmats2[2][39] + coeff0_3*dmats2[3][39] + coeff0_4*dmats2[4][39] + coeff0_5*dmats2[5][39] + coeff0_6*dmats2[6][39] + coeff0_7*dmats2[7][39] + coeff0_8*dmats2[8][39] + coeff0_9*dmats2[9][39] + coeff0_10*dmats2[10][39] + coeff0_11*dmats2[11][39] + coeff0_12*dmats2[12][39] + coeff0_13*dmats2[13][39] + coeff0_14*dmats2[14][39] + coeff0_15*dmats2[15][39] + coeff0_16*dmats2[16][39] + coeff0_17*dmats2[17][39] + coeff0_18*dmats2[18][39] + coeff0_19*dmats2[19][39] + coeff0_20*dmats2[20][39] + coeff0_21*dmats2[21][39] + coeff0_22*dmats2[22][39] + coeff0_23*dmats2[23][39] + coeff0_24*dmats2[24][39] + coeff0_25*dmats2[25][39] + coeff0_26*dmats2[26][39] + coeff0_27*dmats2[27][39] + coeff0_28*dmats2[28][39] + coeff0_29*dmats2[29][39] + coeff0_30*dmats2[30][39] + coeff0_31*dmats2[31][39] + coeff0_32*dmats2[32][39] + coeff0_33*dmats2[33][39] + coeff0_34*dmats2[34][39] + coeff0_35*dmats2[35][39] + coeff0_36*dmats2[36][39] + coeff0_37*dmats2[37][39] + coeff0_38*dmats2[38][39] + coeff0_39*dmats2[39][39] + coeff0_40*dmats2[40][39] + coeff0_41*dmats2[41][39] + coeff0_42*dmats2[42][39] + coeff0_43*dmats2[43][39] + coeff0_44*dmats2[44][39] + coeff0_45*dmats2[45][39] + coeff0_46*dmats2[46][39] + coeff0_47*dmats2[47][39] + coeff0_48*dmats2[48][39] + coeff0_49*dmats2[49][39] + coeff0_50*dmats2[50][39] + coeff0_51*dmats2[51][39] + coeff0_52*dmats2[52][39] + coeff0_53*dmats2[53][39] + coeff0_54*dmats2[54][39] + coeff0_55*dmats2[55][39];
          new_coeff0_40 = coeff0_0*dmats2[0][40] + coeff0_1*dmats2[1][40] + coeff0_2*dmats2[2][40] + coeff0_3*dmats2[3][40] + coeff0_4*dmats2[4][40] + coeff0_5*dmats2[5][40] + coeff0_6*dmats2[6][40] + coeff0_7*dmats2[7][40] + coeff0_8*dmats2[8][40] + coeff0_9*dmats2[9][40] + coeff0_10*dmats2[10][40] + coeff0_11*dmats2[11][40] + coeff0_12*dmats2[12][40] + coeff0_13*dmats2[13][40] + coeff0_14*dmats2[14][40] + coeff0_15*dmats2[15][40] + coeff0_16*dmats2[16][40] + coeff0_17*dmats2[17][40] + coeff0_18*dmats2[18][40] + coeff0_19*dmats2[19][40] + coeff0_20*dmats2[20][40] + coeff0_21*dmats2[21][40] + coeff0_22*dmats2[22][40] + coeff0_23*dmats2[23][40] + coeff0_24*dmats2[24][40] + coeff0_25*dmats2[25][40] + coeff0_26*dmats2[26][40] + coeff0_27*dmats2[27][40] + coeff0_28*dmats2[28][40] + coeff0_29*dmats2[29][40] + coeff0_30*dmats2[30][40] + coeff0_31*dmats2[31][40] + coeff0_32*dmats2[32][40] + coeff0_33*dmats2[33][40] + coeff0_34*dmats2[34][40] + coeff0_35*dmats2[35][40] + coeff0_36*dmats2[36][40] + coeff0_37*dmats2[37][40] + coeff0_38*dmats2[38][40] + coeff0_39*dmats2[39][40] + coeff0_40*dmats2[40][40] + coeff0_41*dmats2[41][40] + coeff0_42*dmats2[42][40] + coeff0_43*dmats2[43][40] + coeff0_44*dmats2[44][40] + coeff0_45*dmats2[45][40] + coeff0_46*dmats2[46][40] + coeff0_47*dmats2[47][40] + coeff0_48*dmats2[48][40] + coeff0_49*dmats2[49][40] + coeff0_50*dmats2[50][40] + coeff0_51*dmats2[51][40] + coeff0_52*dmats2[52][40] + coeff0_53*dmats2[53][40] + coeff0_54*dmats2[54][40] + coeff0_55*dmats2[55][40];
          new_coeff0_41 = coeff0_0*dmats2[0][41] + coeff0_1*dmats2[1][41] + coeff0_2*dmats2[2][41] + coeff0_3*dmats2[3][41] + coeff0_4*dmats2[4][41] + coeff0_5*dmats2[5][41] + coeff0_6*dmats2[6][41] + coeff0_7*dmats2[7][41] + coeff0_8*dmats2[8][41] + coeff0_9*dmats2[9][41] + coeff0_10*dmats2[10][41] + coeff0_11*dmats2[11][41] + coeff0_12*dmats2[12][41] + coeff0_13*dmats2[13][41] + coeff0_14*dmats2[14][41] + coeff0_15*dmats2[15][41] + coeff0_16*dmats2[16][41] + coeff0_17*dmats2[17][41] + coeff0_18*dmats2[18][41] + coeff0_19*dmats2[19][41] + coeff0_20*dmats2[20][41] + coeff0_21*dmats2[21][41] + coeff0_22*dmats2[22][41] + coeff0_23*dmats2[23][41] + coeff0_24*dmats2[24][41] + coeff0_25*dmats2[25][41] + coeff0_26*dmats2[26][41] + coeff0_27*dmats2[27][41] + coeff0_28*dmats2[28][41] + coeff0_29*dmats2[29][41] + coeff0_30*dmats2[30][41] + coeff0_31*dmats2[31][41] + coeff0_32*dmats2[32][41] + coeff0_33*dmats2[33][41] + coeff0_34*dmats2[34][41] + coeff0_35*dmats2[35][41] + coeff0_36*dmats2[36][41] + coeff0_37*dmats2[37][41] + coeff0_38*dmats2[38][41] + coeff0_39*dmats2[39][41] + coeff0_40*dmats2[40][41] + coeff0_41*dmats2[41][41] + coeff0_42*dmats2[42][41] + coeff0_43*dmats2[43][41] + coeff0_44*dmats2[44][41] + coeff0_45*dmats2[45][41] + coeff0_46*dmats2[46][41] + coeff0_47*dmats2[47][41] + coeff0_48*dmats2[48][41] + coeff0_49*dmats2[49][41] + coeff0_50*dmats2[50][41] + coeff0_51*dmats2[51][41] + coeff0_52*dmats2[52][41] + coeff0_53*dmats2[53][41] + coeff0_54*dmats2[54][41] + coeff0_55*dmats2[55][41];
          new_coeff0_42 = coeff0_0*dmats2[0][42] + coeff0_1*dmats2[1][42] + coeff0_2*dmats2[2][42] + coeff0_3*dmats2[3][42] + coeff0_4*dmats2[4][42] + coeff0_5*dmats2[5][42] + coeff0_6*dmats2[6][42] + coeff0_7*dmats2[7][42] + coeff0_8*dmats2[8][42] + coeff0_9*dmats2[9][42] + coeff0_10*dmats2[10][42] + coeff0_11*dmats2[11][42] + coeff0_12*dmats2[12][42] + coeff0_13*dmats2[13][42] + coeff0_14*dmats2[14][42] + coeff0_15*dmats2[15][42] + coeff0_16*dmats2[16][42] + coeff0_17*dmats2[17][42] + coeff0_18*dmats2[18][42] + coeff0_19*dmats2[19][42] + coeff0_20*dmats2[20][42] + coeff0_21*dmats2[21][42] + coeff0_22*dmats2[22][42] + coeff0_23*dmats2[23][42] + coeff0_24*dmats2[24][42] + coeff0_25*dmats2[25][42] + coeff0_26*dmats2[26][42] + coeff0_27*dmats2[27][42] + coeff0_28*dmats2[28][42] + coeff0_29*dmats2[29][42] + coeff0_30*dmats2[30][42] + coeff0_31*dmats2[31][42] + coeff0_32*dmats2[32][42] + coeff0_33*dmats2[33][42] + coeff0_34*dmats2[34][42] + coeff0_35*dmats2[35][42] + coeff0_36*dmats2[36][42] + coeff0_37*dmats2[37][42] + coeff0_38*dmats2[38][42] + coeff0_39*dmats2[39][42] + coeff0_40*dmats2[40][42] + coeff0_41*dmats2[41][42] + coeff0_42*dmats2[42][42] + coeff0_43*dmats2[43][42] + coeff0_44*dmats2[44][42] + coeff0_45*dmats2[45][42] + coeff0_46*dmats2[46][42] + coeff0_47*dmats2[47][42] + coeff0_48*dmats2[48][42] + coeff0_49*dmats2[49][42] + coeff0_50*dmats2[50][42] + coeff0_51*dmats2[51][42] + coeff0_52*dmats2[52][42] + coeff0_53*dmats2[53][42] + coeff0_54*dmats2[54][42] + coeff0_55*dmats2[55][42];
          new_coeff0_43 = coeff0_0*dmats2[0][43] + coeff0_1*dmats2[1][43] + coeff0_2*dmats2[2][43] + coeff0_3*dmats2[3][43] + coeff0_4*dmats2[4][43] + coeff0_5*dmats2[5][43] + coeff0_6*dmats2[6][43] + coeff0_7*dmats2[7][43] + coeff0_8*dmats2[8][43] + coeff0_9*dmats2[9][43] + coeff0_10*dmats2[10][43] + coeff0_11*dmats2[11][43] + coeff0_12*dmats2[12][43] + coeff0_13*dmats2[13][43] + coeff0_14*dmats2[14][43] + coeff0_15*dmats2[15][43] + coeff0_16*dmats2[16][43] + coeff0_17*dmats2[17][43] + coeff0_18*dmats2[18][43] + coeff0_19*dmats2[19][43] + coeff0_20*dmats2[20][43] + coeff0_21*dmats2[21][43] + coeff0_22*dmats2[22][43] + coeff0_23*dmats2[23][43] + coeff0_24*dmats2[24][43] + coeff0_25*dmats2[25][43] + coeff0_26*dmats2[26][43] + coeff0_27*dmats2[27][43] + coeff0_28*dmats2[28][43] + coeff0_29*dmats2[29][43] + coeff0_30*dmats2[30][43] + coeff0_31*dmats2[31][43] + coeff0_32*dmats2[32][43] + coeff0_33*dmats2[33][43] + coeff0_34*dmats2[34][43] + coeff0_35*dmats2[35][43] + coeff0_36*dmats2[36][43] + coeff0_37*dmats2[37][43] + coeff0_38*dmats2[38][43] + coeff0_39*dmats2[39][43] + coeff0_40*dmats2[40][43] + coeff0_41*dmats2[41][43] + coeff0_42*dmats2[42][43] + coeff0_43*dmats2[43][43] + coeff0_44*dmats2[44][43] + coeff0_45*dmats2[45][43] + coeff0_46*dmats2[46][43] + coeff0_47*dmats2[47][43] + coeff0_48*dmats2[48][43] + coeff0_49*dmats2[49][43] + coeff0_50*dmats2[50][43] + coeff0_51*dmats2[51][43] + coeff0_52*dmats2[52][43] + coeff0_53*dmats2[53][43] + coeff0_54*dmats2[54][43] + coeff0_55*dmats2[55][43];
          new_coeff0_44 = coeff0_0*dmats2[0][44] + coeff0_1*dmats2[1][44] + coeff0_2*dmats2[2][44] + coeff0_3*dmats2[3][44] + coeff0_4*dmats2[4][44] + coeff0_5*dmats2[5][44] + coeff0_6*dmats2[6][44] + coeff0_7*dmats2[7][44] + coeff0_8*dmats2[8][44] + coeff0_9*dmats2[9][44] + coeff0_10*dmats2[10][44] + coeff0_11*dmats2[11][44] + coeff0_12*dmats2[12][44] + coeff0_13*dmats2[13][44] + coeff0_14*dmats2[14][44] + coeff0_15*dmats2[15][44] + coeff0_16*dmats2[16][44] + coeff0_17*dmats2[17][44] + coeff0_18*dmats2[18][44] + coeff0_19*dmats2[19][44] + coeff0_20*dmats2[20][44] + coeff0_21*dmats2[21][44] + coeff0_22*dmats2[22][44] + coeff0_23*dmats2[23][44] + coeff0_24*dmats2[24][44] + coeff0_25*dmats2[25][44] + coeff0_26*dmats2[26][44] + coeff0_27*dmats2[27][44] + coeff0_28*dmats2[28][44] + coeff0_29*dmats2[29][44] + coeff0_30*dmats2[30][44] + coeff0_31*dmats2[31][44] + coeff0_32*dmats2[32][44] + coeff0_33*dmats2[33][44] + coeff0_34*dmats2[34][44] + coeff0_35*dmats2[35][44] + coeff0_36*dmats2[36][44] + coeff0_37*dmats2[37][44] + coeff0_38*dmats2[38][44] + coeff0_39*dmats2[39][44] + coeff0_40*dmats2[40][44] + coeff0_41*dmats2[41][44] + coeff0_42*dmats2[42][44] + coeff0_43*dmats2[43][44] + coeff0_44*dmats2[44][44] + coeff0_45*dmats2[45][44] + coeff0_46*dmats2[46][44] + coeff0_47*dmats2[47][44] + coeff0_48*dmats2[48][44] + coeff0_49*dmats2[49][44] + coeff0_50*dmats2[50][44] + coeff0_51*dmats2[51][44] + coeff0_52*dmats2[52][44] + coeff0_53*dmats2[53][44] + coeff0_54*dmats2[54][44] + coeff0_55*dmats2[55][44];
          new_coeff0_45 = coeff0_0*dmats2[0][45] + coeff0_1*dmats2[1][45] + coeff0_2*dmats2[2][45] + coeff0_3*dmats2[3][45] + coeff0_4*dmats2[4][45] + coeff0_5*dmats2[5][45] + coeff0_6*dmats2[6][45] + coeff0_7*dmats2[7][45] + coeff0_8*dmats2[8][45] + coeff0_9*dmats2[9][45] + coeff0_10*dmats2[10][45] + coeff0_11*dmats2[11][45] + coeff0_12*dmats2[12][45] + coeff0_13*dmats2[13][45] + coeff0_14*dmats2[14][45] + coeff0_15*dmats2[15][45] + coeff0_16*dmats2[16][45] + coeff0_17*dmats2[17][45] + coeff0_18*dmats2[18][45] + coeff0_19*dmats2[19][45] + coeff0_20*dmats2[20][45] + coeff0_21*dmats2[21][45] + coeff0_22*dmats2[22][45] + coeff0_23*dmats2[23][45] + coeff0_24*dmats2[24][45] + coeff0_25*dmats2[25][45] + coeff0_26*dmats2[26][45] + coeff0_27*dmats2[27][45] + coeff0_28*dmats2[28][45] + coeff0_29*dmats2[29][45] + coeff0_30*dmats2[30][45] + coeff0_31*dmats2[31][45] + coeff0_32*dmats2[32][45] + coeff0_33*dmats2[33][45] + coeff0_34*dmats2[34][45] + coeff0_35*dmats2[35][45] + coeff0_36*dmats2[36][45] + coeff0_37*dmats2[37][45] + coeff0_38*dmats2[38][45] + coeff0_39*dmats2[39][45] + coeff0_40*dmats2[40][45] + coeff0_41*dmats2[41][45] + coeff0_42*dmats2[42][45] + coeff0_43*dmats2[43][45] + coeff0_44*dmats2[44][45] + coeff0_45*dmats2[45][45] + coeff0_46*dmats2[46][45] + coeff0_47*dmats2[47][45] + coeff0_48*dmats2[48][45] + coeff0_49*dmats2[49][45] + coeff0_50*dmats2[50][45] + coeff0_51*dmats2[51][45] + coeff0_52*dmats2[52][45] + coeff0_53*dmats2[53][45] + coeff0_54*dmats2[54][45] + coeff0_55*dmats2[55][45];
          new_coeff0_46 = coeff0_0*dmats2[0][46] + coeff0_1*dmats2[1][46] + coeff0_2*dmats2[2][46] + coeff0_3*dmats2[3][46] + coeff0_4*dmats2[4][46] + coeff0_5*dmats2[5][46] + coeff0_6*dmats2[6][46] + coeff0_7*dmats2[7][46] + coeff0_8*dmats2[8][46] + coeff0_9*dmats2[9][46] + coeff0_10*dmats2[10][46] + coeff0_11*dmats2[11][46] + coeff0_12*dmats2[12][46] + coeff0_13*dmats2[13][46] + coeff0_14*dmats2[14][46] + coeff0_15*dmats2[15][46] + coeff0_16*dmats2[16][46] + coeff0_17*dmats2[17][46] + coeff0_18*dmats2[18][46] + coeff0_19*dmats2[19][46] + coeff0_20*dmats2[20][46] + coeff0_21*dmats2[21][46] + coeff0_22*dmats2[22][46] + coeff0_23*dmats2[23][46] + coeff0_24*dmats2[24][46] + coeff0_25*dmats2[25][46] + coeff0_26*dmats2[26][46] + coeff0_27*dmats2[27][46] + coeff0_28*dmats2[28][46] + coeff0_29*dmats2[29][46] + coeff0_30*dmats2[30][46] + coeff0_31*dmats2[31][46] + coeff0_32*dmats2[32][46] + coeff0_33*dmats2[33][46] + coeff0_34*dmats2[34][46] + coeff0_35*dmats2[35][46] + coeff0_36*dmats2[36][46] + coeff0_37*dmats2[37][46] + coeff0_38*dmats2[38][46] + coeff0_39*dmats2[39][46] + coeff0_40*dmats2[40][46] + coeff0_41*dmats2[41][46] + coeff0_42*dmats2[42][46] + coeff0_43*dmats2[43][46] + coeff0_44*dmats2[44][46] + coeff0_45*dmats2[45][46] + coeff0_46*dmats2[46][46] + coeff0_47*dmats2[47][46] + coeff0_48*dmats2[48][46] + coeff0_49*dmats2[49][46] + coeff0_50*dmats2[50][46] + coeff0_51*dmats2[51][46] + coeff0_52*dmats2[52][46] + coeff0_53*dmats2[53][46] + coeff0_54*dmats2[54][46] + coeff0_55*dmats2[55][46];
          new_coeff0_47 = coeff0_0*dmats2[0][47] + coeff0_1*dmats2[1][47] + coeff0_2*dmats2[2][47] + coeff0_3*dmats2[3][47] + coeff0_4*dmats2[4][47] + coeff0_5*dmats2[5][47] + coeff0_6*dmats2[6][47] + coeff0_7*dmats2[7][47] + coeff0_8*dmats2[8][47] + coeff0_9*dmats2[9][47] + coeff0_10*dmats2[10][47] + coeff0_11*dmats2[11][47] + coeff0_12*dmats2[12][47] + coeff0_13*dmats2[13][47] + coeff0_14*dmats2[14][47] + coeff0_15*dmats2[15][47] + coeff0_16*dmats2[16][47] + coeff0_17*dmats2[17][47] + coeff0_18*dmats2[18][47] + coeff0_19*dmats2[19][47] + coeff0_20*dmats2[20][47] + coeff0_21*dmats2[21][47] + coeff0_22*dmats2[22][47] + coeff0_23*dmats2[23][47] + coeff0_24*dmats2[24][47] + coeff0_25*dmats2[25][47] + coeff0_26*dmats2[26][47] + coeff0_27*dmats2[27][47] + coeff0_28*dmats2[28][47] + coeff0_29*dmats2[29][47] + coeff0_30*dmats2[30][47] + coeff0_31*dmats2[31][47] + coeff0_32*dmats2[32][47] + coeff0_33*dmats2[33][47] + coeff0_34*dmats2[34][47] + coeff0_35*dmats2[35][47] + coeff0_36*dmats2[36][47] + coeff0_37*dmats2[37][47] + coeff0_38*dmats2[38][47] + coeff0_39*dmats2[39][47] + coeff0_40*dmats2[40][47] + coeff0_41*dmats2[41][47] + coeff0_42*dmats2[42][47] + coeff0_43*dmats2[43][47] + coeff0_44*dmats2[44][47] + coeff0_45*dmats2[45][47] + coeff0_46*dmats2[46][47] + coeff0_47*dmats2[47][47] + coeff0_48*dmats2[48][47] + coeff0_49*dmats2[49][47] + coeff0_50*dmats2[50][47] + coeff0_51*dmats2[51][47] + coeff0_52*dmats2[52][47] + coeff0_53*dmats2[53][47] + coeff0_54*dmats2[54][47] + coeff0_55*dmats2[55][47];
          new_coeff0_48 = coeff0_0*dmats2[0][48] + coeff0_1*dmats2[1][48] + coeff0_2*dmats2[2][48] + coeff0_3*dmats2[3][48] + coeff0_4*dmats2[4][48] + coeff0_5*dmats2[5][48] + coeff0_6*dmats2[6][48] + coeff0_7*dmats2[7][48] + coeff0_8*dmats2[8][48] + coeff0_9*dmats2[9][48] + coeff0_10*dmats2[10][48] + coeff0_11*dmats2[11][48] + coeff0_12*dmats2[12][48] + coeff0_13*dmats2[13][48] + coeff0_14*dmats2[14][48] + coeff0_15*dmats2[15][48] + coeff0_16*dmats2[16][48] + coeff0_17*dmats2[17][48] + coeff0_18*dmats2[18][48] + coeff0_19*dmats2[19][48] + coeff0_20*dmats2[20][48] + coeff0_21*dmats2[21][48] + coeff0_22*dmats2[22][48] + coeff0_23*dmats2[23][48] + coeff0_24*dmats2[24][48] + coeff0_25*dmats2[25][48] + coeff0_26*dmats2[26][48] + coeff0_27*dmats2[27][48] + coeff0_28*dmats2[28][48] + coeff0_29*dmats2[29][48] + coeff0_30*dmats2[30][48] + coeff0_31*dmats2[31][48] + coeff0_32*dmats2[32][48] + coeff0_33*dmats2[33][48] + coeff0_34*dmats2[34][48] + coeff0_35*dmats2[35][48] + coeff0_36*dmats2[36][48] + coeff0_37*dmats2[37][48] + coeff0_38*dmats2[38][48] + coeff0_39*dmats2[39][48] + coeff0_40*dmats2[40][48] + coeff0_41*dmats2[41][48] + coeff0_42*dmats2[42][48] + coeff0_43*dmats2[43][48] + coeff0_44*dmats2[44][48] + coeff0_45*dmats2[45][48] + coeff0_46*dmats2[46][48] + coeff0_47*dmats2[47][48] + coeff0_48*dmats2[48][48] + coeff0_49*dmats2[49][48] + coeff0_50*dmats2[50][48] + coeff0_51*dmats2[51][48] + coeff0_52*dmats2[52][48] + coeff0_53*dmats2[53][48] + coeff0_54*dmats2[54][48] + coeff0_55*dmats2[55][48];
          new_coeff0_49 = coeff0_0*dmats2[0][49] + coeff0_1*dmats2[1][49] + coeff0_2*dmats2[2][49] + coeff0_3*dmats2[3][49] + coeff0_4*dmats2[4][49] + coeff0_5*dmats2[5][49] + coeff0_6*dmats2[6][49] + coeff0_7*dmats2[7][49] + coeff0_8*dmats2[8][49] + coeff0_9*dmats2[9][49] + coeff0_10*dmats2[10][49] + coeff0_11*dmats2[11][49] + coeff0_12*dmats2[12][49] + coeff0_13*dmats2[13][49] + coeff0_14*dmats2[14][49] + coeff0_15*dmats2[15][49] + coeff0_16*dmats2[16][49] + coeff0_17*dmats2[17][49] + coeff0_18*dmats2[18][49] + coeff0_19*dmats2[19][49] + coeff0_20*dmats2[20][49] + coeff0_21*dmats2[21][49] + coeff0_22*dmats2[22][49] + coeff0_23*dmats2[23][49] + coeff0_24*dmats2[24][49] + coeff0_25*dmats2[25][49] + coeff0_26*dmats2[26][49] + coeff0_27*dmats2[27][49] + coeff0_28*dmats2[28][49] + coeff0_29*dmats2[29][49] + coeff0_30*dmats2[30][49] + coeff0_31*dmats2[31][49] + coeff0_32*dmats2[32][49] + coeff0_33*dmats2[33][49] + coeff0_34*dmats2[34][49] + coeff0_35*dmats2[35][49] + coeff0_36*dmats2[36][49] + coeff0_37*dmats2[37][49] + coeff0_38*dmats2[38][49] + coeff0_39*dmats2[39][49] + coeff0_40*dmats2[40][49] + coeff0_41*dmats2[41][49] + coeff0_42*dmats2[42][49] + coeff0_43*dmats2[43][49] + coeff0_44*dmats2[44][49] + coeff0_45*dmats2[45][49] + coeff0_46*dmats2[46][49] + coeff0_47*dmats2[47][49] + coeff0_48*dmats2[48][49] + coeff0_49*dmats2[49][49] + coeff0_50*dmats2[50][49] + coeff0_51*dmats2[51][49] + coeff0_52*dmats2[52][49] + coeff0_53*dmats2[53][49] + coeff0_54*dmats2[54][49] + coeff0_55*dmats2[55][49];
          new_coeff0_50 = coeff0_0*dmats2[0][50] + coeff0_1*dmats2[1][50] + coeff0_2*dmats2[2][50] + coeff0_3*dmats2[3][50] + coeff0_4*dmats2[4][50] + coeff0_5*dmats2[5][50] + coeff0_6*dmats2[6][50] + coeff0_7*dmats2[7][50] + coeff0_8*dmats2[8][50] + coeff0_9*dmats2[9][50] + coeff0_10*dmats2[10][50] + coeff0_11*dmats2[11][50] + coeff0_12*dmats2[12][50] + coeff0_13*dmats2[13][50] + coeff0_14*dmats2[14][50] + coeff0_15*dmats2[15][50] + coeff0_16*dmats2[16][50] + coeff0_17*dmats2[17][50] + coeff0_18*dmats2[18][50] + coeff0_19*dmats2[19][50] + coeff0_20*dmats2[20][50] + coeff0_21*dmats2[21][50] + coeff0_22*dmats2[22][50] + coeff0_23*dmats2[23][50] + coeff0_24*dmats2[24][50] + coeff0_25*dmats2[25][50] + coeff0_26*dmats2[26][50] + coeff0_27*dmats2[27][50] + coeff0_28*dmats2[28][50] + coeff0_29*dmats2[29][50] + coeff0_30*dmats2[30][50] + coeff0_31*dmats2[31][50] + coeff0_32*dmats2[32][50] + coeff0_33*dmats2[33][50] + coeff0_34*dmats2[34][50] + coeff0_35*dmats2[35][50] + coeff0_36*dmats2[36][50] + coeff0_37*dmats2[37][50] + coeff0_38*dmats2[38][50] + coeff0_39*dmats2[39][50] + coeff0_40*dmats2[40][50] + coeff0_41*dmats2[41][50] + coeff0_42*dmats2[42][50] + coeff0_43*dmats2[43][50] + coeff0_44*dmats2[44][50] + coeff0_45*dmats2[45][50] + coeff0_46*dmats2[46][50] + coeff0_47*dmats2[47][50] + coeff0_48*dmats2[48][50] + coeff0_49*dmats2[49][50] + coeff0_50*dmats2[50][50] + coeff0_51*dmats2[51][50] + coeff0_52*dmats2[52][50] + coeff0_53*dmats2[53][50] + coeff0_54*dmats2[54][50] + coeff0_55*dmats2[55][50];
          new_coeff0_51 = coeff0_0*dmats2[0][51] + coeff0_1*dmats2[1][51] + coeff0_2*dmats2[2][51] + coeff0_3*dmats2[3][51] + coeff0_4*dmats2[4][51] + coeff0_5*dmats2[5][51] + coeff0_6*dmats2[6][51] + coeff0_7*dmats2[7][51] + coeff0_8*dmats2[8][51] + coeff0_9*dmats2[9][51] + coeff0_10*dmats2[10][51] + coeff0_11*dmats2[11][51] + coeff0_12*dmats2[12][51] + coeff0_13*dmats2[13][51] + coeff0_14*dmats2[14][51] + coeff0_15*dmats2[15][51] + coeff0_16*dmats2[16][51] + coeff0_17*dmats2[17][51] + coeff0_18*dmats2[18][51] + coeff0_19*dmats2[19][51] + coeff0_20*dmats2[20][51] + coeff0_21*dmats2[21][51] + coeff0_22*dmats2[22][51] + coeff0_23*dmats2[23][51] + coeff0_24*dmats2[24][51] + coeff0_25*dmats2[25][51] + coeff0_26*dmats2[26][51] + coeff0_27*dmats2[27][51] + coeff0_28*dmats2[28][51] + coeff0_29*dmats2[29][51] + coeff0_30*dmats2[30][51] + coeff0_31*dmats2[31][51] + coeff0_32*dmats2[32][51] + coeff0_33*dmats2[33][51] + coeff0_34*dmats2[34][51] + coeff0_35*dmats2[35][51] + coeff0_36*dmats2[36][51] + coeff0_37*dmats2[37][51] + coeff0_38*dmats2[38][51] + coeff0_39*dmats2[39][51] + coeff0_40*dmats2[40][51] + coeff0_41*dmats2[41][51] + coeff0_42*dmats2[42][51] + coeff0_43*dmats2[43][51] + coeff0_44*dmats2[44][51] + coeff0_45*dmats2[45][51] + coeff0_46*dmats2[46][51] + coeff0_47*dmats2[47][51] + coeff0_48*dmats2[48][51] + coeff0_49*dmats2[49][51] + coeff0_50*dmats2[50][51] + coeff0_51*dmats2[51][51] + coeff0_52*dmats2[52][51] + coeff0_53*dmats2[53][51] + coeff0_54*dmats2[54][51] + coeff0_55*dmats2[55][51];
          new_coeff0_52 = coeff0_0*dmats2[0][52] + coeff0_1*dmats2[1][52] + coeff0_2*dmats2[2][52] + coeff0_3*dmats2[3][52] + coeff0_4*dmats2[4][52] + coeff0_5*dmats2[5][52] + coeff0_6*dmats2[6][52] + coeff0_7*dmats2[7][52] + coeff0_8*dmats2[8][52] + coeff0_9*dmats2[9][52] + coeff0_10*dmats2[10][52] + coeff0_11*dmats2[11][52] + coeff0_12*dmats2[12][52] + coeff0_13*dmats2[13][52] + coeff0_14*dmats2[14][52] + coeff0_15*dmats2[15][52] + coeff0_16*dmats2[16][52] + coeff0_17*dmats2[17][52] + coeff0_18*dmats2[18][52] + coeff0_19*dmats2[19][52] + coeff0_20*dmats2[20][52] + coeff0_21*dmats2[21][52] + coeff0_22*dmats2[22][52] + coeff0_23*dmats2[23][52] + coeff0_24*dmats2[24][52] + coeff0_25*dmats2[25][52] + coeff0_26*dmats2[26][52] + coeff0_27*dmats2[27][52] + coeff0_28*dmats2[28][52] + coeff0_29*dmats2[29][52] + coeff0_30*dmats2[30][52] + coeff0_31*dmats2[31][52] + coeff0_32*dmats2[32][52] + coeff0_33*dmats2[33][52] + coeff0_34*dmats2[34][52] + coeff0_35*dmats2[35][52] + coeff0_36*dmats2[36][52] + coeff0_37*dmats2[37][52] + coeff0_38*dmats2[38][52] + coeff0_39*dmats2[39][52] + coeff0_40*dmats2[40][52] + coeff0_41*dmats2[41][52] + coeff0_42*dmats2[42][52] + coeff0_43*dmats2[43][52] + coeff0_44*dmats2[44][52] + coeff0_45*dmats2[45][52] + coeff0_46*dmats2[46][52] + coeff0_47*dmats2[47][52] + coeff0_48*dmats2[48][52] + coeff0_49*dmats2[49][52] + coeff0_50*dmats2[50][52] + coeff0_51*dmats2[51][52] + coeff0_52*dmats2[52][52] + coeff0_53*dmats2[53][52] + coeff0_54*dmats2[54][52] + coeff0_55*dmats2[55][52];
          new_coeff0_53 = coeff0_0*dmats2[0][53] + coeff0_1*dmats2[1][53] + coeff0_2*dmats2[2][53] + coeff0_3*dmats2[3][53] + coeff0_4*dmats2[4][53] + coeff0_5*dmats2[5][53] + coeff0_6*dmats2[6][53] + coeff0_7*dmats2[7][53] + coeff0_8*dmats2[8][53] + coeff0_9*dmats2[9][53] + coeff0_10*dmats2[10][53] + coeff0_11*dmats2[11][53] + coeff0_12*dmats2[12][53] + coeff0_13*dmats2[13][53] + coeff0_14*dmats2[14][53] + coeff0_15*dmats2[15][53] + coeff0_16*dmats2[16][53] + coeff0_17*dmats2[17][53] + coeff0_18*dmats2[18][53] + coeff0_19*dmats2[19][53] + coeff0_20*dmats2[20][53] + coeff0_21*dmats2[21][53] + coeff0_22*dmats2[22][53] + coeff0_23*dmats2[23][53] + coeff0_24*dmats2[24][53] + coeff0_25*dmats2[25][53] + coeff0_26*dmats2[26][53] + coeff0_27*dmats2[27][53] + coeff0_28*dmats2[28][53] + coeff0_29*dmats2[29][53] + coeff0_30*dmats2[30][53] + coeff0_31*dmats2[31][53] + coeff0_32*dmats2[32][53] + coeff0_33*dmats2[33][53] + coeff0_34*dmats2[34][53] + coeff0_35*dmats2[35][53] + coeff0_36*dmats2[36][53] + coeff0_37*dmats2[37][53] + coeff0_38*dmats2[38][53] + coeff0_39*dmats2[39][53] + coeff0_40*dmats2[40][53] + coeff0_41*dmats2[41][53] + coeff0_42*dmats2[42][53] + coeff0_43*dmats2[43][53] + coeff0_44*dmats2[44][53] + coeff0_45*dmats2[45][53] + coeff0_46*dmats2[46][53] + coeff0_47*dmats2[47][53] + coeff0_48*dmats2[48][53] + coeff0_49*dmats2[49][53] + coeff0_50*dmats2[50][53] + coeff0_51*dmats2[51][53] + coeff0_52*dmats2[52][53] + coeff0_53*dmats2[53][53] + coeff0_54*dmats2[54][53] + coeff0_55*dmats2[55][53];
          new_coeff0_54 = coeff0_0*dmats2[0][54] + coeff0_1*dmats2[1][54] + coeff0_2*dmats2[2][54] + coeff0_3*dmats2[3][54] + coeff0_4*dmats2[4][54] + coeff0_5*dmats2[5][54] + coeff0_6*dmats2[6][54] + coeff0_7*dmats2[7][54] + coeff0_8*dmats2[8][54] + coeff0_9*dmats2[9][54] + coeff0_10*dmats2[10][54] + coeff0_11*dmats2[11][54] + coeff0_12*dmats2[12][54] + coeff0_13*dmats2[13][54] + coeff0_14*dmats2[14][54] + coeff0_15*dmats2[15][54] + coeff0_16*dmats2[16][54] + coeff0_17*dmats2[17][54] + coeff0_18*dmats2[18][54] + coeff0_19*dmats2[19][54] + coeff0_20*dmats2[20][54] + coeff0_21*dmats2[21][54] + coeff0_22*dmats2[22][54] + coeff0_23*dmats2[23][54] + coeff0_24*dmats2[24][54] + coeff0_25*dmats2[25][54] + coeff0_26*dmats2[26][54] + coeff0_27*dmats2[27][54] + coeff0_28*dmats2[28][54] + coeff0_29*dmats2[29][54] + coeff0_30*dmats2[30][54] + coeff0_31*dmats2[31][54] + coeff0_32*dmats2[32][54] + coeff0_33*dmats2[33][54] + coeff0_34*dmats2[34][54] + coeff0_35*dmats2[35][54] + coeff0_36*dmats2[36][54] + coeff0_37*dmats2[37][54] + coeff0_38*dmats2[38][54] + coeff0_39*dmats2[39][54] + coeff0_40*dmats2[40][54] + coeff0_41*dmats2[41][54] + coeff0_42*dmats2[42][54] + coeff0_43*dmats2[43][54] + coeff0_44*dmats2[44][54] + coeff0_45*dmats2[45][54] + coeff0_46*dmats2[46][54] + coeff0_47*dmats2[47][54] + coeff0_48*dmats2[48][54] + coeff0_49*dmats2[49][54] + coeff0_50*dmats2[50][54] + coeff0_51*dmats2[51][54] + coeff0_52*dmats2[52][54] + coeff0_53*dmats2[53][54] + coeff0_54*dmats2[54][54] + coeff0_55*dmats2[55][54];
          new_coeff0_55 = coeff0_0*dmats2[0][55] + coeff0_1*dmats2[1][55] + coeff0_2*dmats2[2][55] + coeff0_3*dmats2[3][55] + coeff0_4*dmats2[4][55] + coeff0_5*dmats2[5][55] + coeff0_6*dmats2[6][55] + coeff0_7*dmats2[7][55] + coeff0_8*dmats2[8][55] + coeff0_9*dmats2[9][55] + coeff0_10*dmats2[10][55] + coeff0_11*dmats2[11][55] + coeff0_12*dmats2[12][55] + coeff0_13*dmats2[13][55] + coeff0_14*dmats2[14][55] + coeff0_15*dmats2[15][55] + coeff0_16*dmats2[16][55] + coeff0_17*dmats2[17][55] + coeff0_18*dmats2[18][55] + coeff0_19*dmats2[19][55] + coeff0_20*dmats2[20][55] + coeff0_21*dmats2[21][55] + coeff0_22*dmats2[22][55] + coeff0_23*dmats2[23][55] + coeff0_24*dmats2[24][55] + coeff0_25*dmats2[25][55] + coeff0_26*dmats2[26][55] + coeff0_27*dmats2[27][55] + coeff0_28*dmats2[28][55] + coeff0_29*dmats2[29][55] + coeff0_30*dmats2[30][55] + coeff0_31*dmats2[31][55] + coeff0_32*dmats2[32][55] + coeff0_33*dmats2[33][55] + coeff0_34*dmats2[34][55] + coeff0_35*dmats2[35][55] + coeff0_36*dmats2[36][55] + coeff0_37*dmats2[37][55] + coeff0_38*dmats2[38][55] + coeff0_39*dmats2[39][55] + coeff0_40*dmats2[40][55] + coeff0_41*dmats2[41][55] + coeff0_42*dmats2[42][55] + coeff0_43*dmats2[43][55] + coeff0_44*dmats2[44][55] + coeff0_45*dmats2[45][55] + coeff0_46*dmats2[46][55] + coeff0_47*dmats2[47][55] + coeff0_48*dmats2[48][55] + coeff0_49*dmats2[49][55] + coeff0_50*dmats2[50][55] + coeff0_51*dmats2[51][55] + coeff0_52*dmats2[52][55] + coeff0_53*dmats2[53][55] + coeff0_54*dmats2[54][55] + coeff0_55*dmats2[55][55];
        }
    
      }
      // Compute derivatives on reference element as dot product of coefficients and basisvalues
      derivatives[deriv_num] = new_coeff0_0*basisvalue0 + new_coeff0_1*basisvalue1 + new_coeff0_2*basisvalue2 + new_coeff0_3*basisvalue3 + new_coeff0_4*basisvalue4 + new_coeff0_5*basisvalue5 + new_coeff0_6*basisvalue6 + new_coeff0_7*basisvalue7 + new_coeff0_8*basisvalue8 + new_coeff0_9*basisvalue9 + new_coeff0_10*basisvalue10 + new_coeff0_11*basisvalue11 + new_coeff0_12*basisvalue12 + new_coeff0_13*basisvalue13 + new_coeff0_14*basisvalue14 + new_coeff0_15*basisvalue15 + new_coeff0_16*basisvalue16 + new_coeff0_17*basisvalue17 + new_coeff0_18*basisvalue18 + new_coeff0_19*basisvalue19 + new_coeff0_20*basisvalue20 + new_coeff0_21*basisvalue21 + new_coeff0_22*basisvalue22 + new_coeff0_23*basisvalue23 + new_coeff0_24*basisvalue24 + new_coeff0_25*basisvalue25 + new_coeff0_26*basisvalue26 + new_coeff0_27*basisvalue27 + new_coeff0_28*basisvalue28 + new_coeff0_29*basisvalue29 + new_coeff0_30*basisvalue30 + new_coeff0_31*basisvalue31 + new_coeff0_32*basisvalue32 + new_coeff0_33*basisvalue33 + new_coeff0_34*basisvalue34 + new_coeff0_35*basisvalue35 + new_coeff0_36*basisvalue36 + new_coeff0_37*basisvalue37 + new_coeff0_38*basisvalue38 + new_coeff0_39*basisvalue39 + new_coeff0_40*basisvalue40 + new_coeff0_41*basisvalue41 + new_coeff0_42*basisvalue42 + new_coeff0_43*basisvalue43 + new_coeff0_44*basisvalue44 + new_coeff0_45*basisvalue45 + new_coeff0_46*basisvalue46 + new_coeff0_47*basisvalue47 + new_coeff0_48*basisvalue48 + new_coeff0_49*basisvalue49 + new_coeff0_50*basisvalue50 + new_coeff0_51*basisvalue51 + new_coeff0_52*basisvalue52 + new_coeff0_53*basisvalue53 + new_coeff0_54*basisvalue54 + new_coeff0_55*basisvalue55;
    }
    
    // Transform derivatives back to physical element
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        values[row] += transform[row][col]*derivatives[col];
      }
    }
    // Delete pointer to array of derivatives on FIAT element
    delete [] derivatives;
    
    // Delete pointer to array of combinations of derivatives and transform
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      delete [] combinations[row];
      delete [] transform[row];
    }
    
    delete [] combinations;
    delete [] transform;
  }

  /// Evaluate order n derivatives of all basis functions at given point in cell
  virtual void evaluate_basis_derivatives_all(unsigned int n,
                                              double* values,
                                              const double* coordinates,
                                              const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis_derivatives() is not yet implemented.");
  }

  /// Evaluate linear functional for dof i on the function f
  virtual double evaluate_dof(unsigned int i,
                              const ufc::function& f,
                              const ufc::cell& c) const
  {
    // The reference points, direction and weights:
    const static double X[56][1][3] = {{{0, 0, 0}}, {{1, 0, 0}}, {{0, 1, 0}}, {{0, 0, 1}}, {{0, 0.8, 0.2}}, {{0, 0.6, 0.4}}, {{0, 0.4, 0.6}}, {{0, 0.2, 0.8}}, {{0.8, 0, 0.2}}, {{0.6, 0, 0.4}}, {{0.4, 0, 0.6}}, {{0.2, 0, 0.8}}, {{0.8, 0.2, 0}}, {{0.6, 0.4, 0}}, {{0.4, 0.6, 0}}, {{0.2, 0.8, 0}}, {{0, 0, 0.2}}, {{0, 0, 0.4}}, {{0, 0, 0.6}}, {{0, 0, 0.8}}, {{0, 0.2, 0}}, {{0, 0.4, 0}}, {{0, 0.6, 0}}, {{0, 0.8, 0}}, {{0.2, 0, 0}}, {{0.4, 0, 0}}, {{0.6, 0, 0}}, {{0.8, 0, 0}}, {{0.6, 0.2, 0.2}}, {{0.4, 0.4, 0.2}}, {{0.2, 0.6, 0.2}}, {{0.4, 0.2, 0.4}}, {{0.2, 0.4, 0.4}}, {{0.2, 0.2, 0.6}}, {{0, 0.2, 0.2}}, {{0, 0.4, 0.2}}, {{0, 0.6, 0.2}}, {{0, 0.2, 0.4}}, {{0, 0.4, 0.4}}, {{0, 0.2, 0.6}}, {{0.2, 0, 0.2}}, {{0.4, 0, 0.2}}, {{0.6, 0, 0.2}}, {{0.2, 0, 0.4}}, {{0.4, 0, 0.4}}, {{0.2, 0, 0.6}}, {{0.2, 0.2, 0}}, {{0.4, 0.2, 0}}, {{0.6, 0.2, 0}}, {{0.2, 0.4, 0}}, {{0.4, 0.4, 0}}, {{0.2, 0.6, 0}}, {{0.2, 0.2, 0.2}}, {{0.4, 0.2, 0.2}}, {{0.2, 0.4, 0.2}}, {{0.2, 0.2, 0.4}}};
    const static double W[56][1] = {{1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}};
    const static double D[56][1][1] = {{{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}};
    
    const double * const * x = c.coordinates;
    double result = 0.0;
    // Iterate over the points:
    // Evaluate basis functions for affine mapping
    const double w0 = 1.0 - X[i][0][0] - X[i][0][1] - X[i][0][2];
    const double w1 = X[i][0][0];
    const double w2 = X[i][0][1];
    const double w3 = X[i][0][2];
    
    // Compute affine mapping y = F(X)
    double y[3];
    y[0] = w0*x[0][0] + w1*x[1][0] + w2*x[2][0] + w3*x[3][0];
    y[1] = w0*x[0][1] + w1*x[1][1] + w2*x[2][1] + w3*x[3][1];
    y[2] = w0*x[0][2] + w1*x[1][2] + w2*x[2][2] + w3*x[3][2];
    
    // Evaluate function at physical points
    double values[1];
    f.evaluate(values, y, c);
    
    // Map function values using appropriate mapping
    // Affine map: Do nothing
    
    // Note that we do not map the weights (yet).
    
    // Take directional components
    for(int k = 0; k < 1; k++)
      result += values[k]*D[i][0][k];
    // Multiply by weights 
    result *= W[i][0];
    
    return result;
  }

  /// Evaluate linear functionals for all dofs on the function f
  virtual void evaluate_dofs(double* values,
                             const ufc::function& f,
                             const ufc::cell& c) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Interpolate vertex values from dof values
  virtual void interpolate_vertex_values(double* vertex_values,
                                         const double* dof_values,
                                         const ufc::cell& c) const
  {
    // Evaluate at vertices and use affine mapping
    vertex_values[0] = dof_values[0];
    vertex_values[1] = dof_values[1];
    vertex_values[2] = dof_values[2];
    vertex_values[3] = dof_values[3];
  }

  /// Return the number of sub elements (for a mixed element)
  virtual unsigned int num_sub_elements() const
  {
    return 1;
  }

  /// Create a new finite element for sub element i (for a mixed element)
  virtual ufc::finite_element* create_sub_element(unsigned int i) const
  {
    return new poisson3d_5_1_finite_element_0();
  }

};

/// This class defines the interface for a finite element.

class poisson3d_5_1_finite_element_1: public ufc::finite_element
{
public:

  /// Constructor
  poisson3d_5_1_finite_element_1() : ufc::finite_element()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_1_finite_element_1()
  {
    // Do nothing
  }

  /// Return a string identifying the finite element
  virtual const char* signature() const
  {
    return "FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return the cell shape
  virtual ufc::shape cell_shape() const
  {
    return ufc::tetrahedron;
  }

  /// Return the dimension of the finite element function space
  virtual unsigned int space_dimension() const
  {
    return 56;
  }

  /// Return the rank of the value space
  virtual unsigned int value_rank() const
  {
    return 0;
  }

  /// Return the dimension of the value space for axis i
  virtual unsigned int value_dimension(unsigned int i) const
  {
    return 1;
  }

  /// Evaluate basis function i at given point in cell
  virtual void evaluate_basis(unsigned int i,
                              double* values,
                              const double* coordinates,
                              const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Reset values
    *values = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Extract relevant coefficients
    const double coeff0_0 = coefficients0[dof][0];
    const double coeff0_1 = coefficients0[dof][1];
    const double coeff0_2 = coefficients0[dof][2];
    const double coeff0_3 = coefficients0[dof][3];
    const double coeff0_4 = coefficients0[dof][4];
    const double coeff0_5 = coefficients0[dof][5];
    const double coeff0_6 = coefficients0[dof][6];
    const double coeff0_7 = coefficients0[dof][7];
    const double coeff0_8 = coefficients0[dof][8];
    const double coeff0_9 = coefficients0[dof][9];
    const double coeff0_10 = coefficients0[dof][10];
    const double coeff0_11 = coefficients0[dof][11];
    const double coeff0_12 = coefficients0[dof][12];
    const double coeff0_13 = coefficients0[dof][13];
    const double coeff0_14 = coefficients0[dof][14];
    const double coeff0_15 = coefficients0[dof][15];
    const double coeff0_16 = coefficients0[dof][16];
    const double coeff0_17 = coefficients0[dof][17];
    const double coeff0_18 = coefficients0[dof][18];
    const double coeff0_19 = coefficients0[dof][19];
    const double coeff0_20 = coefficients0[dof][20];
    const double coeff0_21 = coefficients0[dof][21];
    const double coeff0_22 = coefficients0[dof][22];
    const double coeff0_23 = coefficients0[dof][23];
    const double coeff0_24 = coefficients0[dof][24];
    const double coeff0_25 = coefficients0[dof][25];
    const double coeff0_26 = coefficients0[dof][26];
    const double coeff0_27 = coefficients0[dof][27];
    const double coeff0_28 = coefficients0[dof][28];
    const double coeff0_29 = coefficients0[dof][29];
    const double coeff0_30 = coefficients0[dof][30];
    const double coeff0_31 = coefficients0[dof][31];
    const double coeff0_32 = coefficients0[dof][32];
    const double coeff0_33 = coefficients0[dof][33];
    const double coeff0_34 = coefficients0[dof][34];
    const double coeff0_35 = coefficients0[dof][35];
    const double coeff0_36 = coefficients0[dof][36];
    const double coeff0_37 = coefficients0[dof][37];
    const double coeff0_38 = coefficients0[dof][38];
    const double coeff0_39 = coefficients0[dof][39];
    const double coeff0_40 = coefficients0[dof][40];
    const double coeff0_41 = coefficients0[dof][41];
    const double coeff0_42 = coefficients0[dof][42];
    const double coeff0_43 = coefficients0[dof][43];
    const double coeff0_44 = coefficients0[dof][44];
    const double coeff0_45 = coefficients0[dof][45];
    const double coeff0_46 = coefficients0[dof][46];
    const double coeff0_47 = coefficients0[dof][47];
    const double coeff0_48 = coefficients0[dof][48];
    const double coeff0_49 = coefficients0[dof][49];
    const double coeff0_50 = coefficients0[dof][50];
    const double coeff0_51 = coefficients0[dof][51];
    const double coeff0_52 = coefficients0[dof][52];
    const double coeff0_53 = coefficients0[dof][53];
    const double coeff0_54 = coefficients0[dof][54];
    const double coeff0_55 = coefficients0[dof][55];
    
    // Compute value(s)
    *values = coeff0_0*basisvalue0 + coeff0_1*basisvalue1 + coeff0_2*basisvalue2 + coeff0_3*basisvalue3 + coeff0_4*basisvalue4 + coeff0_5*basisvalue5 + coeff0_6*basisvalue6 + coeff0_7*basisvalue7 + coeff0_8*basisvalue8 + coeff0_9*basisvalue9 + coeff0_10*basisvalue10 + coeff0_11*basisvalue11 + coeff0_12*basisvalue12 + coeff0_13*basisvalue13 + coeff0_14*basisvalue14 + coeff0_15*basisvalue15 + coeff0_16*basisvalue16 + coeff0_17*basisvalue17 + coeff0_18*basisvalue18 + coeff0_19*basisvalue19 + coeff0_20*basisvalue20 + coeff0_21*basisvalue21 + coeff0_22*basisvalue22 + coeff0_23*basisvalue23 + coeff0_24*basisvalue24 + coeff0_25*basisvalue25 + coeff0_26*basisvalue26 + coeff0_27*basisvalue27 + coeff0_28*basisvalue28 + coeff0_29*basisvalue29 + coeff0_30*basisvalue30 + coeff0_31*basisvalue31 + coeff0_32*basisvalue32 + coeff0_33*basisvalue33 + coeff0_34*basisvalue34 + coeff0_35*basisvalue35 + coeff0_36*basisvalue36 + coeff0_37*basisvalue37 + coeff0_38*basisvalue38 + coeff0_39*basisvalue39 + coeff0_40*basisvalue40 + coeff0_41*basisvalue41 + coeff0_42*basisvalue42 + coeff0_43*basisvalue43 + coeff0_44*basisvalue44 + coeff0_45*basisvalue45 + coeff0_46*basisvalue46 + coeff0_47*basisvalue47 + coeff0_48*basisvalue48 + coeff0_49*basisvalue49 + coeff0_50*basisvalue50 + coeff0_51*basisvalue51 + coeff0_52*basisvalue52 + coeff0_53*basisvalue53 + coeff0_54*basisvalue54 + coeff0_55*basisvalue55;
  }

  /// Evaluate all basis functions at given point in cell
  virtual void evaluate_basis_all(double* values,
                                  const double* coordinates,
                                  const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis() is not yet implemented.");
  }

  /// Evaluate order n derivatives of basis function i at given point in cell
  virtual void evaluate_basis_derivatives(unsigned int i,
                                          unsigned int n,
                                          double* values,
                                          const double* coordinates,
                                          const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * element_coordinates = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = element_coordinates[1][0] - element_coordinates[0][0];
    const double J_01 = element_coordinates[2][0] - element_coordinates[0][0];
    const double J_02 = element_coordinates[3][0] - element_coordinates[0][0];
    const double J_10 = element_coordinates[1][1] - element_coordinates[0][1];
    const double J_11 = element_coordinates[2][1] - element_coordinates[0][1];
    const double J_12 = element_coordinates[3][1] - element_coordinates[0][1];
    const double J_20 = element_coordinates[1][2] - element_coordinates[0][2];
    const double J_21 = element_coordinates[2][2] - element_coordinates[0][2];
    const double J_22 = element_coordinates[3][2] - element_coordinates[0][2];
      
    // Compute sub determinants
    const double d00 = J_11*J_22 - J_12*J_21;
    const double d01 = J_12*J_20 - J_10*J_22;
    const double d02 = J_10*J_21 - J_11*J_20;
    
    const double d10 = J_02*J_21 - J_01*J_22;
    const double d11 = J_00*J_22 - J_02*J_20;
    const double d12 = J_01*J_20 - J_00*J_21;
    
    const double d20 = J_01*J_12 - J_02*J_11;
    const double d21 = J_02*J_10 - J_00*J_12;
    const double d22 = J_00*J_11 - J_01*J_10;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d00 + J_10*d10 + J_20*d20;
    
    // Compute inverse of Jacobian
    
    // Compute constants
    const double C0 = d00*(element_coordinates[0][0] - element_coordinates[2][0] - element_coordinates[3][0]) \
                    + d10*(element_coordinates[0][1] - element_coordinates[2][1] - element_coordinates[3][1]) \
                    + d20*(element_coordinates[0][2] - element_coordinates[2][2] - element_coordinates[3][2]);
    
    const double C1 = d01*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[3][0]) \
                    + d11*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[3][1]) \
                    + d21*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[3][2]);
    
    const double C2 = d02*(element_coordinates[0][0] - element_coordinates[1][0] - element_coordinates[2][0]) \
                    + d12*(element_coordinates[0][1] - element_coordinates[1][1] - element_coordinates[2][1]) \
                    + d22*(element_coordinates[0][2] - element_coordinates[1][2] - element_coordinates[2][2]);
    
    // Get coordinates and map to the UFC reference element
    double x = (C0 + d00*coordinates[0] + d10*coordinates[1] + d20*coordinates[2]) / detJ;
    double y = (C1 + d01*coordinates[0] + d11*coordinates[1] + d21*coordinates[2]) / detJ;
    double z = (C2 + d02*coordinates[0] + d12*coordinates[1] + d22*coordinates[2]) / detJ;
    
    // Map coordinates to the reference cube
    if (std::abs(y + z - 1.0) < 1e-14)
      x = 1.0;
    else
      x = -2.0 * x/(y + z - 1.0) - 1.0;
    if (std::abs(z - 1.0) < 1e-14)
      y = -1.0;
    else
      y = 2.0 * y/(1.0 - z) - 1.0;
    z = 2.0 * z - 1.0;
    
    // Compute number of derivatives
    unsigned int num_derivatives = 1;
    
    for (unsigned int j = 0; j < n; j++)
      num_derivatives *= 3;
    
    
    // Declare pointer to two dimensional array that holds combinations of derivatives and initialise
    unsigned int **combinations = new unsigned int *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      combinations[j] = new unsigned int [n];
      for (unsigned int k = 0; k < n; k++)
        combinations[j][k] = 0;
    }
        
    // Generate combinations of derivatives
    for (unsigned int row = 1; row < num_derivatives; row++)
    {
      for (unsigned int num = 0; num < row; num++)
      {
        for (unsigned int col = n-1; col+1 > 0; col--)
        {
          if (combinations[row][col] + 1 > 2)
            combinations[row][col] = 0;
          else
          {
            combinations[row][col] += 1;
            break;
          }
        }
      }
    }
    
    // Compute inverse of Jacobian
    const double Jinv[3][3] ={{d00 / detJ, d10 / detJ, d20 / detJ}, {d01 / detJ, d11 / detJ, d21 / detJ}, {d02 / detJ, d12 / detJ, d22 / detJ}};
    
    // Declare transformation matrix
    // Declare pointer to two dimensional array and initialise
    double **transform = new double *[num_derivatives];
        
    for (unsigned int j = 0; j < num_derivatives; j++)
    {
      transform[j] = new double [num_derivatives];
      for (unsigned int k = 0; k < num_derivatives; k++)
        transform[j][k] = 1;
    }
    
    // Construct transformation matrix
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        for (unsigned int k = 0; k < n; k++)
          transform[row][col] *= Jinv[combinations[col][k]][combinations[row][k]];
      }
    }
    
    // Reset values
    for (unsigned int j = 0; j < 1*num_derivatives; j++)
      values[j] = 0;
    
    // Map degree of freedom to element degree of freedom
    const unsigned int dof = i;
    
    // Generate scalings
    const double scalings_y_0 = 1;
    const double scalings_y_1 = scalings_y_0*(0.5 - 0.5*y);
    const double scalings_y_2 = scalings_y_1*(0.5 - 0.5*y);
    const double scalings_y_3 = scalings_y_2*(0.5 - 0.5*y);
    const double scalings_y_4 = scalings_y_3*(0.5 - 0.5*y);
    const double scalings_y_5 = scalings_y_4*(0.5 - 0.5*y);
    const double scalings_z_0 = 1;
    const double scalings_z_1 = scalings_z_0*(0.5 - 0.5*z);
    const double scalings_z_2 = scalings_z_1*(0.5 - 0.5*z);
    const double scalings_z_3 = scalings_z_2*(0.5 - 0.5*z);
    const double scalings_z_4 = scalings_z_3*(0.5 - 0.5*z);
    const double scalings_z_5 = scalings_z_4*(0.5 - 0.5*z);
    
    // Compute psitilde_a
    const double psitilde_a_0 = 1;
    const double psitilde_a_1 = x;
    const double psitilde_a_2 = 1.5*x*psitilde_a_1 - 0.5*psitilde_a_0;
    const double psitilde_a_3 = 1.66666666666667*x*psitilde_a_2 - 0.666666666666667*psitilde_a_1;
    const double psitilde_a_4 = 1.75*x*psitilde_a_3 - 0.75*psitilde_a_2;
    const double psitilde_a_5 = 1.8*x*psitilde_a_4 - 0.8*psitilde_a_3;
    
    // Compute psitilde_bs
    const double psitilde_bs_0_0 = 1;
    const double psitilde_bs_0_1 = 1.5*y + 0.5;
    const double psitilde_bs_0_2 = 0.111111111111111*psitilde_bs_0_1 + 1.66666666666667*y*psitilde_bs_0_1 - 0.555555555555556*psitilde_bs_0_0;
    const double psitilde_bs_0_3 = 0.05*psitilde_bs_0_2 + 1.75*y*psitilde_bs_0_2 - 0.7*psitilde_bs_0_1;
    const double psitilde_bs_0_4 = 0.0285714285714286*psitilde_bs_0_3 + 1.8*y*psitilde_bs_0_3 - 0.771428571428571*psitilde_bs_0_2;
    const double psitilde_bs_0_5 = 0.0185185185185185*psitilde_bs_0_4 + 1.83333333333333*y*psitilde_bs_0_4 - 0.814814814814815*psitilde_bs_0_3;
    const double psitilde_bs_1_0 = 1;
    const double psitilde_bs_1_1 = 2.5*y + 1.5;
    const double psitilde_bs_1_2 = 0.54*psitilde_bs_1_1 + 2.1*y*psitilde_bs_1_1 - 0.56*psitilde_bs_1_0;
    const double psitilde_bs_1_3 = 0.285714285714286*psitilde_bs_1_2 + 2*y*psitilde_bs_1_2 - 0.714285714285714*psitilde_bs_1_1;
    const double psitilde_bs_1_4 = 0.178571428571429*psitilde_bs_1_3 + 1.96428571428571*y*psitilde_bs_1_3 - 0.785714285714286*psitilde_bs_1_2;
    const double psitilde_bs_2_0 = 1;
    const double psitilde_bs_2_1 = 3.5*y + 2.5;
    const double psitilde_bs_2_2 = 1.02040816326531*psitilde_bs_2_1 + 2.57142857142857*y*psitilde_bs_2_1 - 0.551020408163265*psitilde_bs_2_0;
    const double psitilde_bs_2_3 = 0.578703703703704*psitilde_bs_2_2 + 2.29166666666667*y*psitilde_bs_2_2 - 0.712962962962963*psitilde_bs_2_1;
    const double psitilde_bs_3_0 = 1;
    const double psitilde_bs_3_1 = 4.5*y + 3.5;
    const double psitilde_bs_3_2 = 1.51234567901235*psitilde_bs_3_1 + 3.05555555555556*y*psitilde_bs_3_1 - 0.54320987654321*psitilde_bs_3_0;
    const double psitilde_bs_4_0 = 1;
    const double psitilde_bs_4_1 = 5.5*y + 4.5;
    const double psitilde_bs_5_0 = 1;
    
    // Compute psitilde_cs
    const double psitilde_cs_00_0 = 1;
    const double psitilde_cs_00_1 = 2*z + 1;
    const double psitilde_cs_00_2 = 0.3125*psitilde_cs_00_1 + 1.875*z*psitilde_cs_00_1 - 0.5625*psitilde_cs_00_0;
    const double psitilde_cs_00_3 = 0.155555555555556*psitilde_cs_00_2 + 1.86666666666667*z*psitilde_cs_00_2 - 0.711111111111111*psitilde_cs_00_1;
    const double psitilde_cs_00_4 = 0.09375*psitilde_cs_00_3 + 1.875*z*psitilde_cs_00_3 - 0.78125*psitilde_cs_00_2;
    const double psitilde_cs_00_5 = 0.0628571428571429*psitilde_cs_00_4 + 1.88571428571429*z*psitilde_cs_00_4 - 0.822857142857143*psitilde_cs_00_3;
    const double psitilde_cs_01_0 = 1;
    const double psitilde_cs_01_1 = 3*z + 2;
    const double psitilde_cs_01_2 = 0.777777777777778*psitilde_cs_01_1 + 2.33333333333333*z*psitilde_cs_01_1 - 0.555555555555556*psitilde_cs_01_0;
    const double psitilde_cs_01_3 = 0.428571428571429*psitilde_cs_01_2 + 2.14285714285714*z*psitilde_cs_01_2 - 0.714285714285714*psitilde_cs_01_1;
    const double psitilde_cs_01_4 = 0.275*psitilde_cs_01_3 + 2.0625*z*psitilde_cs_01_3 - 0.7875*psitilde_cs_01_2;
    const double psitilde_cs_02_0 = 1;
    const double psitilde_cs_02_1 = 4*z + 3;
    const double psitilde_cs_02_2 = 1.265625*psitilde_cs_02_1 + 2.8125*z*psitilde_cs_02_1 - 0.546875*psitilde_cs_02_0;
    const double psitilde_cs_02_3 = 0.733333333333333*psitilde_cs_02_2 + 2.44444444444444*z*psitilde_cs_02_2 - 0.711111111111111*psitilde_cs_02_1;
    const double psitilde_cs_03_0 = 1;
    const double psitilde_cs_03_1 = 5*z + 4;
    const double psitilde_cs_03_2 = 1.76*psitilde_cs_03_1 + 3.3*z*psitilde_cs_03_1 - 0.54*psitilde_cs_03_0;
    const double psitilde_cs_04_0 = 1;
    const double psitilde_cs_04_1 = 6*z + 5;
    const double psitilde_cs_05_0 = 1;
    const double psitilde_cs_10_0 = 1;
    const double psitilde_cs_10_1 = 3*z + 2;
    const double psitilde_cs_10_2 = 0.777777777777778*psitilde_cs_10_1 + 2.33333333333333*z*psitilde_cs_10_1 - 0.555555555555556*psitilde_cs_10_0;
    const double psitilde_cs_10_3 = 0.428571428571429*psitilde_cs_10_2 + 2.14285714285714*z*psitilde_cs_10_2 - 0.714285714285714*psitilde_cs_10_1;
    const double psitilde_cs_10_4 = 0.275*psitilde_cs_10_3 + 2.0625*z*psitilde_cs_10_3 - 0.7875*psitilde_cs_10_2;
    const double psitilde_cs_11_0 = 1;
    const double psitilde_cs_11_1 = 4*z + 3;
    const double psitilde_cs_11_2 = 1.265625*psitilde_cs_11_1 + 2.8125*z*psitilde_cs_11_1 - 0.546875*psitilde_cs_11_0;
    const double psitilde_cs_11_3 = 0.733333333333333*psitilde_cs_11_2 + 2.44444444444444*z*psitilde_cs_11_2 - 0.711111111111111*psitilde_cs_11_1;
    const double psitilde_cs_12_0 = 1;
    const double psitilde_cs_12_1 = 5*z + 4;
    const double psitilde_cs_12_2 = 1.76*psitilde_cs_12_1 + 3.3*z*psitilde_cs_12_1 - 0.54*psitilde_cs_12_0;
    const double psitilde_cs_13_0 = 1;
    const double psitilde_cs_13_1 = 6*z + 5;
    const double psitilde_cs_14_0 = 1;
    const double psitilde_cs_20_0 = 1;
    const double psitilde_cs_20_1 = 4*z + 3;
    const double psitilde_cs_20_2 = 1.265625*psitilde_cs_20_1 + 2.8125*z*psitilde_cs_20_1 - 0.546875*psitilde_cs_20_0;
    const double psitilde_cs_20_3 = 0.733333333333333*psitilde_cs_20_2 + 2.44444444444444*z*psitilde_cs_20_2 - 0.711111111111111*psitilde_cs_20_1;
    const double psitilde_cs_21_0 = 1;
    const double psitilde_cs_21_1 = 5*z + 4;
    const double psitilde_cs_21_2 = 1.76*psitilde_cs_21_1 + 3.3*z*psitilde_cs_21_1 - 0.54*psitilde_cs_21_0;
    const double psitilde_cs_22_0 = 1;
    const double psitilde_cs_22_1 = 6*z + 5;
    const double psitilde_cs_23_0 = 1;
    const double psitilde_cs_30_0 = 1;
    const double psitilde_cs_30_1 = 5*z + 4;
    const double psitilde_cs_30_2 = 1.76*psitilde_cs_30_1 + 3.3*z*psitilde_cs_30_1 - 0.54*psitilde_cs_30_0;
    const double psitilde_cs_31_0 = 1;
    const double psitilde_cs_31_1 = 6*z + 5;
    const double psitilde_cs_32_0 = 1;
    const double psitilde_cs_40_0 = 1;
    const double psitilde_cs_40_1 = 6*z + 5;
    const double psitilde_cs_41_0 = 1;
    const double psitilde_cs_50_0 = 1;
    
    // Compute basisvalues
    const double basisvalue0 = 0.866025403784439*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_0;
    const double basisvalue1 = 2.73861278752583*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_0;
    const double basisvalue2 = 1.58113883008419*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_0;
    const double basisvalue3 = 1.11803398874989*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_1;
    const double basisvalue4 = 5.1234753829798*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_0;
    const double basisvalue5 = 3.96862696659689*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_0;
    const double basisvalue6 = 2.29128784747792*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_0;
    const double basisvalue7 = 3.24037034920393*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_1;
    const double basisvalue8 = 1.87082869338697*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_1;
    const double basisvalue9 = 1.3228756555323*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_2;
    const double basisvalue10 = 7.93725393319377*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_0;
    const double basisvalue11 = 6.70820393249937*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_0;
    const double basisvalue12 = 5.19615242270663*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_0;
    const double basisvalue13 = 3*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_0;
    const double basisvalue14 = 5.80947501931113*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_1;
    const double basisvalue15 = 4.5*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_1;
    const double basisvalue16 = 2.59807621135332*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_1;
    const double basisvalue17 = 3.67423461417477*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_2;
    const double basisvalue18 = 2.12132034355964*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_2;
    const double basisvalue19 = 1.5*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_3;
    const double basisvalue20 = 11.1242977306435*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_0;
    const double basisvalue21 = 9.81070843517429*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_0;
    const double basisvalue22 = 8.2915619758885*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_0;
    const double basisvalue23 = 6.42261628933256*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_0;
    const double basisvalue24 = 3.70809924354783*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_0;
    const double basisvalue25 = 8.77496438739212*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_1;
    const double basisvalue26 = 7.41619848709566*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_1;
    const double basisvalue27 = 5.74456264653803*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_1;
    const double basisvalue28 = 3.3166247903554*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_1;
    const double basisvalue29 = 6.42261628933256*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_2;
    const double basisvalue30 = 4.9749371855331*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_2;
    const double basisvalue31 = 2.87228132326901*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_2;
    const double basisvalue32 = 4.06201920231798*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_3;
    const double basisvalue33 = 2.34520787991171*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_3;
    const double basisvalue34 = 1.6583123951777*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_4;
    const double basisvalue35 = 14.6458185158768*psitilde_a_5*scalings_y_5*psitilde_bs_5_0*scalings_z_5*psitilde_cs_50_0;
    const double basisvalue36 = 13.2476412994918*psitilde_a_4*scalings_y_4*psitilde_bs_4_1*scalings_z_5*psitilde_cs_41_0;
    const double basisvalue37 = 11.6833214455479*psitilde_a_3*scalings_y_3*psitilde_bs_3_2*scalings_z_5*psitilde_cs_32_0;
    const double basisvalue38 = 9.87420882906575*psitilde_a_2*scalings_y_2*psitilde_bs_2_3*scalings_z_5*psitilde_cs_23_0;
    const double basisvalue39 = 7.64852927038918*psitilde_a_1*scalings_y_1*psitilde_bs_1_4*scalings_z_5*psitilde_cs_14_0;
    const double basisvalue40 = 4.41588043316392*psitilde_a_0*scalings_y_0*psitilde_bs_0_5*scalings_z_5*psitilde_cs_05_0;
    const double basisvalue41 = 12.0933866224478*psitilde_a_4*scalings_y_4*psitilde_bs_4_0*scalings_z_4*psitilde_cs_40_1;
    const double basisvalue42 = 10.6653645038508*psitilde_a_3*scalings_y_3*psitilde_bs_3_1*scalings_z_4*psitilde_cs_31_1;
    const double basisvalue43 = 9.01387818865997*psitilde_a_2*scalings_y_2*psitilde_bs_2_2*scalings_z_4*psitilde_cs_22_1;
    const double basisvalue44 = 6.98212002188447*psitilde_a_1*scalings_y_1*psitilde_bs_1_3*scalings_z_4*psitilde_cs_13_1;
    const double basisvalue45 = 4.03112887414927*psitilde_a_0*scalings_y_0*psitilde_bs_0_4*scalings_z_4*psitilde_cs_04_1;
    const double basisvalue46 = 9.53939201416946*psitilde_a_3*scalings_y_3*psitilde_bs_3_0*scalings_z_3*psitilde_cs_30_2;
    const double basisvalue47 = 8.06225774829855*psitilde_a_2*scalings_y_2*psitilde_bs_2_1*scalings_z_3*psitilde_cs_21_2;
    const double basisvalue48 = 6.2449979983984*psitilde_a_1*scalings_y_1*psitilde_bs_1_2*scalings_z_3*psitilde_cs_12_2;
    const double basisvalue49 = 3.60555127546399*psitilde_a_0*scalings_y_0*psitilde_bs_0_3*scalings_z_3*psitilde_cs_03_2;
    const double basisvalue50 = 6.98212002188447*psitilde_a_2*scalings_y_2*psitilde_bs_2_0*scalings_z_2*psitilde_cs_20_3;
    const double basisvalue51 = 5.40832691319598*psitilde_a_1*scalings_y_1*psitilde_bs_1_1*scalings_z_2*psitilde_cs_11_3;
    const double basisvalue52 = 3.1224989991992*psitilde_a_0*scalings_y_0*psitilde_bs_0_2*scalings_z_2*psitilde_cs_02_3;
    const double basisvalue53 = 4.41588043316392*psitilde_a_1*scalings_y_1*psitilde_bs_1_0*scalings_z_1*psitilde_cs_10_4;
    const double basisvalue54 = 2.54950975679639*psitilde_a_0*scalings_y_0*psitilde_bs_0_1*scalings_z_1*psitilde_cs_01_4;
    const double basisvalue55 = 1.80277563773199*psitilde_a_0*scalings_y_0*psitilde_bs_0_0*scalings_z_0*psitilde_cs_00_5;
    
    // Table(s) of coefficients
    const static double coefficients0[56][56] = \
    {{0.00945067404923491, 0.00609788120679252, 0.00352061335622799, 0.00248944957812474, 0.00705946233325039, 0.00546823600997147, 0.00315708753234944, 0.00446479600584754, 0.00257775117585285, 0.00182274533665714, -0.00298267418725716, -0.0025208197798293, -0.00195261860521384, -0.00112734487734488, -0.00218309396769447, -0.00169101731601732, -0.000976309302606928, -0.00138070985681772, -0.000797153207506486, -0.00056367243867244, 0.00278687112460004, 0.00245778931055954, 0.00207721109304566, 0.00160900079398463, 0.000928957041533337, 0.00219831358911339, 0.0018579140830667, 0.00143913406048032, 0.000830884437218271, 0.00160900079398463, 0.0012463266558274, 0.000719567030240154, 0.00101762145320217, 0.000587524019939402, 0.00041544221860914, -0.00705593524717798, -0.00638233357089081, -0.00562868913761197, -0.00475711057319694, -0.00368484200521178, -0.00212744452363026, -0.00582624677716565, -0.00513826668309062, -0.00434262794914382, -0.00336378514516178, -0.00194208225905521, -0.00459580543596519, -0.00388416451811042, -0.00300866089851428, -0.00173705117965752, -0.00336378514516177, -0.00260557676948628, -0.00150433044925714, -0.00212744452363027, -0.00122828066840393, -0.000868525589828764},
    {0.00945067404923494, -0.00609788120679252, 0.00352061335622803, 0.00248944957812476, 0.00705946233325039, -0.00546823600997146, 0.00315708753234943, -0.00446479600584756, 0.00257775117585286, 0.00182274533665715, 0.00298267418725717, -0.00252081977982931, 0.00195261860521383, -0.00112734487734488, -0.00218309396769448, 0.00169101731601731, -0.000976309302606917, 0.00138070985681772, -0.000797153207506481, -0.000563672438672439, 0.00278687112460004, -0.00245778931055954, 0.00207721109304566, -0.00160900079398463, 0.000928957041533346, -0.00219831358911339, 0.00185791408306669, -0.00143913406048031, 0.000830884437218264, 0.00160900079398463, -0.00124632665582739, 0.000719567030240151, -0.00101762145320216, 0.000587524019939403, 0.00041544221860913, 0.00705593524717798, -0.0063823335708908, 0.00562868913761196, -0.00475711057319694, 0.00368484200521179, -0.00212744452363027, -0.00582624677716565, 0.00513826668309062, -0.00434262794914382, 0.00336378514516178, -0.00194208225905522, 0.0045958054359652, -0.00388416451811044, 0.00300866089851429, -0.00173705117965753, -0.00336378514516178, 0.00260557676948629, -0.00150433044925715, 0.00212744452363027, -0.00122828066840393, -0.000868525589828763},
    {0.00945067404923496, 0, -0.00704122671245606, 0.00248944957812477, 0, 0, 0.00947126259704827, 0, -0.00515550235170571, 0.00182274533665715, 0, 0, 0, 0.00450937950937951, 0, 0, -0.00292892790782075, 0, 0.00159430641501296, -0.000563672438672442, 0, 0, 0, 0, 0.00464478520766674, 0, 0, 0, -0.00332353774887306, 0, 0, 0.00215870109072046, 0, -0.00117504803987881, 0.000415442218609132, 0, 0, 0, 0, 0, 0.0127646671417816, 0, 0, 0, 0, -0.00971041129527608, 0, 0, 0, 0.00694820471863012, 0, 0, -0.00451299134777144, 0, 0.00245656133680786, -0.000868525589828762},
    {0.00945067404923489, 0, 0, -0.00746834873437432, 0, 0, 0, 0, 0, 0.0109364720199429, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00563672438672437, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.00623163327913697, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0182390373864041},
    {-0.010023442173431, 0, 0.0374718748311399, -0.0289614183593723, 0, 0, 0.0284137877911448, 0, 0.00515550235170571, -0.00619733414463432, 0, 0, 0, 0.0315656565656566, 0, 0, -0.0113902751970807, 0, 0.00265717735835493, -0.000187890812890798, 0, 0, 0, 0, 0.0232239260383337, 0, 0, 0, -0.00166176887443653, 0, 0, -0.00647610327216137, 0, 0.00646276421933344, -0.00290809553026392, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0213629048496074, 0, 0, 0, -0.0277928188745205, 0, 0, 0.0243701532779658, 0, -0.0157219925555703, 0.00607967912880134},
    {0.0100234421734311, 0, -0.0287574853355259, 0.0536094339843699, 0, 0, -0.0189425251940966, 0, 0.0154665070551171, 0.0153110608279201, 0, 0, 0, -0.0045093795093795, 0, 0, 0.0370997534990628, 0, -0.0281660799985623, 0.0108976671476671, 0, 0, 0, 0, 0, 0, 0, 0, 0.0299118397398575, 0, 0, -0.00431740218144092, 0, -0.0123380044187275, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0312669212338355, 0, 0, -0.0487403065559315, 0, 0.041270230458372, -0.018239037386404},
    {0.010023442173431, 0, 0.0409576306293854, -0.0449826285156206, 0, 0, 0.0189425251940966, 0, -0.00515550235170571, -0.0211438459052229, 0, 0, 0, 0, 0, 0, 0.00455611007883226, 0, 0.0356061766019561, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0302218152700864, 0, 0.00411266813957584, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0379091273212801, 0, -0.055026973944496, 0.0303983956440067},
    {-0.0100234421734309, 0, -0.0148144621425437, 0.0449826285156208, 0, 0, 0, 0, 0.0206220094068228, 0.0211438459052229, 0, 0, 0, 0, 0, 0, 0, 0, 0.0106287094334197, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0205633406978791, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.03439185871531, -0.0303983956440068},
    {-0.0100234421734311, 0.0324515955311978, -0.0187359374155699, -0.0289614183593723, 0.0211783869997512, -0.0164047080299144, 0.00947126259704827, 0.00446479600584756, -0.00257775117585285, -0.00619733414463431, 0.0208787193108001, -0.0176457384588051, 0.0136683302364968, -0.00789141414141414, -0.00848980987436741, 0.00657617845117845, -0.00379675839902689, 0.0023011830946962, -0.00132858867917746, -0.000187890812890803, 0.0139343556230002, -0.0122889465527977, 0.0103860554652283, -0.00804500396992315, 0.00464478520766674, -0.0010991567945567, 0.000928957041533349, -0.000719567030240152, 0.000415442218609127, -0.00482700238195388, 0.00373897996748219, -0.00215870109072046, 0.00559691799261186, -0.00323138210966672, -0.00290809553026393, 0, 0, 0, 0, 0, 0, 0.0128177429097644, -0.0113041867027994, 0.00955378148811641, -0.00740032731935591, 0.00427258096992148, -0.0183832217438608, 0.0155366580724417, -0.0120346435940572, 0.00694820471863011, 0.0181644397838736, -0.014070114555226, 0.00812338442598859, -0.0136156449512337, 0.00786099627778516, 0.00607967912880135},
    {0.0100234421734311, -0.0249047128495239, 0.014378742667763, 0.05360943398437, -0.0141189246665008, 0.0109364720199429, -0.00631417506469884, 0.0133943880175427, -0.0077332535275586, 0.0153110608279201, -0.00298267418725715, 0.00252081977982931, -0.00195261860521383, 0.00112734487734488, 0.0276525235907967, -0.0214195526695527, 0.0123665844996876, -0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, 0.0197848223020205, -0.0167212267476002, 0.0129522065443228, -0.00747795993496437, -0.00321800158796926, 0.0024926533116548, -0.0014391340604803, -0.0106850252586226, 0.00616900220936373, 0.00872428659079178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0206811244618434, -0.017478740331497, 0.0135389740433143, -0.00781673030845888, -0.0363288795677472, 0.028140229110452, -0.0162467688519772, 0.0357410679969885, -0.020635115229186, -0.0182390373864041},
    {0.010023442173431, 0.0354703486038674, -0.0204788153146927, -0.0449826285156208, 0.0141189246665008, -0.0109364720199429, 0.00631417506469885, -0.00446479600584756, 0.00257775117585287, -0.021143845905223, 0, 0, 0, 0, 0.00339592394974696, -0.00263047138047138, 0.00151870335961075, 0.0308358534689291, -0.017803088300978, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, -0.0174485731815836, 0.0100739384233621, 0.00356167508620755, -0.00205633406978791, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, -0.0218868448636849, 0.01263637577376, -0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, -0.0128297005588457, 0.00740723107127182, 0.0449826285156208, 0, 0, 0, 0.0178591840233903, -0.0103110047034114, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, 0.00920473237878479, -0.00531435471670985, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.010023442173431, 0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, 0.0010936472019943, -0.00568275755822897, -0.0169662248222208, 0.00567105258687629, 0.00838462854862291, 0.0208787193108001, -0.0109235523792603, 0.00499002532443534, -0.00187890812890812, -0.0162519217595033, 0.00958243145743146, -0.00466458889023305, 0.0108922666482287, -0.00558007245254535, -0.00469727032227033, 0.0139343556230002, -0.00245778931055954, -0.00415442218609131, 0.0064360031759385, -0.00464478520766674, -0.0120907247401236, 0.00464478520766674, -0.000719567030240151, -0.000415442218609137, 0.00965400476390778, -0.00498530662330958, 0.00215870109072047, -0.006614539445814, 0.0032313821096667, 0.00290809553026392, 0, 0.0127646671417816, -0.0202632808954031, 0.0228341307513453, -0.020635115229186, 0.0127646671417816, -0.00116524935543313, -0.00719357335632687, 0.0112908326677739, -0.0114368694935501, 0.00737991258440983, 0.00183832217438608, 0.00310733161448835, -0.00481385743762287, 0.00347410235931505, -0.00201827108709706, -0.00052111535389726, 0.000902598269554287, 0.00170195561890421, -0.000491312267361568, -0.000868525589828764},
    {0.010023442173431, -0.0249047128495239, 0.0553363732971484, -0.00431340273437458, -0.0141189246665008, 0.0153110608279201, 0.00883984509057843, 0.00803663281052563, -0.0159820572902877, 0.000729098134662848, -0.00298267418725716, 0.0277290175781224, -0.0301571095694136, 0.0191648629148629, -0.00145539597846298, -0.0116492303992304, 0.00976309302606916, 0.00352848074520083, 0.00132858867917745, -0.00263047138047137, 0, 0.0196623144844763, -0.00727023882565981, -0.00724050357293084, 0.00928957041533347, -0.00219831358911339, -0.0148633126645336, 0.0129522065443228, -0.00664707549774611, 0.00402250198496158, 0.00685479660705067, -0.00575653624192123, -0.0045792965394097, -0.000293762009969687, 0.00290809553026391, 0, 0, 0.0202632808954031, -0.0399597288148543, 0.0464290092656686, -0.031911667854454, 0, -0.00411061334647249, -0.00303983956440068, 0.00908221989193681, -0.00776832903622088, 0.000459580543596522, 0.00427258096992148, -0.00270779480866287, 0.000868525589828773, -0.00100913554354854, -0.00234501909253766, 0.00180519653910858, 0.00127646671417816, 0.000245656133680783, -0.000868525589828761},
    {0.010023442173431, 0.0354703486038674, -0.0492363006502186, -0.00431340273437459, 0.0141189246665008, -0.00656188321196576, -0.016416855168217, -0.00982255121286466, 0.0149509568199466, 0.000729098134662871, 0, 0.00336109303977241, 0.0282044909641998, -0.0353234728234728, -0.000485131992820999, -0.0124007936507937, 0.008895262534863, 0.00291483191994851, 0.00239145962251945, -0.00263047138047138, 0, 0, 0.0218107164769794, -0.00402250198496157, -0.00928957041533347, 0, -0.00557374224920008, -0.0143913406048031, 0.0141250354327105, 0.000804500396992315, 0.00934744991870547, -0.0028782681209606, -0.00254405363300539, -0.00381890612960613, 0.00290809553026392, 0, 0, 0, 0.0266398192099029, -0.0515877880729651, 0.0425488904726054, 0, 0, -0.00911951869320202, 0.00840946286290444, -0.00388416451811042, 0, 0.00233049871086626, 0.0030086608985143, -0.00347410235931506, -0.000336378514516173, -0.00286613444643492, 0.00120346435940572, 0.000850977809452109, 0.00098262453472315, -0.000868525589828765},
    {-0.010023442173431, -0.0128297005588457, 0.0448791059024117, -0.00801060507812424, 0, 0.0174983552319087, 0.0132597676358676, -0.00357183680467804, -0.0175287079957994, 0.00838462854862289, 0, 0, 0.00867830491206148, 0.0225468975468975, 0, -0.00300625300625302, -0.019200749617936, 0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, 0.0160900079398463, 0.00464478520766673, 0, 0, -0.00719567030240153, -0.0108014976838374, 0, 0.00249265331165479, 0.0107935054536023, -0.000508810726601081, -0.00734405024924253, 0.00290809553026393, 0, 0, 0, 0, 0.0257938940364825, -0.031911667854454, 0, 0, 0, -0.0134551405806471, 0.0135945758133865, 0, 0, 0.00601732179702858, -0.00347410235931506, 0, -0.00208446141558903, -0.000902598269554285, 0.000425488904726055, 0.0017195929357655, -0.000868525589828766},
    {-0.010023442173431, -0.0324515955311979, -0.0187359374155699, -0.0289614183593722, 0.0211783869997511, 0.0164047080299144, 0.00947126259704826, -0.00446479600584754, -0.00257775117585284, -0.00619733414463432, -0.0208787193108001, -0.0176457384588052, -0.0136683302364968, -0.00789141414141415, -0.00848980987436741, -0.00657617845117846, -0.00379675839902691, -0.00230118309469618, -0.00132858867917746, -0.000187890812890801, 0.0139343556230002, 0.0122889465527977, 0.0103860554652283, 0.00804500396992315, 0.00464478520766674, 0.00109915679455669, 0.000928957041533341, 0.000719567030240148, 0.000415442218609125, -0.00482700238195389, -0.0037389799674822, -0.00215870109072046, -0.00559691799261187, -0.00323138210966672, -0.00290809553026391, 0, 0, 0, 0, 0, 0, 0.0128177429097644, 0.0113041867027994, 0.0095537814881164, 0.00740032731935591, 0.00427258096992148, 0.0183832217438608, 0.0155366580724417, 0.0120346435940572, 0.00694820471863011, 0.0181644397838736, 0.014070114555226, 0.00812338442598859, 0.0136156449512337, 0.00786099627778515, 0.00607967912880134},
    {0.0100234421734309, 0.0249047128495239, 0.014378742667763, 0.0536094339843699, -0.0141189246665008, -0.0109364720199429, -0.00631417506469885, -0.0133943880175427, -0.0077332535275586, 0.0153110608279201, 0.00298267418725715, 0.0025208197798293, 0.00195261860521384, 0.00112734487734489, 0.0276525235907967, 0.0214195526695527, 0.0123665844996876, 0.0243925408037797, 0.0140830399992811, 0.0108976671476671, 0, 0, 0, 0, 0, -0.0197848223020205, -0.0167212267476002, -0.0129522065443228, -0.00747795993496437, -0.00321800158796925, -0.00249265331165479, -0.0014391340604803, 0.0106850252586227, 0.00616900220936373, 0.00872428659079176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0206811244618434, -0.0174787403314969, -0.0135389740433143, -0.00781673030845888, -0.0363288795677472, -0.028140229110452, -0.0162467688519772, -0.0357410679969885, -0.020635115229186, -0.018239037386404},
    {0.0100234421734309, -0.0354703486038674, -0.0204788153146927, -0.0449826285156207, 0.0141189246665008, 0.0109364720199429, 0.00631417506469886, 0.00446479600584757, 0.00257775117585287, -0.0211438459052229, 0, 0, 0, 0, 0.00339592394974696, 0.00263047138047138, 0.00151870335961076, -0.030835853468929, -0.0178030883009781, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0225260111157848, 0.0174485731815835, 0.0100739384233621, -0.00356167508620757, -0.00205633406978792, -0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0282557952193589, 0.0218868448636849, 0.01263637577376, 0.047654757329318, 0.027513486972248, 0.0303983956440067},
    {-0.010023442173431, 0.0128297005588456, 0.0074072310712718, 0.0449826285156208, 0, 0, 0, -0.0178591840233903, -0.0103110047034115, 0.021143845905223, 0, 0, 0, 0, 0, 0, 0, -0.00920473237878481, -0.00531435471670986, 0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0178083754310377, -0.0102816703489395, 0.0145404776513196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0297842233308237, -0.017195929357655, -0.0303983956440068},
    {-0.0100234421734311, -0.0324515955311978, -0.0335503995581136, -0.00801060507812425, 0.0211783869997512, -0.00109364720199428, -0.00568275755822899, 0.0169662248222208, 0.00567105258687631, 0.0083846285486229, -0.0208787193108001, -0.0109235523792604, -0.00499002532443534, -0.00187890812890814, -0.0162519217595033, -0.00958243145743147, -0.00466458889023305, -0.0108922666482287, -0.00558007245254535, -0.00469727032227032, 0.0139343556230002, 0.00245778931055953, -0.00415442218609132, -0.00643600317593851, -0.00464478520766672, 0.0120907247401236, 0.00464478520766673, 0.00071956703024015, -0.000415442218609144, 0.00965400476390777, 0.00498530662330958, 0.00215870109072047, 0.00661453944581401, 0.0032313821096667, 0.00290809553026393, 0, 0.0127646671417816, 0.0202632808954031, 0.0228341307513453, 0.020635115229186, 0.0127646671417816, -0.00116524935543313, 0.00719357335632687, 0.0112908326677739, 0.0114368694935501, 0.00737991258440984, -0.00183832217438608, 0.00310733161448835, 0.00481385743762286, 0.00347410235931505, -0.00201827108709706, 0.000521115353897262, 0.00090259826955429, -0.00170195561890422, -0.000491312267361567, -0.000868525589828765},
    {0.010023442173431, 0.0249047128495239, 0.0553363732971484, -0.0043134027343746, -0.0141189246665008, -0.0153110608279201, 0.00883984509057842, -0.00803663281052563, -0.0159820572902878, 0.000729098134662859, 0.00298267418725716, 0.0277290175781224, 0.0301571095694136, 0.0191648629148629, -0.00145539597846298, 0.0116492303992304, 0.00976309302606918, -0.00352848074520084, 0.00132858867917746, -0.00263047138047138, 0, -0.0196623144844763, -0.00727023882565981, 0.00724050357293083, 0.00928957041533346, 0.00219831358911339, -0.0148633126645336, -0.0129522065443228, -0.00664707549774609, 0.00402250198496158, -0.00685479660705068, -0.00575653624192124, 0.0045792965394097, -0.00029376200996968, 0.00290809553026392, 0, 0, -0.0202632808954031, -0.0399597288148543, -0.0464290092656686, -0.031911667854454, 0, 0.00411061334647249, -0.00303983956440067, -0.00908221989193682, -0.00776832903622089, -0.000459580543596519, 0.00427258096992148, 0.00270779480866288, 0.000868525589828772, -0.00100913554354853, 0.00234501909253766, 0.00180519653910858, -0.00127646671417816, 0.000245656133680779, -0.000868525589828762},
    {0.0100234421734308, -0.0354703486038674, -0.0492363006502188, -0.00431340273437457, 0.0141189246665008, 0.00656188321196576, -0.016416855168217, 0.00982255121286464, 0.0149509568199466, 0.000729098134662869, 0, 0.0033610930397724, -0.0282044909641998, -0.0353234728234728, -0.000485131992820994, 0.0124007936507936, 0.00889526253486298, -0.00291483191994852, 0.00239145962251946, -0.00263047138047138, 0, 0, 0.0218107164769794, 0.00402250198496157, -0.00928957041533346, 0, -0.00557374224920008, 0.0143913406048031, 0.0141250354327105, 0.000804500396992312, -0.00934744991870547, -0.0028782681209606, 0.00254405363300539, -0.00381890612960614, 0.00290809553026393, 0, 0, 0, 0.0266398192099029, 0.0515877880729651, 0.0425488904726053, 0, 0, -0.00911951869320203, -0.00840946286290443, -0.00388416451811041, 0, 0.00233049871086626, -0.0030086608985143, -0.00347410235931506, -0.000336378514516177, 0.00286613444643492, 0.00120346435940572, -0.000850977809452107, 0.000982624534723154, -0.000868525589828766},
    {-0.0100234421734312, 0.0128297005588457, 0.0448791059024116, -0.00801060507812422, 0, -0.0174983552319087, 0.0132597676358676, 0.00357183680467807, -0.0175287079957994, 0.0083846285486229, 0, 0, -0.00867830491206146, 0.0225468975468975, 0, 0.00300625300625302, -0.019200749617936, -0.000613648825252317, 0.0122230158484327, -0.00469727032227032, 0, 0, 0, -0.0160900079398463, 0.00464478520766673, 0, 0, 0.00719567030240153, -0.0108014976838374, 0, -0.0024926533116548, 0.0107935054536023, 0.000508810726601074, -0.00734405024924252, 0.00290809553026392, 0, 0, 0, 0, -0.0257938940364825, -0.031911667854454, 0, 0, 0, 0.0134551405806471, 0.0135945758133865, 0, 0, -0.00601732179702859, -0.00347410235931506, 0, 0.00208446141558903, -0.000902598269554288, -0.000425488904726052, 0.0017195929357655, -0.000868525589828764},
    {-0.010023442173431, -0.0452812960900435, -0.0113287063442981, -0.00801060507812424, -0.00141189246665009, 0.0164047080299144, 0.0145226026488074, 0.0133943880175427, 0.0118576554089231, 0.00838462854862289, -0.00894802256177148, -0.0142846454190328, -0.014536160727703, -0.00939454064454065, -0.0123708658169354, -0.0125886844636845, -0.00813591085505764, -0.0102786178229763, -0.00664294339588733, -0.00469727032227033, -0.00836061337380012, 0.00245778931055953, 0.00830884437218264, 0.00965400476390777, 0.00650269929073345, 0.00219831358911338, 0.00743165633226678, 0.00863480436288183, 0.00581619106052785, 0.00643600317593852, 0.00747795993496437, 0.00503696921168108, 0.00610572871921293, 0.00411266813957582, 0.00290809553026394, 0.0352796762358899, 0.0191470007126724, 0.00788016479265675, 0.000951422114639394, -0.00221090520312706, -0.00212744452363027, 0.017478740331497, 0.00719357335632686, 0.000868525589828768, -0.00201827108709706, -0.00194208225905521, 0.00643412761035128, 0.000776832903622091, -0.00180519653910858, -0.00173705117965753, 0.000672757029032361, -0.00156334606169177, -0.00150433044925715, -0.00127646671417816, -0.00122828066840393, -0.000868525589828768},
    {0.010023442173431, 0.0603750614533914, -0.00610007264692976, -0.0043134027343746, -0.00564756986660028, -0.0218729440398859, 0.00126283501293978, -0.0178591840233903, 0.00103110047034114, 0.000729098134662877, 0.0417574386216002, 0.0168054651988621, -0.000867830491206145, -0.00526094276094275, 0.0145539597846299, -0.000751563251563254, -0.00455611007883227, -0.000613648825252328, -0.0037200483016969, -0.00263047138047138, 0.00557374224920006, -0.0196623144844763, -0.0103860554652283, 0.00321800158796927, 0.00650269929073342, -0.0175865087129071, -0.00928957041533348, 0.00287826812096063, 0.00581619106052784, -0.00804500396992315, 0.0024926533116548, 0.00503696921168106, 0.00203524290640432, 0.00411266813957581, 0.00290809553026391, -0.0705593524717798, -0.0127646671417816, 0.00450295131008959, 0.00380568845855754, -0.000736968401042368, -0.00212744452363026, -0.0116524935543313, 0.00411061334647251, 0.00347410235931506, -0.000672757029032363, -0.00194208225905521, 0.00367664434877217, 0.00310733161448834, -0.000601732179702864, -0.00173705117965753, 0.00269102811612941, -0.000521115353897262, -0.00150433044925715, -0.000425488904726057, -0.00122828066840393, -0.000868525589828762},
    {0.0100234421734309, -0.0603750614533914, -0.00610007264692973, -0.00431340273437457, -0.00564756986660034, 0.0218729440398859, 0.00126283501293976, 0.0178591840233903, 0.00103110047034114, 0.000729098134662853, -0.0417574386216002, 0.016805465198862, 0.000867830491206158, -0.00526094276094277, 0.0145539597846298, 0.00075156325156326, -0.00455611007883228, 0.000613648825252334, -0.00372004830169691, -0.00263047138047138, 0.00557374224920012, 0.0196623144844763, -0.0103860554652283, -0.00321800158796927, 0.00650269929073344, 0.0175865087129071, -0.00928957041533346, -0.00287826812096063, 0.00581619106052786, -0.00804500396992314, -0.0024926533116548, 0.00503696921168108, -0.00203524290640433, 0.00411266813957582, 0.00290809553026393, 0.0705593524717798, -0.0127646671417816, -0.00450295131008958, 0.00380568845855756, 0.000736968401042369, -0.00212744452363027, -0.0116524935543313, -0.00411061334647251, 0.00347410235931506, 0.00067275702903236, -0.00194208225905522, -0.00367664434877217, 0.00310733161448835, 0.000601732179702864, -0.00173705117965753, 0.00269102811612942, 0.000521115353897261, -0.00150433044925715, 0.00042548890472606, -0.00122828066840393, -0.00086852558982877},
    {-0.010023442173431, 0.0452812960900435, -0.0113287063442981, -0.00801060507812426, -0.00141189246665007, -0.0164047080299144, 0.0145226026488074, -0.0133943880175427, 0.0118576554089231, 0.00838462854862291, 0.00894802256177146, -0.0142846454190327, 0.014536160727703, -0.00939454064454063, -0.0123708658169354, 0.0125886844636845, -0.00813591085505763, 0.0102786178229763, -0.00664294339588733, -0.00469727032227032, -0.00836061337380014, -0.00245778931055954, 0.00830884437218263, -0.00965400476390776, 0.00650269929073343, -0.00219831358911339, 0.00743165633226678, -0.00863480436288183, 0.00581619106052785, 0.00643600317593852, -0.00747795993496437, 0.00503696921168107, -0.00610572871921292, 0.00411266813957582, 0.00290809553026393, -0.0352796762358899, 0.0191470007126724, -0.00788016479265674, 0.000951422114639387, 0.00221090520312707, -0.00212744452363027, 0.0174787403314969, -0.00719357335632687, 0.000868525589828768, 0.00201827108709706, -0.00194208225905521, -0.00643412761035128, 0.000776832903622089, 0.00180519653910857, -0.00173705117965753, 0.000672757029032358, 0.00156334606169177, -0.00150433044925715, 0.00127646671417815, -0.00122828066840393, -0.000868525589828767},
    {0.0787556170769579, 0.0679219441350652, -0.00435719474780693, -0.00308100195312473, 0.0705946233325038, -0.0328094160598287, 0.0126283501293977, -0.0267887760350854, 0.03608851646194, -0.00729098134662863, 0.0298267418725716, 0.0151249186789758, -0.0325436434202305, 0.0248015873015873, 0.0130985638061669, -0.0229226791726792, 0.0169226945785199, -0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, 0.0245778931055954, -0.036351194128299, 0.0362025178646541, -0.0232239260383337, 0.0219831358911339, -0.00743165633226678, 0, 0.00166176887443652, -0.0345935170706695, 0.0130864298861876, -0.00359783515120078, 0.0335815079556711, -0.014688100498485, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0.0226083734055987, -0.0334382352084074, 0.0333014729371016, -0.0213629048496074, -0.0045958054359652, -0.0194208225905522, 0.0270779480866286, -0.0191075629762328, 0.0090822198919368, 0.00703505727761299, -0.00812338442598857, -0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083694, 0.00217859737390342, -0.0215670136718729, 0, 0.0984282481794862, -0.0852413633734345, -0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, 0.0236742424242424, -0.0335199527228374, -0.00138070985681772, -0.000797153207506437, 0.00394570707070705, 0, 0, 0.036351194128299, -0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838374, -0.00724050357293084, -0.0392592896585629, 0.0259044130886455, 0.0188259968842399, 0.0108691943688789, -0.0178640154001926, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, -0.0555024548951693, 0.0427258096992148, 0, -0.0155366580724418, 0, 0.00694820471863007, 0.0030274066306456, 0.0164151336477636, -0.0108311792346515, -0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, 0.0301875307266957, 0.0610007264692974, -0.00308100195312469, 0, 0.0218729440398859, 0.0757701007763863, 0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, 0.0520698294723689, -0.00901875901875902, 0, -0.0127765752765753, 0.0286384062098029, 0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, 0.0402250198496157, -0.0464478520766674, 0, 0, 0.0143913406048031, 0.0182794576188018, 0, -0.0137095932141014, -0.0345392174515274, 0.00407048581280862, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0370016365967795, -0.0427258096992148, 0, 0, -0.0300866089851429, 0.0243187165152054, 0, 0.014070114555226, 0, -0.00340391123780844, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573523, 0.00377344134083676, -0.0196073763651313, 0.00924300585937421, 0, -0.0109364720199428, 0.00947126259704827, 0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965861, 0.00650872868404616, -0.00450937950937951, 0.0465726713108155, 0.0214195526695527, -0.0289638426440052, -0.00782402252196702, -0.0263060558477138, 0.000563672438672466, 0, 0, 0, 0, 0, 0, 0.0334424534952005, -0.0431740218144092, 0.0299118397398575, 0.0289620142917233, -0.00249265331165482, -0.00431740218144091, -0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, -0.0451299134777144, 0.0312669212338355, -0.0121096265225824, -0.028140229110452, 0.0270779480866286, 0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573521, -0.0150937653633478, 0.0130715842434208, 0.0092430058593741, 0, -0.0109364720199429, 0.00947126259704829, -0.00892959201169515, 0.123732056440937, -0.0601505961096861, 0, 0, -0.00650872868404611, 0.00676406926406927, 0, 0.0574945887445887, 0.0126920209338899, -0.0266937238984759, 0.00637722566005183, 0.000563672438672468, 0, 0, 0, 0, 0, 0, 0, 0.0431740218144092, -0.0448677596097863, 0, 0.0199412264932383, 0.0215870109072046, -0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0451299134777144, -0.0469003818507533, 0, -0.0375203054806026, 0.0162467688519772, 0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, 0.0301875307266958, 0.0174287789912279, 0.0585390371093694, 0, 0.0218729440398859, -0.0189425251940965, 0.0178591840233903, 0.0103110047034115, 0.083846285486229, 0, 0, 0, 0, 0, 0.00526094276094277, -0.00455611007883226, 0.0533874477969518, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0348971463631671, -0.0302218152700864, 0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0437736897273697, -0.0379091273212801, -0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.0787556170769579, -0.0679219441350653, -0.00435719474780696, -0.00308100195312474, 0.0705946233325038, 0.0328094160598287, 0.0126283501293977, 0.0267887760350854, 0.03608851646194, -0.00729098134662861, -0.0298267418725716, 0.0151249186789758, 0.0325436434202305, 0.0248015873015873, 0.0130985638061669, 0.0229226791726792, 0.0169226945785199, 0.0248527774227189, 0.0164744996218006, 0.0142797017797018, 0, -0.0245778931055954, -0.036351194128299, -0.0362025178646542, -0.0232239260383337, -0.0219831358911339, -0.00743165633226677, 0, 0.00166176887443653, -0.0345935170706695, -0.0130864298861877, -0.00359783515120077, -0.0335815079556711, -0.0146881004984851, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, -0.0226083734055987, -0.0334382352084074, -0.0333014729371016, -0.0213629048496074, 0.0045958054359652, -0.0194208225905522, -0.0270779480866286, -0.0191075629762328, 0.00908221989193679, -0.00703505727761299, -0.00812338442598858, 0.0102117337134253, 0.00196524906944629, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, 0.00217859737390347, -0.021567013671873, 0, -0.0984282481794862, -0.0852413633734346, 0.031253572040933, -0.0180442582309699, 0.0309866707231716, 0, 0.0453747560369276, 0, -0.0202922077922078, -0.0116431678277039, -0.0236742424242424, -0.0335199527228374, 0.00138070985681773, -0.000797153207506457, 0.00394570707070706, 0, 0, 0.036351194128299, 0.0603375297744236, 0.0464478520766674, 0, 0.024152883079867, 0, -0.0108014976838375, -0.00724050357293084, 0.0392592896585629, 0.0259044130886455, -0.0188259968842399, 0.0108691943688789, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0.0334382352084074, 0.0555024548951694, 0.0427258096992148, 0, -0.0155366580724417, 0, 0.00694820471863009, 0.00302740663064561, -0.0164151336477636, -0.0108311792346515, 0.00680782247561685, -0.00393049813889256, 0.00607967912880134},
    {0.0787556170769578, -0.0301875307266956, 0.0610007264692975, -0.00308100195312472, 0, -0.0218729440398858, 0.0757701007763862, -0.0178591840233903, -0.0412440188136458, -0.00729098134662864, 0, 0, -0.0520698294723689, -0.00901875901875903, 0, 0.0127765752765753, 0.0286384062098028, -0.00184094647575697, -0.0297603864135753, 0.0142797017797018, 0, 0, 0, -0.0402250198496157, -0.0464478520766674, 0, 0, -0.0143913406048031, 0.0182794576188018, 0, 0.0137095932141014, -0.0345392174515273, -0.0040704858128086, 0.036426489236243, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0370016365967796, -0.0427258096992148, 0, 0, 0.030086608985143, 0.0243187165152054, 0, -0.014070114555226, 0, 0.00340391123780843, -0.00982624534723145, 0.00607967912880136},
    {-0.0214788046573521, -0.00377344134083693, -0.0196073763651313, 0.00924300585937419, 0, 0.0109364720199429, 0.00947126259704825, -0.102690308134494, -0.0695992817480272, -0.060150596109686, 0, -0.00504163955965863, -0.00650872868404612, -0.00450937950937953, 0.0465726713108155, -0.0214195526695527, -0.0289638426440052, 0.00782402252196705, -0.0263060558477139, 0.000563672438672429, 0, 0, 0, 0, 0, 0, 0.0334424534952005, 0.0431740218144092, 0.0299118397398575, 0.0289620142917233, 0.00249265331165481, -0.00431740218144093, 0.0605484764655283, 0.0185070066280912, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0349574806629939, 0.0451299134777144, 0.0312669212338355, -0.0121096265225824, 0.028140229110452, 0.0270779480866286, -0.023827378664659, 0, -0.0182390373864041},
    {-0.0214788046573522, 0.0150937653633479, 0.0130715842434208, 0.00924300585937409, 0, 0.0109364720199429, 0.00947126259704827, 0.00892959201169516, 0.123732056440937, -0.060150596109686, 0, 0, 0.00650872868404612, 0.00676406926406929, 0, -0.0574945887445887, 0.0126920209338899, 0.0266937238984758, 0.00637722566005188, 0.000563672438672467, 0, 0, 0, 0, 0, 0, 0, -0.0431740218144092, -0.0448677596097862, 0, -0.0199412264932383, 0.0215870109072046, 0.0142467003448302, -0.0616900220936373, 0.0461140862656136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0451299134777144, -0.0469003818507533, 0, 0.0375203054806026, 0.0162467688519772, -0.0119136893323295, 0.020635115229186, -0.0182390373864041},
    {0.0787556170769578, -0.0301875307266957, 0.0174287789912279, 0.0585390371093694, 0, -0.0218729440398858, -0.0189425251940966, -0.0178591840233903, 0.0103110047034114, 0.083846285486229, 0, 0, 0, 0, 0, -0.00526094276094278, -0.00455611007883225, -0.0533874477969517, 0.0308232573569172, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0348971463631671, -0.0302218152700864, -0.0284934006896604, 0.0164506725583033, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0437736897273697, -0.0379091273212801, 0.023827378664659, -0.013756743486124, 0.0303983956440068},
    {0.078755617076958, -0.0377344134083696, -0.0566435317214905, -0.00308100195312475, 0.0423567739995023, 0.0546823600997145, 0.0378850503881931, 0.0446479600584756, 0.00515550235170575, -0.00729098134662859, 0.0417574386216002, -0.00504163955965861, -0.0247331689993752, -0.0202922077922078, 0.0295930515620807, 0.0101461038961039, 0.00216957622801536, 0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, -0.0245778931055953, -0.00519302773261415, 0.00402250198496157, 0.00464478520766673, -0.00219831358911336, -0.0130053985814669, -0.0158304746652834, -0.0108014976838374, -0.0168945083368386, -0.026796023100289, -0.0194283098164841, -0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, -0.0226083734055987, -0.00477689074405821, 0.00370016365967795, 0.00427258096992148, -0.0367664434877216, -0.00776832903622087, 0.00601732179702858, 0.00694820471863012, -0.00908221989193681, 0.00703505727761298, 0.0081233844259886, 0.00680782247561685, 0.00786099627778516, 0.00607967912880136},
    {-0.0214788046573523, 0, -0.00435719474780694, -0.021567013671873, -0.127070321998507, 0, 0.0284137877911448, 0, 0.03608851646194, 0.0309866707231716, 0, 0.0453747560369275, 0, -0.0202922077922078, -0.0422064833754266, 0, -0.00618329224984376, 0, 0.00159430641501295, 0.00394570707070706, 0.0836061337380013, 0, -0.0103860554652283, 0, 0.00464478520766673, 0, 0.024152883079867, 0, -0.0108014976838374, 0.043443021437585, 0, -0.0194283098164841, 0, -0.0217383887377578, -0.0178640154001927, 0, 0, 0, 0, 0, 0, 0.0769064574585866, 0, -0.0095537814881164, 0, 0.00427258096992146, 0, -0.0155366580724417, 0, 0.00694820471863012, -0.0181644397838736, 0, 0.00812338442598857, 0, 0.00786099627778514, 0.00607967912880135},
    {0.0787556170769579, 0.0377344134083696, -0.0566435317214905, -0.00308100195312473, 0.0423567739995023, -0.0546823600997146, 0.0378850503881931, -0.0446479600584757, 0.00515550235170575, -0.00729098134662861, -0.0417574386216002, -0.00504163955965862, 0.0247331689993752, -0.0202922077922078, 0.0295930515620807, -0.0101461038961039, 0.00216957622801535, -0.0266937238984759, 0.0132858867917747, 0.0142797017797018, -0.0557374224920008, 0.0245778931055954, -0.00519302773261415, -0.00402250198496158, 0.00464478520766674, 0.0021983135891134, -0.0130053985814669, 0.0158304746652834, -0.0108014976838374, -0.0168945083368386, 0.026796023100289, -0.0194283098164841, 0.0295110221428625, -0.0217383887377579, -0.0178640154001927, 0, 0, 0, 0, 0, 0, -0.0512709716390577, 0.0226083734055987, -0.00477689074405821, -0.00370016365967796, 0.00427258096992148, 0.0367664434877216, -0.00776832903622088, -0.00601732179702859, 0.00694820471863012, -0.00908221989193681, -0.00703505727761299, 0.0081233844259886, -0.00680782247561686, 0.00786099627778516, 0.00607967912880137},
    {-0.0214788046573522, -0.0188672067041847, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234944, -0.111619900146189, -0.0541327746929101, -0.0601505961096861, -0.0089480225617715, -0.00252081977982932, 0.000650872868404613, 0.00112734487734488, -0.0276525235907967, 0.0360750360750361, 0.0374251899332651, -0.0188697013765088, 0.019928830187662, 0.000563672438672442, 0, 0, 0, 0, 0, 0.0593544669060614, 0.0167212267476003, -0.0043174021814409, -0.00747795993496438, 0.00321800158796927, 0.0224338798048931, 0.018708742786244, 0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0.0620433733855302, 0.017478740331497, -0.00451299134777142, -0.00781673030845889, 0.0363288795677472, -0.00938007637015065, -0.0162467688519772, -0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {-0.0214788046573522, 0.0188672067041848, 0.00653579212171048, 0.00924300585937412, 0.0141189246665008, 0, -0.00315708753234943, 0.111619900146189, -0.0541327746929101, -0.060150596109686, 0.00894802256177147, -0.00252081977982932, -0.000650872868404603, 0.00112734487734487, -0.0276525235907967, -0.0360750360750361, 0.0374251899332651, 0.0188697013765088, 0.019928830187662, 0.000563672438672466, 0, 0, 0, 0, 0, -0.0593544669060614, 0.0167212267476002, 0.00431740218144092, -0.00747795993496438, 0.00321800158796926, -0.0224338798048931, 0.018708742786244, -0.0463017761206981, 0.0431830154655461, 0.0461140862656137, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0620433733855302, 0.017478740331497, 0.00451299134777143, -0.00781673030845888, 0.0363288795677472, 0.00938007637015065, -0.0162467688519772, 0.0119136893323295, -0.020635115229186, -0.0182390373864041},
    {0.0787556170769579, 0, -0.0348575579824557, 0.0585390371093694, -0.0282378493330016, 0, 0.00631417506469888, 0, -0.0206220094068228, 0.083846285486229, 0, 0, 0, 0, -0.00679184789949392, 0, 0.00151870335961076, 0, -0.0616465147138344, -0.0319414381914382, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0450520222315696, 0, 0.0100739384233621, 0, -0.0329013451166066, -0.0643935438844155, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0565115904387179, 0, 0.01263637577376, 0, 0.0275134869722481, 0.0303983956440068},
    {0.0787556170769579, -0.0377344134083696, -0.0217859737390349, -0.0523770332031201, 0.0423567739995023, 0.0546823600997146, 0, 0.0446479600584757, 0.0257775117585286, 0.0291639253865145, 0.0417574386216002, 0.0285692908380655, 0.0273366604729937, 0.0187890812890813, -0.0092175078635989, -0.00789141414141413, -0.0034713219648246, -0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920009, -0.00491557862111904, -0.0197335053839338, -0.0394205194526234, -0.0325134964536672, -0.0241814494802472, -0.00928957041533348, -0.0158304746652834, -0.0141250354327105, -0.00241350119097695, -0.000623163327913702, -0.00215870109072047, 0.00712335017241509, 0.00411266813957581, 0.0054007488419187, 0, -0.0510586685671264, -0.0405265617908061, -0.0114170653756727, 0.010317557614593, 0.0127646671417816, 0.00466099742173251, -0.0143871467126537, -0.00564541633388697, 0.00571843474677501, 0.00737991258440982, 0.00367664434877216, -0.00155366580724418, 0.00240692871881143, 0.00347410235931506, 0.00100913554354853, 0.000260557676948637, 0.000902598269554288, -0.000850977809452104, -0.000491312267361571, -0.00086852558982876},
    {-0.021478804657352, 0, -0.0217859737390348, 0.00308100195312482, -0.127070321998507, 0, 0.0473563129852414, 0, 0.0257775117585285, 0.0127592173566, 0, -0.0352914769176103, 0, 0.00225468975468977, 0.0509388592462044, 0, -0.00943765659186683, 0, -0.0143487577351166, -0.0129644660894661, 0.0836061337380013, 0, 0.0477758551400502, 0, -0.0325134964536671, 0, 0.00928957041533349, 0, -0.0141250354327105, -0.0144810071458616, 0, -0.00215870109072046, 0, 0.00411266813957585, 0.00540074884191873, 0, 0.0765880028506897, 0, -0.0228341307513453, 0, 0.0127646671417816, -0.00699149613259877, 0, -0.0112908326677739, 0, 0.0073799125844098, 0, -0.00310733161448834, 0, 0.00347410235931506, 0.00201827108709706, 0, 0.000902598269554283, 0, -0.000491312267361592, -0.000868525589828771},
    {0.0787556170769579, 0.0377344134083696, -0.0217859737390348, -0.0523770332031201, 0.0423567739995023, -0.0546823600997146, 0, -0.0446479600584757, 0.0257775117585286, 0.0291639253865145, -0.0417574386216002, 0.0285692908380655, -0.0273366604729936, 0.0187890812890813, -0.0092175078635989, 0.00789141414141415, -0.00347132196482461, 0.0248527774227189, -0.0143487577351166, -0.015031265031265, -0.0557374224920008, 0.00491557862111909, -0.0197335053839338, 0.0394205194526234, -0.0325134964536672, 0.0241814494802473, -0.00928957041533348, 0.0158304746652834, -0.0141250354327105, -0.00241350119097695, 0.000623163327913698, -0.00215870109072046, -0.00712335017241509, 0.00411266813957582, 0.0054007488419187, 0, -0.0510586685671264, 0.0405265617908062, -0.0114170653756727, -0.010317557614593, 0.0127646671417816, 0.00466099742173252, 0.0143871467126538, -0.00564541633388697, -0.00571843474677502, 0.00737991258440984, -0.00367664434877217, -0.00155366580724418, -0.00240692871881143, 0.00347410235931506, 0.00100913554354854, -0.000260557676948627, 0.000902598269554284, 0.000850977809452108, -0.000491312267361573, -0.000868525589828761},
    {-0.0214788046573522, -0.0188672067041848, 0.0108929868695174, 0.00308100195312472, 0.0141189246665008, -0.109364720199429, -0.0789271883087357, 0.0223239800292378, -0.0128887558792643, 0.0127592173566001, -0.00894802256177149, -0.0277290175781224, -0.0058578558156415, 0.0191648629148629, 0.001455395978463, 0.0383297258297258, 0.0348216984596467, -0.0124263887113595, 0.00717437886755831, -0.0129644660894661, 0, 0.0589869434534289, 0.0072702388256598, 0.0506835250105158, 0.0650269929073344, -0.00659494076734015, 0.0148633126645336, -0.00431740218144092, -0.00166176887443655, -0.00402250198496158, -0.00810112326287806, -0.0115130724838424, 0.00356167508620756, -0.00205633406978791, 0.00540074884191871, 0, 0, 0.0607898426862092, 0.0399597288148543, -0.0154763364218895, -0.031911667854454, 0, -0.0123318400394175, 0.00303983956440066, -0.00302740663064558, -0.00776832903622087, 0.00137874163078956, -0.00427258096992148, 0.000902598269554308, 0.000868525589828756, 0.00100913554354853, 0.000781673030845879, 0.00180519653910857, -0.000425488904726061, 0.000245656133680788, -0.000868525589828768},
    {-0.0214788046573522, 0.0188672067041848, 0.0108929868695173, 0.00308100195312472, 0.0141189246665008, 0.109364720199429, -0.0789271883087357, -0.0223239800292378, -0.0128887558792643, 0.0127592173566001, 0.00894802256177149, -0.0277290175781224, 0.00585785581564148, 0.0191648629148629, 0.00145539597846298, -0.0383297258297258, 0.0348216984596467, 0.0124263887113595, 0.00717437886755832, -0.0129644660894661, 0, -0.0589869434534289, 0.00727023882565981, -0.0506835250105158, 0.0650269929073343, 0.00659494076734013, 0.0148633126645336, 0.00431740218144092, -0.00166176887443652, -0.00402250198496157, 0.00810112326287806, -0.0115130724838425, -0.00356167508620754, -0.00205633406978792, 0.00540074884191871, 0, 0, -0.0607898426862092, 0.0399597288148543, 0.0154763364218895, -0.031911667854454, 0, 0.0123318400394175, 0.00303983956440068, 0.00302740663064559, -0.00776832903622088, -0.00137874163078956, -0.00427258096992148, -0.000902598269554285, 0.000868525589828752, 0.00100913554354853, -0.00078167303084589, 0.00180519653910857, 0.000425488904726054, 0.00024565613368079, -0.000868525589828768},
    {0.0787556170769579, 0, 0.0435719474780696, -0.0523770332031201, -0.0282378493330016, 0, 0.0631417506469886, 0, -0.0515550235170572, 0.0291639253865144, 0, -0.0067221860795448, 0, -0.0601250601250601, 0.000970263985641979, 0, -0.0125835421224892, 0, 0.0286975154702333, -0.015031265031265, 0, 0, -0.0436214329539589, 0, -0.0650269929073343, 0, 0.0111474844984002, 0, 0.031573608614294, -0.00160900079398463, 0, -0.00287826812096061, 0, -0.00822533627915162, 0.00540074884191872, 0, 0, 0, -0.0532796384198057, 0, 0.0425488904726053, 0, 0, 0.018239037386404, 0, -0.00388416451811042, 0, -0.00466099742173252, 0, -0.00347410235931505, 0.000672757029032358, 0, 0.00120346435940572, 0, 0.000982624534723141, -0.000868525589828768},
    {0.107394023286761, -0.188672067041848, -0.108929868695174, -0.0770250488281177, -0.0705946233325038, -0.0546823600997146, -0.0315708753234943, -0.0446479600584756, -0.0257775117585285, -0.0182274533665716, 0.0894802256177148, -0.0151249186789759, 0.058578558156415, 0.0744047619047619, -0.0130985638061669, -0.0281836219336219, 0.00976309302606911, 0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, 0.0737336793167861, 0.036351194128299, -0.0120675059548847, -0.0232239260383337, 0.0659494076734015, 0.00743165633226673, 0.0431740218144092, 0.0465295284842227, 0.0345935170706695, 0.0155790831978424, 0.0251848460584054, -0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0.0678251202167962, 0.0334382352084074, -0.0111004909790339, -0.0213629048496074, -0.0137874163078956, 0.0194208225905522, -0.00902598269554289, -0.0191075629762328, -0.00908221989193677, -0.00234501909253767, -0.00812338442598857, 0.00340391123780843, 0.00196524906944629, 0.00607967912880134},
    {0.107394023286761, 0.188672067041848, -0.108929868695174, -0.0770250488281178, -0.0705946233325038, 0.0546823600997147, -0.0315708753234943, 0.0446479600584757, -0.0257775117585286, -0.0182274533665715, -0.0894802256177147, -0.0151249186789758, -0.0585785581564149, 0.0744047619047619, -0.0130985638061668, 0.0281836219336219, 0.00976309302606919, -0.0690354928408859, 0.039857660375324, 0.0597492784992785, 0, -0.0737336793167861, 0.0363511941282991, 0.0120675059548847, -0.0232239260383337, -0.0659494076734016, 0.00743165633226681, -0.0431740218144092, 0.0465295284842228, 0.0345935170706695, -0.0155790831978425, 0.0251848460584054, 0.0254405363300539, -0.0146881004984851, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, -0.0678251202167962, 0.0334382352084074, 0.0111004909790339, -0.0213629048496074, 0.0137874163078956, 0.0194208225905522, 0.00902598269554287, -0.0191075629762328, -0.00908221989193679, 0.00234501909253767, -0.00812338442598858, -0.00340391123780843, 0.00196524906944629, 0.00607967912880136},
    {0.107394023286762, 0, 0.217859737390348, -0.0770250488281177, 0, 0, -0.0947126259704827, 0, 0.051555023517057, -0.0182274533665715, 0, -0.0907495120738551, 0, -0.0946969696969697, 0.0232863356554078, 0, -0.0227805503941613, 0, -0.0797153207506479, 0.0597492784992785, 0, 0, -0.0727023882565981, 0, 0.0464478520766673, 0, -0.0483057661597341, 0, -0.0781031370985168, 0.0144810071458616, 0, 0.0431740218144091, 0, 0.0293762009969702, -0.0328199352701214, 0, 0, 0, 0, 0, 0, 0, 0, -0.0668764704168148, 0, 0.0427258096992147, 0, 0.0310733161448835, 0, 0.00694820471863014, -0.00605481326129119, 0, -0.0108311792346515, 0, -0.00393049813889257, 0.00607967912880136},
    {0.107394023286761, 0, 0, 0.231075146484353, 0, 0, 0, 0, 0, -0.109364720199429, 0, 0.0100832791193172, 0, -0.00450937950937955, -0.093145342621631, 0, -0.104139658944738, 0, 0, -0.09244227994228, 0, 0, 0, 0, 0, 0, -0.066884906990401, 0, 0.0299118397398575, -0.0579240285834467, 0, -0.0647610327216138, 0, 0, 0.0835038859404355, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -0.0699149613259878, 0, 0.0312669212338356, 0.0242192530451648, 0, 0.0270779480866286, 0, 0, -0.018239037386404}};
    
    // Interesting (new) part
    // Tables of derivatives of the polynomial base (transpose)
    const static double dmats0[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.32455532033676, 0, -1.14376677014985e-14, 1.62513232038197e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.226276025168e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.2249721603218, 0, 0, 0, 1.51109207276003e-14, 0, 0, 1.7779939846807e-14, 0, -1.0584837800154e-14, 0, 0, 0, 0, 0, -1.00872575799093e-14, 0, 0, 1.03757106873844e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.58257569495584, 0, 8.36660026534074, -1.18321595661991, 0, -1.45923311721618e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.02203768115554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.74165738677394, 0, 0, 8.69482604771369, 0, 0, 0, 0, 1.78666554661835e-14, 0, 0, 0, 0, 0, 1.07473131066306e-14, 0, 0, 0, -1.11533477710537e-14, 2.38264269425414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.49909083394701, -1.6247766670982e-14, -3.3466401061363, -2.36643191323984, 15.4919333848297, 0, 0.692820323027544, 0, 0.565685424949235, 0.4, -1.83948951574252e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00288811754535e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.89897948556636, -1.43896667584992e-14, 0, 1.15516000140692e-14, 14.1985914794391, 0, -0.828078671210835, 2.47538399283584e-14, 0, 0, -1.83091262688552e-14, 1.02722007327841e-14, -1.56195834108856e-14, 0, 0, -1.91729044059553e-14, 0, 0, 0, 0, 0, 1.12036901882012e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.41804190462393e-14, 0, -1.19125833850358e-14, 0, 0, -1.13598572445865e-14, 0, -1.07549059979877e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.60000000000001, 0, 8.76356092008264, -1.54919333848296, 0, 0, 9.52470471983252, 0, -1.48131215963608, 0.261861468283188, 0, 0, 0, -2.03129367268393e-14, 0, 0, 2.48374782197935e-14, 0, -2.78808329533534e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.04489815276121e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00610790048597e-14, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 4.24264068711929, 0, 1.13239065646931e-14, 0, 0, 0, 14.3427433120127, 1.68846056927685e-14, 0, 0, 0, 0, 0, 1.92963956808162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.11769145362398, -1.38374576748428e-14, 3.16227766016837, 4.91934955049958, 0, 0, -1.29538515160783e-14, -1.04815557124913e-14, 10.690449676497, -2.41897262725904, 0, 0, 0, 0, 0, 2.10489624344795e-14, 0, -1.67945221763201e-14, -3.13102977027619e-14, 2.84355872182118e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.79907925474428e-14, 0, -1.53961627596513e-14, 1.10259024133086e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.54558441227157, 0, 0, 7.66811580507233, 0, 0, 0, 0, 2.32369836935692e-14, 10.3691851174526, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 11.60576914948, 0, 1.09730925298582e-14, 0, -4.20458932936042, 0, -3.43303281162797, 0, 0, 19.6214168703486, 0, 0.611677741841187, 1.15273118941668e-14, 0, 0.529728463363971, 0, 0.432521479156778, 0, 1.6058715222196e-14, 0, -1.16729361337554e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.53137212479104, -1.01690618327065e-14, 3.54562104171169, -2.50713268211205, 4.78713553878169, 0, -5.56626745075489, 0, -1.04880884817015, 0.741619848709564, 0, 18.8034951158403, 0, 1.68183573174418, -0.603122387046456, 0, 0.70128378121765, 0, 0.132137494528682, -0.0934353184302471, 0, 0, 0, -1.0082826842246e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07842270669413e-14, 0, 0, 0, 0, 0, -1.43736268462506e-14, 0, 1.40644587163015e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.5951288749407, 0, 0, 0, 10.0285307284481, 0, -0.767649473578742, 0, 0, 0, 0, 16.4130361329658, -1.65111444887587e-14, 0, -1.26347611061158, 0, 0.0967147429123319, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.96647939483827, 0, 8.12403840463594, -1.64130361329659, 0, 0, 11.7728501222091, 0, -2.40312296813958, 0.48550415622761, 0, 0, 0, 10.2761860629321, 0, 0, -1.48323969741912, 0, 0.302765035409732, -0.0611677741841287, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.05298244095218, 0, -1.58564993434419, 4.48489528465109, 4.28174419288837, 0, 0.191485421551277, 0, -3.75233260785876, -4.31161222746203, 0, 0, 0, 0, 18.8807171866294, 0, 0.844371341865034, -1.40094110434133e-14, 1.18187368057056, 1.04463861754666, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.321153829896, 0, 0, 0, 3.92428337406971, 0, 5.49285249860475, 1.63666823149722e-14, 0, 0, 0, 0, -1.21592089550238e-14, 0, 17.3044631365566, -1.98459387250407e-14, -1.73008591662713, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.78485070541082e-14, 0, 0, 0, 0, -1.10973688891617e-14, 0, 2.78631828811134e-14, 0, 0, 0, 0},
    {2.65329983228432, -1.19347092313647e-14, 4.1522061999051, 2.93605316083777, 0, -1.18275179297788e-14, 2.63248931621762, 0, 9.82591326180786, -2.8226127713774, 0, 0, 0, -1.25702218603545e-14, 0, 1.56555930303565e-14, 11.6081867662439, -2.18250550506549e-14, -3.09487177319471, 0.68387650554026, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47816108620456e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.14018107676926e-14, 0, 0, 1.65626348131594e-14, 0, -2.85468388090362e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 2.01017818278146, 0, 1.31743415178767e-14, 0, 0, 0, 8.91928088068604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.8558564884489, 1.01802247187699e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.2978250586152, 0, 1.49829835452877, 5.50917601898538, 0, 0, 0, 0, 6.64803945320941, 4.13676892548488, 0, 0, 0, 0, 0, 1.7956276449824e-14, 0, 0, 12.5636136423842, -3.55352656109504, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.18752842449636e-14, 0, -1.81638809042383e-14, 1.41922064378353e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87616630392937, 0, 0, 6.22830929985768, 0, 0, 0, 0, 1.27788751430286e-14, 11.0541524195338, 0, 0, 0, 0, -1.24460589269538e-14, 0, 1.31323882635267e-14, 0, 0, 11.6057691494799, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {4.83186700722507, 0, -4.41087092453692, -3.11895674167863, 16.6749979177077, 0, 2.13065307820924, 0, 1.73967095350099, 1.23013312825382, 0, -4.3665394383501, 0, -0.557935943461974, -3.78153408023783, 0, -0.483186700722511, 0, -0.394520289089677, -0.278967971730981, 23.6981011897578, 0, 0.490653381462665, 0, 0.0626933893908993, 0, 0.438853725736261, 0, 0.05607467216716, 0.380058475033047, 0, 0.0485620906056402, 0, 0.0396507809422115, 0.028037336083582, 0, 0, 0, 0, 0, 0, -1.4054211872897e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.91050664139875, -2.39578864559553e-14, 0, 0, 10.5706241650195, 0, -2.72554057547698, -1.52585599320562e-14, 0, 4.67332857821918, 0, -7.8670586781146, -2.04874497115916e-14, 0, -2.39719223514613, 0, 0.618094504365256, 0, 0, 0, 23.10555488766, 0, 1.62065746295906, 0, -0.469687194424187, 0, 0.790669146636839, 0, 0, 0.240926884676761, 0, -0.0621208350291021, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00653548533975e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.85449644663772, 0, 5.98171817966648, -2.48806675764062, 1.90029237516522, 1.1743756718293e-14, -0.339934634239532, 0, -2.35922146606161, 0.981306762925312, 1.26408545402584e-14, 9.95226703056241, 0, -6.45364422706459, -0.430945803685666, 0, 0.0770899289327487, 1.15125419787792e-14, 0.535021138879238, -0.222539456105688, 0, 0, 21.5273297444417, 0, 2.75066129614998, 0, -1.00024047132728, 0, 0.648615649442923, 0.0433116829031338, 0, -0.00774782937530679, 0, -0.0537716476536673, 0.022366056877342, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.54523626091315, 0, 0, 0, 6.71778024562961, 0, -0.609449400220043, 0, 0, 0, 1.34513153299042e-14, 14.6593983227032, 0, 0, -1.52344936219872, 0, 0.138210132827979, 0, 0, 0, 0, 0, 18.119501277094, 0, 0, 0, -1.47332496632642, 0, 0, 0.153112421864225, 0, -0.0138906409944101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.52336024752225, 0, 7.37120708415866, -1.62882203585592, 0, 0, 12.0171306297064, 0, -2.90724328050878, 0.642416074439622, 0, 0, 0, 13.9858820944259, 0, -1.58432045778813e-14, -2.72522906732402, 0, 0.659300804656272, -0.145686271816947, 0, 0, 0, 0, 10.8043830863937, 0, 0, 0, -1.40563403846548, 0, 0, 0.273895826790425, 0, -0.066262224031037, 0.0146420212340151, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00201541731901e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 6.3084006188056, 0, -1.26706433592532e-14, 0, -1.52362350055011, 0, 11.1963004093827, -1.80488219855834e-14, 0, 4.26614580154031, 0, 0.132992762321602, 0, -2.81814707567137e-14, -4.72217953828916, 0, -6.6768459701302, 0, 0, 0, 0, 0, 0, 0, 23.1532444221696, 0, 0.721778878560592, 0, 0, 1.11125127955291, 0, 1.19087439227729, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.75883613229288e-14, 0, 0},
    {3.51865775274499, 0, 1.92724822331887, 2.72554057547696, 1.73472166622177, 0, -2.01705689521106, 0, 3.42052627529741, -4.03112887414929, 0, 4.08831086321549, 0, 0.365669640132029, 5.37643791520786, 0, -6.25148194071026, 0, -2.03981013744549, 1.80803322065276, 0, 0, 0, 0, 0, 0, 22.1880978975596, 0, 1.98456380761454, -1.26521523890981, 0, 1.4711357857929, 0, 0.363818136386341, -0.294009452979946, 0, 0, 0, 0, 0, 0, 0, -1.54553205611541e-14, 0, 1.15952481122279e-14, 0, 0, 1.43620668240546e-14, 0, 0, 0, 0, -1.05116925393268e-14, 0, 0, -1.5785116269651e-14},
    {0, 1.41060126129509, 0, 0, 0, 3.63405410063598, 0, 2.50356888118884, 0, 0, 0, 0, 3.56857028479907, 0, 0, 11.263055412878, 0, -1.49298814645068, 1.38190240500657e-14, 0, 0, 0, 0, 0, 0, 0, 0, 19.3673596462205, 0, 0, -2.65048896124153, 0, 0.266287609379577, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.60041438401192e-14, 0, 0, 0, -1.39285916740261e-14, 0, 0, 0, 0, -1.79660973598228e-14, 0, 0},
    {2.30350221379959, 0, 4.4158804331639, 1.78428514239954, 0, 0, 4.2661458015403, 0, 7.83741028656788, -2.63899331455874, 0, 0, 0, 2.23427840700301, 0, 0, 13.2221027072096, 0, -4.67379217909115, 1.18363558466232, 0, 0, 0, 0, 0, 0, 0, 0, 12.1258851598179, 0, 0, -3.11150358274815, 0, 0.833612074594106, -0.192474367616157, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18321633904026e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.80903542948782e-14, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.14718316987778, 1.13474050017499e-14, -0.86189160737134, 6.09449400220041, 1.55158222708543, 0, 0.0693888666488805, 0, -3.0594117081557, 1.80277563773198, 1.20363012761808e-14, -1.0807889766904e-14, 0, 0, 9.03122156537878, 0, 0.403888506800973, -1.0302390341142e-14, -3.67461994579464, -5.49650682721195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 21.7841260588564, -1.02507068376833e-14, 0.974215733960552, 0, 1.78974858569576, 1.8079190879493, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.26168012376113, 1.18273446592099e-14, 1.57200977122562e-14, 0, 1.42204860051343, 0, 4.47852016375308, 0, 0, 0, 1.10987276082662e-14, 0, 0, 0, 8.27725128825318, 0, 5.37909280973871, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.9654813226339, 0, -2.61992366301004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.24759447164935e-14, 0, 0},
    {2.06031501455084, -1.74209683534797e-14, 2.25696201807214, 3.98978286964829, 0, 0, 0.953939201416936, 0, 8.01142041980429, 1.18019368870418, 0, 0, 0, 0, 0, 1.94785199387925e-14, 5.55254896421454, -2.57142210914795e-14, 9.62241374388478, -3.59830837050572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13.3932520322736, 0, -4.68666192508058, 1.18356086726904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06752353778446e-14, 0, 0, -2.32785032194072e-14, 1.53466649110978e-14},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 1.09264703862701, 0, -1.95067300612033e-14, 0, 0, 0, 5.38682254607084, 0, 0, 0, 0, 0, 0, -1.87552786673862e-14, 0, 0, 13.4377817958112, 0, -1.51672730138571e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18.907670401189, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.38196745713692e-14, 0, 0},
    {1.78428514239955, 0, 0.814411017927951, 5.06770487035908, 0, 0, 0, 0, 4.01510046524765, 6.58672305740272, 0, 0, 0, -1.66919444397739e-14, 0, 0, 0, 0, 10.0159311874144, 2.83293314500741, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14.0929454377398, -4.55552790213387, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.0397792145408e-14, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.45686271816937, 0, 0, 5.07816454066238, 0, 0, 0, 0, 0, 10.0142755247554, 0, 0, 1.12786864624392e-14, 0, 0, 2.17930072871246e-14, 0, 0, 0, 13.8784813613723, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.5535587278944, 0, 0, 0, 0, 0, 0, 0, 1.19526598856153e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats1[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.47722557505166, 0, 0, 1.40751126032068e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.06911007824451e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.76376261582596, 0, 0, 0, 0, 1.14716615426708e-14, 0, -1.04150722074414e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.09700660014256e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747793, 7.24568837309471, 4.18330013267037, -0.591607978309947, 0, 0, 0, 0, 1.56424483988496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-2.64575131106459, 0, 9.66091783079295, 0.683130051063975, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00911719995905e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 0, 0, 4.34741302385685, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.19132134712707e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.24037034920393, 0, 0, 7.52994023880671, 0, 0, 0, 0, 1.5531385856235e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00830684779644e-14, 2.81476231211997e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847576, -1.67332005306815, -1.18321595661991, 7.74596669241484, -1.2, 0.346410161513776, -0.979795897113268, 0.282842712474625, 0.200000000000004, -1.25790505365476e-14, 0, 0, 1.05528898544744e-14, 0, 0, 0, -1.12515066521072e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 9.16515138991169, 7.09929573971953, -2.04939015319193, -0.414039335605418, -0.478091443733742, 0.169030850945706, -1.25706005145317e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07716088515501e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.8, -5.69209978830307, 4.3817804600413, -0.774596669241499, 0, 10.998181667894, 4.76235235991625, 0.962140470884724, -0.740656079818034, 0.13093073414159, 0, -1.12401392033415e-14, 0, -3.21594604552363e-14, -1.31211420896762e-14, 0, 0, 0, -1.70767152060798e-14, -1.55264798414045e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2325574011616e-14, 0, 0, 0, 0, 0, 0, 0, 0, -1.03479319100648e-14, 0, 0, 0, 0, 0, 0},
    {5.19615242270665, 0, -3.16227766016841, -2.2360679774998, 0, 0, 13.7477270848675, 0, 0.534522483824853, 0.37796447300922, 0, 0, 0, -3.83748191193675e-14, 0, 0, 2.1315292421099e-14, 0, -1.62182060497289e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.68659168002595e-14, 0, 0, 0, 0, 1.40965823998977e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974982, 2.12132034355964, -0.40824829046386, 3.17542648054296, 0, 0, 0, 7.17137165600636, -1.38013111868469, -1.56144011671765, 0, 0, 0, 0, 1.60086230480545e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 2.73861278752582, 1.58113883008418, 2.4596747752498, 0, 0, 0, 9.25820099772551, 5.34522483824851, -1.20948631362952, 0, 0, 0, 0, 1.34977494398807e-14, 1.99156888319442e-14, 0, 0, -2.15636170105579e-14, 2.42856949828063e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16523470700075e-14, 0, 0, -1.09194628747146e-14, 1.11395268009851e-14},
    {-1.80000000000001, -1.20044841895264e-14, 3.6514837167011, -2.84018778721876, 0, -1.08976206329851e-14, -1.29819986860444e-14, 0, 12.3442679969674, 1.39659449751036, 0, 0, 0, 0, -1.50769312330474e-14, 1.13191919416064e-14, 1.11250942527182e-14, -1.93488728499311e-14, -2.44419195896427e-14, 1.02799713186386e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.16729566976785e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.23874183066048e-14, 0, -1.16953047556544e-14, 0},
    {1.27279220613579, 0, 0, 3.83405790253616, 0, 0, 0, 0, 1.22025515571026e-14, 5.18459255872629, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.20454076850486, 0, 0, 6.6407830863536, 0, 0, 0, 0, 2.01466364901978e-14, 8.97997772825746, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573302, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341419, -1.71651640581399, 0.594618725379066, 0.420458932936045, 9.8107084351743, -1.18450885369836, 0.305838870920594, -0.105945692672787, -1.02581475831037, 0.264864231681993, -0.09175166127617, 0.21626073957839, -0.0749149177264317, -0.0529728463363858, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403131, -2.78313372537745, -0.908295106229251, -0.524404424085076, 0.370809924354782, 11.1242977306435, 9.40174755792014, -2.42752078113806, 0.840917865872085, -0.301561193523232, -0.794200206656966, 0.350641890608823, 0.114434427054266, 0.0660687472643449, -0.0467176592151217, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747036, 3.74574588632197, -1.05945692672796, -8.09173593712688, 5.01426536422408, 1.80936716113936, -0.383824736789376, -1.10800657553489, 0.313391585263996, 0, 12.7134831207354, 8.2065180664829, -2.84282124887607, 1.01946290306866, -0.631738055305799, -0.227958835180076, 0.0483573714561715, 0.139595707137601, -0.0394836284566235, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 7.03562363973514, 4.06201920231798, -0.820651806648283, 0, -6.79705818718658, 5.88642506110458, -2.08116553882673, -1.2015614840698, 0.242752078113809, 0, 0, 14.8323969741913, 5.13809303146605, 0, 0.856348838577665, -0.741619848709558, 0.262202212042531, 0.151382517704873, -0.0305838870920523, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-3.42539535431071, 0, 9.38083151964686, 1.89521416591735, 0, 0, -3.39852909359328, 0, -2.77488738510233, -0.560611910581382, 0, 0, 0, 17.7988763690296, 0, 0, 0.4281744192888, 0, 0.34960294939005, 0.0706304617818509, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.19229891779162e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172086, 2.24244764232556, 2.14087209644419, -0.331662479035536, 0.0957427107756383, 6.49923072370878, -1.87616630392937, -2.15580611373101, 0, 0, 0, 0, 9.4403585933147, -1.46249406456535, 0.422185670932515, -2.04706526287666, 0.590936840285285, 0.522319308773338, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.05431025609327e-14, 0, 0},
    {1.71269767715535, 1.16057691494799, 1.34011878852097, 1.89521416591737, 2.53311402559511, 1.96214168703485, -0.56642151559888, 2.74642624930238, 3.17129986868838, -1.82198870938951, 0, 0, 0, 0, 11.1699829238239, 8.6522315682783, -2.49768411251823, -0.865042958313582, -0.998865569685885, 0.441440386136645, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.03475770530409e-14, 1.29209414685306e-14, 0, 0, 0, 0, 0, 0, 1.60120018608036e-14, 0, 0, -1.26160718303102e-14, 0},
    {1.32664991614215, -2.69693703815181, 2.07610309995255, 1.46802658041886, 0, 3.03973683071412, 1.3162446581088, -6.38211787508102, 4.91295663090393, -1.4113063856887, 0, 0, 0, -1.51913273054672e-14, -2.55599087474972e-14, 13.4039795085888, 5.80409338312195, 2.01017818278148, -1.54743588659735, 0.341938252770119, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.2030832256185e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.39126707790871e-14, 1.05862461256535e-14, 0, 0, 0, 0, -1.27456553064636e-14, 0, 1.42541964027269e-14, 0, 0, -1.47910175216627e-14, 0},
    {3.82970843102536, 0, -1.49829835452879, 4.23782770691178, 0, 0, 3.79967103839267, 0, -3.54562104171168, -4.07409060843207, 0, 0, 0, 0, 0, 0, 16.7549743857359, 0, 1.11676565710082, 0.987090711415275, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.21705165839016e-14, 0, 0, 0, 0, 0, -1.21257170970779e-14},
    {1.48323969741913, 1.00508909139073, -0.193429485824663, 3.55615782880927, 0, 0, 0, 4.45964044034302, -0.858258202906985, 2.67027285925187, 0, 0, 0, 0, 0, 0, 0, 8.42792824422443, -1.62195554683794, -2.29379153190447, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.14891252930761, 1.29756443747035, 0.749149177264386, 2.75458800949269, 0, 0, 0, 5.75737105184054, 3.3240197266047, 2.06838446274244, 0, 0, 0, 0, 0, 1.63535268777982e-14, 0, 10.8804085776374, 6.28180682119208, -1.77676328054753, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.10314190327717e-14, 0, 0, 0},
    {-1.32664991614216, -1.36618976334274e-14, 1.73008591662712, -3.18072425757423, 0, 0, 0, 0, 7.67649473578737, -2.38836465270395, 0, 0, 0, 0, 0, 1.75825778552664e-14, -1.61250752397677e-14, -2.1076052013037e-14, 14.5072114368499, 2.05162951662072, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.938083151964686, 0, 0, 3.11415464992885, 0, 0, 0, 0, 0, 5.52707620976691, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62480768092719, 0, 0, 5.39387407630363, 0, 0, 0, 0, 1.11162283755055e-14, 9.57317681262151, 0, 0, 0, 0, -1.0778909817559e-14, 0, 1.14540099911627e-14, 0, 0, 10.0508909139073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993662, 0.86983547675049, 0.615066564126915, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.278967971730982, -1.89076704011892, 0.627677936394719, -0.241593350361255, 0.512496888990065, -0.197260144544833, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954525, -1.03851746182648, 0.219426862868131, -0.0728431359084663, 0.0280373360835797, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711053, 0.0140186680417948, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725405, 3.45525332069938, 0.997445717412069, -1.41060126129511, 3.23209352764251, 5.28531208250978, -2.8908723349783, -1.3627702877385, -0.393397896234731, 0.556348640264194, 2.3366642891096, 9.0278480722887, -3.93352933905729, 1.64018416088946, -0.732969916135167, -1.19859611757306, 0.655588223176202, 0.309047252182634, 0.0892142571199805, -0.12616801237611, 13.0996183150502, 11.55277744383, -2.44096975264614, 0.810328731479527, -0.311895674167858, -0.234843597212094, -0.907332870306511, 0.39533457331842, -0.16484471056831, 0.0736662483163195, 0.120463442338379, -0.0658890955530703, -0.0310604175145504, -0.00896637020658568, 0.0126803623514093, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066012, 2.99085908983323, -1.24403337882031, 0.950146187582609, 5.74064456311311, -0.169967317119758, -0.721110255092799, -1.17961073303081, 0.490653381462658, -10.3037210107158, 4.9761335152812, 5.78174466995658, -3.2268221135323, -0.215472901842833, -1.3018558182182, 0.0385449644663712, 0.163532434528623, 0.267510569439619, -0.111269728052842, 0, 14.555131461167, 10.7636648722209, -3.5732138395088, 1.37533064807499, 1.03556292536503, -0.500120235663637, -0.581087203147972, 0.324307824721462, 0.0216558414515678, 0.13084143273245, -0.0038739146876535, -0.0164356280722662, -0.0268858238268361, 0.011183028438671, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585591, 0.772618130456579, 3.86595114186566, -1.05140010313427, 9.1544290607646, 3.35889012281481, 3.878512233171, -0.304724700110019, -1.52475169285616, 0.414677792940096, 0, -9.46260092820841, 7.32969916135161, 0.564240504518017, -2.07602937339135, -0.761724681099362, -0.879563899362184, 0.0691050664139924, 0.345781182036189, -0.0940400840863445, 0, 0, 16.3745228938128, 9.05975063854702, -3.48709964663734, 0, 0.951027176355638, -0.736662483163211, -0.0567083043941542, 0.208648802584722, 0.0765562109321131, 0.0883994979795834, -0.006945320497205, -0.0347523163751387, 0.00945138406569424, 0, 0, 0, 0, 0, -1.0442355414814e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, -6.78263087840204, 3.68560354207932, -0.814411017927972, 0, 10.0216907612581, 6.00856531485321, 2.67510569439611, -1.45362164025439, 0.321208037219812, 0, 0, -7.5700807425667, 6.99294104721295, 0, -2.27270584034422, -1.36261453366201, -0.60665694841583, 0.329650402328123, -0.0728431359084861, 0, 0, 0, 18.7137404500718, 5.40219154319687, 0, 0, 0.760821741084505, -0.702817019232738, 0, 0.228415531250637, 0.136947913395213, 0.0609713174047677, -0.0331311120155155, 0.00732101061700594, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.13362172336404e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.09901951359279, 0, -4.65474668125631, -3.2914029430219, 0, 1.1660466779942e-14, 13.490737563232, 0, 1.83585684909537, 1.29814682728311, 0, 0, 0, -3.53270434653113, 0, -2.35369542990423e-14, -3.05941170815564, 0, -0.416333199893202, -0.294392028877585, 0, 0, 0, 0, 21.8326971917504, 0, 0, 0, 0.355050145839434, 0, 0, 0.307482445914322, 0, 0.0418430609640539, 0.0295875121532883, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.51979983923137e-14, 1.31936453578951e-14, 0, 0, 0, 1.03690494372784e-14, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.1542003094028, -1.09264703862703, 1.54523626091313, 2.95048422176041, -0.76181175027506, 0.263899331455881, 5.59815020469135, -1.93925611658552, -2.28543525082516, 2.13307290077015, -0.257539376818861, 0.0664963811608048, -0.0230350221379904, 9.14446135479764, -2.36108976914457, 0.817905488277896, -3.3384229850651, 1.1564636454577, 1.02505848514081, 0, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280294, -0.125015768949701, -2.15192884958005, 0.555625639776455, -0.192474367616153, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.07577610922145e-14, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659431, 1.36277028773846, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871973, 1.7102631376487, -2.01556443707465, 2.41867732448956, 2.04415543160775, -0.527798662911745, 0.182834820066009, 2.68821895760391, 7.07977053255618, -3.12574097035514, -1.76652739792483, -1.01990506872274, 0.904016610326372, 0, 0, 0, 0, 0, 13.1266557397187, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454906, -1.66605356688628, 0.735567892896448, 0.315075748468082, 0.181909068193171, -0.147004726489972, 0, 0, 0, 0, 0, 0, 0, -1.19843614648072e-14, 0, 1.70149229231864e-14, 0, 0, 1.13549801043889e-14, 0, 0, 0, 0, 0, -1.36131053899298e-14, 0, -1.03720200830826e-14},
    {1.48690428533295, 0.705300630647538, 2.0360275448199, 1.15175110689976, -2.93221479395416, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967313, 0, 2.76420265655951, 1.78428514239953, -0.618094504365259, -9.08783875864328, 5.631527706439, 2.03210252328835, -0.746494073225345, -2.15494277062552, 0.764033484562584, 0, 0, 0, 0, 0, 0, 15.0018922739643, 9.68367982311023, -3.3545250915713, 2.13860408462396, -1.32524448062077, -0.478206411017798, 0.133143804689786, 0.384353057392894, -0.124241670058205, 0, 0, 0, 0, 0, 0, 0, -1.06952639252695e-14, 0, 1.24523903365769e-14, 0, 0, 1.13816587687308e-14, -1.06362575304491e-14, 0, 1.13288756971e-14, 0, -1.21696875531858e-14, -1.03472165536955e-14, 0, -1.2600380808192e-14},
    {1.15175110689979, 3.82426463519456, 2.20794021658195, 0.892142571199782, 0, -2.46306042692148, 2.13307290077015, 6.78739640804928, 3.91870514328393, -1.31949665727936, 0, 0, 3.22490309931941, 1.11713920350152, 1.32014938580353e-14, -7.63378455726037, 6.61105135360481, -4.04762275910198, -2.33689608954557, 0.591817792331178, 0, 0, 0, 0, 0, 0, 0, 17.5022076529583, 6.06294257990892, 0, 1.79642743108413, -1.55575179137408, 0.721929233499942, 0.416806037297049, -0.096237183808073, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.27043515283634e-14, 0, 0},
    {-2.65985524643219, 1.31595766643121e-14, 5.09901951359278, -2.06031501455086, 0, 1.2454667647061e-14, -1.23153021346074, 0, 9.04986187739902, 3.04724700110024, 0, 0, 0, 3.8698837191833, 1.50559796220762e-14, -1.82444885045587e-14, -3.81689227863021, 2.48972418334491e-14, -5.39683034546926, -1.36674464685442, 0, 0, 0, 0, 1.11023026702718e-14, 0, 0, 0, 21.00264918355, 0, 0, 0.898213715542071, 0, 0.962572311333264, 0.222250255910579, 0, 0, 0, 0, 0, 0, 0, 0, 1.30048635444922e-14, 0, -2.8168247578276e-14, 0, 0, 0, 0, 0, -1.22574722556207e-14, 0, 0, 0, 0},
    {1.57359158493889, 1.49284005458437, -0.430945803685673, 3.04724700110021, 0.775791113542717, -0.120185042515475, 0.0346944333244397, 5.29905651979671, -1.52970585407785, 0.901387818865986, 0, 0, 0, 0, 4.51561078268939, -0.699555414372413, 0.201944253400488, 6.36462844462229, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980277, -3.09993548319961, 0.894874292847881, 0.903959543974646, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880569, 0.728431359084677, 2.57539376818856, 0.917928424547677, 0.71102430025671, -0.205255035576791, 2.23926008187654, 2.58567482211399, 0.761811750275056, 0, 0, 0, 0, 5.34294273196306, 4.13862564412661, -1.19471831485579, 2.68954640486934, 3.1056206816986, -2.32269806558124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.8876627769294, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.76398525469263, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, -1.46593983227033, 1.12848100903608, 1.99489143482414, 0, 1.10151410945722, 0.476969600708474, -5.20357020296093, 4.00571020990214, 0.590096844352093, 0, 0, 0, 0, -1.06679106813357e-14, 6.4115312783557, 2.77627448210726, -6.24994106094659, 4.81120687194238, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.4651953323153, 6.69662601613678, 3.0440762145518, -2.34333096254029, 0.591780433634522, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.29095028749876e-14, 0},
    {2.97380857066591, 0, -0.814411017927952, 5.75875553449896, 0, 0, 1.37689263682153, 0, -2.89087233497831, 1.70346285967311, 0, 0, 0, 0, 0, 0, 8.01441409794461, 0, -3.47218947830365, -5.19371076584693, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19.3314941653941, 0, 1.69115345252877, 1.70832296330021, 0, 0, 0, 0, 0, 0, 0, 0, 1.01698699146052e-14, 0, 0, 0, 0, 0, 1.04634390793553e-14, 0, 0, -1.24951195166655e-14, 0, 0, 0},
    {1.15175110689979, 0.546323519313506, -0.105140010313426, 3.27118942773248, 0, 0, 0, 2.69341127303542, -0.518347241175112, 4.25171145123352, 0, 0, 0, 0, -1.50547813101981e-14, 0, 0, 6.71889089790563, -1.29305115618718, 1.82865048192211, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635795, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199775, 0.705300630647549, 0.407205508963978, 2.53385243517953, 0, 0, 0, 3.47717900165117, 2.00755023262382, 3.29336152870136, 0, 0, 0, 0, 0, 0, 0, 8.6740508508577, 5.0079655937072, 1.41646657250369, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12.2048487632307, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.09128807146668e-14, 0, 0, 0, 0, 0, 0, 0},
    {-1.03015750727542, 0, 0.940400840863396, -2.92584077107542, 0, 0, 0, 0, 4.6362386688682, -3.80284633026898, 0, 0, 0, 0, 1.68691976659293e-14, 0, -1.57365387853084e-14, 0, 11.5654011344769, -1.63559471386627, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16.2731316843076, 2.63013526059784, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.15424097657397e-14, 0, 0, -1.09417683247237e-14},
    {0.728431359084685, 0, 0, 2.53908227033119, 0, 0, 0, 0, 0, 5.00713776237767, 0, 0, 0, 0, 0, 1.10587002885661e-14, 0, 0, 0, 6.93924068068616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6.2767793639472, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376112, 0, 0, 4.39781949681095, 0, 0, 0, 0, 0, 8.67261700493487, 0, 0, 0, 0, 0, 1.88729435175678e-14, 0, 0, 0, 12.0191174248973, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10.8717007662564, 0, 0, 0, 0, 0, 0, 0, 1.03515041106796e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}};
    
    const static double dmats2[56][56] = \
    {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {3.16227766016838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.82574185835055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.16397779494323, 0, 0, 1.29984998459287e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00622635224035e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.95803989154981, 5.6124860801609, -1.08012344973464, -0.763762615825961, 0, 0, 0, 0, 0, 0, -1.12787476580434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.00211722600663e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.29128784747792, 1.44913767461894, 4.18330013267037, -0.591607978309952, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.00245830515541e-14, 0, 0, 0, 0, -1.10514927319296e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.3228756555323, 0, 3.86436713231717, -0.341565025531983, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.87082869338697, 7.09929573971953, 0, 4.34741302385685, 0, 1.16116958235673e-14, 0, 0, 1.97703621279534e-14, 0, 0, 0, 0, 0, 1.19025197250128e-14, 0, 0, 0, 0, 1.15385132004597e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.08012344973465, 0, 7.09929573971953, 2.50998007960224, 0, 0, 0, 0, 1.2984107062089e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2.21524148795069e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.18401735111452e-14, 0},
    {-3.81881307912987, 0, 1.20295604068146e-14, 8.87411967464943, 0, 1.13142405616155e-14, 0, 0, 0, 0, 0, 0, 0, 1.25032789779226e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.7495454169735, 5.79655069847577, -1.67332005306815, -1.18321595661992, 7.74596669241485, -1.2, 0.346410161513777, -0.979795897113271, 0.282842712474625, 0.200000000000004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.32379000772445, 2.44948974278317, 2.82842712474618, -0.999999999999999, 1.30930734141596, 7.09929573971954, -2.04939015319192, -0.41403933560542, -0.47809144373374, 0.169030850945707, 0, 0, 0, -1.01115137587522e-14, 0, 0, -1.19390261962029e-14, 0, -1.01768611746272e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.80000000000001, 0.632455532033679, 4.38178046004131, -0.77459666924148, 0, 3.14233761939829, 4.76235235991626, -0.106904496764969, -0.740656079818034, 0.130930734141593, 0, 0, 0, -1.8947471087206e-14, 0, 0, 1.24782077916574e-14, 0, -1.57210017045496e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03923048454133, 0, 3.16227766016837, -0.447213595499959, 0, 0, 5.89188303637179, 0, -0.534522483824846, 0.0755928946018422, 0, 0, 0, -1.32102604647237e-14, 0, 0, 1.28087199916397e-14, 0, -1.09806075799093e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.01246117974981, 2.12132034355963, -0.408248290463856, 3.17542648054296, 9.07114735222146, 0, 0, 7.17137165600636, -1.3801311186847, -1.56144011671765, 0, 0, 0, 1.05914511754833e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.55884572681199, 0.547722557505163, 1.58113883008417, 2.45967477524979, 0, 9.07114735222145, 0, 1.85164019954509, 5.34522483824851, -1.20948631362952, 0, 0, 0, -1.11256081632663e-14, 0, 0, 0, 0, -2.1484687092401e-14, 1.51441359452775e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.03593488692865e-14, 0, -1.10855626475394e-14, 0},
    {0.900000000000005, 0, 1.46059348668043, 1.4200938936094, 0, 0, 9.07114735222145, 0, 4.93770719878695, -0.698297248755175, 0, 0, 0, 0, 0, 0, 2.13673764691668e-14, 0, -1.74964245430402e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.07342779687771e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.27279220613579, -6.2609903369994, 0, 3.83405790253616, 0, -1.49065575463019e-14, 0, 10.5830052442584, 0, 5.18459255872628, 0, 0, 0, 0, 0, 1.30274753827373e-14, 0, 1.32206973351868e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.734846922834947, -1.04202290943615e-14, -6.26099033699941, 2.21359436211788, 0, 0, 0, 0, 10.5830052442584, 2.99332590941916, 0, 0, 0, 0, 0, 0, 0, 0, -1.10071029919877e-14, 1.58024635044107e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {5.71576766497729, 0, 0, -4.69574275274958, 0, -1.13946705425176e-14, 0, 0, 1.07947992678322e-14, 12.69960629311, 0, 0, 0, -2.12576157138471e-14, -1.14768107589579e-14, 0, 0, 0, 0, -1.45786160921091e-14, 0, 0, 0, 0, 0, 0, 0, 0, 1.11099168517849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16464450008484e-14, 0, 0, 0, 0, 0, 0, 0},
    {2.56904651573303, 5.80288457473997, -2.01017818278147, -1.42141062443802, 8.14215222512715, -2.10229466468021, 0.728256234341418, -1.71651640581399, 0.594618725379066, 0.420458932936047, 9.81070843517429, -1.18450885369836, 0.305838870920593, -0.105945692672788, -1.02581475831037, 0.264864231681991, -0.0917516612761725, 0.216260739578389, -0.0749149177264338, -0.0529728463363881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.26568606239552, 3.07059789431495, 1.77281052085584, -1.25356634105603, 2.39356776939085, 6.30376871403132, -2.78313372537745, -0.908295106229256, -0.524404424085065, 0.370809924354784, 1.23603308118261, 9.40174755792014, -2.42752078113806, 0.840917865872082, -0.301561193523232, -0.794200206656965, 0.350641890608817, 0.114434427054266, 0.0660687472643408, -0.0467176592151232, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.09687112732375e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.91485421551268, 1.29756443747035, 3.74574588632197, -1.05945692672795, 0.404586796856342, 5.01426536422407, 1.80936716113936, -0.38382473678937, -1.10800657553489, 0.313391585264001, 0, 2.82521847127454, 8.2065180664829, -2.84282124887607, -0.0509731451534336, -0.631738055305794, -0.227958835180071, 0.0483573714561653, 0.139595707137598, -0.0394836284566152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 0.335029697130247, 4.06201920231797, -0.820651806648293, 0, 1.69926454679664, 5.88642506110457, -0.0991031208965088, -1.20156148406979, 0.242752078113803, 0, 0, 4.94413232473044, 5.13809303146604, 0, -0.214087209644424, -0.741619848709556, 0.0124858196210727, 0.151382517704866, -0.030583887092065, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.856348838577677, 0, 2.68023757704196, -0.473803541479351, 0, 0, 5.09779364038993, 0, -0.792824967172094, 0.140152977645347, 0, 0, 0, 7.9106117195687, 0, 0, -0.642261628933262, 0, 0.0998865569685846, -0.0176576154454718, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.02649122047609, 2.74642624930237, -0.792824967172091, 2.24244764232556, 2.14087209644418, -0.331662479035544, 0.0957427107756388, 6.49923072370878, -1.87616630392938, -2.15580611373101, 11.0554159678513, 0, 0, 0, 9.44035859331469, -1.46249406456535, 0.42218567093252, -2.04706526287666, 0.590936840285289, 0.522319308773339, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.71269767715534, 1.160576914948, 1.34011878852098, 1.89521416591738, 0.361873432227874, 1.96214168703486, -0.566421515598884, 2.74642624930237, 3.17129986868839, -1.82198870938951, 0, 11.0554159678513, 0, 0, 1.59571184626056, 8.6522315682783, -2.49768411251823, -0.865042958313566, -0.99886556968588, 0.441440386136656, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.67261791825198e-14, 0, 0, 0, 0, 0, 0, 1.30794708089814e-14, 0, 0, -1.0374605283645e-14, 0},
    {1.32664991614216, 0.29965967090575, 2.07610309995255, 1.46802658041888, 0, 0.868496237346876, 1.31624465810881, 0.709124208342335, 4.91295663090393, -1.4113063856887, 0, 0, 11.0554159678513, 0, 0, 3.82970843102537, 5.80409338312195, -0.223353131420173, -1.54743588659735, 0.341938252770127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.50077495359425e-14, 0},
    {0.765941686205065, 0, 1.49829835452878, 0.84756554138235, 0, 0, 1.62843044502543, 0, 3.54562104171167, -0.81481812168641, 0, 0, -1.13658139175294e-14, 11.0554159678513, 0, 0, 7.18070330817253, 0, -1.11676565710083, 0.197418142283055, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.48323969741914, 1.00508909139074, -0.193429485824671, 3.55615782880925, -8.46157280212813, 0, 0, 4.45964044034302, -0.85825820290699, 2.67027285925187, 0, 0, 0, -1.0471287355653e-14, 12.4373429638327, 0, 0, 8.42792824422442, -1.62195554683794, -2.29379153190449, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.1489125293076, 0.259512887494065, 0.749149177264405, 2.75458800949269, 0, -8.46157280212812, 0, 1.15147421036811, 3.3240197266047, 2.06838446274243, 0, 1.28739579884012e-14, 0, 1.43483072465507e-14, 0, 12.4373429638328, 0, 2.17608171552748, 6.28180682119208, -1.77676328054752, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.1069077748037e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.66332495807107, 0, 0.692034366650861, 1.5903621287871, 0, 0, -8.46157280212812, 0, 3.07059789431495, 1.19418232635199, 0, 0, 0, 1.58467639420295e-14, 0, 1.59120238800483e-14, 12.4373429638327, -1.09120262064712e-14, 5.80288457473997, -1.02581475831036, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.17878507096849e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.93808315196469, 7.62808987244124, 0, 3.11415464992885, 0, 0, 0, -7.5213980463361, 0, 5.52707620976692, -1.06609684736951e-14, 0, 0, 0, -1.38639078823126e-14, 0, 1.48563198377856e-14, 14.2141062443803, 1.67911998216622e-14, 5.80288457473997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.541602560309069, 0, 7.62808987244124, 1.79795802543454, 0, 0, 0, 0, -7.5213980463361, 3.19105893754051, 0, 0, 0, 0, 0, 0, 0, 0, 14.2141062443803, 3.35029697130244, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {-5.3615918034355, 0, 0, 8.89943818451481, 0, 0, 0, 0, 0, -5.26497863243528, 0, 0, 0, 1.27752977123219e-14, 0, 0, 0, -1.16097894474412e-14, 1.10230978840132e-14, 16.583123951777, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.41593350361254, 5.7298894101947, -2.20543546226846, -1.55947837083931, 8.33749895885385, -2.76779953857109, 1.06532653910462, -2.25989885993663, 0.86983547675049, 0.615066564126914, 10.333118277332, -2.18326971917505, 0.724780051083766, -0.27896797173098, -1.89076704011892, 0.627677936394719, -0.241593350361254, 0.512496888990065, -0.197260144544832, -0.139483985865483, 11.8490505948789, -1.16109782023228, 0.245326690731333, -0.0814411017927967, 0.0313466946954516, -1.03851746182648, 0.219426862868131, -0.0728431359084662, 0.0280373360835794, 0.190029237516524, -0.0630840061880569, 0.0242810453028224, -0.0515078753637723, 0.0198253904711051, 0.0140186680417946, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {2.18529407725404, 3.45525332069938, 0.997445717412055, -1.41060126129511, 3.23209352764251, 5.28531208250977, -2.8908723349783, -1.3627702877385, -0.393397896234727, 0.556348640264192, 2.33666428910959, 9.02784807228868, -3.93352933905729, 1.64018416088945, -0.732969916135173, -1.19859611757306, 0.655588223176204, 0.309047252182629, 0.0892142571199751, -0.126168012376112, 1.19087439227729, 11.55277744383, -2.44096975264613, 0.810328731479525, -0.311895674167859, -0.234843597212091, -0.907332870306511, 0.395334573318418, -0.164844710568308, 0.0736662483163234, 0.120463442338379, -0.0658890955530668, -0.0310604175145528, -0.00896637020658492, 0.012680362351411, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.04376434543615e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.92724822331886, 1.82834820066013, 2.99085908983323, -1.24403337882031, 0.950146187582614, 5.74064456311311, -0.169967317119763, -0.721110255092803, -1.1796107330308, 0.490653381462655, 0.294392028877601, 4.97613351528119, 5.78174466995657, -3.2268221135323, -0.215472901842835, -1.3018558182182, 0.0385449644663701, 0.16353243452863, 0.267510569439621, -0.111269728052844, 0, 2.64638753839399, 10.7636648722209, -3.5732138395088, 1.37533064807499, -0.0295875121532872, -0.500120235663636, -0.581087203147972, 0.324307824721462, 0.0216558414515659, 0.130841432732449, -0.00387391468765372, -0.0164356280722662, -0.0268858238268349, 0.0111830284386701, 0, 0, 0, 0, -1.28026114151189e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.62882203585592, 0.772618130456574, 3.86595114186566, -1.05140010313427, 0.160604018609906, 3.35889012281481, 3.878512233171, -0.30472470011002, -1.52475169285616, 0.414677792940093, 0, 1.13551211138501, 7.32969916135161, 0.564240504518021, -0.0364215679542351, -0.761724681099363, -0.879563899362178, 0.0691050664139924, 0.345781182036181, -0.094040084086348, 0, 0, 4.46577897103986, 9.05975063854702, -3.48709964663735, 0, -0.114123261162678, -0.736662483163213, -0.0567083043941508, 0.00366050530850509, 0.076556210932112, 0.0883994979795821, -0.00694532049720509, -0.0347523163751398, 0.00945138406569354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.26168012376113, 0.199489143482414, 3.68560354207933, -0.814411017927961, 0, 1.0278657191034, 6.00856531485322, -0.0786795792469394, -1.45362164025439, 0.321208037219813, 0, 0, 3.02803229702669, 6.99294104721296, 0, -0.23309803490711, -1.36261453366201, 0.0178428514239989, 0.329650402328134, -0.072843135908474, 0, 0, 0, 6.80499652729884, 5.40219154319687, 0, 0, -0.304328696433804, -0.70281701923274, 0, 0.0234272339744255, 0.136947913395213, -0.00179327404131462, -0.0331311120155176, 0.00732101061700848, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.728431359084683, 0, 2.32737334062817, -0.470200420431708, 0, 0, 4.49691252107735, 0, -0.917928424547684, 0.185449546754732, 0, 0, 0, 7.06540869306229, 0, -1.02749514743743e-14, -1.01980390271856, 0, 0.208166599946621, -0.0420560041253766, 0, 0, 0, 0, 9.92395326897747, 0, 0, 0, -0.710100291678883, 0, 0, 0.102494148638111, 0, -0.0209215304820291, 0.00422678745046967, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.99489143482413, 3.15420030940281, -1.09264703862702, 1.54523626091312, 2.95048422176041, -0.761811750275057, 0.263899331455879, 5.59815020469135, -1.93925611658552, -2.28543525082517, 2.13307290077016, -0.257539376818857, 0.0664963811608075, -0.0230350221379865, 9.14446135479764, -2.36108976914457, 0.817905488277892, -3.3384229850651, 1.1564636454577, 1.02505848514081, 13.0453753561106, 0, 0, 0, 0, 11.5766222110848, -1.39771878815471, 0.360889439280297, -0.125015768949703, -2.15192884958005, 0.555625639776455, -0.192474367616155, 0.595437196138644, -0.206265495285702, -0.166687691932932, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.75932887637249, 1.66904592079256, 0.963624111659433, 1.36277028773847, 0.867360833110882, 2.28430636201792, -1.00852844760553, 2.96226264871972, 1.7102631376487, -2.01556443707464, 0.268741924943282, 2.04415543160775, -0.527798662911754, 0.182834820066007, 2.68821895760393, 7.07977053255618, -3.12574097035514, -1.76652739792482, -1.01990506872274, 0.904016610326381, 0, 13.0453753561106, 0, 0, 0, 1.4585173044132, 11.0940489487798, -2.8644711213756, 0.992281903807274, -0.632607619454905, -1.66605356688628, 0.735567892896452, 0.315075748468088, 0.181909068193171, -0.14700472648997, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.76253856517652e-14, 0, 0, 0, 0, 0, 0, 0, -1.02644438987504e-14, 0, 0, 0},
    {1.48690428533294, 0.705300630647549, 2.0360275448199, 1.15175110689978, 0.146610739697706, 1.81702705031799, 0.655663160391204, 1.25178444059441, 3.61359041872287, -1.70346285967312, 1.19461378362765e-14, 0.614267257013224, 1.78428514239954, -0.61809450436525, 0.454391937932155, 5.631527706439, 2.03210252328835, -0.746494073225347, -2.1549427706255, 0.764033484562606, 0, 0, 13.0453753561106, 0, 0, 0, 3.33375383865873, 9.68367982311023, -3.3545250915713, -0.1069302042312, -1.32524448062077, -0.47820641101779, 0.133143804689788, 0.384353057392899, -0.124241670058195, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.33133676896015e-14, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.182107839771165, 2.20794021658195, 0.892142571199765, 0, 0.615765106730381, 2.13307290077015, 0.323209352764259, 3.91870514328393, -1.31949665727937, 0, 0, 1.07496769977315, 1.11713920350151, 0, 1.90844613931509, 6.61105135360481, -0.192743940909622, -2.33689608954558, 0.591817792331162, 0, 0, 0, 13.0453753561106, 0, 0, 0, 5.83406921765277, 6.06294257990893, 0, -0.449106857771032, -1.55575179137408, 0.0343775825476156, 0.416806037297052, -0.0962371838080755, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.664963811608044, 0, 1.45686271816936, 0.515078753637704, 0, 0, 1.84729532019112, 0, 2.58567482211401, -0.761811750275049, 0, 0, 0, 1.71994831963702, 1.05069828708852e-14, -1.56804141189904e-14, 5.72533841794525, 1.28292660358282e-14, -1.54195152727692, 0.341686161713602, 0, 0, 0, 0, 13.0453753561106, 0, 0, 0, 9.33451074824443, 0, 0, -1.34732057331309, 0, 0.275020660380932, -0.0555625639776445, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.3208801604271e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.57359158493888, 1.49284005458436, -0.430945803685674, 3.04724700110019, 0.775791113542713, -0.120185042515468, 0.0346944333244412, 5.29905651979672, -1.52970585407786, 0.901387818865991, -10.576283741361, 0, 0, 0, 4.51561078268937, -0.699555414372417, 0.20194425340049, 6.36462844462228, -1.83730997289732, -2.74825341360598, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 0, 10.8920630294282, -1.68739114875269, 0.487107866980274, -3.09993548319962, 0.894874292847881, 0.903959543974651, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.32992762321609, 0.630840061880566, 0.72843135908468, 2.57539376818856, 0.131132632078236, 0.71102430025671, -0.205255035576782, 2.23926008187654, 2.585674822114, 0.761811750275049, 0, -10.576283741361, 0, 0, 0.763277533137571, 4.1386256441266, -1.19471831485579, 2.68954640486935, 3.1056206816986, -2.32269806558126, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 1.84109468241848, 9.98274066131696, -2.88176900403078, -1.30996183150502, -1.51261363209512, 0.763985254692621, 0, 0, 0, 0, 0, 0, 0, 0, -1.35629152642122e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.03015750727542, 0.162882203585585, 1.12848100903607, 1.99489143482414, 0, 0.31471831698778, 0.476969600708467, 0.578174466995659, 4.00571020990214, 0.590096844352089, 0, 0, -10.576283741361, 0, -1.14841985676491e-14, 1.83186607953021, 2.77627448210727, 0.694437895660718, 4.8112068719424, -1.79915418525286, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 4.41862723780437, 6.69662601613678, -0.338230690505757, -2.34333096254029, 0.591780433634517, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.594761714133188, 0, 0.814411017927947, 1.1517511068998, 0, 1.39874122938874e-14, 0.590096844352078, 0, 2.89087233497829, 0.340692571934624, 0, 0, 1.04169365895487e-14, -10.576283741361, 0, 0, 3.43474889911913, 0, 3.47218947830366, -1.03874215316938, 0, 0, 0, 0, 0, 0, 0, 0, 14.3499128917217, 0, 0, 8.28492607088319, 0, -1.69115345252878, 0.341664592660038, 0, 0, 0, 0, 0, 0, 0, 0, 1.04348006604658e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {1.15175110689979, 0.546323519313508, -0.105140010313428, 3.27118942773248, 9.65295620481433, 0, 0, 2.69341127303542, -0.51834724117513, 4.25171145123353, 0, 0, 0, 0, -9.91526600752599, 0, 0, 6.71889089790562, -1.29305115618718, 1.82865048192213, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 0, 9.45383520059451, -1.81939143264587, -2.94058061635794, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.892142571199779, 0.141060126129514, 0.407205508963965, 2.53385243517954, 0, 9.65295620481433, 0, 0.695435800330239, 2.00755023262382, 3.29336152870136, 0, 0, 0, -1.35671976966506e-14, 0, -9.91526600752598, 0, 1.73481017017155, 5.00796559370719, 1.4164665725037, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 2.44096975264614, 7.04647271886991, -2.27776395106694, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.515078753637729, 0, 0.376160336345341, 1.46292038553772, 0, 0, 9.65295620481433, 0, 1.85449546754728, 1.90142316513449, 0, 0, 0, -2.50850100800641e-14, 0, -1.15008035787034e-14, -9.91526600752594, 0, 4.62616045379078, 0.817797356933146, 0, 0, 0, 0, -1.24919104274206e-14, 0, 0, 0, 0, 0, 0, 15.9443476574685, 0, 6.50925267372303, -1.31506763029891, 0, 0, 0, 0, 0, -1.31906496265821e-14, 0, 0, 1.19318131197878e-14, -1.10848897873181e-14, 1.67436700563434e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {0.72843135908468, -7.94708263760856, 0, 2.53908227033116, 0, 0, 0, 10.2207771580387, 0, 5.00713776237768, 0, 0, 1.91058434396028e-14, 0, -1.58541378910724e-14, 1.90136980421293e-14, -1.88766397254795e-14, -8.49879943502228, -1.97928218732183e-14, 6.93924068068615, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 0, 6.27677936394721, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1.47602702235557e-14, 0, 0},
    {0.420560041253711, 0, -7.94708263760856, 1.46593983227032, 0, 0, 0, 0, 10.2207771580387, 2.89087233497828, 0, 0, 0, -1.08180349039434e-14, 1.10015960051229e-14, 0, 1.60406067004907e-14, 0, -8.49879943502225, 4.00637247496576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17.9373911146521, 3.62390025541881, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.00860104949949e-14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    {6.542378855465, 1.44235171923932e-14, 0, -6.91050664139876, 0, 0, 0, 0, -1.41976691442264e-14, 12.2649325896464, 0, 0, 1.30312779804118e-14, 0, 0, 2.24879933982623e-14, 0, 1.64486782168017e-14, -1.79783245387702e-14, -5.66586629001484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 20.4998755596024, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.16147208367439e-14, 0, 0, 0, 0, 0, 0, 1.28659042607863e-14, 0, 0, 0, 0}};
    
    // Compute reference derivatives
    // Declare pointer to array of derivatives on FIAT element
    double *derivatives = new double [num_derivatives];
    
    // Declare coefficients
    double coeff0_0 = 0;
    double coeff0_1 = 0;
    double coeff0_2 = 0;
    double coeff0_3 = 0;
    double coeff0_4 = 0;
    double coeff0_5 = 0;
    double coeff0_6 = 0;
    double coeff0_7 = 0;
    double coeff0_8 = 0;
    double coeff0_9 = 0;
    double coeff0_10 = 0;
    double coeff0_11 = 0;
    double coeff0_12 = 0;
    double coeff0_13 = 0;
    double coeff0_14 = 0;
    double coeff0_15 = 0;
    double coeff0_16 = 0;
    double coeff0_17 = 0;
    double coeff0_18 = 0;
    double coeff0_19 = 0;
    double coeff0_20 = 0;
    double coeff0_21 = 0;
    double coeff0_22 = 0;
    double coeff0_23 = 0;
    double coeff0_24 = 0;
    double coeff0_25 = 0;
    double coeff0_26 = 0;
    double coeff0_27 = 0;
    double coeff0_28 = 0;
    double coeff0_29 = 0;
    double coeff0_30 = 0;
    double coeff0_31 = 0;
    double coeff0_32 = 0;
    double coeff0_33 = 0;
    double coeff0_34 = 0;
    double coeff0_35 = 0;
    double coeff0_36 = 0;
    double coeff0_37 = 0;
    double coeff0_38 = 0;
    double coeff0_39 = 0;
    double coeff0_40 = 0;
    double coeff0_41 = 0;
    double coeff0_42 = 0;
    double coeff0_43 = 0;
    double coeff0_44 = 0;
    double coeff0_45 = 0;
    double coeff0_46 = 0;
    double coeff0_47 = 0;
    double coeff0_48 = 0;
    double coeff0_49 = 0;
    double coeff0_50 = 0;
    double coeff0_51 = 0;
    double coeff0_52 = 0;
    double coeff0_53 = 0;
    double coeff0_54 = 0;
    double coeff0_55 = 0;
    
    // Declare new coefficients
    double new_coeff0_0 = 0;
    double new_coeff0_1 = 0;
    double new_coeff0_2 = 0;
    double new_coeff0_3 = 0;
    double new_coeff0_4 = 0;
    double new_coeff0_5 = 0;
    double new_coeff0_6 = 0;
    double new_coeff0_7 = 0;
    double new_coeff0_8 = 0;
    double new_coeff0_9 = 0;
    double new_coeff0_10 = 0;
    double new_coeff0_11 = 0;
    double new_coeff0_12 = 0;
    double new_coeff0_13 = 0;
    double new_coeff0_14 = 0;
    double new_coeff0_15 = 0;
    double new_coeff0_16 = 0;
    double new_coeff0_17 = 0;
    double new_coeff0_18 = 0;
    double new_coeff0_19 = 0;
    double new_coeff0_20 = 0;
    double new_coeff0_21 = 0;
    double new_coeff0_22 = 0;
    double new_coeff0_23 = 0;
    double new_coeff0_24 = 0;
    double new_coeff0_25 = 0;
    double new_coeff0_26 = 0;
    double new_coeff0_27 = 0;
    double new_coeff0_28 = 0;
    double new_coeff0_29 = 0;
    double new_coeff0_30 = 0;
    double new_coeff0_31 = 0;
    double new_coeff0_32 = 0;
    double new_coeff0_33 = 0;
    double new_coeff0_34 = 0;
    double new_coeff0_35 = 0;
    double new_coeff0_36 = 0;
    double new_coeff0_37 = 0;
    double new_coeff0_38 = 0;
    double new_coeff0_39 = 0;
    double new_coeff0_40 = 0;
    double new_coeff0_41 = 0;
    double new_coeff0_42 = 0;
    double new_coeff0_43 = 0;
    double new_coeff0_44 = 0;
    double new_coeff0_45 = 0;
    double new_coeff0_46 = 0;
    double new_coeff0_47 = 0;
    double new_coeff0_48 = 0;
    double new_coeff0_49 = 0;
    double new_coeff0_50 = 0;
    double new_coeff0_51 = 0;
    double new_coeff0_52 = 0;
    double new_coeff0_53 = 0;
    double new_coeff0_54 = 0;
    double new_coeff0_55 = 0;
    
    // Loop possible derivatives
    for (unsigned int deriv_num = 0; deriv_num < num_derivatives; deriv_num++)
    {
      // Get values from coefficients array
      new_coeff0_0 = coefficients0[dof][0];
      new_coeff0_1 = coefficients0[dof][1];
      new_coeff0_2 = coefficients0[dof][2];
      new_coeff0_3 = coefficients0[dof][3];
      new_coeff0_4 = coefficients0[dof][4];
      new_coeff0_5 = coefficients0[dof][5];
      new_coeff0_6 = coefficients0[dof][6];
      new_coeff0_7 = coefficients0[dof][7];
      new_coeff0_8 = coefficients0[dof][8];
      new_coeff0_9 = coefficients0[dof][9];
      new_coeff0_10 = coefficients0[dof][10];
      new_coeff0_11 = coefficients0[dof][11];
      new_coeff0_12 = coefficients0[dof][12];
      new_coeff0_13 = coefficients0[dof][13];
      new_coeff0_14 = coefficients0[dof][14];
      new_coeff0_15 = coefficients0[dof][15];
      new_coeff0_16 = coefficients0[dof][16];
      new_coeff0_17 = coefficients0[dof][17];
      new_coeff0_18 = coefficients0[dof][18];
      new_coeff0_19 = coefficients0[dof][19];
      new_coeff0_20 = coefficients0[dof][20];
      new_coeff0_21 = coefficients0[dof][21];
      new_coeff0_22 = coefficients0[dof][22];
      new_coeff0_23 = coefficients0[dof][23];
      new_coeff0_24 = coefficients0[dof][24];
      new_coeff0_25 = coefficients0[dof][25];
      new_coeff0_26 = coefficients0[dof][26];
      new_coeff0_27 = coefficients0[dof][27];
      new_coeff0_28 = coefficients0[dof][28];
      new_coeff0_29 = coefficients0[dof][29];
      new_coeff0_30 = coefficients0[dof][30];
      new_coeff0_31 = coefficients0[dof][31];
      new_coeff0_32 = coefficients0[dof][32];
      new_coeff0_33 = coefficients0[dof][33];
      new_coeff0_34 = coefficients0[dof][34];
      new_coeff0_35 = coefficients0[dof][35];
      new_coeff0_36 = coefficients0[dof][36];
      new_coeff0_37 = coefficients0[dof][37];
      new_coeff0_38 = coefficients0[dof][38];
      new_coeff0_39 = coefficients0[dof][39];
      new_coeff0_40 = coefficients0[dof][40];
      new_coeff0_41 = coefficients0[dof][41];
      new_coeff0_42 = coefficients0[dof][42];
      new_coeff0_43 = coefficients0[dof][43];
      new_coeff0_44 = coefficients0[dof][44];
      new_coeff0_45 = coefficients0[dof][45];
      new_coeff0_46 = coefficients0[dof][46];
      new_coeff0_47 = coefficients0[dof][47];
      new_coeff0_48 = coefficients0[dof][48];
      new_coeff0_49 = coefficients0[dof][49];
      new_coeff0_50 = coefficients0[dof][50];
      new_coeff0_51 = coefficients0[dof][51];
      new_coeff0_52 = coefficients0[dof][52];
      new_coeff0_53 = coefficients0[dof][53];
      new_coeff0_54 = coefficients0[dof][54];
      new_coeff0_55 = coefficients0[dof][55];
    
      // Loop derivative order
      for (unsigned int j = 0; j < n; j++)
      {
        // Update old coefficients
        coeff0_0 = new_coeff0_0;
        coeff0_1 = new_coeff0_1;
        coeff0_2 = new_coeff0_2;
        coeff0_3 = new_coeff0_3;
        coeff0_4 = new_coeff0_4;
        coeff0_5 = new_coeff0_5;
        coeff0_6 = new_coeff0_6;
        coeff0_7 = new_coeff0_7;
        coeff0_8 = new_coeff0_8;
        coeff0_9 = new_coeff0_9;
        coeff0_10 = new_coeff0_10;
        coeff0_11 = new_coeff0_11;
        coeff0_12 = new_coeff0_12;
        coeff0_13 = new_coeff0_13;
        coeff0_14 = new_coeff0_14;
        coeff0_15 = new_coeff0_15;
        coeff0_16 = new_coeff0_16;
        coeff0_17 = new_coeff0_17;
        coeff0_18 = new_coeff0_18;
        coeff0_19 = new_coeff0_19;
        coeff0_20 = new_coeff0_20;
        coeff0_21 = new_coeff0_21;
        coeff0_22 = new_coeff0_22;
        coeff0_23 = new_coeff0_23;
        coeff0_24 = new_coeff0_24;
        coeff0_25 = new_coeff0_25;
        coeff0_26 = new_coeff0_26;
        coeff0_27 = new_coeff0_27;
        coeff0_28 = new_coeff0_28;
        coeff0_29 = new_coeff0_29;
        coeff0_30 = new_coeff0_30;
        coeff0_31 = new_coeff0_31;
        coeff0_32 = new_coeff0_32;
        coeff0_33 = new_coeff0_33;
        coeff0_34 = new_coeff0_34;
        coeff0_35 = new_coeff0_35;
        coeff0_36 = new_coeff0_36;
        coeff0_37 = new_coeff0_37;
        coeff0_38 = new_coeff0_38;
        coeff0_39 = new_coeff0_39;
        coeff0_40 = new_coeff0_40;
        coeff0_41 = new_coeff0_41;
        coeff0_42 = new_coeff0_42;
        coeff0_43 = new_coeff0_43;
        coeff0_44 = new_coeff0_44;
        coeff0_45 = new_coeff0_45;
        coeff0_46 = new_coeff0_46;
        coeff0_47 = new_coeff0_47;
        coeff0_48 = new_coeff0_48;
        coeff0_49 = new_coeff0_49;
        coeff0_50 = new_coeff0_50;
        coeff0_51 = new_coeff0_51;
        coeff0_52 = new_coeff0_52;
        coeff0_53 = new_coeff0_53;
        coeff0_54 = new_coeff0_54;
        coeff0_55 = new_coeff0_55;
    
        if(combinations[deriv_num][j] == 0)
        {
          new_coeff0_0 = coeff0_0*dmats0[0][0] + coeff0_1*dmats0[1][0] + coeff0_2*dmats0[2][0] + coeff0_3*dmats0[3][0] + coeff0_4*dmats0[4][0] + coeff0_5*dmats0[5][0] + coeff0_6*dmats0[6][0] + coeff0_7*dmats0[7][0] + coeff0_8*dmats0[8][0] + coeff0_9*dmats0[9][0] + coeff0_10*dmats0[10][0] + coeff0_11*dmats0[11][0] + coeff0_12*dmats0[12][0] + coeff0_13*dmats0[13][0] + coeff0_14*dmats0[14][0] + coeff0_15*dmats0[15][0] + coeff0_16*dmats0[16][0] + coeff0_17*dmats0[17][0] + coeff0_18*dmats0[18][0] + coeff0_19*dmats0[19][0] + coeff0_20*dmats0[20][0] + coeff0_21*dmats0[21][0] + coeff0_22*dmats0[22][0] + coeff0_23*dmats0[23][0] + coeff0_24*dmats0[24][0] + coeff0_25*dmats0[25][0] + coeff0_26*dmats0[26][0] + coeff0_27*dmats0[27][0] + coeff0_28*dmats0[28][0] + coeff0_29*dmats0[29][0] + coeff0_30*dmats0[30][0] + coeff0_31*dmats0[31][0] + coeff0_32*dmats0[32][0] + coeff0_33*dmats0[33][0] + coeff0_34*dmats0[34][0] + coeff0_35*dmats0[35][0] + coeff0_36*dmats0[36][0] + coeff0_37*dmats0[37][0] + coeff0_38*dmats0[38][0] + coeff0_39*dmats0[39][0] + coeff0_40*dmats0[40][0] + coeff0_41*dmats0[41][0] + coeff0_42*dmats0[42][0] + coeff0_43*dmats0[43][0] + coeff0_44*dmats0[44][0] + coeff0_45*dmats0[45][0] + coeff0_46*dmats0[46][0] + coeff0_47*dmats0[47][0] + coeff0_48*dmats0[48][0] + coeff0_49*dmats0[49][0] + coeff0_50*dmats0[50][0] + coeff0_51*dmats0[51][0] + coeff0_52*dmats0[52][0] + coeff0_53*dmats0[53][0] + coeff0_54*dmats0[54][0] + coeff0_55*dmats0[55][0];
          new_coeff0_1 = coeff0_0*dmats0[0][1] + coeff0_1*dmats0[1][1] + coeff0_2*dmats0[2][1] + coeff0_3*dmats0[3][1] + coeff0_4*dmats0[4][1] + coeff0_5*dmats0[5][1] + coeff0_6*dmats0[6][1] + coeff0_7*dmats0[7][1] + coeff0_8*dmats0[8][1] + coeff0_9*dmats0[9][1] + coeff0_10*dmats0[10][1] + coeff0_11*dmats0[11][1] + coeff0_12*dmats0[12][1] + coeff0_13*dmats0[13][1] + coeff0_14*dmats0[14][1] + coeff0_15*dmats0[15][1] + coeff0_16*dmats0[16][1] + coeff0_17*dmats0[17][1] + coeff0_18*dmats0[18][1] + coeff0_19*dmats0[19][1] + coeff0_20*dmats0[20][1] + coeff0_21*dmats0[21][1] + coeff0_22*dmats0[22][1] + coeff0_23*dmats0[23][1] + coeff0_24*dmats0[24][1] + coeff0_25*dmats0[25][1] + coeff0_26*dmats0[26][1] + coeff0_27*dmats0[27][1] + coeff0_28*dmats0[28][1] + coeff0_29*dmats0[29][1] + coeff0_30*dmats0[30][1] + coeff0_31*dmats0[31][1] + coeff0_32*dmats0[32][1] + coeff0_33*dmats0[33][1] + coeff0_34*dmats0[34][1] + coeff0_35*dmats0[35][1] + coeff0_36*dmats0[36][1] + coeff0_37*dmats0[37][1] + coeff0_38*dmats0[38][1] + coeff0_39*dmats0[39][1] + coeff0_40*dmats0[40][1] + coeff0_41*dmats0[41][1] + coeff0_42*dmats0[42][1] + coeff0_43*dmats0[43][1] + coeff0_44*dmats0[44][1] + coeff0_45*dmats0[45][1] + coeff0_46*dmats0[46][1] + coeff0_47*dmats0[47][1] + coeff0_48*dmats0[48][1] + coeff0_49*dmats0[49][1] + coeff0_50*dmats0[50][1] + coeff0_51*dmats0[51][1] + coeff0_52*dmats0[52][1] + coeff0_53*dmats0[53][1] + coeff0_54*dmats0[54][1] + coeff0_55*dmats0[55][1];
          new_coeff0_2 = coeff0_0*dmats0[0][2] + coeff0_1*dmats0[1][2] + coeff0_2*dmats0[2][2] + coeff0_3*dmats0[3][2] + coeff0_4*dmats0[4][2] + coeff0_5*dmats0[5][2] + coeff0_6*dmats0[6][2] + coeff0_7*dmats0[7][2] + coeff0_8*dmats0[8][2] + coeff0_9*dmats0[9][2] + coeff0_10*dmats0[10][2] + coeff0_11*dmats0[11][2] + coeff0_12*dmats0[12][2] + coeff0_13*dmats0[13][2] + coeff0_14*dmats0[14][2] + coeff0_15*dmats0[15][2] + coeff0_16*dmats0[16][2] + coeff0_17*dmats0[17][2] + coeff0_18*dmats0[18][2] + coeff0_19*dmats0[19][2] + coeff0_20*dmats0[20][2] + coeff0_21*dmats0[21][2] + coeff0_22*dmats0[22][2] + coeff0_23*dmats0[23][2] + coeff0_24*dmats0[24][2] + coeff0_25*dmats0[25][2] + coeff0_26*dmats0[26][2] + coeff0_27*dmats0[27][2] + coeff0_28*dmats0[28][2] + coeff0_29*dmats0[29][2] + coeff0_30*dmats0[30][2] + coeff0_31*dmats0[31][2] + coeff0_32*dmats0[32][2] + coeff0_33*dmats0[33][2] + coeff0_34*dmats0[34][2] + coeff0_35*dmats0[35][2] + coeff0_36*dmats0[36][2] + coeff0_37*dmats0[37][2] + coeff0_38*dmats0[38][2] + coeff0_39*dmats0[39][2] + coeff0_40*dmats0[40][2] + coeff0_41*dmats0[41][2] + coeff0_42*dmats0[42][2] + coeff0_43*dmats0[43][2] + coeff0_44*dmats0[44][2] + coeff0_45*dmats0[45][2] + coeff0_46*dmats0[46][2] + coeff0_47*dmats0[47][2] + coeff0_48*dmats0[48][2] + coeff0_49*dmats0[49][2] + coeff0_50*dmats0[50][2] + coeff0_51*dmats0[51][2] + coeff0_52*dmats0[52][2] + coeff0_53*dmats0[53][2] + coeff0_54*dmats0[54][2] + coeff0_55*dmats0[55][2];
          new_coeff0_3 = coeff0_0*dmats0[0][3] + coeff0_1*dmats0[1][3] + coeff0_2*dmats0[2][3] + coeff0_3*dmats0[3][3] + coeff0_4*dmats0[4][3] + coeff0_5*dmats0[5][3] + coeff0_6*dmats0[6][3] + coeff0_7*dmats0[7][3] + coeff0_8*dmats0[8][3] + coeff0_9*dmats0[9][3] + coeff0_10*dmats0[10][3] + coeff0_11*dmats0[11][3] + coeff0_12*dmats0[12][3] + coeff0_13*dmats0[13][3] + coeff0_14*dmats0[14][3] + coeff0_15*dmats0[15][3] + coeff0_16*dmats0[16][3] + coeff0_17*dmats0[17][3] + coeff0_18*dmats0[18][3] + coeff0_19*dmats0[19][3] + coeff0_20*dmats0[20][3] + coeff0_21*dmats0[21][3] + coeff0_22*dmats0[22][3] + coeff0_23*dmats0[23][3] + coeff0_24*dmats0[24][3] + coeff0_25*dmats0[25][3] + coeff0_26*dmats0[26][3] + coeff0_27*dmats0[27][3] + coeff0_28*dmats0[28][3] + coeff0_29*dmats0[29][3] + coeff0_30*dmats0[30][3] + coeff0_31*dmats0[31][3] + coeff0_32*dmats0[32][3] + coeff0_33*dmats0[33][3] + coeff0_34*dmats0[34][3] + coeff0_35*dmats0[35][3] + coeff0_36*dmats0[36][3] + coeff0_37*dmats0[37][3] + coeff0_38*dmats0[38][3] + coeff0_39*dmats0[39][3] + coeff0_40*dmats0[40][3] + coeff0_41*dmats0[41][3] + coeff0_42*dmats0[42][3] + coeff0_43*dmats0[43][3] + coeff0_44*dmats0[44][3] + coeff0_45*dmats0[45][3] + coeff0_46*dmats0[46][3] + coeff0_47*dmats0[47][3] + coeff0_48*dmats0[48][3] + coeff0_49*dmats0[49][3] + coeff0_50*dmats0[50][3] + coeff0_51*dmats0[51][3] + coeff0_52*dmats0[52][3] + coeff0_53*dmats0[53][3] + coeff0_54*dmats0[54][3] + coeff0_55*dmats0[55][3];
          new_coeff0_4 = coeff0_0*dmats0[0][4] + coeff0_1*dmats0[1][4] + coeff0_2*dmats0[2][4] + coeff0_3*dmats0[3][4] + coeff0_4*dmats0[4][4] + coeff0_5*dmats0[5][4] + coeff0_6*dmats0[6][4] + coeff0_7*dmats0[7][4] + coeff0_8*dmats0[8][4] + coeff0_9*dmats0[9][4] + coeff0_10*dmats0[10][4] + coeff0_11*dmats0[11][4] + coeff0_12*dmats0[12][4] + coeff0_13*dmats0[13][4] + coeff0_14*dmats0[14][4] + coeff0_15*dmats0[15][4] + coeff0_16*dmats0[16][4] + coeff0_17*dmats0[17][4] + coeff0_18*dmats0[18][4] + coeff0_19*dmats0[19][4] + coeff0_20*dmats0[20][4] + coeff0_21*dmats0[21][4] + coeff0_22*dmats0[22][4] + coeff0_23*dmats0[23][4] + coeff0_24*dmats0[24][4] + coeff0_25*dmats0[25][4] + coeff0_26*dmats0[26][4] + coeff0_27*dmats0[27][4] + coeff0_28*dmats0[28][4] + coeff0_29*dmats0[29][4] + coeff0_30*dmats0[30][4] + coeff0_31*dmats0[31][4] + coeff0_32*dmats0[32][4] + coeff0_33*dmats0[33][4] + coeff0_34*dmats0[34][4] + coeff0_35*dmats0[35][4] + coeff0_36*dmats0[36][4] + coeff0_37*dmats0[37][4] + coeff0_38*dmats0[38][4] + coeff0_39*dmats0[39][4] + coeff0_40*dmats0[40][4] + coeff0_41*dmats0[41][4] + coeff0_42*dmats0[42][4] + coeff0_43*dmats0[43][4] + coeff0_44*dmats0[44][4] + coeff0_45*dmats0[45][4] + coeff0_46*dmats0[46][4] + coeff0_47*dmats0[47][4] + coeff0_48*dmats0[48][4] + coeff0_49*dmats0[49][4] + coeff0_50*dmats0[50][4] + coeff0_51*dmats0[51][4] + coeff0_52*dmats0[52][4] + coeff0_53*dmats0[53][4] + coeff0_54*dmats0[54][4] + coeff0_55*dmats0[55][4];
          new_coeff0_5 = coeff0_0*dmats0[0][5] + coeff0_1*dmats0[1][5] + coeff0_2*dmats0[2][5] + coeff0_3*dmats0[3][5] + coeff0_4*dmats0[4][5] + coeff0_5*dmats0[5][5] + coeff0_6*dmats0[6][5] + coeff0_7*dmats0[7][5] + coeff0_8*dmats0[8][5] + coeff0_9*dmats0[9][5] + coeff0_10*dmats0[10][5] + coeff0_11*dmats0[11][5] + coeff0_12*dmats0[12][5] + coeff0_13*dmats0[13][5] + coeff0_14*dmats0[14][5] + coeff0_15*dmats0[15][5] + coeff0_16*dmats0[16][5] + coeff0_17*dmats0[17][5] + coeff0_18*dmats0[18][5] + coeff0_19*dmats0[19][5] + coeff0_20*dmats0[20][5] + coeff0_21*dmats0[21][5] + coeff0_22*dmats0[22][5] + coeff0_23*dmats0[23][5] + coeff0_24*dmats0[24][5] + coeff0_25*dmats0[25][5] + coeff0_26*dmats0[26][5] + coeff0_27*dmats0[27][5] + coeff0_28*dmats0[28][5] + coeff0_29*dmats0[29][5] + coeff0_30*dmats0[30][5] + coeff0_31*dmats0[31][5] + coeff0_32*dmats0[32][5] + coeff0_33*dmats0[33][5] + coeff0_34*dmats0[34][5] + coeff0_35*dmats0[35][5] + coeff0_36*dmats0[36][5] + coeff0_37*dmats0[37][5] + coeff0_38*dmats0[38][5] + coeff0_39*dmats0[39][5] + coeff0_40*dmats0[40][5] + coeff0_41*dmats0[41][5] + coeff0_42*dmats0[42][5] + coeff0_43*dmats0[43][5] + coeff0_44*dmats0[44][5] + coeff0_45*dmats0[45][5] + coeff0_46*dmats0[46][5] + coeff0_47*dmats0[47][5] + coeff0_48*dmats0[48][5] + coeff0_49*dmats0[49][5] + coeff0_50*dmats0[50][5] + coeff0_51*dmats0[51][5] + coeff0_52*dmats0[52][5] + coeff0_53*dmats0[53][5] + coeff0_54*dmats0[54][5] + coeff0_55*dmats0[55][5];
          new_coeff0_6 = coeff0_0*dmats0[0][6] + coeff0_1*dmats0[1][6] + coeff0_2*dmats0[2][6] + coeff0_3*dmats0[3][6] + coeff0_4*dmats0[4][6] + coeff0_5*dmats0[5][6] + coeff0_6*dmats0[6][6] + coeff0_7*dmats0[7][6] + coeff0_8*dmats0[8][6] + coeff0_9*dmats0[9][6] + coeff0_10*dmats0[10][6] + coeff0_11*dmats0[11][6] + coeff0_12*dmats0[12][6] + coeff0_13*dmats0[13][6] + coeff0_14*dmats0[14][6] + coeff0_15*dmats0[15][6] + coeff0_16*dmats0[16][6] + coeff0_17*dmats0[17][6] + coeff0_18*dmats0[18][6] + coeff0_19*dmats0[19][6] + coeff0_20*dmats0[20][6] + coeff0_21*dmats0[21][6] + coeff0_22*dmats0[22][6] + coeff0_23*dmats0[23][6] + coeff0_24*dmats0[24][6] + coeff0_25*dmats0[25][6] + coeff0_26*dmats0[26][6] + coeff0_27*dmats0[27][6] + coeff0_28*dmats0[28][6] + coeff0_29*dmats0[29][6] + coeff0_30*dmats0[30][6] + coeff0_31*dmats0[31][6] + coeff0_32*dmats0[32][6] + coeff0_33*dmats0[33][6] + coeff0_34*dmats0[34][6] + coeff0_35*dmats0[35][6] + coeff0_36*dmats0[36][6] + coeff0_37*dmats0[37][6] + coeff0_38*dmats0[38][6] + coeff0_39*dmats0[39][6] + coeff0_40*dmats0[40][6] + coeff0_41*dmats0[41][6] + coeff0_42*dmats0[42][6] + coeff0_43*dmats0[43][6] + coeff0_44*dmats0[44][6] + coeff0_45*dmats0[45][6] + coeff0_46*dmats0[46][6] + coeff0_47*dmats0[47][6] + coeff0_48*dmats0[48][6] + coeff0_49*dmats0[49][6] + coeff0_50*dmats0[50][6] + coeff0_51*dmats0[51][6] + coeff0_52*dmats0[52][6] + coeff0_53*dmats0[53][6] + coeff0_54*dmats0[54][6] + coeff0_55*dmats0[55][6];
          new_coeff0_7 = coeff0_0*dmats0[0][7] + coeff0_1*dmats0[1][7] + coeff0_2*dmats0[2][7] + coeff0_3*dmats0[3][7] + coeff0_4*dmats0[4][7] + coeff0_5*dmats0[5][7] + coeff0_6*dmats0[6][7] + coeff0_7*dmats0[7][7] + coeff0_8*dmats0[8][7] + coeff0_9*dmats0[9][7] + coeff0_10*dmats0[10][7] + coeff0_11*dmats0[11][7] + coeff0_12*dmats0[12][7] + coeff0_13*dmats0[13][7] + coeff0_14*dmats0[14][7] + coeff0_15*dmats0[15][7] + coeff0_16*dmats0[16][7] + coeff0_17*dmats0[17][7] + coeff0_18*dmats0[18][7] + coeff0_19*dmats0[19][7] + coeff0_20*dmats0[20][7] + coeff0_21*dmats0[21][7] + coeff0_22*dmats0[22][7] + coeff0_23*dmats0[23][7] + coeff0_24*dmats0[24][7] + coeff0_25*dmats0[25][7] + coeff0_26*dmats0[26][7] + coeff0_27*dmats0[27][7] + coeff0_28*dmats0[28][7] + coeff0_29*dmats0[29][7] + coeff0_30*dmats0[30][7] + coeff0_31*dmats0[31][7] + coeff0_32*dmats0[32][7] + coeff0_33*dmats0[33][7] + coeff0_34*dmats0[34][7] + coeff0_35*dmats0[35][7] + coeff0_36*dmats0[36][7] + coeff0_37*dmats0[37][7] + coeff0_38*dmats0[38][7] + coeff0_39*dmats0[39][7] + coeff0_40*dmats0[40][7] + coeff0_41*dmats0[41][7] + coeff0_42*dmats0[42][7] + coeff0_43*dmats0[43][7] + coeff0_44*dmats0[44][7] + coeff0_45*dmats0[45][7] + coeff0_46*dmats0[46][7] + coeff0_47*dmats0[47][7] + coeff0_48*dmats0[48][7] + coeff0_49*dmats0[49][7] + coeff0_50*dmats0[50][7] + coeff0_51*dmats0[51][7] + coeff0_52*dmats0[52][7] + coeff0_53*dmats0[53][7] + coeff0_54*dmats0[54][7] + coeff0_55*dmats0[55][7];
          new_coeff0_8 = coeff0_0*dmats0[0][8] + coeff0_1*dmats0[1][8] + coeff0_2*dmats0[2][8] + coeff0_3*dmats0[3][8] + coeff0_4*dmats0[4][8] + coeff0_5*dmats0[5][8] + coeff0_6*dmats0[6][8] + coeff0_7*dmats0[7][8] + coeff0_8*dmats0[8][8] + coeff0_9*dmats0[9][8] + coeff0_10*dmats0[10][8] + coeff0_11*dmats0[11][8] + coeff0_12*dmats0[12][8] + coeff0_13*dmats0[13][8] + coeff0_14*dmats0[14][8] + coeff0_15*dmats0[15][8] + coeff0_16*dmats0[16][8] + coeff0_17*dmats0[17][8] + coeff0_18*dmats0[18][8] + coeff0_19*dmats0[19][8] + coeff0_20*dmats0[20][8] + coeff0_21*dmats0[21][8] + coeff0_22*dmats0[22][8] + coeff0_23*dmats0[23][8] + coeff0_24*dmats0[24][8] + coeff0_25*dmats0[25][8] + coeff0_26*dmats0[26][8] + coeff0_27*dmats0[27][8] + coeff0_28*dmats0[28][8] + coeff0_29*dmats0[29][8] + coeff0_30*dmats0[30][8] + coeff0_31*dmats0[31][8] + coeff0_32*dmats0[32][8] + coeff0_33*dmats0[33][8] + coeff0_34*dmats0[34][8] + coeff0_35*dmats0[35][8] + coeff0_36*dmats0[36][8] + coeff0_37*dmats0[37][8] + coeff0_38*dmats0[38][8] + coeff0_39*dmats0[39][8] + coeff0_40*dmats0[40][8] + coeff0_41*dmats0[41][8] + coeff0_42*dmats0[42][8] + coeff0_43*dmats0[43][8] + coeff0_44*dmats0[44][8] + coeff0_45*dmats0[45][8] + coeff0_46*dmats0[46][8] + coeff0_47*dmats0[47][8] + coeff0_48*dmats0[48][8] + coeff0_49*dmats0[49][8] + coeff0_50*dmats0[50][8] + coeff0_51*dmats0[51][8] + coeff0_52*dmats0[52][8] + coeff0_53*dmats0[53][8] + coeff0_54*dmats0[54][8] + coeff0_55*dmats0[55][8];
          new_coeff0_9 = coeff0_0*dmats0[0][9] + coeff0_1*dmats0[1][9] + coeff0_2*dmats0[2][9] + coeff0_3*dmats0[3][9] + coeff0_4*dmats0[4][9] + coeff0_5*dmats0[5][9] + coeff0_6*dmats0[6][9] + coeff0_7*dmats0[7][9] + coeff0_8*dmats0[8][9] + coeff0_9*dmats0[9][9] + coeff0_10*dmats0[10][9] + coeff0_11*dmats0[11][9] + coeff0_12*dmats0[12][9] + coeff0_13*dmats0[13][9] + coeff0_14*dmats0[14][9] + coeff0_15*dmats0[15][9] + coeff0_16*dmats0[16][9] + coeff0_17*dmats0[17][9] + coeff0_18*dmats0[18][9] + coeff0_19*dmats0[19][9] + coeff0_20*dmats0[20][9] + coeff0_21*dmats0[21][9] + coeff0_22*dmats0[22][9] + coeff0_23*dmats0[23][9] + coeff0_24*dmats0[24][9] + coeff0_25*dmats0[25][9] + coeff0_26*dmats0[26][9] + coeff0_27*dmats0[27][9] + coeff0_28*dmats0[28][9] + coeff0_29*dmats0[29][9] + coeff0_30*dmats0[30][9] + coeff0_31*dmats0[31][9] + coeff0_32*dmats0[32][9] + coeff0_33*dmats0[33][9] + coeff0_34*dmats0[34][9] + coeff0_35*dmats0[35][9] + coeff0_36*dmats0[36][9] + coeff0_37*dmats0[37][9] + coeff0_38*dmats0[38][9] + coeff0_39*dmats0[39][9] + coeff0_40*dmats0[40][9] + coeff0_41*dmats0[41][9] + coeff0_42*dmats0[42][9] + coeff0_43*dmats0[43][9] + coeff0_44*dmats0[44][9] + coeff0_45*dmats0[45][9] + coeff0_46*dmats0[46][9] + coeff0_47*dmats0[47][9] + coeff0_48*dmats0[48][9] + coeff0_49*dmats0[49][9] + coeff0_50*dmats0[50][9] + coeff0_51*dmats0[51][9] + coeff0_52*dmats0[52][9] + coeff0_53*dmats0[53][9] + coeff0_54*dmats0[54][9] + coeff0_55*dmats0[55][9];
          new_coeff0_10 = coeff0_0*dmats0[0][10] + coeff0_1*dmats0[1][10] + coeff0_2*dmats0[2][10] + coeff0_3*dmats0[3][10] + coeff0_4*dmats0[4][10] + coeff0_5*dmats0[5][10] + coeff0_6*dmats0[6][10] + coeff0_7*dmats0[7][10] + coeff0_8*dmats0[8][10] + coeff0_9*dmats0[9][10] + coeff0_10*dmats0[10][10] + coeff0_11*dmats0[11][10] + coeff0_12*dmats0[12][10] + coeff0_13*dmats0[13][10] + coeff0_14*dmats0[14][10] + coeff0_15*dmats0[15][10] + coeff0_16*dmats0[16][10] + coeff0_17*dmats0[17][10] + coeff0_18*dmats0[18][10] + coeff0_19*dmats0[19][10] + coeff0_20*dmats0[20][10] + coeff0_21*dmats0[21][10] + coeff0_22*dmats0[22][10] + coeff0_23*dmats0[23][10] + coeff0_24*dmats0[24][10] + coeff0_25*dmats0[25][10] + coeff0_26*dmats0[26][10] + coeff0_27*dmats0[27][10] + coeff0_28*dmats0[28][10] + coeff0_29*dmats0[29][10] + coeff0_30*dmats0[30][10] + coeff0_31*dmats0[31][10] + coeff0_32*dmats0[32][10] + coeff0_33*dmats0[33][10] + coeff0_34*dmats0[34][10] + coeff0_35*dmats0[35][10] + coeff0_36*dmats0[36][10] + coeff0_37*dmats0[37][10] + coeff0_38*dmats0[38][10] + coeff0_39*dmats0[39][10] + coeff0_40*dmats0[40][10] + coeff0_41*dmats0[41][10] + coeff0_42*dmats0[42][10] + coeff0_43*dmats0[43][10] + coeff0_44*dmats0[44][10] + coeff0_45*dmats0[45][10] + coeff0_46*dmats0[46][10] + coeff0_47*dmats0[47][10] + coeff0_48*dmats0[48][10] + coeff0_49*dmats0[49][10] + coeff0_50*dmats0[50][10] + coeff0_51*dmats0[51][10] + coeff0_52*dmats0[52][10] + coeff0_53*dmats0[53][10] + coeff0_54*dmats0[54][10] + coeff0_55*dmats0[55][10];
          new_coeff0_11 = coeff0_0*dmats0[0][11] + coeff0_1*dmats0[1][11] + coeff0_2*dmats0[2][11] + coeff0_3*dmats0[3][11] + coeff0_4*dmats0[4][11] + coeff0_5*dmats0[5][11] + coeff0_6*dmats0[6][11] + coeff0_7*dmats0[7][11] + coeff0_8*dmats0[8][11] + coeff0_9*dmats0[9][11] + coeff0_10*dmats0[10][11] + coeff0_11*dmats0[11][11] + coeff0_12*dmats0[12][11] + coeff0_13*dmats0[13][11] + coeff0_14*dmats0[14][11] + coeff0_15*dmats0[15][11] + coeff0_16*dmats0[16][11] + coeff0_17*dmats0[17][11] + coeff0_18*dmats0[18][11] + coeff0_19*dmats0[19][11] + coeff0_20*dmats0[20][11] + coeff0_21*dmats0[21][11] + coeff0_22*dmats0[22][11] + coeff0_23*dmats0[23][11] + coeff0_24*dmats0[24][11] + coeff0_25*dmats0[25][11] + coeff0_26*dmats0[26][11] + coeff0_27*dmats0[27][11] + coeff0_28*dmats0[28][11] + coeff0_29*dmats0[29][11] + coeff0_30*dmats0[30][11] + coeff0_31*dmats0[31][11] + coeff0_32*dmats0[32][11] + coeff0_33*dmats0[33][11] + coeff0_34*dmats0[34][11] + coeff0_35*dmats0[35][11] + coeff0_36*dmats0[36][11] + coeff0_37*dmats0[37][11] + coeff0_38*dmats0[38][11] + coeff0_39*dmats0[39][11] + coeff0_40*dmats0[40][11] + coeff0_41*dmats0[41][11] + coeff0_42*dmats0[42][11] + coeff0_43*dmats0[43][11] + coeff0_44*dmats0[44][11] + coeff0_45*dmats0[45][11] + coeff0_46*dmats0[46][11] + coeff0_47*dmats0[47][11] + coeff0_48*dmats0[48][11] + coeff0_49*dmats0[49][11] + coeff0_50*dmats0[50][11] + coeff0_51*dmats0[51][11] + coeff0_52*dmats0[52][11] + coeff0_53*dmats0[53][11] + coeff0_54*dmats0[54][11] + coeff0_55*dmats0[55][11];
          new_coeff0_12 = coeff0_0*dmats0[0][12] + coeff0_1*dmats0[1][12] + coeff0_2*dmats0[2][12] + coeff0_3*dmats0[3][12] + coeff0_4*dmats0[4][12] + coeff0_5*dmats0[5][12] + coeff0_6*dmats0[6][12] + coeff0_7*dmats0[7][12] + coeff0_8*dmats0[8][12] + coeff0_9*dmats0[9][12] + coeff0_10*dmats0[10][12] + coeff0_11*dmats0[11][12] + coeff0_12*dmats0[12][12] + coeff0_13*dmats0[13][12] + coeff0_14*dmats0[14][12] + coeff0_15*dmats0[15][12] + coeff0_16*dmats0[16][12] + coeff0_17*dmats0[17][12] + coeff0_18*dmats0[18][12] + coeff0_19*dmats0[19][12] + coeff0_20*dmats0[20][12] + coeff0_21*dmats0[21][12] + coeff0_22*dmats0[22][12] + coeff0_23*dmats0[23][12] + coeff0_24*dmats0[24][12] + coeff0_25*dmats0[25][12] + coeff0_26*dmats0[26][12] + coeff0_27*dmats0[27][12] + coeff0_28*dmats0[28][12] + coeff0_29*dmats0[29][12] + coeff0_30*dmats0[30][12] + coeff0_31*dmats0[31][12] + coeff0_32*dmats0[32][12] + coeff0_33*dmats0[33][12] + coeff0_34*dmats0[34][12] + coeff0_35*dmats0[35][12] + coeff0_36*dmats0[36][12] + coeff0_37*dmats0[37][12] + coeff0_38*dmats0[38][12] + coeff0_39*dmats0[39][12] + coeff0_40*dmats0[40][12] + coeff0_41*dmats0[41][12] + coeff0_42*dmats0[42][12] + coeff0_43*dmats0[43][12] + coeff0_44*dmats0[44][12] + coeff0_45*dmats0[45][12] + coeff0_46*dmats0[46][12] + coeff0_47*dmats0[47][12] + coeff0_48*dmats0[48][12] + coeff0_49*dmats0[49][12] + coeff0_50*dmats0[50][12] + coeff0_51*dmats0[51][12] + coeff0_52*dmats0[52][12] + coeff0_53*dmats0[53][12] + coeff0_54*dmats0[54][12] + coeff0_55*dmats0[55][12];
          new_coeff0_13 = coeff0_0*dmats0[0][13] + coeff0_1*dmats0[1][13] + coeff0_2*dmats0[2][13] + coeff0_3*dmats0[3][13] + coeff0_4*dmats0[4][13] + coeff0_5*dmats0[5][13] + coeff0_6*dmats0[6][13] + coeff0_7*dmats0[7][13] + coeff0_8*dmats0[8][13] + coeff0_9*dmats0[9][13] + coeff0_10*dmats0[10][13] + coeff0_11*dmats0[11][13] + coeff0_12*dmats0[12][13] + coeff0_13*dmats0[13][13] + coeff0_14*dmats0[14][13] + coeff0_15*dmats0[15][13] + coeff0_16*dmats0[16][13] + coeff0_17*dmats0[17][13] + coeff0_18*dmats0[18][13] + coeff0_19*dmats0[19][13] + coeff0_20*dmats0[20][13] + coeff0_21*dmats0[21][13] + coeff0_22*dmats0[22][13] + coeff0_23*dmats0[23][13] + coeff0_24*dmats0[24][13] + coeff0_25*dmats0[25][13] + coeff0_26*dmats0[26][13] + coeff0_27*dmats0[27][13] + coeff0_28*dmats0[28][13] + coeff0_29*dmats0[29][13] + coeff0_30*dmats0[30][13] + coeff0_31*dmats0[31][13] + coeff0_32*dmats0[32][13] + coeff0_33*dmats0[33][13] + coeff0_34*dmats0[34][13] + coeff0_35*dmats0[35][13] + coeff0_36*dmats0[36][13] + coeff0_37*dmats0[37][13] + coeff0_38*dmats0[38][13] + coeff0_39*dmats0[39][13] + coeff0_40*dmats0[40][13] + coeff0_41*dmats0[41][13] + coeff0_42*dmats0[42][13] + coeff0_43*dmats0[43][13] + coeff0_44*dmats0[44][13] + coeff0_45*dmats0[45][13] + coeff0_46*dmats0[46][13] + coeff0_47*dmats0[47][13] + coeff0_48*dmats0[48][13] + coeff0_49*dmats0[49][13] + coeff0_50*dmats0[50][13] + coeff0_51*dmats0[51][13] + coeff0_52*dmats0[52][13] + coeff0_53*dmats0[53][13] + coeff0_54*dmats0[54][13] + coeff0_55*dmats0[55][13];
          new_coeff0_14 = coeff0_0*dmats0[0][14] + coeff0_1*dmats0[1][14] + coeff0_2*dmats0[2][14] + coeff0_3*dmats0[3][14] + coeff0_4*dmats0[4][14] + coeff0_5*dmats0[5][14] + coeff0_6*dmats0[6][14] + coeff0_7*dmats0[7][14] + coeff0_8*dmats0[8][14] + coeff0_9*dmats0[9][14] + coeff0_10*dmats0[10][14] + coeff0_11*dmats0[11][14] + coeff0_12*dmats0[12][14] + coeff0_13*dmats0[13][14] + coeff0_14*dmats0[14][14] + coeff0_15*dmats0[15][14] + coeff0_16*dmats0[16][14] + coeff0_17*dmats0[17][14] + coeff0_18*dmats0[18][14] + coeff0_19*dmats0[19][14] + coeff0_20*dmats0[20][14] + coeff0_21*dmats0[21][14] + coeff0_22*dmats0[22][14] + coeff0_23*dmats0[23][14] + coeff0_24*dmats0[24][14] + coeff0_25*dmats0[25][14] + coeff0_26*dmats0[26][14] + coeff0_27*dmats0[27][14] + coeff0_28*dmats0[28][14] + coeff0_29*dmats0[29][14] + coeff0_30*dmats0[30][14] + coeff0_31*dmats0[31][14] + coeff0_32*dmats0[32][14] + coeff0_33*dmats0[33][14] + coeff0_34*dmats0[34][14] + coeff0_35*dmats0[35][14] + coeff0_36*dmats0[36][14] + coeff0_37*dmats0[37][14] + coeff0_38*dmats0[38][14] + coeff0_39*dmats0[39][14] + coeff0_40*dmats0[40][14] + coeff0_41*dmats0[41][14] + coeff0_42*dmats0[42][14] + coeff0_43*dmats0[43][14] + coeff0_44*dmats0[44][14] + coeff0_45*dmats0[45][14] + coeff0_46*dmats0[46][14] + coeff0_47*dmats0[47][14] + coeff0_48*dmats0[48][14] + coeff0_49*dmats0[49][14] + coeff0_50*dmats0[50][14] + coeff0_51*dmats0[51][14] + coeff0_52*dmats0[52][14] + coeff0_53*dmats0[53][14] + coeff0_54*dmats0[54][14] + coeff0_55*dmats0[55][14];
          new_coeff0_15 = coeff0_0*dmats0[0][15] + coeff0_1*dmats0[1][15] + coeff0_2*dmats0[2][15] + coeff0_3*dmats0[3][15] + coeff0_4*dmats0[4][15] + coeff0_5*dmats0[5][15] + coeff0_6*dmats0[6][15] + coeff0_7*dmats0[7][15] + coeff0_8*dmats0[8][15] + coeff0_9*dmats0[9][15] + coeff0_10*dmats0[10][15] + coeff0_11*dmats0[11][15] + coeff0_12*dmats0[12][15] + coeff0_13*dmats0[13][15] + coeff0_14*dmats0[14][15] + coeff0_15*dmats0[15][15] + coeff0_16*dmats0[16][15] + coeff0_17*dmats0[17][15] + coeff0_18*dmats0[18][15] + coeff0_19*dmats0[19][15] + coeff0_20*dmats0[20][15] + coeff0_21*dmats0[21][15] + coeff0_22*dmats0[22][15] + coeff0_23*dmats0[23][15] + coeff0_24*dmats0[24][15] + coeff0_25*dmats0[25][15] + coeff0_26*dmats0[26][15] + coeff0_27*dmats0[27][15] + coeff0_28*dmats0[28][15] + coeff0_29*dmats0[29][15] + coeff0_30*dmats0[30][15] + coeff0_31*dmats0[31][15] + coeff0_32*dmats0[32][15] + coeff0_33*dmats0[33][15] + coeff0_34*dmats0[34][15] + coeff0_35*dmats0[35][15] + coeff0_36*dmats0[36][15] + coeff0_37*dmats0[37][15] + coeff0_38*dmats0[38][15] + coeff0_39*dmats0[39][15] + coeff0_40*dmats0[40][15] + coeff0_41*dmats0[41][15] + coeff0_42*dmats0[42][15] + coeff0_43*dmats0[43][15] + coeff0_44*dmats0[44][15] + coeff0_45*dmats0[45][15] + coeff0_46*dmats0[46][15] + coeff0_47*dmats0[47][15] + coeff0_48*dmats0[48][15] + coeff0_49*dmats0[49][15] + coeff0_50*dmats0[50][15] + coeff0_51*dmats0[51][15] + coeff0_52*dmats0[52][15] + coeff0_53*dmats0[53][15] + coeff0_54*dmats0[54][15] + coeff0_55*dmats0[55][15];
          new_coeff0_16 = coeff0_0*dmats0[0][16] + coeff0_1*dmats0[1][16] + coeff0_2*dmats0[2][16] + coeff0_3*dmats0[3][16] + coeff0_4*dmats0[4][16] + coeff0_5*dmats0[5][16] + coeff0_6*dmats0[6][16] + coeff0_7*dmats0[7][16] + coeff0_8*dmats0[8][16] + coeff0_9*dmats0[9][16] + coeff0_10*dmats0[10][16] + coeff0_11*dmats0[11][16] + coeff0_12*dmats0[12][16] + coeff0_13*dmats0[13][16] + coeff0_14*dmats0[14][16] + coeff0_15*dmats0[15][16] + coeff0_16*dmats0[16][16] + coeff0_17*dmats0[17][16] + coeff0_18*dmats0[18][16] + coeff0_19*dmats0[19][16] + coeff0_20*dmats0[20][16] + coeff0_21*dmats0[21][16] + coeff0_22*dmats0[22][16] + coeff0_23*dmats0[23][16] + coeff0_24*dmats0[24][16] + coeff0_25*dmats0[25][16] + coeff0_26*dmats0[26][16] + coeff0_27*dmats0[27][16] + coeff0_28*dmats0[28][16] + coeff0_29*dmats0[29][16] + coeff0_30*dmats0[30][16] + coeff0_31*dmats0[31][16] + coeff0_32*dmats0[32][16] + coeff0_33*dmats0[33][16] + coeff0_34*dmats0[34][16] + coeff0_35*dmats0[35][16] + coeff0_36*dmats0[36][16] + coeff0_37*dmats0[37][16] + coeff0_38*dmats0[38][16] + coeff0_39*dmats0[39][16] + coeff0_40*dmats0[40][16] + coeff0_41*dmats0[41][16] + coeff0_42*dmats0[42][16] + coeff0_43*dmats0[43][16] + coeff0_44*dmats0[44][16] + coeff0_45*dmats0[45][16] + coeff0_46*dmats0[46][16] + coeff0_47*dmats0[47][16] + coeff0_48*dmats0[48][16] + coeff0_49*dmats0[49][16] + coeff0_50*dmats0[50][16] + coeff0_51*dmats0[51][16] + coeff0_52*dmats0[52][16] + coeff0_53*dmats0[53][16] + coeff0_54*dmats0[54][16] + coeff0_55*dmats0[55][16];
          new_coeff0_17 = coeff0_0*dmats0[0][17] + coeff0_1*dmats0[1][17] + coeff0_2*dmats0[2][17] + coeff0_3*dmats0[3][17] + coeff0_4*dmats0[4][17] + coeff0_5*dmats0[5][17] + coeff0_6*dmats0[6][17] + coeff0_7*dmats0[7][17] + coeff0_8*dmats0[8][17] + coeff0_9*dmats0[9][17] + coeff0_10*dmats0[10][17] + coeff0_11*dmats0[11][17] + coeff0_12*dmats0[12][17] + coeff0_13*dmats0[13][17] + coeff0_14*dmats0[14][17] + coeff0_15*dmats0[15][17] + coeff0_16*dmats0[16][17] + coeff0_17*dmats0[17][17] + coeff0_18*dmats0[18][17] + coeff0_19*dmats0[19][17] + coeff0_20*dmats0[20][17] + coeff0_21*dmats0[21][17] + coeff0_22*dmats0[22][17] + coeff0_23*dmats0[23][17] + coeff0_24*dmats0[24][17] + coeff0_25*dmats0[25][17] + coeff0_26*dmats0[26][17] + coeff0_27*dmats0[27][17] + coeff0_28*dmats0[28][17] + coeff0_29*dmats0[29][17] + coeff0_30*dmats0[30][17] + coeff0_31*dmats0[31][17] + coeff0_32*dmats0[32][17] + coeff0_33*dmats0[33][17] + coeff0_34*dmats0[34][17] + coeff0_35*dmats0[35][17] + coeff0_36*dmats0[36][17] + coeff0_37*dmats0[37][17] + coeff0_38*dmats0[38][17] + coeff0_39*dmats0[39][17] + coeff0_40*dmats0[40][17] + coeff0_41*dmats0[41][17] + coeff0_42*dmats0[42][17] + coeff0_43*dmats0[43][17] + coeff0_44*dmats0[44][17] + coeff0_45*dmats0[45][17] + coeff0_46*dmats0[46][17] + coeff0_47*dmats0[47][17] + coeff0_48*dmats0[48][17] + coeff0_49*dmats0[49][17] + coeff0_50*dmats0[50][17] + coeff0_51*dmats0[51][17] + coeff0_52*dmats0[52][17] + coeff0_53*dmats0[53][17] + coeff0_54*dmats0[54][17] + coeff0_55*dmats0[55][17];
          new_coeff0_18 = coeff0_0*dmats0[0][18] + coeff0_1*dmats0[1][18] + coeff0_2*dmats0[2][18] + coeff0_3*dmats0[3][18] + coeff0_4*dmats0[4][18] + coeff0_5*dmats0[5][18] + coeff0_6*dmats0[6][18] + coeff0_7*dmats0[7][18] + coeff0_8*dmats0[8][18] + coeff0_9*dmats0[9][18] + coeff0_10*dmats0[10][18] + coeff0_11*dmats0[11][18] + coeff0_12*dmats0[12][18] + coeff0_13*dmats0[13][18] + coeff0_14*dmats0[14][18] + coeff0_15*dmats0[15][18] + coeff0_16*dmats0[16][18] + coeff0_17*dmats0[17][18] + coeff0_18*dmats0[18][18] + coeff0_19*dmats0[19][18] + coeff0_20*dmats0[20][18] + coeff0_21*dmats0[21][18] + coeff0_22*dmats0[22][18] + coeff0_23*dmats0[23][18] + coeff0_24*dmats0[24][18] + coeff0_25*dmats0[25][18] + coeff0_26*dmats0[26][18] + coeff0_27*dmats0[27][18] + coeff0_28*dmats0[28][18] + coeff0_29*dmats0[29][18] + coeff0_30*dmats0[30][18] + coeff0_31*dmats0[31][18] + coeff0_32*dmats0[32][18] + coeff0_33*dmats0[33][18] + coeff0_34*dmats0[34][18] + coeff0_35*dmats0[35][18] + coeff0_36*dmats0[36][18] + coeff0_37*dmats0[37][18] + coeff0_38*dmats0[38][18] + coeff0_39*dmats0[39][18] + coeff0_40*dmats0[40][18] + coeff0_41*dmats0[41][18] + coeff0_42*dmats0[42][18] + coeff0_43*dmats0[43][18] + coeff0_44*dmats0[44][18] + coeff0_45*dmats0[45][18] + coeff0_46*dmats0[46][18] + coeff0_47*dmats0[47][18] + coeff0_48*dmats0[48][18] + coeff0_49*dmats0[49][18] + coeff0_50*dmats0[50][18] + coeff0_51*dmats0[51][18] + coeff0_52*dmats0[52][18] + coeff0_53*dmats0[53][18] + coeff0_54*dmats0[54][18] + coeff0_55*dmats0[55][18];
          new_coeff0_19 = coeff0_0*dmats0[0][19] + coeff0_1*dmats0[1][19] + coeff0_2*dmats0[2][19] + coeff0_3*dmats0[3][19] + coeff0_4*dmats0[4][19] + coeff0_5*dmats0[5][19] + coeff0_6*dmats0[6][19] + coeff0_7*dmats0[7][19] + coeff0_8*dmats0[8][19] + coeff0_9*dmats0[9][19] + coeff0_10*dmats0[10][19] + coeff0_11*dmats0[11][19] + coeff0_12*dmats0[12][19] + coeff0_13*dmats0[13][19] + coeff0_14*dmats0[14][19] + coeff0_15*dmats0[15][19] + coeff0_16*dmats0[16][19] + coeff0_17*dmats0[17][19] + coeff0_18*dmats0[18][19] + coeff0_19*dmats0[19][19] + coeff0_20*dmats0[20][19] + coeff0_21*dmats0[21][19] + coeff0_22*dmats0[22][19] + coeff0_23*dmats0[23][19] + coeff0_24*dmats0[24][19] + coeff0_25*dmats0[25][19] + coeff0_26*dmats0[26][19] + coeff0_27*dmats0[27][19] + coeff0_28*dmats0[28][19] + coeff0_29*dmats0[29][19] + coeff0_30*dmats0[30][19] + coeff0_31*dmats0[31][19] + coeff0_32*dmats0[32][19] + coeff0_33*dmats0[33][19] + coeff0_34*dmats0[34][19] + coeff0_35*dmats0[35][19] + coeff0_36*dmats0[36][19] + coeff0_37*dmats0[37][19] + coeff0_38*dmats0[38][19] + coeff0_39*dmats0[39][19] + coeff0_40*dmats0[40][19] + coeff0_41*dmats0[41][19] + coeff0_42*dmats0[42][19] + coeff0_43*dmats0[43][19] + coeff0_44*dmats0[44][19] + coeff0_45*dmats0[45][19] + coeff0_46*dmats0[46][19] + coeff0_47*dmats0[47][19] + coeff0_48*dmats0[48][19] + coeff0_49*dmats0[49][19] + coeff0_50*dmats0[50][19] + coeff0_51*dmats0[51][19] + coeff0_52*dmats0[52][19] + coeff0_53*dmats0[53][19] + coeff0_54*dmats0[54][19] + coeff0_55*dmats0[55][19];
          new_coeff0_20 = coeff0_0*dmats0[0][20] + coeff0_1*dmats0[1][20] + coeff0_2*dmats0[2][20] + coeff0_3*dmats0[3][20] + coeff0_4*dmats0[4][20] + coeff0_5*dmats0[5][20] + coeff0_6*dmats0[6][20] + coeff0_7*dmats0[7][20] + coeff0_8*dmats0[8][20] + coeff0_9*dmats0[9][20] + coeff0_10*dmats0[10][20] + coeff0_11*dmats0[11][20] + coeff0_12*dmats0[12][20] + coeff0_13*dmats0[13][20] + coeff0_14*dmats0[14][20] + coeff0_15*dmats0[15][20] + coeff0_16*dmats0[16][20] + coeff0_17*dmats0[17][20] + coeff0_18*dmats0[18][20] + coeff0_19*dmats0[19][20] + coeff0_20*dmats0[20][20] + coeff0_21*dmats0[21][20] + coeff0_22*dmats0[22][20] + coeff0_23*dmats0[23][20] + coeff0_24*dmats0[24][20] + coeff0_25*dmats0[25][20] + coeff0_26*dmats0[26][20] + coeff0_27*dmats0[27][20] + coeff0_28*dmats0[28][20] + coeff0_29*dmats0[29][20] + coeff0_30*dmats0[30][20] + coeff0_31*dmats0[31][20] + coeff0_32*dmats0[32][20] + coeff0_33*dmats0[33][20] + coeff0_34*dmats0[34][20] + coeff0_35*dmats0[35][20] + coeff0_36*dmats0[36][20] + coeff0_37*dmats0[37][20] + coeff0_38*dmats0[38][20] + coeff0_39*dmats0[39][20] + coeff0_40*dmats0[40][20] + coeff0_41*dmats0[41][20] + coeff0_42*dmats0[42][20] + coeff0_43*dmats0[43][20] + coeff0_44*dmats0[44][20] + coeff0_45*dmats0[45][20] + coeff0_46*dmats0[46][20] + coeff0_47*dmats0[47][20] + coeff0_48*dmats0[48][20] + coeff0_49*dmats0[49][20] + coeff0_50*dmats0[50][20] + coeff0_51*dmats0[51][20] + coeff0_52*dmats0[52][20] + coeff0_53*dmats0[53][20] + coeff0_54*dmats0[54][20] + coeff0_55*dmats0[55][20];
          new_coeff0_21 = coeff0_0*dmats0[0][21] + coeff0_1*dmats0[1][21] + coeff0_2*dmats0[2][21] + coeff0_3*dmats0[3][21] + coeff0_4*dmats0[4][21] + coeff0_5*dmats0[5][21] + coeff0_6*dmats0[6][21] + coeff0_7*dmats0[7][21] + coeff0_8*dmats0[8][21] + coeff0_9*dmats0[9][21] + coeff0_10*dmats0[10][21] + coeff0_11*dmats0[11][21] + coeff0_12*dmats0[12][21] + coeff0_13*dmats0[13][21] + coeff0_14*dmats0[14][21] + coeff0_15*dmats0[15][21] + coeff0_16*dmats0[16][21] + coeff0_17*dmats0[17][21] + coeff0_18*dmats0[18][21] + coeff0_19*dmats0[19][21] + coeff0_20*dmats0[20][21] + coeff0_21*dmats0[21][21] + coeff0_22*dmats0[22][21] + coeff0_23*dmats0[23][21] + coeff0_24*dmats0[24][21] + coeff0_25*dmats0[25][21] + coeff0_26*dmats0[26][21] + coeff0_27*dmats0[27][21] + coeff0_28*dmats0[28][21] + coeff0_29*dmats0[29][21] + coeff0_30*dmats0[30][21] + coeff0_31*dmats0[31][21] + coeff0_32*dmats0[32][21] + coeff0_33*dmats0[33][21] + coeff0_34*dmats0[34][21] + coeff0_35*dmats0[35][21] + coeff0_36*dmats0[36][21] + coeff0_37*dmats0[37][21] + coeff0_38*dmats0[38][21] + coeff0_39*dmats0[39][21] + coeff0_40*dmats0[40][21] + coeff0_41*dmats0[41][21] + coeff0_42*dmats0[42][21] + coeff0_43*dmats0[43][21] + coeff0_44*dmats0[44][21] + coeff0_45*dmats0[45][21] + coeff0_46*dmats0[46][21] + coeff0_47*dmats0[47][21] + coeff0_48*dmats0[48][21] + coeff0_49*dmats0[49][21] + coeff0_50*dmats0[50][21] + coeff0_51*dmats0[51][21] + coeff0_52*dmats0[52][21] + coeff0_53*dmats0[53][21] + coeff0_54*dmats0[54][21] + coeff0_55*dmats0[55][21];
          new_coeff0_22 = coeff0_0*dmats0[0][22] + coeff0_1*dmats0[1][22] + coeff0_2*dmats0[2][22] + coeff0_3*dmats0[3][22] + coeff0_4*dmats0[4][22] + coeff0_5*dmats0[5][22] + coeff0_6*dmats0[6][22] + coeff0_7*dmats0[7][22] + coeff0_8*dmats0[8][22] + coeff0_9*dmats0[9][22] + coeff0_10*dmats0[10][22] + coeff0_11*dmats0[11][22] + coeff0_12*dmats0[12][22] + coeff0_13*dmats0[13][22] + coeff0_14*dmats0[14][22] + coeff0_15*dmats0[15][22] + coeff0_16*dmats0[16][22] + coeff0_17*dmats0[17][22] + coeff0_18*dmats0[18][22] + coeff0_19*dmats0[19][22] + coeff0_20*dmats0[20][22] + coeff0_21*dmats0[21][22] + coeff0_22*dmats0[22][22] + coeff0_23*dmats0[23][22] + coeff0_24*dmats0[24][22] + coeff0_25*dmats0[25][22] + coeff0_26*dmats0[26][22] + coeff0_27*dmats0[27][22] + coeff0_28*dmats0[28][22] + coeff0_29*dmats0[29][22] + coeff0_30*dmats0[30][22] + coeff0_31*dmats0[31][22] + coeff0_32*dmats0[32][22] + coeff0_33*dmats0[33][22] + coeff0_34*dmats0[34][22] + coeff0_35*dmats0[35][22] + coeff0_36*dmats0[36][22] + coeff0_37*dmats0[37][22] + coeff0_38*dmats0[38][22] + coeff0_39*dmats0[39][22] + coeff0_40*dmats0[40][22] + coeff0_41*dmats0[41][22] + coeff0_42*dmats0[42][22] + coeff0_43*dmats0[43][22] + coeff0_44*dmats0[44][22] + coeff0_45*dmats0[45][22] + coeff0_46*dmats0[46][22] + coeff0_47*dmats0[47][22] + coeff0_48*dmats0[48][22] + coeff0_49*dmats0[49][22] + coeff0_50*dmats0[50][22] + coeff0_51*dmats0[51][22] + coeff0_52*dmats0[52][22] + coeff0_53*dmats0[53][22] + coeff0_54*dmats0[54][22] + coeff0_55*dmats0[55][22];
          new_coeff0_23 = coeff0_0*dmats0[0][23] + coeff0_1*dmats0[1][23] + coeff0_2*dmats0[2][23] + coeff0_3*dmats0[3][23] + coeff0_4*dmats0[4][23] + coeff0_5*dmats0[5][23] + coeff0_6*dmats0[6][23] + coeff0_7*dmats0[7][23] + coeff0_8*dmats0[8][23] + coeff0_9*dmats0[9][23] + coeff0_10*dmats0[10][23] + coeff0_11*dmats0[11][23] + coeff0_12*dmats0[12][23] + coeff0_13*dmats0[13][23] + coeff0_14*dmats0[14][23] + coeff0_15*dmats0[15][23] + coeff0_16*dmats0[16][23] + coeff0_17*dmats0[17][23] + coeff0_18*dmats0[18][23] + coeff0_19*dmats0[19][23] + coeff0_20*dmats0[20][23] + coeff0_21*dmats0[21][23] + coeff0_22*dmats0[22][23] + coeff0_23*dmats0[23][23] + coeff0_24*dmats0[24][23] + coeff0_25*dmats0[25][23] + coeff0_26*dmats0[26][23] + coeff0_27*dmats0[27][23] + coeff0_28*dmats0[28][23] + coeff0_29*dmats0[29][23] + coeff0_30*dmats0[30][23] + coeff0_31*dmats0[31][23] + coeff0_32*dmats0[32][23] + coeff0_33*dmats0[33][23] + coeff0_34*dmats0[34][23] + coeff0_35*dmats0[35][23] + coeff0_36*dmats0[36][23] + coeff0_37*dmats0[37][23] + coeff0_38*dmats0[38][23] + coeff0_39*dmats0[39][23] + coeff0_40*dmats0[40][23] + coeff0_41*dmats0[41][23] + coeff0_42*dmats0[42][23] + coeff0_43*dmats0[43][23] + coeff0_44*dmats0[44][23] + coeff0_45*dmats0[45][23] + coeff0_46*dmats0[46][23] + coeff0_47*dmats0[47][23] + coeff0_48*dmats0[48][23] + coeff0_49*dmats0[49][23] + coeff0_50*dmats0[50][23] + coeff0_51*dmats0[51][23] + coeff0_52*dmats0[52][23] + coeff0_53*dmats0[53][23] + coeff0_54*dmats0[54][23] + coeff0_55*dmats0[55][23];
          new_coeff0_24 = coeff0_0*dmats0[0][24] + coeff0_1*dmats0[1][24] + coeff0_2*dmats0[2][24] + coeff0_3*dmats0[3][24] + coeff0_4*dmats0[4][24] + coeff0_5*dmats0[5][24] + coeff0_6*dmats0[6][24] + coeff0_7*dmats0[7][24] + coeff0_8*dmats0[8][24] + coeff0_9*dmats0[9][24] + coeff0_10*dmats0[10][24] + coeff0_11*dmats0[11][24] + coeff0_12*dmats0[12][24] + coeff0_13*dmats0[13][24] + coeff0_14*dmats0[14][24] + coeff0_15*dmats0[15][24] + coeff0_16*dmats0[16][24] + coeff0_17*dmats0[17][24] + coeff0_18*dmats0[18][24] + coeff0_19*dmats0[19][24] + coeff0_20*dmats0[20][24] + coeff0_21*dmats0[21][24] + coeff0_22*dmats0[22][24] + coeff0_23*dmats0[23][24] + coeff0_24*dmats0[24][24] + coeff0_25*dmats0[25][24] + coeff0_26*dmats0[26][24] + coeff0_27*dmats0[27][24] + coeff0_28*dmats0[28][24] + coeff0_29*dmats0[29][24] + coeff0_30*dmats0[30][24] + coeff0_31*dmats0[31][24] + coeff0_32*dmats0[32][24] + coeff0_33*dmats0[33][24] + coeff0_34*dmats0[34][24] + coeff0_35*dmats0[35][24] + coeff0_36*dmats0[36][24] + coeff0_37*dmats0[37][24] + coeff0_38*dmats0[38][24] + coeff0_39*dmats0[39][24] + coeff0_40*dmats0[40][24] + coeff0_41*dmats0[41][24] + coeff0_42*dmats0[42][24] + coeff0_43*dmats0[43][24] + coeff0_44*dmats0[44][24] + coeff0_45*dmats0[45][24] + coeff0_46*dmats0[46][24] + coeff0_47*dmats0[47][24] + coeff0_48*dmats0[48][24] + coeff0_49*dmats0[49][24] + coeff0_50*dmats0[50][24] + coeff0_51*dmats0[51][24] + coeff0_52*dmats0[52][24] + coeff0_53*dmats0[53][24] + coeff0_54*dmats0[54][24] + coeff0_55*dmats0[55][24];
          new_coeff0_25 = coeff0_0*dmats0[0][25] + coeff0_1*dmats0[1][25] + coeff0_2*dmats0[2][25] + coeff0_3*dmats0[3][25] + coeff0_4*dmats0[4][25] + coeff0_5*dmats0[5][25] + coeff0_6*dmats0[6][25] + coeff0_7*dmats0[7][25] + coeff0_8*dmats0[8][25] + coeff0_9*dmats0[9][25] + coeff0_10*dmats0[10][25] + coeff0_11*dmats0[11][25] + coeff0_12*dmats0[12][25] + coeff0_13*dmats0[13][25] + coeff0_14*dmats0[14][25] + coeff0_15*dmats0[15][25] + coeff0_16*dmats0[16][25] + coeff0_17*dmats0[17][25] + coeff0_18*dmats0[18][25] + coeff0_19*dmats0[19][25] + coeff0_20*dmats0[20][25] + coeff0_21*dmats0[21][25] + coeff0_22*dmats0[22][25] + coeff0_23*dmats0[23][25] + coeff0_24*dmats0[24][25] + coeff0_25*dmats0[25][25] + coeff0_26*dmats0[26][25] + coeff0_27*dmats0[27][25] + coeff0_28*dmats0[28][25] + coeff0_29*dmats0[29][25] + coeff0_30*dmats0[30][25] + coeff0_31*dmats0[31][25] + coeff0_32*dmats0[32][25] + coeff0_33*dmats0[33][25] + coeff0_34*dmats0[34][25] + coeff0_35*dmats0[35][25] + coeff0_36*dmats0[36][25] + coeff0_37*dmats0[37][25] + coeff0_38*dmats0[38][25] + coeff0_39*dmats0[39][25] + coeff0_40*dmats0[40][25] + coeff0_41*dmats0[41][25] + coeff0_42*dmats0[42][25] + coeff0_43*dmats0[43][25] + coeff0_44*dmats0[44][25] + coeff0_45*dmats0[45][25] + coeff0_46*dmats0[46][25] + coeff0_47*dmats0[47][25] + coeff0_48*dmats0[48][25] + coeff0_49*dmats0[49][25] + coeff0_50*dmats0[50][25] + coeff0_51*dmats0[51][25] + coeff0_52*dmats0[52][25] + coeff0_53*dmats0[53][25] + coeff0_54*dmats0[54][25] + coeff0_55*dmats0[55][25];
          new_coeff0_26 = coeff0_0*dmats0[0][26] + coeff0_1*dmats0[1][26] + coeff0_2*dmats0[2][26] + coeff0_3*dmats0[3][26] + coeff0_4*dmats0[4][26] + coeff0_5*dmats0[5][26] + coeff0_6*dmats0[6][26] + coeff0_7*dmats0[7][26] + coeff0_8*dmats0[8][26] + coeff0_9*dmats0[9][26] + coeff0_10*dmats0[10][26] + coeff0_11*dmats0[11][26] + coeff0_12*dmats0[12][26] + coeff0_13*dmats0[13][26] + coeff0_14*dmats0[14][26] + coeff0_15*dmats0[15][26] + coeff0_16*dmats0[16][26] + coeff0_17*dmats0[17][26] + coeff0_18*dmats0[18][26] + coeff0_19*dmats0[19][26] + coeff0_20*dmats0[20][26] + coeff0_21*dmats0[21][26] + coeff0_22*dmats0[22][26] + coeff0_23*dmats0[23][26] + coeff0_24*dmats0[24][26] + coeff0_25*dmats0[25][26] + coeff0_26*dmats0[26][26] + coeff0_27*dmats0[27][26] + coeff0_28*dmats0[28][26] + coeff0_29*dmats0[29][26] + coeff0_30*dmats0[30][26] + coeff0_31*dmats0[31][26] + coeff0_32*dmats0[32][26] + coeff0_33*dmats0[33][26] + coeff0_34*dmats0[34][26] + coeff0_35*dmats0[35][26] + coeff0_36*dmats0[36][26] + coeff0_37*dmats0[37][26] + coeff0_38*dmats0[38][26] + coeff0_39*dmats0[39][26] + coeff0_40*dmats0[40][26] + coeff0_41*dmats0[41][26] + coeff0_42*dmats0[42][26] + coeff0_43*dmats0[43][26] + coeff0_44*dmats0[44][26] + coeff0_45*dmats0[45][26] + coeff0_46*dmats0[46][26] + coeff0_47*dmats0[47][26] + coeff0_48*dmats0[48][26] + coeff0_49*dmats0[49][26] + coeff0_50*dmats0[50][26] + coeff0_51*dmats0[51][26] + coeff0_52*dmats0[52][26] + coeff0_53*dmats0[53][26] + coeff0_54*dmats0[54][26] + coeff0_55*dmats0[55][26];
          new_coeff0_27 = coeff0_0*dmats0[0][27] + coeff0_1*dmats0[1][27] + coeff0_2*dmats0[2][27] + coeff0_3*dmats0[3][27] + coeff0_4*dmats0[4][27] + coeff0_5*dmats0[5][27] + coeff0_6*dmats0[6][27] + coeff0_7*dmats0[7][27] + coeff0_8*dmats0[8][27] + coeff0_9*dmats0[9][27] + coeff0_10*dmats0[10][27] + coeff0_11*dmats0[11][27] + coeff0_12*dmats0[12][27] + coeff0_13*dmats0[13][27] + coeff0_14*dmats0[14][27] + coeff0_15*dmats0[15][27] + coeff0_16*dmats0[16][27] + coeff0_17*dmats0[17][27] + coeff0_18*dmats0[18][27] + coeff0_19*dmats0[19][27] + coeff0_20*dmats0[20][27] + coeff0_21*dmats0[21][27] + coeff0_22*dmats0[22][27] + coeff0_23*dmats0[23][27] + coeff0_24*dmats0[24][27] + coeff0_25*dmats0[25][27] + coeff0_26*dmats0[26][27] + coeff0_27*dmats0[27][27] + coeff0_28*dmats0[28][27] + coeff0_29*dmats0[29][27] + coeff0_30*dmats0[30][27] + coeff0_31*dmats0[31][27] + coeff0_32*dmats0[32][27] + coeff0_33*dmats0[33][27] + coeff0_34*dmats0[34][27] + coeff0_35*dmats0[35][27] + coeff0_36*dmats0[36][27] + coeff0_37*dmats0[37][27] + coeff0_38*dmats0[38][27] + coeff0_39*dmats0[39][27] + coeff0_40*dmats0[40][27] + coeff0_41*dmats0[41][27] + coeff0_42*dmats0[42][27] + coeff0_43*dmats0[43][27] + coeff0_44*dmats0[44][27] + coeff0_45*dmats0[45][27] + coeff0_46*dmats0[46][27] + coeff0_47*dmats0[47][27] + coeff0_48*dmats0[48][27] + coeff0_49*dmats0[49][27] + coeff0_50*dmats0[50][27] + coeff0_51*dmats0[51][27] + coeff0_52*dmats0[52][27] + coeff0_53*dmats0[53][27] + coeff0_54*dmats0[54][27] + coeff0_55*dmats0[55][27];
          new_coeff0_28 = coeff0_0*dmats0[0][28] + coeff0_1*dmats0[1][28] + coeff0_2*dmats0[2][28] + coeff0_3*dmats0[3][28] + coeff0_4*dmats0[4][28] + coeff0_5*dmats0[5][28] + coeff0_6*dmats0[6][28] + coeff0_7*dmats0[7][28] + coeff0_8*dmats0[8][28] + coeff0_9*dmats0[9][28] + coeff0_10*dmats0[10][28] + coeff0_11*dmats0[11][28] + coeff0_12*dmats0[12][28] + coeff0_13*dmats0[13][28] + coeff0_14*dmats0[14][28] + coeff0_15*dmats0[15][28] + coeff0_16*dmats0[16][28] + coeff0_17*dmats0[17][28] + coeff0_18*dmats0[18][28] + coeff0_19*dmats0[19][28] + coeff0_20*dmats0[20][28] + coeff0_21*dmats0[21][28] + coeff0_22*dmats0[22][28] + coeff0_23*dmats0[23][28] + coeff0_24*dmats0[24][28] + coeff0_25*dmats0[25][28] + coeff0_26*dmats0[26][28] + coeff0_27*dmats0[27][28] + coeff0_28*dmats0[28][28] + coeff0_29*dmats0[29][28] + coeff0_30*dmats0[30][28] + coeff0_31*dmats0[31][28] + coeff0_32*dmats0[32][28] + coeff0_33*dmats0[33][28] + coeff0_34*dmats0[34][28] + coeff0_35*dmats0[35][28] + coeff0_36*dmats0[36][28] + coeff0_37*dmats0[37][28] + coeff0_38*dmats0[38][28] + coeff0_39*dmats0[39][28] + coeff0_40*dmats0[40][28] + coeff0_41*dmats0[41][28] + coeff0_42*dmats0[42][28] + coeff0_43*dmats0[43][28] + coeff0_44*dmats0[44][28] + coeff0_45*dmats0[45][28] + coeff0_46*dmats0[46][28] + coeff0_47*dmats0[47][28] + coeff0_48*dmats0[48][28] + coeff0_49*dmats0[49][28] + coeff0_50*dmats0[50][28] + coeff0_51*dmats0[51][28] + coeff0_52*dmats0[52][28] + coeff0_53*dmats0[53][28] + coeff0_54*dmats0[54][28] + coeff0_55*dmats0[55][28];
          new_coeff0_29 = coeff0_0*dmats0[0][29] + coeff0_1*dmats0[1][29] + coeff0_2*dmats0[2][29] + coeff0_3*dmats0[3][29] + coeff0_4*dmats0[4][29] + coeff0_5*dmats0[5][29] + coeff0_6*dmats0[6][29] + coeff0_7*dmats0[7][29] + coeff0_8*dmats0[8][29] + coeff0_9*dmats0[9][29] + coeff0_10*dmats0[10][29] + coeff0_11*dmats0[11][29] + coeff0_12*dmats0[12][29] + coeff0_13*dmats0[13][29] + coeff0_14*dmats0[14][29] + coeff0_15*dmats0[15][29] + coeff0_16*dmats0[16][29] + coeff0_17*dmats0[17][29] + coeff0_18*dmats0[18][29] + coeff0_19*dmats0[19][29] + coeff0_20*dmats0[20][29] + coeff0_21*dmats0[21][29] + coeff0_22*dmats0[22][29] + coeff0_23*dmats0[23][29] + coeff0_24*dmats0[24][29] + coeff0_25*dmats0[25][29] + coeff0_26*dmats0[26][29] + coeff0_27*dmats0[27][29] + coeff0_28*dmats0[28][29] + coeff0_29*dmats0[29][29] + coeff0_30*dmats0[30][29] + coeff0_31*dmats0[31][29] + coeff0_32*dmats0[32][29] + coeff0_33*dmats0[33][29] + coeff0_34*dmats0[34][29] + coeff0_35*dmats0[35][29] + coeff0_36*dmats0[36][29] + coeff0_37*dmats0[37][29] + coeff0_38*dmats0[38][29] + coeff0_39*dmats0[39][29] + coeff0_40*dmats0[40][29] + coeff0_41*dmats0[41][29] + coeff0_42*dmats0[42][29] + coeff0_43*dmats0[43][29] + coeff0_44*dmats0[44][29] + coeff0_45*dmats0[45][29] + coeff0_46*dmats0[46][29] + coeff0_47*dmats0[47][29] + coeff0_48*dmats0[48][29] + coeff0_49*dmats0[49][29] + coeff0_50*dmats0[50][29] + coeff0_51*dmats0[51][29] + coeff0_52*dmats0[52][29] + coeff0_53*dmats0[53][29] + coeff0_54*dmats0[54][29] + coeff0_55*dmats0[55][29];
          new_coeff0_30 = coeff0_0*dmats0[0][30] + coeff0_1*dmats0[1][30] + coeff0_2*dmats0[2][30] + coeff0_3*dmats0[3][30] + coeff0_4*dmats0[4][30] + coeff0_5*dmats0[5][30] + coeff0_6*dmats0[6][30] + coeff0_7*dmats0[7][30] + coeff0_8*dmats0[8][30] + coeff0_9*dmats0[9][30] + coeff0_10*dmats0[10][30] + coeff0_11*dmats0[11][30] + coeff0_12*dmats0[12][30] + coeff0_13*dmats0[13][30] + coeff0_14*dmats0[14][30] + coeff0_15*dmats0[15][30] + coeff0_16*dmats0[16][30] + coeff0_17*dmats0[17][30] + coeff0_18*dmats0[18][30] + coeff0_19*dmats0[19][30] + coeff0_20*dmats0[20][30] + coeff0_21*dmats0[21][30] + coeff0_22*dmats0[22][30] + coeff0_23*dmats0[23][30] + coeff0_24*dmats0[24][30] + coeff0_25*dmats0[25][30] + coeff0_26*dmats0[26][30] + coeff0_27*dmats0[27][30] + coeff0_28*dmats0[28][30] + coeff0_29*dmats0[29][30] + coeff0_30*dmats0[30][30] + coeff0_31*dmats0[31][30] + coeff0_32*dmats0[32][30] + coeff0_33*dmats0[33][30] + coeff0_34*dmats0[34][30] + coeff0_35*dmats0[35][30] + coeff0_36*dmats0[36][30] + coeff0_37*dmats0[37][30] + coeff0_38*dmats0[38][30] + coeff0_39*dmats0[39][30] + coeff0_40*dmats0[40][30] + coeff0_41*dmats0[41][30] + coeff0_42*dmats0[42][30] + coeff0_43*dmats0[43][30] + coeff0_44*dmats0[44][30] + coeff0_45*dmats0[45][30] + coeff0_46*dmats0[46][30] + coeff0_47*dmats0[47][30] + coeff0_48*dmats0[48][30] + coeff0_49*dmats0[49][30] + coeff0_50*dmats0[50][30] + coeff0_51*dmats0[51][30] + coeff0_52*dmats0[52][30] + coeff0_53*dmats0[53][30] + coeff0_54*dmats0[54][30] + coeff0_55*dmats0[55][30];
          new_coeff0_31 = coeff0_0*dmats0[0][31] + coeff0_1*dmats0[1][31] + coeff0_2*dmats0[2][31] + coeff0_3*dmats0[3][31] + coeff0_4*dmats0[4][31] + coeff0_5*dmats0[5][31] + coeff0_6*dmats0[6][31] + coeff0_7*dmats0[7][31] + coeff0_8*dmats0[8][31] + coeff0_9*dmats0[9][31] + coeff0_10*dmats0[10][31] + coeff0_11*dmats0[11][31] + coeff0_12*dmats0[12][31] + coeff0_13*dmats0[13][31] + coeff0_14*dmats0[14][31] + coeff0_15*dmats0[15][31] + coeff0_16*dmats0[16][31] + coeff0_17*dmats0[17][31] + coeff0_18*dmats0[18][31] + coeff0_19*dmats0[19][31] + coeff0_20*dmats0[20][31] + coeff0_21*dmats0[21][31] + coeff0_22*dmats0[22][31] + coeff0_23*dmats0[23][31] + coeff0_24*dmats0[24][31] + coeff0_25*dmats0[25][31] + coeff0_26*dmats0[26][31] + coeff0_27*dmats0[27][31] + coeff0_28*dmats0[28][31] + coeff0_29*dmats0[29][31] + coeff0_30*dmats0[30][31] + coeff0_31*dmats0[31][31] + coeff0_32*dmats0[32][31] + coeff0_33*dmats0[33][31] + coeff0_34*dmats0[34][31] + coeff0_35*dmats0[35][31] + coeff0_36*dmats0[36][31] + coeff0_37*dmats0[37][31] + coeff0_38*dmats0[38][31] + coeff0_39*dmats0[39][31] + coeff0_40*dmats0[40][31] + coeff0_41*dmats0[41][31] + coeff0_42*dmats0[42][31] + coeff0_43*dmats0[43][31] + coeff0_44*dmats0[44][31] + coeff0_45*dmats0[45][31] + coeff0_46*dmats0[46][31] + coeff0_47*dmats0[47][31] + coeff0_48*dmats0[48][31] + coeff0_49*dmats0[49][31] + coeff0_50*dmats0[50][31] + coeff0_51*dmats0[51][31] + coeff0_52*dmats0[52][31] + coeff0_53*dmats0[53][31] + coeff0_54*dmats0[54][31] + coeff0_55*dmats0[55][31];
          new_coeff0_32 = coeff0_0*dmats0[0][32] + coeff0_1*dmats0[1][32] + coeff0_2*dmats0[2][32] + coeff0_3*dmats0[3][32] + coeff0_4*dmats0[4][32] + coeff0_5*dmats0[5][32] + coeff0_6*dmats0[6][32] + coeff0_7*dmats0[7][32] + coeff0_8*dmats0[8][32] + coeff0_9*dmats0[9][32] + coeff0_10*dmats0[10][32] + coeff0_11*dmats0[11][32] + coeff0_12*dmats0[12][32] + coeff0_13*dmats0[13][32] + coeff0_14*dmats0[14][32] + coeff0_15*dmats0[15][32] + coeff0_16*dmats0[16][32] + coeff0_17*dmats0[17][32] + coeff0_18*dmats0[18][32] + coeff0_19*dmats0[19][32] + coeff0_20*dmats0[20][32] + coeff0_21*dmats0[21][32] + coeff0_22*dmats0[22][32] + coeff0_23*dmats0[23][32] + coeff0_24*dmats0[24][32] + coeff0_25*dmats0[25][32] + coeff0_26*dmats0[26][32] + coeff0_27*dmats0[27][32] + coeff0_28*dmats0[28][32] + coeff0_29*dmats0[29][32] + coeff0_30*dmats0[30][32] + coeff0_31*dmats0[31][32] + coeff0_32*dmats0[32][32] + coeff0_33*dmats0[33][32] + coeff0_34*dmats0[34][32] + coeff0_35*dmats0[35][32] + coeff0_36*dmats0[36][32] + coeff0_37*dmats0[37][32] + coeff0_38*dmats0[38][32] + coeff0_39*dmats0[39][32] + coeff0_40*dmats0[40][32] + coeff0_41*dmats0[41][32] + coeff0_42*dmats0[42][32] + coeff0_43*dmats0[43][32] + coeff0_44*dmats0[44][32] + coeff0_45*dmats0[45][32] + coeff0_46*dmats0[46][32] + coeff0_47*dmats0[47][32] + coeff0_48*dmats0[48][32] + coeff0_49*dmats0[49][32] + coeff0_50*dmats0[50][32] + coeff0_51*dmats0[51][32] + coeff0_52*dmats0[52][32] + coeff0_53*dmats0[53][32] + coeff0_54*dmats0[54][32] + coeff0_55*dmats0[55][32];
          new_coeff0_33 = coeff0_0*dmats0[0][33] + coeff0_1*dmats0[1][33] + coeff0_2*dmats0[2][33] + coeff0_3*dmats0[3][33] + coeff0_4*dmats0[4][33] + coeff0_5*dmats0[5][33] + coeff0_6*dmats0[6][33] + coeff0_7*dmats0[7][33] + coeff0_8*dmats0[8][33] + coeff0_9*dmats0[9][33] + coeff0_10*dmats0[10][33] + coeff0_11*dmats0[11][33] + coeff0_12*dmats0[12][33] + coeff0_13*dmats0[13][33] + coeff0_14*dmats0[14][33] + coeff0_15*dmats0[15][33] + coeff0_16*dmats0[16][33] + coeff0_17*dmats0[17][33] + coeff0_18*dmats0[18][33] + coeff0_19*dmats0[19][33] + coeff0_20*dmats0[20][33] + coeff0_21*dmats0[21][33] + coeff0_22*dmats0[22][33] + coeff0_23*dmats0[23][33] + coeff0_24*dmats0[24][33] + coeff0_25*dmats0[25][33] + coeff0_26*dmats0[26][33] + coeff0_27*dmats0[27][33] + coeff0_28*dmats0[28][33] + coeff0_29*dmats0[29][33] + coeff0_30*dmats0[30][33] + coeff0_31*dmats0[31][33] + coeff0_32*dmats0[32][33] + coeff0_33*dmats0[33][33] + coeff0_34*dmats0[34][33] + coeff0_35*dmats0[35][33] + coeff0_36*dmats0[36][33] + coeff0_37*dmats0[37][33] + coeff0_38*dmats0[38][33] + coeff0_39*dmats0[39][33] + coeff0_40*dmats0[40][33] + coeff0_41*dmats0[41][33] + coeff0_42*dmats0[42][33] + coeff0_43*dmats0[43][33] + coeff0_44*dmats0[44][33] + coeff0_45*dmats0[45][33] + coeff0_46*dmats0[46][33] + coeff0_47*dmats0[47][33] + coeff0_48*dmats0[48][33] + coeff0_49*dmats0[49][33] + coeff0_50*dmats0[50][33] + coeff0_51*dmats0[51][33] + coeff0_52*dmats0[52][33] + coeff0_53*dmats0[53][33] + coeff0_54*dmats0[54][33] + coeff0_55*dmats0[55][33];
          new_coeff0_34 = coeff0_0*dmats0[0][34] + coeff0_1*dmats0[1][34] + coeff0_2*dmats0[2][34] + coeff0_3*dmats0[3][34] + coeff0_4*dmats0[4][34] + coeff0_5*dmats0[5][34] + coeff0_6*dmats0[6][34] + coeff0_7*dmats0[7][34] + coeff0_8*dmats0[8][34] + coeff0_9*dmats0[9][34] + coeff0_10*dmats0[10][34] + coeff0_11*dmats0[11][34] + coeff0_12*dmats0[12][34] + coeff0_13*dmats0[13][34] + coeff0_14*dmats0[14][34] + coeff0_15*dmats0[15][34] + coeff0_16*dmats0[16][34] + coeff0_17*dmats0[17][34] + coeff0_18*dmats0[18][34] + coeff0_19*dmats0[19][34] + coeff0_20*dmats0[20][34] + coeff0_21*dmats0[21][34] + coeff0_22*dmats0[22][34] + coeff0_23*dmats0[23][34] + coeff0_24*dmats0[24][34] + coeff0_25*dmats0[25][34] + coeff0_26*dmats0[26][34] + coeff0_27*dmats0[27][34] + coeff0_28*dmats0[28][34] + coeff0_29*dmats0[29][34] + coeff0_30*dmats0[30][34] + coeff0_31*dmats0[31][34] + coeff0_32*dmats0[32][34] + coeff0_33*dmats0[33][34] + coeff0_34*dmats0[34][34] + coeff0_35*dmats0[35][34] + coeff0_36*dmats0[36][34] + coeff0_37*dmats0[37][34] + coeff0_38*dmats0[38][34] + coeff0_39*dmats0[39][34] + coeff0_40*dmats0[40][34] + coeff0_41*dmats0[41][34] + coeff0_42*dmats0[42][34] + coeff0_43*dmats0[43][34] + coeff0_44*dmats0[44][34] + coeff0_45*dmats0[45][34] + coeff0_46*dmats0[46][34] + coeff0_47*dmats0[47][34] + coeff0_48*dmats0[48][34] + coeff0_49*dmats0[49][34] + coeff0_50*dmats0[50][34] + coeff0_51*dmats0[51][34] + coeff0_52*dmats0[52][34] + coeff0_53*dmats0[53][34] + coeff0_54*dmats0[54][34] + coeff0_55*dmats0[55][34];
          new_coeff0_35 = coeff0_0*dmats0[0][35] + coeff0_1*dmats0[1][35] + coeff0_2*dmats0[2][35] + coeff0_3*dmats0[3][35] + coeff0_4*dmats0[4][35] + coeff0_5*dmats0[5][35] + coeff0_6*dmats0[6][35] + coeff0_7*dmats0[7][35] + coeff0_8*dmats0[8][35] + coeff0_9*dmats0[9][35] + coeff0_10*dmats0[10][35] + coeff0_11*dmats0[11][35] + coeff0_12*dmats0[12][35] + coeff0_13*dmats0[13][35] + coeff0_14*dmats0[14][35] + coeff0_15*dmats0[15][35] + coeff0_16*dmats0[16][35] + coeff0_17*dmats0[17][35] + coeff0_18*dmats0[18][35] + coeff0_19*dmats0[19][35] + coeff0_20*dmats0[20][35] + coeff0_21*dmats0[21][35] + coeff0_22*dmats0[22][35] + coeff0_23*dmats0[23][35] + coeff0_24*dmats0[24][35] + coeff0_25*dmats0[25][35] + coeff0_26*dmats0[26][35] + coeff0_27*dmats0[27][35] + coeff0_28*dmats0[28][35] + coeff0_29*dmats0[29][35] + coeff0_30*dmats0[30][35] + coeff0_31*dmats0[31][35] + coeff0_32*dmats0[32][35] + coeff0_33*dmats0[33][35] + coeff0_34*dmats0[34][35] + coeff0_35*dmats0[35][35] + coeff0_36*dmats0[36][35] + coeff0_37*dmats0[37][35] + coeff0_38*dmats0[38][35] + coeff0_39*dmats0[39][35] + coeff0_40*dmats0[40][35] + coeff0_41*dmats0[41][35] + coeff0_42*dmats0[42][35] + coeff0_43*dmats0[43][35] + coeff0_44*dmats0[44][35] + coeff0_45*dmats0[45][35] + coeff0_46*dmats0[46][35] + coeff0_47*dmats0[47][35] + coeff0_48*dmats0[48][35] + coeff0_49*dmats0[49][35] + coeff0_50*dmats0[50][35] + coeff0_51*dmats0[51][35] + coeff0_52*dmats0[52][35] + coeff0_53*dmats0[53][35] + coeff0_54*dmats0[54][35] + coeff0_55*dmats0[55][35];
          new_coeff0_36 = coeff0_0*dmats0[0][36] + coeff0_1*dmats0[1][36] + coeff0_2*dmats0[2][36] + coeff0_3*dmats0[3][36] + coeff0_4*dmats0[4][36] + coeff0_5*dmats0[5][36] + coeff0_6*dmats0[6][36] + coeff0_7*dmats0[7][36] + coeff0_8*dmats0[8][36] + coeff0_9*dmats0[9][36] + coeff0_10*dmats0[10][36] + coeff0_11*dmats0[11][36] + coeff0_12*dmats0[12][36] + coeff0_13*dmats0[13][36] + coeff0_14*dmats0[14][36] + coeff0_15*dmats0[15][36] + coeff0_16*dmats0[16][36] + coeff0_17*dmats0[17][36] + coeff0_18*dmats0[18][36] + coeff0_19*dmats0[19][36] + coeff0_20*dmats0[20][36] + coeff0_21*dmats0[21][36] + coeff0_22*dmats0[22][36] + coeff0_23*dmats0[23][36] + coeff0_24*dmats0[24][36] + coeff0_25*dmats0[25][36] + coeff0_26*dmats0[26][36] + coeff0_27*dmats0[27][36] + coeff0_28*dmats0[28][36] + coeff0_29*dmats0[29][36] + coeff0_30*dmats0[30][36] + coeff0_31*dmats0[31][36] + coeff0_32*dmats0[32][36] + coeff0_33*dmats0[33][36] + coeff0_34*dmats0[34][36] + coeff0_35*dmats0[35][36] + coeff0_36*dmats0[36][36] + coeff0_37*dmats0[37][36] + coeff0_38*dmats0[38][36] + coeff0_39*dmats0[39][36] + coeff0_40*dmats0[40][36] + coeff0_41*dmats0[41][36] + coeff0_42*dmats0[42][36] + coeff0_43*dmats0[43][36] + coeff0_44*dmats0[44][36] + coeff0_45*dmats0[45][36] + coeff0_46*dmats0[46][36] + coeff0_47*dmats0[47][36] + coeff0_48*dmats0[48][36] + coeff0_49*dmats0[49][36] + coeff0_50*dmats0[50][36] + coeff0_51*dmats0[51][36] + coeff0_52*dmats0[52][36] + coeff0_53*dmats0[53][36] + coeff0_54*dmats0[54][36] + coeff0_55*dmats0[55][36];
          new_coeff0_37 = coeff0_0*dmats0[0][37] + coeff0_1*dmats0[1][37] + coeff0_2*dmats0[2][37] + coeff0_3*dmats0[3][37] + coeff0_4*dmats0[4][37] + coeff0_5*dmats0[5][37] + coeff0_6*dmats0[6][37] + coeff0_7*dmats0[7][37] + coeff0_8*dmats0[8][37] + coeff0_9*dmats0[9][37] + coeff0_10*dmats0[10][37] + coeff0_11*dmats0[11][37] + coeff0_12*dmats0[12][37] + coeff0_13*dmats0[13][37] + coeff0_14*dmats0[14][37] + coeff0_15*dmats0[15][37] + coeff0_16*dmats0[16][37] + coeff0_17*dmats0[17][37] + coeff0_18*dmats0[18][37] + coeff0_19*dmats0[19][37] + coeff0_20*dmats0[20][37] + coeff0_21*dmats0[21][37] + coeff0_22*dmats0[22][37] + coeff0_23*dmats0[23][37] + coeff0_24*dmats0[24][37] + coeff0_25*dmats0[25][37] + coeff0_26*dmats0[26][37] + coeff0_27*dmats0[27][37] + coeff0_28*dmats0[28][37] + coeff0_29*dmats0[29][37] + coeff0_30*dmats0[30][37] + coeff0_31*dmats0[31][37] + coeff0_32*dmats0[32][37] + coeff0_33*dmats0[33][37] + coeff0_34*dmats0[34][37] + coeff0_35*dmats0[35][37] + coeff0_36*dmats0[36][37] + coeff0_37*dmats0[37][37] + coeff0_38*dmats0[38][37] + coeff0_39*dmats0[39][37] + coeff0_40*dmats0[40][37] + coeff0_41*dmats0[41][37] + coeff0_42*dmats0[42][37] + coeff0_43*dmats0[43][37] + coeff0_44*dmats0[44][37] + coeff0_45*dmats0[45][37] + coeff0_46*dmats0[46][37] + coeff0_47*dmats0[47][37] + coeff0_48*dmats0[48][37] + coeff0_49*dmats0[49][37] + coeff0_50*dmats0[50][37] + coeff0_51*dmats0[51][37] + coeff0_52*dmats0[52][37] + coeff0_53*dmats0[53][37] + coeff0_54*dmats0[54][37] + coeff0_55*dmats0[55][37];
          new_coeff0_38 = coeff0_0*dmats0[0][38] + coeff0_1*dmats0[1][38] + coeff0_2*dmats0[2][38] + coeff0_3*dmats0[3][38] + coeff0_4*dmats0[4][38] + coeff0_5*dmats0[5][38] + coeff0_6*dmats0[6][38] + coeff0_7*dmats0[7][38] + coeff0_8*dmats0[8][38] + coeff0_9*dmats0[9][38] + coeff0_10*dmats0[10][38] + coeff0_11*dmats0[11][38] + coeff0_12*dmats0[12][38] + coeff0_13*dmats0[13][38] + coeff0_14*dmats0[14][38] + coeff0_15*dmats0[15][38] + coeff0_16*dmats0[16][38] + coeff0_17*dmats0[17][38] + coeff0_18*dmats0[18][38] + coeff0_19*dmats0[19][38] + coeff0_20*dmats0[20][38] + coeff0_21*dmats0[21][38] + coeff0_22*dmats0[22][38] + coeff0_23*dmats0[23][38] + coeff0_24*dmats0[24][38] + coeff0_25*dmats0[25][38] + coeff0_26*dmats0[26][38] + coeff0_27*dmats0[27][38] + coeff0_28*dmats0[28][38] + coeff0_29*dmats0[29][38] + coeff0_30*dmats0[30][38] + coeff0_31*dmats0[31][38] + coeff0_32*dmats0[32][38] + coeff0_33*dmats0[33][38] + coeff0_34*dmats0[34][38] + coeff0_35*dmats0[35][38] + coeff0_36*dmats0[36][38] + coeff0_37*dmats0[37][38] + coeff0_38*dmats0[38][38] + coeff0_39*dmats0[39][38] + coeff0_40*dmats0[40][38] + coeff0_41*dmats0[41][38] + coeff0_42*dmats0[42][38] + coeff0_43*dmats0[43][38] + coeff0_44*dmats0[44][38] + coeff0_45*dmats0[45][38] + coeff0_46*dmats0[46][38] + coeff0_47*dmats0[47][38] + coeff0_48*dmats0[48][38] + coeff0_49*dmats0[49][38] + coeff0_50*dmats0[50][38] + coeff0_51*dmats0[51][38] + coeff0_52*dmats0[52][38] + coeff0_53*dmats0[53][38] + coeff0_54*dmats0[54][38] + coeff0_55*dmats0[55][38];
          new_coeff0_39 = coeff0_0*dmats0[0][39] + coeff0_1*dmats0[1][39] + coeff0_2*dmats0[2][39] + coeff0_3*dmats0[3][39] + coeff0_4*dmats0[4][39] + coeff0_5*dmats0[5][39] + coeff0_6*dmats0[6][39] + coeff0_7*dmats0[7][39] + coeff0_8*dmats0[8][39] + coeff0_9*dmats0[9][39] + coeff0_10*dmats0[10][39] + coeff0_11*dmats0[11][39] + coeff0_12*dmats0[12][39] + coeff0_13*dmats0[13][39] + coeff0_14*dmats0[14][39] + coeff0_15*dmats0[15][39] + coeff0_16*dmats0[16][39] + coeff0_17*dmats0[17][39] + coeff0_18*dmats0[18][39] + coeff0_19*dmats0[19][39] + coeff0_20*dmats0[20][39] + coeff0_21*dmats0[21][39] + coeff0_22*dmats0[22][39] + coeff0_23*dmats0[23][39] + coeff0_24*dmats0[24][39] + coeff0_25*dmats0[25][39] + coeff0_26*dmats0[26][39] + coeff0_27*dmats0[27][39] + coeff0_28*dmats0[28][39] + coeff0_29*dmats0[29][39] + coeff0_30*dmats0[30][39] + coeff0_31*dmats0[31][39] + coeff0_32*dmats0[32][39] + coeff0_33*dmats0[33][39] + coeff0_34*dmats0[34][39] + coeff0_35*dmats0[35][39] + coeff0_36*dmats0[36][39] + coeff0_37*dmats0[37][39] + coeff0_38*dmats0[38][39] + coeff0_39*dmats0[39][39] + coeff0_40*dmats0[40][39] + coeff0_41*dmats0[41][39] + coeff0_42*dmats0[42][39] + coeff0_43*dmats0[43][39] + coeff0_44*dmats0[44][39] + coeff0_45*dmats0[45][39] + coeff0_46*dmats0[46][39] + coeff0_47*dmats0[47][39] + coeff0_48*dmats0[48][39] + coeff0_49*dmats0[49][39] + coeff0_50*dmats0[50][39] + coeff0_51*dmats0[51][39] + coeff0_52*dmats0[52][39] + coeff0_53*dmats0[53][39] + coeff0_54*dmats0[54][39] + coeff0_55*dmats0[55][39];
          new_coeff0_40 = coeff0_0*dmats0[0][40] + coeff0_1*dmats0[1][40] + coeff0_2*dmats0[2][40] + coeff0_3*dmats0[3][40] + coeff0_4*dmats0[4][40] + coeff0_5*dmats0[5][40] + coeff0_6*dmats0[6][40] + coeff0_7*dmats0[7][40] + coeff0_8*dmats0[8][40] + coeff0_9*dmats0[9][40] + coeff0_10*dmats0[10][40] + coeff0_11*dmats0[11][40] + coeff0_12*dmats0[12][40] + coeff0_13*dmats0[13][40] + coeff0_14*dmats0[14][40] + coeff0_15*dmats0[15][40] + coeff0_16*dmats0[16][40] + coeff0_17*dmats0[17][40] + coeff0_18*dmats0[18][40] + coeff0_19*dmats0[19][40] + coeff0_20*dmats0[20][40] + coeff0_21*dmats0[21][40] + coeff0_22*dmats0[22][40] + coeff0_23*dmats0[23][40] + coeff0_24*dmats0[24][40] + coeff0_25*dmats0[25][40] + coeff0_26*dmats0[26][40] + coeff0_27*dmats0[27][40] + coeff0_28*dmats0[28][40] + coeff0_29*dmats0[29][40] + coeff0_30*dmats0[30][40] + coeff0_31*dmats0[31][40] + coeff0_32*dmats0[32][40] + coeff0_33*dmats0[33][40] + coeff0_34*dmats0[34][40] + coeff0_35*dmats0[35][40] + coeff0_36*dmats0[36][40] + coeff0_37*dmats0[37][40] + coeff0_38*dmats0[38][40] + coeff0_39*dmats0[39][40] + coeff0_40*dmats0[40][40] + coeff0_41*dmats0[41][40] + coeff0_42*dmats0[42][40] + coeff0_43*dmats0[43][40] + coeff0_44*dmats0[44][40] + coeff0_45*dmats0[45][40] + coeff0_46*dmats0[46][40] + coeff0_47*dmats0[47][40] + coeff0_48*dmats0[48][40] + coeff0_49*dmats0[49][40] + coeff0_50*dmats0[50][40] + coeff0_51*dmats0[51][40] + coeff0_52*dmats0[52][40] + coeff0_53*dmats0[53][40] + coeff0_54*dmats0[54][40] + coeff0_55*dmats0[55][40];
          new_coeff0_41 = coeff0_0*dmats0[0][41] + coeff0_1*dmats0[1][41] + coeff0_2*dmats0[2][41] + coeff0_3*dmats0[3][41] + coeff0_4*dmats0[4][41] + coeff0_5*dmats0[5][41] + coeff0_6*dmats0[6][41] + coeff0_7*dmats0[7][41] + coeff0_8*dmats0[8][41] + coeff0_9*dmats0[9][41] + coeff0_10*dmats0[10][41] + coeff0_11*dmats0[11][41] + coeff0_12*dmats0[12][41] + coeff0_13*dmats0[13][41] + coeff0_14*dmats0[14][41] + coeff0_15*dmats0[15][41] + coeff0_16*dmats0[16][41] + coeff0_17*dmats0[17][41] + coeff0_18*dmats0[18][41] + coeff0_19*dmats0[19][41] + coeff0_20*dmats0[20][41] + coeff0_21*dmats0[21][41] + coeff0_22*dmats0[22][41] + coeff0_23*dmats0[23][41] + coeff0_24*dmats0[24][41] + coeff0_25*dmats0[25][41] + coeff0_26*dmats0[26][41] + coeff0_27*dmats0[27][41] + coeff0_28*dmats0[28][41] + coeff0_29*dmats0[29][41] + coeff0_30*dmats0[30][41] + coeff0_31*dmats0[31][41] + coeff0_32*dmats0[32][41] + coeff0_33*dmats0[33][41] + coeff0_34*dmats0[34][41] + coeff0_35*dmats0[35][41] + coeff0_36*dmats0[36][41] + coeff0_37*dmats0[37][41] + coeff0_38*dmats0[38][41] + coeff0_39*dmats0[39][41] + coeff0_40*dmats0[40][41] + coeff0_41*dmats0[41][41] + coeff0_42*dmats0[42][41] + coeff0_43*dmats0[43][41] + coeff0_44*dmats0[44][41] + coeff0_45*dmats0[45][41] + coeff0_46*dmats0[46][41] + coeff0_47*dmats0[47][41] + coeff0_48*dmats0[48][41] + coeff0_49*dmats0[49][41] + coeff0_50*dmats0[50][41] + coeff0_51*dmats0[51][41] + coeff0_52*dmats0[52][41] + coeff0_53*dmats0[53][41] + coeff0_54*dmats0[54][41] + coeff0_55*dmats0[55][41];
          new_coeff0_42 = coeff0_0*dmats0[0][42] + coeff0_1*dmats0[1][42] + coeff0_2*dmats0[2][42] + coeff0_3*dmats0[3][42] + coeff0_4*dmats0[4][42] + coeff0_5*dmats0[5][42] + coeff0_6*dmats0[6][42] + coeff0_7*dmats0[7][42] + coeff0_8*dmats0[8][42] + coeff0_9*dmats0[9][42] + coeff0_10*dmats0[10][42] + coeff0_11*dmats0[11][42] + coeff0_12*dmats0[12][42] + coeff0_13*dmats0[13][42] + coeff0_14*dmats0[14][42] + coeff0_15*dmats0[15][42] + coeff0_16*dmats0[16][42] + coeff0_17*dmats0[17][42] + coeff0_18*dmats0[18][42] + coeff0_19*dmats0[19][42] + coeff0_20*dmats0[20][42] + coeff0_21*dmats0[21][42] + coeff0_22*dmats0[22][42] + coeff0_23*dmats0[23][42] + coeff0_24*dmats0[24][42] + coeff0_25*dmats0[25][42] + coeff0_26*dmats0[26][42] + coeff0_27*dmats0[27][42] + coeff0_28*dmats0[28][42] + coeff0_29*dmats0[29][42] + coeff0_30*dmats0[30][42] + coeff0_31*dmats0[31][42] + coeff0_32*dmats0[32][42] + coeff0_33*dmats0[33][42] + coeff0_34*dmats0[34][42] + coeff0_35*dmats0[35][42] + coeff0_36*dmats0[36][42] + coeff0_37*dmats0[37][42] + coeff0_38*dmats0[38][42] + coeff0_39*dmats0[39][42] + coeff0_40*dmats0[40][42] + coeff0_41*dmats0[41][42] + coeff0_42*dmats0[42][42] + coeff0_43*dmats0[43][42] + coeff0_44*dmats0[44][42] + coeff0_45*dmats0[45][42] + coeff0_46*dmats0[46][42] + coeff0_47*dmats0[47][42] + coeff0_48*dmats0[48][42] + coeff0_49*dmats0[49][42] + coeff0_50*dmats0[50][42] + coeff0_51*dmats0[51][42] + coeff0_52*dmats0[52][42] + coeff0_53*dmats0[53][42] + coeff0_54*dmats0[54][42] + coeff0_55*dmats0[55][42];
          new_coeff0_43 = coeff0_0*dmats0[0][43] + coeff0_1*dmats0[1][43] + coeff0_2*dmats0[2][43] + coeff0_3*dmats0[3][43] + coeff0_4*dmats0[4][43] + coeff0_5*dmats0[5][43] + coeff0_6*dmats0[6][43] + coeff0_7*dmats0[7][43] + coeff0_8*dmats0[8][43] + coeff0_9*dmats0[9][43] + coeff0_10*dmats0[10][43] + coeff0_11*dmats0[11][43] + coeff0_12*dmats0[12][43] + coeff0_13*dmats0[13][43] + coeff0_14*dmats0[14][43] + coeff0_15*dmats0[15][43] + coeff0_16*dmats0[16][43] + coeff0_17*dmats0[17][43] + coeff0_18*dmats0[18][43] + coeff0_19*dmats0[19][43] + coeff0_20*dmats0[20][43] + coeff0_21*dmats0[21][43] + coeff0_22*dmats0[22][43] + coeff0_23*dmats0[23][43] + coeff0_24*dmats0[24][43] + coeff0_25*dmats0[25][43] + coeff0_26*dmats0[26][43] + coeff0_27*dmats0[27][43] + coeff0_28*dmats0[28][43] + coeff0_29*dmats0[29][43] + coeff0_30*dmats0[30][43] + coeff0_31*dmats0[31][43] + coeff0_32*dmats0[32][43] + coeff0_33*dmats0[33][43] + coeff0_34*dmats0[34][43] + coeff0_35*dmats0[35][43] + coeff0_36*dmats0[36][43] + coeff0_37*dmats0[37][43] + coeff0_38*dmats0[38][43] + coeff0_39*dmats0[39][43] + coeff0_40*dmats0[40][43] + coeff0_41*dmats0[41][43] + coeff0_42*dmats0[42][43] + coeff0_43*dmats0[43][43] + coeff0_44*dmats0[44][43] + coeff0_45*dmats0[45][43] + coeff0_46*dmats0[46][43] + coeff0_47*dmats0[47][43] + coeff0_48*dmats0[48][43] + coeff0_49*dmats0[49][43] + coeff0_50*dmats0[50][43] + coeff0_51*dmats0[51][43] + coeff0_52*dmats0[52][43] + coeff0_53*dmats0[53][43] + coeff0_54*dmats0[54][43] + coeff0_55*dmats0[55][43];
          new_coeff0_44 = coeff0_0*dmats0[0][44] + coeff0_1*dmats0[1][44] + coeff0_2*dmats0[2][44] + coeff0_3*dmats0[3][44] + coeff0_4*dmats0[4][44] + coeff0_5*dmats0[5][44] + coeff0_6*dmats0[6][44] + coeff0_7*dmats0[7][44] + coeff0_8*dmats0[8][44] + coeff0_9*dmats0[9][44] + coeff0_10*dmats0[10][44] + coeff0_11*dmats0[11][44] + coeff0_12*dmats0[12][44] + coeff0_13*dmats0[13][44] + coeff0_14*dmats0[14][44] + coeff0_15*dmats0[15][44] + coeff0_16*dmats0[16][44] + coeff0_17*dmats0[17][44] + coeff0_18*dmats0[18][44] + coeff0_19*dmats0[19][44] + coeff0_20*dmats0[20][44] + coeff0_21*dmats0[21][44] + coeff0_22*dmats0[22][44] + coeff0_23*dmats0[23][44] + coeff0_24*dmats0[24][44] + coeff0_25*dmats0[25][44] + coeff0_26*dmats0[26][44] + coeff0_27*dmats0[27][44] + coeff0_28*dmats0[28][44] + coeff0_29*dmats0[29][44] + coeff0_30*dmats0[30][44] + coeff0_31*dmats0[31][44] + coeff0_32*dmats0[32][44] + coeff0_33*dmats0[33][44] + coeff0_34*dmats0[34][44] + coeff0_35*dmats0[35][44] + coeff0_36*dmats0[36][44] + coeff0_37*dmats0[37][44] + coeff0_38*dmats0[38][44] + coeff0_39*dmats0[39][44] + coeff0_40*dmats0[40][44] + coeff0_41*dmats0[41][44] + coeff0_42*dmats0[42][44] + coeff0_43*dmats0[43][44] + coeff0_44*dmats0[44][44] + coeff0_45*dmats0[45][44] + coeff0_46*dmats0[46][44] + coeff0_47*dmats0[47][44] + coeff0_48*dmats0[48][44] + coeff0_49*dmats0[49][44] + coeff0_50*dmats0[50][44] + coeff0_51*dmats0[51][44] + coeff0_52*dmats0[52][44] + coeff0_53*dmats0[53][44] + coeff0_54*dmats0[54][44] + coeff0_55*dmats0[55][44];
          new_coeff0_45 = coeff0_0*dmats0[0][45] + coeff0_1*dmats0[1][45] + coeff0_2*dmats0[2][45] + coeff0_3*dmats0[3][45] + coeff0_4*dmats0[4][45] + coeff0_5*dmats0[5][45] + coeff0_6*dmats0[6][45] + coeff0_7*dmats0[7][45] + coeff0_8*dmats0[8][45] + coeff0_9*dmats0[9][45] + coeff0_10*dmats0[10][45] + coeff0_11*dmats0[11][45] + coeff0_12*dmats0[12][45] + coeff0_13*dmats0[13][45] + coeff0_14*dmats0[14][45] + coeff0_15*dmats0[15][45] + coeff0_16*dmats0[16][45] + coeff0_17*dmats0[17][45] + coeff0_18*dmats0[18][45] + coeff0_19*dmats0[19][45] + coeff0_20*dmats0[20][45] + coeff0_21*dmats0[21][45] + coeff0_22*dmats0[22][45] + coeff0_23*dmats0[23][45] + coeff0_24*dmats0[24][45] + coeff0_25*dmats0[25][45] + coeff0_26*dmats0[26][45] + coeff0_27*dmats0[27][45] + coeff0_28*dmats0[28][45] + coeff0_29*dmats0[29][45] + coeff0_30*dmats0[30][45] + coeff0_31*dmats0[31][45] + coeff0_32*dmats0[32][45] + coeff0_33*dmats0[33][45] + coeff0_34*dmats0[34][45] + coeff0_35*dmats0[35][45] + coeff0_36*dmats0[36][45] + coeff0_37*dmats0[37][45] + coeff0_38*dmats0[38][45] + coeff0_39*dmats0[39][45] + coeff0_40*dmats0[40][45] + coeff0_41*dmats0[41][45] + coeff0_42*dmats0[42][45] + coeff0_43*dmats0[43][45] + coeff0_44*dmats0[44][45] + coeff0_45*dmats0[45][45] + coeff0_46*dmats0[46][45] + coeff0_47*dmats0[47][45] + coeff0_48*dmats0[48][45] + coeff0_49*dmats0[49][45] + coeff0_50*dmats0[50][45] + coeff0_51*dmats0[51][45] + coeff0_52*dmats0[52][45] + coeff0_53*dmats0[53][45] + coeff0_54*dmats0[54][45] + coeff0_55*dmats0[55][45];
          new_coeff0_46 = coeff0_0*dmats0[0][46] + coeff0_1*dmats0[1][46] + coeff0_2*dmats0[2][46] + coeff0_3*dmats0[3][46] + coeff0_4*dmats0[4][46] + coeff0_5*dmats0[5][46] + coeff0_6*dmats0[6][46] + coeff0_7*dmats0[7][46] + coeff0_8*dmats0[8][46] + coeff0_9*dmats0[9][46] + coeff0_10*dmats0[10][46] + coeff0_11*dmats0[11][46] + coeff0_12*dmats0[12][46] + coeff0_13*dmats0[13][46] + coeff0_14*dmats0[14][46] + coeff0_15*dmats0[15][46] + coeff0_16*dmats0[16][46] + coeff0_17*dmats0[17][46] + coeff0_18*dmats0[18][46] + coeff0_19*dmats0[19][46] + coeff0_20*dmats0[20][46] + coeff0_21*dmats0[21][46] + coeff0_22*dmats0[22][46] + coeff0_23*dmats0[23][46] + coeff0_24*dmats0[24][46] + coeff0_25*dmats0[25][46] + coeff0_26*dmats0[26][46] + coeff0_27*dmats0[27][46] + coeff0_28*dmats0[28][46] + coeff0_29*dmats0[29][46] + coeff0_30*dmats0[30][46] + coeff0_31*dmats0[31][46] + coeff0_32*dmats0[32][46] + coeff0_33*dmats0[33][46] + coeff0_34*dmats0[34][46] + coeff0_35*dmats0[35][46] + coeff0_36*dmats0[36][46] + coeff0_37*dmats0[37][46] + coeff0_38*dmats0[38][46] + coeff0_39*dmats0[39][46] + coeff0_40*dmats0[40][46] + coeff0_41*dmats0[41][46] + coeff0_42*dmats0[42][46] + coeff0_43*dmats0[43][46] + coeff0_44*dmats0[44][46] + coeff0_45*dmats0[45][46] + coeff0_46*dmats0[46][46] + coeff0_47*dmats0[47][46] + coeff0_48*dmats0[48][46] + coeff0_49*dmats0[49][46] + coeff0_50*dmats0[50][46] + coeff0_51*dmats0[51][46] + coeff0_52*dmats0[52][46] + coeff0_53*dmats0[53][46] + coeff0_54*dmats0[54][46] + coeff0_55*dmats0[55][46];
          new_coeff0_47 = coeff0_0*dmats0[0][47] + coeff0_1*dmats0[1][47] + coeff0_2*dmats0[2][47] + coeff0_3*dmats0[3][47] + coeff0_4*dmats0[4][47] + coeff0_5*dmats0[5][47] + coeff0_6*dmats0[6][47] + coeff0_7*dmats0[7][47] + coeff0_8*dmats0[8][47] + coeff0_9*dmats0[9][47] + coeff0_10*dmats0[10][47] + coeff0_11*dmats0[11][47] + coeff0_12*dmats0[12][47] + coeff0_13*dmats0[13][47] + coeff0_14*dmats0[14][47] + coeff0_15*dmats0[15][47] + coeff0_16*dmats0[16][47] + coeff0_17*dmats0[17][47] + coeff0_18*dmats0[18][47] + coeff0_19*dmats0[19][47] + coeff0_20*dmats0[20][47] + coeff0_21*dmats0[21][47] + coeff0_22*dmats0[22][47] + coeff0_23*dmats0[23][47] + coeff0_24*dmats0[24][47] + coeff0_25*dmats0[25][47] + coeff0_26*dmats0[26][47] + coeff0_27*dmats0[27][47] + coeff0_28*dmats0[28][47] + coeff0_29*dmats0[29][47] + coeff0_30*dmats0[30][47] + coeff0_31*dmats0[31][47] + coeff0_32*dmats0[32][47] + coeff0_33*dmats0[33][47] + coeff0_34*dmats0[34][47] + coeff0_35*dmats0[35][47] + coeff0_36*dmats0[36][47] + coeff0_37*dmats0[37][47] + coeff0_38*dmats0[38][47] + coeff0_39*dmats0[39][47] + coeff0_40*dmats0[40][47] + coeff0_41*dmats0[41][47] + coeff0_42*dmats0[42][47] + coeff0_43*dmats0[43][47] + coeff0_44*dmats0[44][47] + coeff0_45*dmats0[45][47] + coeff0_46*dmats0[46][47] + coeff0_47*dmats0[47][47] + coeff0_48*dmats0[48][47] + coeff0_49*dmats0[49][47] + coeff0_50*dmats0[50][47] + coeff0_51*dmats0[51][47] + coeff0_52*dmats0[52][47] + coeff0_53*dmats0[53][47] + coeff0_54*dmats0[54][47] + coeff0_55*dmats0[55][47];
          new_coeff0_48 = coeff0_0*dmats0[0][48] + coeff0_1*dmats0[1][48] + coeff0_2*dmats0[2][48] + coeff0_3*dmats0[3][48] + coeff0_4*dmats0[4][48] + coeff0_5*dmats0[5][48] + coeff0_6*dmats0[6][48] + coeff0_7*dmats0[7][48] + coeff0_8*dmats0[8][48] + coeff0_9*dmats0[9][48] + coeff0_10*dmats0[10][48] + coeff0_11*dmats0[11][48] + coeff0_12*dmats0[12][48] + coeff0_13*dmats0[13][48] + coeff0_14*dmats0[14][48] + coeff0_15*dmats0[15][48] + coeff0_16*dmats0[16][48] + coeff0_17*dmats0[17][48] + coeff0_18*dmats0[18][48] + coeff0_19*dmats0[19][48] + coeff0_20*dmats0[20][48] + coeff0_21*dmats0[21][48] + coeff0_22*dmats0[22][48] + coeff0_23*dmats0[23][48] + coeff0_24*dmats0[24][48] + coeff0_25*dmats0[25][48] + coeff0_26*dmats0[26][48] + coeff0_27*dmats0[27][48] + coeff0_28*dmats0[28][48] + coeff0_29*dmats0[29][48] + coeff0_30*dmats0[30][48] + coeff0_31*dmats0[31][48] + coeff0_32*dmats0[32][48] + coeff0_33*dmats0[33][48] + coeff0_34*dmats0[34][48] + coeff0_35*dmats0[35][48] + coeff0_36*dmats0[36][48] + coeff0_37*dmats0[37][48] + coeff0_38*dmats0[38][48] + coeff0_39*dmats0[39][48] + coeff0_40*dmats0[40][48] + coeff0_41*dmats0[41][48] + coeff0_42*dmats0[42][48] + coeff0_43*dmats0[43][48] + coeff0_44*dmats0[44][48] + coeff0_45*dmats0[45][48] + coeff0_46*dmats0[46][48] + coeff0_47*dmats0[47][48] + coeff0_48*dmats0[48][48] + coeff0_49*dmats0[49][48] + coeff0_50*dmats0[50][48] + coeff0_51*dmats0[51][48] + coeff0_52*dmats0[52][48] + coeff0_53*dmats0[53][48] + coeff0_54*dmats0[54][48] + coeff0_55*dmats0[55][48];
          new_coeff0_49 = coeff0_0*dmats0[0][49] + coeff0_1*dmats0[1][49] + coeff0_2*dmats0[2][49] + coeff0_3*dmats0[3][49] + coeff0_4*dmats0[4][49] + coeff0_5*dmats0[5][49] + coeff0_6*dmats0[6][49] + coeff0_7*dmats0[7][49] + coeff0_8*dmats0[8][49] + coeff0_9*dmats0[9][49] + coeff0_10*dmats0[10][49] + coeff0_11*dmats0[11][49] + coeff0_12*dmats0[12][49] + coeff0_13*dmats0[13][49] + coeff0_14*dmats0[14][49] + coeff0_15*dmats0[15][49] + coeff0_16*dmats0[16][49] + coeff0_17*dmats0[17][49] + coeff0_18*dmats0[18][49] + coeff0_19*dmats0[19][49] + coeff0_20*dmats0[20][49] + coeff0_21*dmats0[21][49] + coeff0_22*dmats0[22][49] + coeff0_23*dmats0[23][49] + coeff0_24*dmats0[24][49] + coeff0_25*dmats0[25][49] + coeff0_26*dmats0[26][49] + coeff0_27*dmats0[27][49] + coeff0_28*dmats0[28][49] + coeff0_29*dmats0[29][49] + coeff0_30*dmats0[30][49] + coeff0_31*dmats0[31][49] + coeff0_32*dmats0[32][49] + coeff0_33*dmats0[33][49] + coeff0_34*dmats0[34][49] + coeff0_35*dmats0[35][49] + coeff0_36*dmats0[36][49] + coeff0_37*dmats0[37][49] + coeff0_38*dmats0[38][49] + coeff0_39*dmats0[39][49] + coeff0_40*dmats0[40][49] + coeff0_41*dmats0[41][49] + coeff0_42*dmats0[42][49] + coeff0_43*dmats0[43][49] + coeff0_44*dmats0[44][49] + coeff0_45*dmats0[45][49] + coeff0_46*dmats0[46][49] + coeff0_47*dmats0[47][49] + coeff0_48*dmats0[48][49] + coeff0_49*dmats0[49][49] + coeff0_50*dmats0[50][49] + coeff0_51*dmats0[51][49] + coeff0_52*dmats0[52][49] + coeff0_53*dmats0[53][49] + coeff0_54*dmats0[54][49] + coeff0_55*dmats0[55][49];
          new_coeff0_50 = coeff0_0*dmats0[0][50] + coeff0_1*dmats0[1][50] + coeff0_2*dmats0[2][50] + coeff0_3*dmats0[3][50] + coeff0_4*dmats0[4][50] + coeff0_5*dmats0[5][50] + coeff0_6*dmats0[6][50] + coeff0_7*dmats0[7][50] + coeff0_8*dmats0[8][50] + coeff0_9*dmats0[9][50] + coeff0_10*dmats0[10][50] + coeff0_11*dmats0[11][50] + coeff0_12*dmats0[12][50] + coeff0_13*dmats0[13][50] + coeff0_14*dmats0[14][50] + coeff0_15*dmats0[15][50] + coeff0_16*dmats0[16][50] + coeff0_17*dmats0[17][50] + coeff0_18*dmats0[18][50] + coeff0_19*dmats0[19][50] + coeff0_20*dmats0[20][50] + coeff0_21*dmats0[21][50] + coeff0_22*dmats0[22][50] + coeff0_23*dmats0[23][50] + coeff0_24*dmats0[24][50] + coeff0_25*dmats0[25][50] + coeff0_26*dmats0[26][50] + coeff0_27*dmats0[27][50] + coeff0_28*dmats0[28][50] + coeff0_29*dmats0[29][50] + coeff0_30*dmats0[30][50] + coeff0_31*dmats0[31][50] + coeff0_32*dmats0[32][50] + coeff0_33*dmats0[33][50] + coeff0_34*dmats0[34][50] + coeff0_35*dmats0[35][50] + coeff0_36*dmats0[36][50] + coeff0_37*dmats0[37][50] + coeff0_38*dmats0[38][50] + coeff0_39*dmats0[39][50] + coeff0_40*dmats0[40][50] + coeff0_41*dmats0[41][50] + coeff0_42*dmats0[42][50] + coeff0_43*dmats0[43][50] + coeff0_44*dmats0[44][50] + coeff0_45*dmats0[45][50] + coeff0_46*dmats0[46][50] + coeff0_47*dmats0[47][50] + coeff0_48*dmats0[48][50] + coeff0_49*dmats0[49][50] + coeff0_50*dmats0[50][50] + coeff0_51*dmats0[51][50] + coeff0_52*dmats0[52][50] + coeff0_53*dmats0[53][50] + coeff0_54*dmats0[54][50] + coeff0_55*dmats0[55][50];
          new_coeff0_51 = coeff0_0*dmats0[0][51] + coeff0_1*dmats0[1][51] + coeff0_2*dmats0[2][51] + coeff0_3*dmats0[3][51] + coeff0_4*dmats0[4][51] + coeff0_5*dmats0[5][51] + coeff0_6*dmats0[6][51] + coeff0_7*dmats0[7][51] + coeff0_8*dmats0[8][51] + coeff0_9*dmats0[9][51] + coeff0_10*dmats0[10][51] + coeff0_11*dmats0[11][51] + coeff0_12*dmats0[12][51] + coeff0_13*dmats0[13][51] + coeff0_14*dmats0[14][51] + coeff0_15*dmats0[15][51] + coeff0_16*dmats0[16][51] + coeff0_17*dmats0[17][51] + coeff0_18*dmats0[18][51] + coeff0_19*dmats0[19][51] + coeff0_20*dmats0[20][51] + coeff0_21*dmats0[21][51] + coeff0_22*dmats0[22][51] + coeff0_23*dmats0[23][51] + coeff0_24*dmats0[24][51] + coeff0_25*dmats0[25][51] + coeff0_26*dmats0[26][51] + coeff0_27*dmats0[27][51] + coeff0_28*dmats0[28][51] + coeff0_29*dmats0[29][51] + coeff0_30*dmats0[30][51] + coeff0_31*dmats0[31][51] + coeff0_32*dmats0[32][51] + coeff0_33*dmats0[33][51] + coeff0_34*dmats0[34][51] + coeff0_35*dmats0[35][51] + coeff0_36*dmats0[36][51] + coeff0_37*dmats0[37][51] + coeff0_38*dmats0[38][51] + coeff0_39*dmats0[39][51] + coeff0_40*dmats0[40][51] + coeff0_41*dmats0[41][51] + coeff0_42*dmats0[42][51] + coeff0_43*dmats0[43][51] + coeff0_44*dmats0[44][51] + coeff0_45*dmats0[45][51] + coeff0_46*dmats0[46][51] + coeff0_47*dmats0[47][51] + coeff0_48*dmats0[48][51] + coeff0_49*dmats0[49][51] + coeff0_50*dmats0[50][51] + coeff0_51*dmats0[51][51] + coeff0_52*dmats0[52][51] + coeff0_53*dmats0[53][51] + coeff0_54*dmats0[54][51] + coeff0_55*dmats0[55][51];
          new_coeff0_52 = coeff0_0*dmats0[0][52] + coeff0_1*dmats0[1][52] + coeff0_2*dmats0[2][52] + coeff0_3*dmats0[3][52] + coeff0_4*dmats0[4][52] + coeff0_5*dmats0[5][52] + coeff0_6*dmats0[6][52] + coeff0_7*dmats0[7][52] + coeff0_8*dmats0[8][52] + coeff0_9*dmats0[9][52] + coeff0_10*dmats0[10][52] + coeff0_11*dmats0[11][52] + coeff0_12*dmats0[12][52] + coeff0_13*dmats0[13][52] + coeff0_14*dmats0[14][52] + coeff0_15*dmats0[15][52] + coeff0_16*dmats0[16][52] + coeff0_17*dmats0[17][52] + coeff0_18*dmats0[18][52] + coeff0_19*dmats0[19][52] + coeff0_20*dmats0[20][52] + coeff0_21*dmats0[21][52] + coeff0_22*dmats0[22][52] + coeff0_23*dmats0[23][52] + coeff0_24*dmats0[24][52] + coeff0_25*dmats0[25][52] + coeff0_26*dmats0[26][52] + coeff0_27*dmats0[27][52] + coeff0_28*dmats0[28][52] + coeff0_29*dmats0[29][52] + coeff0_30*dmats0[30][52] + coeff0_31*dmats0[31][52] + coeff0_32*dmats0[32][52] + coeff0_33*dmats0[33][52] + coeff0_34*dmats0[34][52] + coeff0_35*dmats0[35][52] + coeff0_36*dmats0[36][52] + coeff0_37*dmats0[37][52] + coeff0_38*dmats0[38][52] + coeff0_39*dmats0[39][52] + coeff0_40*dmats0[40][52] + coeff0_41*dmats0[41][52] + coeff0_42*dmats0[42][52] + coeff0_43*dmats0[43][52] + coeff0_44*dmats0[44][52] + coeff0_45*dmats0[45][52] + coeff0_46*dmats0[46][52] + coeff0_47*dmats0[47][52] + coeff0_48*dmats0[48][52] + coeff0_49*dmats0[49][52] + coeff0_50*dmats0[50][52] + coeff0_51*dmats0[51][52] + coeff0_52*dmats0[52][52] + coeff0_53*dmats0[53][52] + coeff0_54*dmats0[54][52] + coeff0_55*dmats0[55][52];
          new_coeff0_53 = coeff0_0*dmats0[0][53] + coeff0_1*dmats0[1][53] + coeff0_2*dmats0[2][53] + coeff0_3*dmats0[3][53] + coeff0_4*dmats0[4][53] + coeff0_5*dmats0[5][53] + coeff0_6*dmats0[6][53] + coeff0_7*dmats0[7][53] + coeff0_8*dmats0[8][53] + coeff0_9*dmats0[9][53] + coeff0_10*dmats0[10][53] + coeff0_11*dmats0[11][53] + coeff0_12*dmats0[12][53] + coeff0_13*dmats0[13][53] + coeff0_14*dmats0[14][53] + coeff0_15*dmats0[15][53] + coeff0_16*dmats0[16][53] + coeff0_17*dmats0[17][53] + coeff0_18*dmats0[18][53] + coeff0_19*dmats0[19][53] + coeff0_20*dmats0[20][53] + coeff0_21*dmats0[21][53] + coeff0_22*dmats0[22][53] + coeff0_23*dmats0[23][53] + coeff0_24*dmats0[24][53] + coeff0_25*dmats0[25][53] + coeff0_26*dmats0[26][53] + coeff0_27*dmats0[27][53] + coeff0_28*dmats0[28][53] + coeff0_29*dmats0[29][53] + coeff0_30*dmats0[30][53] + coeff0_31*dmats0[31][53] + coeff0_32*dmats0[32][53] + coeff0_33*dmats0[33][53] + coeff0_34*dmats0[34][53] + coeff0_35*dmats0[35][53] + coeff0_36*dmats0[36][53] + coeff0_37*dmats0[37][53] + coeff0_38*dmats0[38][53] + coeff0_39*dmats0[39][53] + coeff0_40*dmats0[40][53] + coeff0_41*dmats0[41][53] + coeff0_42*dmats0[42][53] + coeff0_43*dmats0[43][53] + coeff0_44*dmats0[44][53] + coeff0_45*dmats0[45][53] + coeff0_46*dmats0[46][53] + coeff0_47*dmats0[47][53] + coeff0_48*dmats0[48][53] + coeff0_49*dmats0[49][53] + coeff0_50*dmats0[50][53] + coeff0_51*dmats0[51][53] + coeff0_52*dmats0[52][53] + coeff0_53*dmats0[53][53] + coeff0_54*dmats0[54][53] + coeff0_55*dmats0[55][53];
          new_coeff0_54 = coeff0_0*dmats0[0][54] + coeff0_1*dmats0[1][54] + coeff0_2*dmats0[2][54] + coeff0_3*dmats0[3][54] + coeff0_4*dmats0[4][54] + coeff0_5*dmats0[5][54] + coeff0_6*dmats0[6][54] + coeff0_7*dmats0[7][54] + coeff0_8*dmats0[8][54] + coeff0_9*dmats0[9][54] + coeff0_10*dmats0[10][54] + coeff0_11*dmats0[11][54] + coeff0_12*dmats0[12][54] + coeff0_13*dmats0[13][54] + coeff0_14*dmats0[14][54] + coeff0_15*dmats0[15][54] + coeff0_16*dmats0[16][54] + coeff0_17*dmats0[17][54] + coeff0_18*dmats0[18][54] + coeff0_19*dmats0[19][54] + coeff0_20*dmats0[20][54] + coeff0_21*dmats0[21][54] + coeff0_22*dmats0[22][54] + coeff0_23*dmats0[23][54] + coeff0_24*dmats0[24][54] + coeff0_25*dmats0[25][54] + coeff0_26*dmats0[26][54] + coeff0_27*dmats0[27][54] + coeff0_28*dmats0[28][54] + coeff0_29*dmats0[29][54] + coeff0_30*dmats0[30][54] + coeff0_31*dmats0[31][54] + coeff0_32*dmats0[32][54] + coeff0_33*dmats0[33][54] + coeff0_34*dmats0[34][54] + coeff0_35*dmats0[35][54] + coeff0_36*dmats0[36][54] + coeff0_37*dmats0[37][54] + coeff0_38*dmats0[38][54] + coeff0_39*dmats0[39][54] + coeff0_40*dmats0[40][54] + coeff0_41*dmats0[41][54] + coeff0_42*dmats0[42][54] + coeff0_43*dmats0[43][54] + coeff0_44*dmats0[44][54] + coeff0_45*dmats0[45][54] + coeff0_46*dmats0[46][54] + coeff0_47*dmats0[47][54] + coeff0_48*dmats0[48][54] + coeff0_49*dmats0[49][54] + coeff0_50*dmats0[50][54] + coeff0_51*dmats0[51][54] + coeff0_52*dmats0[52][54] + coeff0_53*dmats0[53][54] + coeff0_54*dmats0[54][54] + coeff0_55*dmats0[55][54];
          new_coeff0_55 = coeff0_0*dmats0[0][55] + coeff0_1*dmats0[1][55] + coeff0_2*dmats0[2][55] + coeff0_3*dmats0[3][55] + coeff0_4*dmats0[4][55] + coeff0_5*dmats0[5][55] + coeff0_6*dmats0[6][55] + coeff0_7*dmats0[7][55] + coeff0_8*dmats0[8][55] + coeff0_9*dmats0[9][55] + coeff0_10*dmats0[10][55] + coeff0_11*dmats0[11][55] + coeff0_12*dmats0[12][55] + coeff0_13*dmats0[13][55] + coeff0_14*dmats0[14][55] + coeff0_15*dmats0[15][55] + coeff0_16*dmats0[16][55] + coeff0_17*dmats0[17][55] + coeff0_18*dmats0[18][55] + coeff0_19*dmats0[19][55] + coeff0_20*dmats0[20][55] + coeff0_21*dmats0[21][55] + coeff0_22*dmats0[22][55] + coeff0_23*dmats0[23][55] + coeff0_24*dmats0[24][55] + coeff0_25*dmats0[25][55] + coeff0_26*dmats0[26][55] + coeff0_27*dmats0[27][55] + coeff0_28*dmats0[28][55] + coeff0_29*dmats0[29][55] + coeff0_30*dmats0[30][55] + coeff0_31*dmats0[31][55] + coeff0_32*dmats0[32][55] + coeff0_33*dmats0[33][55] + coeff0_34*dmats0[34][55] + coeff0_35*dmats0[35][55] + coeff0_36*dmats0[36][55] + coeff0_37*dmats0[37][55] + coeff0_38*dmats0[38][55] + coeff0_39*dmats0[39][55] + coeff0_40*dmats0[40][55] + coeff0_41*dmats0[41][55] + coeff0_42*dmats0[42][55] + coeff0_43*dmats0[43][55] + coeff0_44*dmats0[44][55] + coeff0_45*dmats0[45][55] + coeff0_46*dmats0[46][55] + coeff0_47*dmats0[47][55] + coeff0_48*dmats0[48][55] + coeff0_49*dmats0[49][55] + coeff0_50*dmats0[50][55] + coeff0_51*dmats0[51][55] + coeff0_52*dmats0[52][55] + coeff0_53*dmats0[53][55] + coeff0_54*dmats0[54][55] + coeff0_55*dmats0[55][55];
        }
        if(combinations[deriv_num][j] == 1)
        {
          new_coeff0_0 = coeff0_0*dmats1[0][0] + coeff0_1*dmats1[1][0] + coeff0_2*dmats1[2][0] + coeff0_3*dmats1[3][0] + coeff0_4*dmats1[4][0] + coeff0_5*dmats1[5][0] + coeff0_6*dmats1[6][0] + coeff0_7*dmats1[7][0] + coeff0_8*dmats1[8][0] + coeff0_9*dmats1[9][0] + coeff0_10*dmats1[10][0] + coeff0_11*dmats1[11][0] + coeff0_12*dmats1[12][0] + coeff0_13*dmats1[13][0] + coeff0_14*dmats1[14][0] + coeff0_15*dmats1[15][0] + coeff0_16*dmats1[16][0] + coeff0_17*dmats1[17][0] + coeff0_18*dmats1[18][0] + coeff0_19*dmats1[19][0] + coeff0_20*dmats1[20][0] + coeff0_21*dmats1[21][0] + coeff0_22*dmats1[22][0] + coeff0_23*dmats1[23][0] + coeff0_24*dmats1[24][0] + coeff0_25*dmats1[25][0] + coeff0_26*dmats1[26][0] + coeff0_27*dmats1[27][0] + coeff0_28*dmats1[28][0] + coeff0_29*dmats1[29][0] + coeff0_30*dmats1[30][0] + coeff0_31*dmats1[31][0] + coeff0_32*dmats1[32][0] + coeff0_33*dmats1[33][0] + coeff0_34*dmats1[34][0] + coeff0_35*dmats1[35][0] + coeff0_36*dmats1[36][0] + coeff0_37*dmats1[37][0] + coeff0_38*dmats1[38][0] + coeff0_39*dmats1[39][0] + coeff0_40*dmats1[40][0] + coeff0_41*dmats1[41][0] + coeff0_42*dmats1[42][0] + coeff0_43*dmats1[43][0] + coeff0_44*dmats1[44][0] + coeff0_45*dmats1[45][0] + coeff0_46*dmats1[46][0] + coeff0_47*dmats1[47][0] + coeff0_48*dmats1[48][0] + coeff0_49*dmats1[49][0] + coeff0_50*dmats1[50][0] + coeff0_51*dmats1[51][0] + coeff0_52*dmats1[52][0] + coeff0_53*dmats1[53][0] + coeff0_54*dmats1[54][0] + coeff0_55*dmats1[55][0];
          new_coeff0_1 = coeff0_0*dmats1[0][1] + coeff0_1*dmats1[1][1] + coeff0_2*dmats1[2][1] + coeff0_3*dmats1[3][1] + coeff0_4*dmats1[4][1] + coeff0_5*dmats1[5][1] + coeff0_6*dmats1[6][1] + coeff0_7*dmats1[7][1] + coeff0_8*dmats1[8][1] + coeff0_9*dmats1[9][1] + coeff0_10*dmats1[10][1] + coeff0_11*dmats1[11][1] + coeff0_12*dmats1[12][1] + coeff0_13*dmats1[13][1] + coeff0_14*dmats1[14][1] + coeff0_15*dmats1[15][1] + coeff0_16*dmats1[16][1] + coeff0_17*dmats1[17][1] + coeff0_18*dmats1[18][1] + coeff0_19*dmats1[19][1] + coeff0_20*dmats1[20][1] + coeff0_21*dmats1[21][1] + coeff0_22*dmats1[22][1] + coeff0_23*dmats1[23][1] + coeff0_24*dmats1[24][1] + coeff0_25*dmats1[25][1] + coeff0_26*dmats1[26][1] + coeff0_27*dmats1[27][1] + coeff0_28*dmats1[28][1] + coeff0_29*dmats1[29][1] + coeff0_30*dmats1[30][1] + coeff0_31*dmats1[31][1] + coeff0_32*dmats1[32][1] + coeff0_33*dmats1[33][1] + coeff0_34*dmats1[34][1] + coeff0_35*dmats1[35][1] + coeff0_36*dmats1[36][1] + coeff0_37*dmats1[37][1] + coeff0_38*dmats1[38][1] + coeff0_39*dmats1[39][1] + coeff0_40*dmats1[40][1] + coeff0_41*dmats1[41][1] + coeff0_42*dmats1[42][1] + coeff0_43*dmats1[43][1] + coeff0_44*dmats1[44][1] + coeff0_45*dmats1[45][1] + coeff0_46*dmats1[46][1] + coeff0_47*dmats1[47][1] + coeff0_48*dmats1[48][1] + coeff0_49*dmats1[49][1] + coeff0_50*dmats1[50][1] + coeff0_51*dmats1[51][1] + coeff0_52*dmats1[52][1] + coeff0_53*dmats1[53][1] + coeff0_54*dmats1[54][1] + coeff0_55*dmats1[55][1];
          new_coeff0_2 = coeff0_0*dmats1[0][2] + coeff0_1*dmats1[1][2] + coeff0_2*dmats1[2][2] + coeff0_3*dmats1[3][2] + coeff0_4*dmats1[4][2] + coeff0_5*dmats1[5][2] + coeff0_6*dmats1[6][2] + coeff0_7*dmats1[7][2] + coeff0_8*dmats1[8][2] + coeff0_9*dmats1[9][2] + coeff0_10*dmats1[10][2] + coeff0_11*dmats1[11][2] + coeff0_12*dmats1[12][2] + coeff0_13*dmats1[13][2] + coeff0_14*dmats1[14][2] + coeff0_15*dmats1[15][2] + coeff0_16*dmats1[16][2] + coeff0_17*dmats1[17][2] + coeff0_18*dmats1[18][2] + coeff0_19*dmats1[19][2] + coeff0_20*dmats1[20][2] + coeff0_21*dmats1[21][2] + coeff0_22*dmats1[22][2] + coeff0_23*dmats1[23][2] + coeff0_24*dmats1[24][2] + coeff0_25*dmats1[25][2] + coeff0_26*dmats1[26][2] + coeff0_27*dmats1[27][2] + coeff0_28*dmats1[28][2] + coeff0_29*dmats1[29][2] + coeff0_30*dmats1[30][2] + coeff0_31*dmats1[31][2] + coeff0_32*dmats1[32][2] + coeff0_33*dmats1[33][2] + coeff0_34*dmats1[34][2] + coeff0_35*dmats1[35][2] + coeff0_36*dmats1[36][2] + coeff0_37*dmats1[37][2] + coeff0_38*dmats1[38][2] + coeff0_39*dmats1[39][2] + coeff0_40*dmats1[40][2] + coeff0_41*dmats1[41][2] + coeff0_42*dmats1[42][2] + coeff0_43*dmats1[43][2] + coeff0_44*dmats1[44][2] + coeff0_45*dmats1[45][2] + coeff0_46*dmats1[46][2] + coeff0_47*dmats1[47][2] + coeff0_48*dmats1[48][2] + coeff0_49*dmats1[49][2] + coeff0_50*dmats1[50][2] + coeff0_51*dmats1[51][2] + coeff0_52*dmats1[52][2] + coeff0_53*dmats1[53][2] + coeff0_54*dmats1[54][2] + coeff0_55*dmats1[55][2];
          new_coeff0_3 = coeff0_0*dmats1[0][3] + coeff0_1*dmats1[1][3] + coeff0_2*dmats1[2][3] + coeff0_3*dmats1[3][3] + coeff0_4*dmats1[4][3] + coeff0_5*dmats1[5][3] + coeff0_6*dmats1[6][3] + coeff0_7*dmats1[7][3] + coeff0_8*dmats1[8][3] + coeff0_9*dmats1[9][3] + coeff0_10*dmats1[10][3] + coeff0_11*dmats1[11][3] + coeff0_12*dmats1[12][3] + coeff0_13*dmats1[13][3] + coeff0_14*dmats1[14][3] + coeff0_15*dmats1[15][3] + coeff0_16*dmats1[16][3] + coeff0_17*dmats1[17][3] + coeff0_18*dmats1[18][3] + coeff0_19*dmats1[19][3] + coeff0_20*dmats1[20][3] + coeff0_21*dmats1[21][3] + coeff0_22*dmats1[22][3] + coeff0_23*dmats1[23][3] + coeff0_24*dmats1[24][3] + coeff0_25*dmats1[25][3] + coeff0_26*dmats1[26][3] + coeff0_27*dmats1[27][3] + coeff0_28*dmats1[28][3] + coeff0_29*dmats1[29][3] + coeff0_30*dmats1[30][3] + coeff0_31*dmats1[31][3] + coeff0_32*dmats1[32][3] + coeff0_33*dmats1[33][3] + coeff0_34*dmats1[34][3] + coeff0_35*dmats1[35][3] + coeff0_36*dmats1[36][3] + coeff0_37*dmats1[37][3] + coeff0_38*dmats1[38][3] + coeff0_39*dmats1[39][3] + coeff0_40*dmats1[40][3] + coeff0_41*dmats1[41][3] + coeff0_42*dmats1[42][3] + coeff0_43*dmats1[43][3] + coeff0_44*dmats1[44][3] + coeff0_45*dmats1[45][3] + coeff0_46*dmats1[46][3] + coeff0_47*dmats1[47][3] + coeff0_48*dmats1[48][3] + coeff0_49*dmats1[49][3] + coeff0_50*dmats1[50][3] + coeff0_51*dmats1[51][3] + coeff0_52*dmats1[52][3] + coeff0_53*dmats1[53][3] + coeff0_54*dmats1[54][3] + coeff0_55*dmats1[55][3];
          new_coeff0_4 = coeff0_0*dmats1[0][4] + coeff0_1*dmats1[1][4] + coeff0_2*dmats1[2][4] + coeff0_3*dmats1[3][4] + coeff0_4*dmats1[4][4] + coeff0_5*dmats1[5][4] + coeff0_6*dmats1[6][4] + coeff0_7*dmats1[7][4] + coeff0_8*dmats1[8][4] + coeff0_9*dmats1[9][4] + coeff0_10*dmats1[10][4] + coeff0_11*dmats1[11][4] + coeff0_12*dmats1[12][4] + coeff0_13*dmats1[13][4] + coeff0_14*dmats1[14][4] + coeff0_15*dmats1[15][4] + coeff0_16*dmats1[16][4] + coeff0_17*dmats1[17][4] + coeff0_18*dmats1[18][4] + coeff0_19*dmats1[19][4] + coeff0_20*dmats1[20][4] + coeff0_21*dmats1[21][4] + coeff0_22*dmats1[22][4] + coeff0_23*dmats1[23][4] + coeff0_24*dmats1[24][4] + coeff0_25*dmats1[25][4] + coeff0_26*dmats1[26][4] + coeff0_27*dmats1[27][4] + coeff0_28*dmats1[28][4] + coeff0_29*dmats1[29][4] + coeff0_30*dmats1[30][4] + coeff0_31*dmats1[31][4] + coeff0_32*dmats1[32][4] + coeff0_33*dmats1[33][4] + coeff0_34*dmats1[34][4] + coeff0_35*dmats1[35][4] + coeff0_36*dmats1[36][4] + coeff0_37*dmats1[37][4] + coeff0_38*dmats1[38][4] + coeff0_39*dmats1[39][4] + coeff0_40*dmats1[40][4] + coeff0_41*dmats1[41][4] + coeff0_42*dmats1[42][4] + coeff0_43*dmats1[43][4] + coeff0_44*dmats1[44][4] + coeff0_45*dmats1[45][4] + coeff0_46*dmats1[46][4] + coeff0_47*dmats1[47][4] + coeff0_48*dmats1[48][4] + coeff0_49*dmats1[49][4] + coeff0_50*dmats1[50][4] + coeff0_51*dmats1[51][4] + coeff0_52*dmats1[52][4] + coeff0_53*dmats1[53][4] + coeff0_54*dmats1[54][4] + coeff0_55*dmats1[55][4];
          new_coeff0_5 = coeff0_0*dmats1[0][5] + coeff0_1*dmats1[1][5] + coeff0_2*dmats1[2][5] + coeff0_3*dmats1[3][5] + coeff0_4*dmats1[4][5] + coeff0_5*dmats1[5][5] + coeff0_6*dmats1[6][5] + coeff0_7*dmats1[7][5] + coeff0_8*dmats1[8][5] + coeff0_9*dmats1[9][5] + coeff0_10*dmats1[10][5] + coeff0_11*dmats1[11][5] + coeff0_12*dmats1[12][5] + coeff0_13*dmats1[13][5] + coeff0_14*dmats1[14][5] + coeff0_15*dmats1[15][5] + coeff0_16*dmats1[16][5] + coeff0_17*dmats1[17][5] + coeff0_18*dmats1[18][5] + coeff0_19*dmats1[19][5] + coeff0_20*dmats1[20][5] + coeff0_21*dmats1[21][5] + coeff0_22*dmats1[22][5] + coeff0_23*dmats1[23][5] + coeff0_24*dmats1[24][5] + coeff0_25*dmats1[25][5] + coeff0_26*dmats1[26][5] + coeff0_27*dmats1[27][5] + coeff0_28*dmats1[28][5] + coeff0_29*dmats1[29][5] + coeff0_30*dmats1[30][5] + coeff0_31*dmats1[31][5] + coeff0_32*dmats1[32][5] + coeff0_33*dmats1[33][5] + coeff0_34*dmats1[34][5] + coeff0_35*dmats1[35][5] + coeff0_36*dmats1[36][5] + coeff0_37*dmats1[37][5] + coeff0_38*dmats1[38][5] + coeff0_39*dmats1[39][5] + coeff0_40*dmats1[40][5] + coeff0_41*dmats1[41][5] + coeff0_42*dmats1[42][5] + coeff0_43*dmats1[43][5] + coeff0_44*dmats1[44][5] + coeff0_45*dmats1[45][5] + coeff0_46*dmats1[46][5] + coeff0_47*dmats1[47][5] + coeff0_48*dmats1[48][5] + coeff0_49*dmats1[49][5] + coeff0_50*dmats1[50][5] + coeff0_51*dmats1[51][5] + coeff0_52*dmats1[52][5] + coeff0_53*dmats1[53][5] + coeff0_54*dmats1[54][5] + coeff0_55*dmats1[55][5];
          new_coeff0_6 = coeff0_0*dmats1[0][6] + coeff0_1*dmats1[1][6] + coeff0_2*dmats1[2][6] + coeff0_3*dmats1[3][6] + coeff0_4*dmats1[4][6] + coeff0_5*dmats1[5][6] + coeff0_6*dmats1[6][6] + coeff0_7*dmats1[7][6] + coeff0_8*dmats1[8][6] + coeff0_9*dmats1[9][6] + coeff0_10*dmats1[10][6] + coeff0_11*dmats1[11][6] + coeff0_12*dmats1[12][6] + coeff0_13*dmats1[13][6] + coeff0_14*dmats1[14][6] + coeff0_15*dmats1[15][6] + coeff0_16*dmats1[16][6] + coeff0_17*dmats1[17][6] + coeff0_18*dmats1[18][6] + coeff0_19*dmats1[19][6] + coeff0_20*dmats1[20][6] + coeff0_21*dmats1[21][6] + coeff0_22*dmats1[22][6] + coeff0_23*dmats1[23][6] + coeff0_24*dmats1[24][6] + coeff0_25*dmats1[25][6] + coeff0_26*dmats1[26][6] + coeff0_27*dmats1[27][6] + coeff0_28*dmats1[28][6] + coeff0_29*dmats1[29][6] + coeff0_30*dmats1[30][6] + coeff0_31*dmats1[31][6] + coeff0_32*dmats1[32][6] + coeff0_33*dmats1[33][6] + coeff0_34*dmats1[34][6] + coeff0_35*dmats1[35][6] + coeff0_36*dmats1[36][6] + coeff0_37*dmats1[37][6] + coeff0_38*dmats1[38][6] + coeff0_39*dmats1[39][6] + coeff0_40*dmats1[40][6] + coeff0_41*dmats1[41][6] + coeff0_42*dmats1[42][6] + coeff0_43*dmats1[43][6] + coeff0_44*dmats1[44][6] + coeff0_45*dmats1[45][6] + coeff0_46*dmats1[46][6] + coeff0_47*dmats1[47][6] + coeff0_48*dmats1[48][6] + coeff0_49*dmats1[49][6] + coeff0_50*dmats1[50][6] + coeff0_51*dmats1[51][6] + coeff0_52*dmats1[52][6] + coeff0_53*dmats1[53][6] + coeff0_54*dmats1[54][6] + coeff0_55*dmats1[55][6];
          new_coeff0_7 = coeff0_0*dmats1[0][7] + coeff0_1*dmats1[1][7] + coeff0_2*dmats1[2][7] + coeff0_3*dmats1[3][7] + coeff0_4*dmats1[4][7] + coeff0_5*dmats1[5][7] + coeff0_6*dmats1[6][7] + coeff0_7*dmats1[7][7] + coeff0_8*dmats1[8][7] + coeff0_9*dmats1[9][7] + coeff0_10*dmats1[10][7] + coeff0_11*dmats1[11][7] + coeff0_12*dmats1[12][7] + coeff0_13*dmats1[13][7] + coeff0_14*dmats1[14][7] + coeff0_15*dmats1[15][7] + coeff0_16*dmats1[16][7] + coeff0_17*dmats1[17][7] + coeff0_18*dmats1[18][7] + coeff0_19*dmats1[19][7] + coeff0_20*dmats1[20][7] + coeff0_21*dmats1[21][7] + coeff0_22*dmats1[22][7] + coeff0_23*dmats1[23][7] + coeff0_24*dmats1[24][7] + coeff0_25*dmats1[25][7] + coeff0_26*dmats1[26][7] + coeff0_27*dmats1[27][7] + coeff0_28*dmats1[28][7] + coeff0_29*dmats1[29][7] + coeff0_30*dmats1[30][7] + coeff0_31*dmats1[31][7] + coeff0_32*dmats1[32][7] + coeff0_33*dmats1[33][7] + coeff0_34*dmats1[34][7] + coeff0_35*dmats1[35][7] + coeff0_36*dmats1[36][7] + coeff0_37*dmats1[37][7] + coeff0_38*dmats1[38][7] + coeff0_39*dmats1[39][7] + coeff0_40*dmats1[40][7] + coeff0_41*dmats1[41][7] + coeff0_42*dmats1[42][7] + coeff0_43*dmats1[43][7] + coeff0_44*dmats1[44][7] + coeff0_45*dmats1[45][7] + coeff0_46*dmats1[46][7] + coeff0_47*dmats1[47][7] + coeff0_48*dmats1[48][7] + coeff0_49*dmats1[49][7] + coeff0_50*dmats1[50][7] + coeff0_51*dmats1[51][7] + coeff0_52*dmats1[52][7] + coeff0_53*dmats1[53][7] + coeff0_54*dmats1[54][7] + coeff0_55*dmats1[55][7];
          new_coeff0_8 = coeff0_0*dmats1[0][8] + coeff0_1*dmats1[1][8] + coeff0_2*dmats1[2][8] + coeff0_3*dmats1[3][8] + coeff0_4*dmats1[4][8] + coeff0_5*dmats1[5][8] + coeff0_6*dmats1[6][8] + coeff0_7*dmats1[7][8] + coeff0_8*dmats1[8][8] + coeff0_9*dmats1[9][8] + coeff0_10*dmats1[10][8] + coeff0_11*dmats1[11][8] + coeff0_12*dmats1[12][8] + coeff0_13*dmats1[13][8] + coeff0_14*dmats1[14][8] + coeff0_15*dmats1[15][8] + coeff0_16*dmats1[16][8] + coeff0_17*dmats1[17][8] + coeff0_18*dmats1[18][8] + coeff0_19*dmats1[19][8] + coeff0_20*dmats1[20][8] + coeff0_21*dmats1[21][8] + coeff0_22*dmats1[22][8] + coeff0_23*dmats1[23][8] + coeff0_24*dmats1[24][8] + coeff0_25*dmats1[25][8] + coeff0_26*dmats1[26][8] + coeff0_27*dmats1[27][8] + coeff0_28*dmats1[28][8] + coeff0_29*dmats1[29][8] + coeff0_30*dmats1[30][8] + coeff0_31*dmats1[31][8] + coeff0_32*dmats1[32][8] + coeff0_33*dmats1[33][8] + coeff0_34*dmats1[34][8] + coeff0_35*dmats1[35][8] + coeff0_36*dmats1[36][8] + coeff0_37*dmats1[37][8] + coeff0_38*dmats1[38][8] + coeff0_39*dmats1[39][8] + coeff0_40*dmats1[40][8] + coeff0_41*dmats1[41][8] + coeff0_42*dmats1[42][8] + coeff0_43*dmats1[43][8] + coeff0_44*dmats1[44][8] + coeff0_45*dmats1[45][8] + coeff0_46*dmats1[46][8] + coeff0_47*dmats1[47][8] + coeff0_48*dmats1[48][8] + coeff0_49*dmats1[49][8] + coeff0_50*dmats1[50][8] + coeff0_51*dmats1[51][8] + coeff0_52*dmats1[52][8] + coeff0_53*dmats1[53][8] + coeff0_54*dmats1[54][8] + coeff0_55*dmats1[55][8];
          new_coeff0_9 = coeff0_0*dmats1[0][9] + coeff0_1*dmats1[1][9] + coeff0_2*dmats1[2][9] + coeff0_3*dmats1[3][9] + coeff0_4*dmats1[4][9] + coeff0_5*dmats1[5][9] + coeff0_6*dmats1[6][9] + coeff0_7*dmats1[7][9] + coeff0_8*dmats1[8][9] + coeff0_9*dmats1[9][9] + coeff0_10*dmats1[10][9] + coeff0_11*dmats1[11][9] + coeff0_12*dmats1[12][9] + coeff0_13*dmats1[13][9] + coeff0_14*dmats1[14][9] + coeff0_15*dmats1[15][9] + coeff0_16*dmats1[16][9] + coeff0_17*dmats1[17][9] + coeff0_18*dmats1[18][9] + coeff0_19*dmats1[19][9] + coeff0_20*dmats1[20][9] + coeff0_21*dmats1[21][9] + coeff0_22*dmats1[22][9] + coeff0_23*dmats1[23][9] + coeff0_24*dmats1[24][9] + coeff0_25*dmats1[25][9] + coeff0_26*dmats1[26][9] + coeff0_27*dmats1[27][9] + coeff0_28*dmats1[28][9] + coeff0_29*dmats1[29][9] + coeff0_30*dmats1[30][9] + coeff0_31*dmats1[31][9] + coeff0_32*dmats1[32][9] + coeff0_33*dmats1[33][9] + coeff0_34*dmats1[34][9] + coeff0_35*dmats1[35][9] + coeff0_36*dmats1[36][9] + coeff0_37*dmats1[37][9] + coeff0_38*dmats1[38][9] + coeff0_39*dmats1[39][9] + coeff0_40*dmats1[40][9] + coeff0_41*dmats1[41][9] + coeff0_42*dmats1[42][9] + coeff0_43*dmats1[43][9] + coeff0_44*dmats1[44][9] + coeff0_45*dmats1[45][9] + coeff0_46*dmats1[46][9] + coeff0_47*dmats1[47][9] + coeff0_48*dmats1[48][9] + coeff0_49*dmats1[49][9] + coeff0_50*dmats1[50][9] + coeff0_51*dmats1[51][9] + coeff0_52*dmats1[52][9] + coeff0_53*dmats1[53][9] + coeff0_54*dmats1[54][9] + coeff0_55*dmats1[55][9];
          new_coeff0_10 = coeff0_0*dmats1[0][10] + coeff0_1*dmats1[1][10] + coeff0_2*dmats1[2][10] + coeff0_3*dmats1[3][10] + coeff0_4*dmats1[4][10] + coeff0_5*dmats1[5][10] + coeff0_6*dmats1[6][10] + coeff0_7*dmats1[7][10] + coeff0_8*dmats1[8][10] + coeff0_9*dmats1[9][10] + coeff0_10*dmats1[10][10] + coeff0_11*dmats1[11][10] + coeff0_12*dmats1[12][10] + coeff0_13*dmats1[13][10] + coeff0_14*dmats1[14][10] + coeff0_15*dmats1[15][10] + coeff0_16*dmats1[16][10] + coeff0_17*dmats1[17][10] + coeff0_18*dmats1[18][10] + coeff0_19*dmats1[19][10] + coeff0_20*dmats1[20][10] + coeff0_21*dmats1[21][10] + coeff0_22*dmats1[22][10] + coeff0_23*dmats1[23][10] + coeff0_24*dmats1[24][10] + coeff0_25*dmats1[25][10] + coeff0_26*dmats1[26][10] + coeff0_27*dmats1[27][10] + coeff0_28*dmats1[28][10] + coeff0_29*dmats1[29][10] + coeff0_30*dmats1[30][10] + coeff0_31*dmats1[31][10] + coeff0_32*dmats1[32][10] + coeff0_33*dmats1[33][10] + coeff0_34*dmats1[34][10] + coeff0_35*dmats1[35][10] + coeff0_36*dmats1[36][10] + coeff0_37*dmats1[37][10] + coeff0_38*dmats1[38][10] + coeff0_39*dmats1[39][10] + coeff0_40*dmats1[40][10] + coeff0_41*dmats1[41][10] + coeff0_42*dmats1[42][10] + coeff0_43*dmats1[43][10] + coeff0_44*dmats1[44][10] + coeff0_45*dmats1[45][10] + coeff0_46*dmats1[46][10] + coeff0_47*dmats1[47][10] + coeff0_48*dmats1[48][10] + coeff0_49*dmats1[49][10] + coeff0_50*dmats1[50][10] + coeff0_51*dmats1[51][10] + coeff0_52*dmats1[52][10] + coeff0_53*dmats1[53][10] + coeff0_54*dmats1[54][10] + coeff0_55*dmats1[55][10];
          new_coeff0_11 = coeff0_0*dmats1[0][11] + coeff0_1*dmats1[1][11] + coeff0_2*dmats1[2][11] + coeff0_3*dmats1[3][11] + coeff0_4*dmats1[4][11] + coeff0_5*dmats1[5][11] + coeff0_6*dmats1[6][11] + coeff0_7*dmats1[7][11] + coeff0_8*dmats1[8][11] + coeff0_9*dmats1[9][11] + coeff0_10*dmats1[10][11] + coeff0_11*dmats1[11][11] + coeff0_12*dmats1[12][11] + coeff0_13*dmats1[13][11] + coeff0_14*dmats1[14][11] + coeff0_15*dmats1[15][11] + coeff0_16*dmats1[16][11] + coeff0_17*dmats1[17][11] + coeff0_18*dmats1[18][11] + coeff0_19*dmats1[19][11] + coeff0_20*dmats1[20][11] + coeff0_21*dmats1[21][11] + coeff0_22*dmats1[22][11] + coeff0_23*dmats1[23][11] + coeff0_24*dmats1[24][11] + coeff0_25*dmats1[25][11] + coeff0_26*dmats1[26][11] + coeff0_27*dmats1[27][11] + coeff0_28*dmats1[28][11] + coeff0_29*dmats1[29][11] + coeff0_30*dmats1[30][11] + coeff0_31*dmats1[31][11] + coeff0_32*dmats1[32][11] + coeff0_33*dmats1[33][11] + coeff0_34*dmats1[34][11] + coeff0_35*dmats1[35][11] + coeff0_36*dmats1[36][11] + coeff0_37*dmats1[37][11] + coeff0_38*dmats1[38][11] + coeff0_39*dmats1[39][11] + coeff0_40*dmats1[40][11] + coeff0_41*dmats1[41][11] + coeff0_42*dmats1[42][11] + coeff0_43*dmats1[43][11] + coeff0_44*dmats1[44][11] + coeff0_45*dmats1[45][11] + coeff0_46*dmats1[46][11] + coeff0_47*dmats1[47][11] + coeff0_48*dmats1[48][11] + coeff0_49*dmats1[49][11] + coeff0_50*dmats1[50][11] + coeff0_51*dmats1[51][11] + coeff0_52*dmats1[52][11] + coeff0_53*dmats1[53][11] + coeff0_54*dmats1[54][11] + coeff0_55*dmats1[55][11];
          new_coeff0_12 = coeff0_0*dmats1[0][12] + coeff0_1*dmats1[1][12] + coeff0_2*dmats1[2][12] + coeff0_3*dmats1[3][12] + coeff0_4*dmats1[4][12] + coeff0_5*dmats1[5][12] + coeff0_6*dmats1[6][12] + coeff0_7*dmats1[7][12] + coeff0_8*dmats1[8][12] + coeff0_9*dmats1[9][12] + coeff0_10*dmats1[10][12] + coeff0_11*dmats1[11][12] + coeff0_12*dmats1[12][12] + coeff0_13*dmats1[13][12] + coeff0_14*dmats1[14][12] + coeff0_15*dmats1[15][12] + coeff0_16*dmats1[16][12] + coeff0_17*dmats1[17][12] + coeff0_18*dmats1[18][12] + coeff0_19*dmats1[19][12] + coeff0_20*dmats1[20][12] + coeff0_21*dmats1[21][12] + coeff0_22*dmats1[22][12] + coeff0_23*dmats1[23][12] + coeff0_24*dmats1[24][12] + coeff0_25*dmats1[25][12] + coeff0_26*dmats1[26][12] + coeff0_27*dmats1[27][12] + coeff0_28*dmats1[28][12] + coeff0_29*dmats1[29][12] + coeff0_30*dmats1[30][12] + coeff0_31*dmats1[31][12] + coeff0_32*dmats1[32][12] + coeff0_33*dmats1[33][12] + coeff0_34*dmats1[34][12] + coeff0_35*dmats1[35][12] + coeff0_36*dmats1[36][12] + coeff0_37*dmats1[37][12] + coeff0_38*dmats1[38][12] + coeff0_39*dmats1[39][12] + coeff0_40*dmats1[40][12] + coeff0_41*dmats1[41][12] + coeff0_42*dmats1[42][12] + coeff0_43*dmats1[43][12] + coeff0_44*dmats1[44][12] + coeff0_45*dmats1[45][12] + coeff0_46*dmats1[46][12] + coeff0_47*dmats1[47][12] + coeff0_48*dmats1[48][12] + coeff0_49*dmats1[49][12] + coeff0_50*dmats1[50][12] + coeff0_51*dmats1[51][12] + coeff0_52*dmats1[52][12] + coeff0_53*dmats1[53][12] + coeff0_54*dmats1[54][12] + coeff0_55*dmats1[55][12];
          new_coeff0_13 = coeff0_0*dmats1[0][13] + coeff0_1*dmats1[1][13] + coeff0_2*dmats1[2][13] + coeff0_3*dmats1[3][13] + coeff0_4*dmats1[4][13] + coeff0_5*dmats1[5][13] + coeff0_6*dmats1[6][13] + coeff0_7*dmats1[7][13] + coeff0_8*dmats1[8][13] + coeff0_9*dmats1[9][13] + coeff0_10*dmats1[10][13] + coeff0_11*dmats1[11][13] + coeff0_12*dmats1[12][13] + coeff0_13*dmats1[13][13] + coeff0_14*dmats1[14][13] + coeff0_15*dmats1[15][13] + coeff0_16*dmats1[16][13] + coeff0_17*dmats1[17][13] + coeff0_18*dmats1[18][13] + coeff0_19*dmats1[19][13] + coeff0_20*dmats1[20][13] + coeff0_21*dmats1[21][13] + coeff0_22*dmats1[22][13] + coeff0_23*dmats1[23][13] + coeff0_24*dmats1[24][13] + coeff0_25*dmats1[25][13] + coeff0_26*dmats1[26][13] + coeff0_27*dmats1[27][13] + coeff0_28*dmats1[28][13] + coeff0_29*dmats1[29][13] + coeff0_30*dmats1[30][13] + coeff0_31*dmats1[31][13] + coeff0_32*dmats1[32][13] + coeff0_33*dmats1[33][13] + coeff0_34*dmats1[34][13] + coeff0_35*dmats1[35][13] + coeff0_36*dmats1[36][13] + coeff0_37*dmats1[37][13] + coeff0_38*dmats1[38][13] + coeff0_39*dmats1[39][13] + coeff0_40*dmats1[40][13] + coeff0_41*dmats1[41][13] + coeff0_42*dmats1[42][13] + coeff0_43*dmats1[43][13] + coeff0_44*dmats1[44][13] + coeff0_45*dmats1[45][13] + coeff0_46*dmats1[46][13] + coeff0_47*dmats1[47][13] + coeff0_48*dmats1[48][13] + coeff0_49*dmats1[49][13] + coeff0_50*dmats1[50][13] + coeff0_51*dmats1[51][13] + coeff0_52*dmats1[52][13] + coeff0_53*dmats1[53][13] + coeff0_54*dmats1[54][13] + coeff0_55*dmats1[55][13];
          new_coeff0_14 = coeff0_0*dmats1[0][14] + coeff0_1*dmats1[1][14] + coeff0_2*dmats1[2][14] + coeff0_3*dmats1[3][14] + coeff0_4*dmats1[4][14] + coeff0_5*dmats1[5][14] + coeff0_6*dmats1[6][14] + coeff0_7*dmats1[7][14] + coeff0_8*dmats1[8][14] + coeff0_9*dmats1[9][14] + coeff0_10*dmats1[10][14] + coeff0_11*dmats1[11][14] + coeff0_12*dmats1[12][14] + coeff0_13*dmats1[13][14] + coeff0_14*dmats1[14][14] + coeff0_15*dmats1[15][14] + coeff0_16*dmats1[16][14] + coeff0_17*dmats1[17][14] + coeff0_18*dmats1[18][14] + coeff0_19*dmats1[19][14] + coeff0_20*dmats1[20][14] + coeff0_21*dmats1[21][14] + coeff0_22*dmats1[22][14] + coeff0_23*dmats1[23][14] + coeff0_24*dmats1[24][14] + coeff0_25*dmats1[25][14] + coeff0_26*dmats1[26][14] + coeff0_27*dmats1[27][14] + coeff0_28*dmats1[28][14] + coeff0_29*dmats1[29][14] + coeff0_30*dmats1[30][14] + coeff0_31*dmats1[31][14] + coeff0_32*dmats1[32][14] + coeff0_33*dmats1[33][14] + coeff0_34*dmats1[34][14] + coeff0_35*dmats1[35][14] + coeff0_36*dmats1[36][14] + coeff0_37*dmats1[37][14] + coeff0_38*dmats1[38][14] + coeff0_39*dmats1[39][14] + coeff0_40*dmats1[40][14] + coeff0_41*dmats1[41][14] + coeff0_42*dmats1[42][14] + coeff0_43*dmats1[43][14] + coeff0_44*dmats1[44][14] + coeff0_45*dmats1[45][14] + coeff0_46*dmats1[46][14] + coeff0_47*dmats1[47][14] + coeff0_48*dmats1[48][14] + coeff0_49*dmats1[49][14] + coeff0_50*dmats1[50][14] + coeff0_51*dmats1[51][14] + coeff0_52*dmats1[52][14] + coeff0_53*dmats1[53][14] + coeff0_54*dmats1[54][14] + coeff0_55*dmats1[55][14];
          new_coeff0_15 = coeff0_0*dmats1[0][15] + coeff0_1*dmats1[1][15] + coeff0_2*dmats1[2][15] + coeff0_3*dmats1[3][15] + coeff0_4*dmats1[4][15] + coeff0_5*dmats1[5][15] + coeff0_6*dmats1[6][15] + coeff0_7*dmats1[7][15] + coeff0_8*dmats1[8][15] + coeff0_9*dmats1[9][15] + coeff0_10*dmats1[10][15] + coeff0_11*dmats1[11][15] + coeff0_12*dmats1[12][15] + coeff0_13*dmats1[13][15] + coeff0_14*dmats1[14][15] + coeff0_15*dmats1[15][15] + coeff0_16*dmats1[16][15] + coeff0_17*dmats1[17][15] + coeff0_18*dmats1[18][15] + coeff0_19*dmats1[19][15] + coeff0_20*dmats1[20][15] + coeff0_21*dmats1[21][15] + coeff0_22*dmats1[22][15] + coeff0_23*dmats1[23][15] + coeff0_24*dmats1[24][15] + coeff0_25*dmats1[25][15] + coeff0_26*dmats1[26][15] + coeff0_27*dmats1[27][15] + coeff0_28*dmats1[28][15] + coeff0_29*dmats1[29][15] + coeff0_30*dmats1[30][15] + coeff0_31*dmats1[31][15] + coeff0_32*dmats1[32][15] + coeff0_33*dmats1[33][15] + coeff0_34*dmats1[34][15] + coeff0_35*dmats1[35][15] + coeff0_36*dmats1[36][15] + coeff0_37*dmats1[37][15] + coeff0_38*dmats1[38][15] + coeff0_39*dmats1[39][15] + coeff0_40*dmats1[40][15] + coeff0_41*dmats1[41][15] + coeff0_42*dmats1[42][15] + coeff0_43*dmats1[43][15] + coeff0_44*dmats1[44][15] + coeff0_45*dmats1[45][15] + coeff0_46*dmats1[46][15] + coeff0_47*dmats1[47][15] + coeff0_48*dmats1[48][15] + coeff0_49*dmats1[49][15] + coeff0_50*dmats1[50][15] + coeff0_51*dmats1[51][15] + coeff0_52*dmats1[52][15] + coeff0_53*dmats1[53][15] + coeff0_54*dmats1[54][15] + coeff0_55*dmats1[55][15];
          new_coeff0_16 = coeff0_0*dmats1[0][16] + coeff0_1*dmats1[1][16] + coeff0_2*dmats1[2][16] + coeff0_3*dmats1[3][16] + coeff0_4*dmats1[4][16] + coeff0_5*dmats1[5][16] + coeff0_6*dmats1[6][16] + coeff0_7*dmats1[7][16] + coeff0_8*dmats1[8][16] + coeff0_9*dmats1[9][16] + coeff0_10*dmats1[10][16] + coeff0_11*dmats1[11][16] + coeff0_12*dmats1[12][16] + coeff0_13*dmats1[13][16] + coeff0_14*dmats1[14][16] + coeff0_15*dmats1[15][16] + coeff0_16*dmats1[16][16] + coeff0_17*dmats1[17][16] + coeff0_18*dmats1[18][16] + coeff0_19*dmats1[19][16] + coeff0_20*dmats1[20][16] + coeff0_21*dmats1[21][16] + coeff0_22*dmats1[22][16] + coeff0_23*dmats1[23][16] + coeff0_24*dmats1[24][16] + coeff0_25*dmats1[25][16] + coeff0_26*dmats1[26][16] + coeff0_27*dmats1[27][16] + coeff0_28*dmats1[28][16] + coeff0_29*dmats1[29][16] + coeff0_30*dmats1[30][16] + coeff0_31*dmats1[31][16] + coeff0_32*dmats1[32][16] + coeff0_33*dmats1[33][16] + coeff0_34*dmats1[34][16] + coeff0_35*dmats1[35][16] + coeff0_36*dmats1[36][16] + coeff0_37*dmats1[37][16] + coeff0_38*dmats1[38][16] + coeff0_39*dmats1[39][16] + coeff0_40*dmats1[40][16] + coeff0_41*dmats1[41][16] + coeff0_42*dmats1[42][16] + coeff0_43*dmats1[43][16] + coeff0_44*dmats1[44][16] + coeff0_45*dmats1[45][16] + coeff0_46*dmats1[46][16] + coeff0_47*dmats1[47][16] + coeff0_48*dmats1[48][16] + coeff0_49*dmats1[49][16] + coeff0_50*dmats1[50][16] + coeff0_51*dmats1[51][16] + coeff0_52*dmats1[52][16] + coeff0_53*dmats1[53][16] + coeff0_54*dmats1[54][16] + coeff0_55*dmats1[55][16];
          new_coeff0_17 = coeff0_0*dmats1[0][17] + coeff0_1*dmats1[1][17] + coeff0_2*dmats1[2][17] + coeff0_3*dmats1[3][17] + coeff0_4*dmats1[4][17] + coeff0_5*dmats1[5][17] + coeff0_6*dmats1[6][17] + coeff0_7*dmats1[7][17] + coeff0_8*dmats1[8][17] + coeff0_9*dmats1[9][17] + coeff0_10*dmats1[10][17] + coeff0_11*dmats1[11][17] + coeff0_12*dmats1[12][17] + coeff0_13*dmats1[13][17] + coeff0_14*dmats1[14][17] + coeff0_15*dmats1[15][17] + coeff0_16*dmats1[16][17] + coeff0_17*dmats1[17][17] + coeff0_18*dmats1[18][17] + coeff0_19*dmats1[19][17] + coeff0_20*dmats1[20][17] + coeff0_21*dmats1[21][17] + coeff0_22*dmats1[22][17] + coeff0_23*dmats1[23][17] + coeff0_24*dmats1[24][17] + coeff0_25*dmats1[25][17] + coeff0_26*dmats1[26][17] + coeff0_27*dmats1[27][17] + coeff0_28*dmats1[28][17] + coeff0_29*dmats1[29][17] + coeff0_30*dmats1[30][17] + coeff0_31*dmats1[31][17] + coeff0_32*dmats1[32][17] + coeff0_33*dmats1[33][17] + coeff0_34*dmats1[34][17] + coeff0_35*dmats1[35][17] + coeff0_36*dmats1[36][17] + coeff0_37*dmats1[37][17] + coeff0_38*dmats1[38][17] + coeff0_39*dmats1[39][17] + coeff0_40*dmats1[40][17] + coeff0_41*dmats1[41][17] + coeff0_42*dmats1[42][17] + coeff0_43*dmats1[43][17] + coeff0_44*dmats1[44][17] + coeff0_45*dmats1[45][17] + coeff0_46*dmats1[46][17] + coeff0_47*dmats1[47][17] + coeff0_48*dmats1[48][17] + coeff0_49*dmats1[49][17] + coeff0_50*dmats1[50][17] + coeff0_51*dmats1[51][17] + coeff0_52*dmats1[52][17] + coeff0_53*dmats1[53][17] + coeff0_54*dmats1[54][17] + coeff0_55*dmats1[55][17];
          new_coeff0_18 = coeff0_0*dmats1[0][18] + coeff0_1*dmats1[1][18] + coeff0_2*dmats1[2][18] + coeff0_3*dmats1[3][18] + coeff0_4*dmats1[4][18] + coeff0_5*dmats1[5][18] + coeff0_6*dmats1[6][18] + coeff0_7*dmats1[7][18] + coeff0_8*dmats1[8][18] + coeff0_9*dmats1[9][18] + coeff0_10*dmats1[10][18] + coeff0_11*dmats1[11][18] + coeff0_12*dmats1[12][18] + coeff0_13*dmats1[13][18] + coeff0_14*dmats1[14][18] + coeff0_15*dmats1[15][18] + coeff0_16*dmats1[16][18] + coeff0_17*dmats1[17][18] + coeff0_18*dmats1[18][18] + coeff0_19*dmats1[19][18] + coeff0_20*dmats1[20][18] + coeff0_21*dmats1[21][18] + coeff0_22*dmats1[22][18] + coeff0_23*dmats1[23][18] + coeff0_24*dmats1[24][18] + coeff0_25*dmats1[25][18] + coeff0_26*dmats1[26][18] + coeff0_27*dmats1[27][18] + coeff0_28*dmats1[28][18] + coeff0_29*dmats1[29][18] + coeff0_30*dmats1[30][18] + coeff0_31*dmats1[31][18] + coeff0_32*dmats1[32][18] + coeff0_33*dmats1[33][18] + coeff0_34*dmats1[34][18] + coeff0_35*dmats1[35][18] + coeff0_36*dmats1[36][18] + coeff0_37*dmats1[37][18] + coeff0_38*dmats1[38][18] + coeff0_39*dmats1[39][18] + coeff0_40*dmats1[40][18] + coeff0_41*dmats1[41][18] + coeff0_42*dmats1[42][18] + coeff0_43*dmats1[43][18] + coeff0_44*dmats1[44][18] + coeff0_45*dmats1[45][18] + coeff0_46*dmats1[46][18] + coeff0_47*dmats1[47][18] + coeff0_48*dmats1[48][18] + coeff0_49*dmats1[49][18] + coeff0_50*dmats1[50][18] + coeff0_51*dmats1[51][18] + coeff0_52*dmats1[52][18] + coeff0_53*dmats1[53][18] + coeff0_54*dmats1[54][18] + coeff0_55*dmats1[55][18];
          new_coeff0_19 = coeff0_0*dmats1[0][19] + coeff0_1*dmats1[1][19] + coeff0_2*dmats1[2][19] + coeff0_3*dmats1[3][19] + coeff0_4*dmats1[4][19] + coeff0_5*dmats1[5][19] + coeff0_6*dmats1[6][19] + coeff0_7*dmats1[7][19] + coeff0_8*dmats1[8][19] + coeff0_9*dmats1[9][19] + coeff0_10*dmats1[10][19] + coeff0_11*dmats1[11][19] + coeff0_12*dmats1[12][19] + coeff0_13*dmats1[13][19] + coeff0_14*dmats1[14][19] + coeff0_15*dmats1[15][19] + coeff0_16*dmats1[16][19] + coeff0_17*dmats1[17][19] + coeff0_18*dmats1[18][19] + coeff0_19*dmats1[19][19] + coeff0_20*dmats1[20][19] + coeff0_21*dmats1[21][19] + coeff0_22*dmats1[22][19] + coeff0_23*dmats1[23][19] + coeff0_24*dmats1[24][19] + coeff0_25*dmats1[25][19] + coeff0_26*dmats1[26][19] + coeff0_27*dmats1[27][19] + coeff0_28*dmats1[28][19] + coeff0_29*dmats1[29][19] + coeff0_30*dmats1[30][19] + coeff0_31*dmats1[31][19] + coeff0_32*dmats1[32][19] + coeff0_33*dmats1[33][19] + coeff0_34*dmats1[34][19] + coeff0_35*dmats1[35][19] + coeff0_36*dmats1[36][19] + coeff0_37*dmats1[37][19] + coeff0_38*dmats1[38][19] + coeff0_39*dmats1[39][19] + coeff0_40*dmats1[40][19] + coeff0_41*dmats1[41][19] + coeff0_42*dmats1[42][19] + coeff0_43*dmats1[43][19] + coeff0_44*dmats1[44][19] + coeff0_45*dmats1[45][19] + coeff0_46*dmats1[46][19] + coeff0_47*dmats1[47][19] + coeff0_48*dmats1[48][19] + coeff0_49*dmats1[49][19] + coeff0_50*dmats1[50][19] + coeff0_51*dmats1[51][19] + coeff0_52*dmats1[52][19] + coeff0_53*dmats1[53][19] + coeff0_54*dmats1[54][19] + coeff0_55*dmats1[55][19];
          new_coeff0_20 = coeff0_0*dmats1[0][20] + coeff0_1*dmats1[1][20] + coeff0_2*dmats1[2][20] + coeff0_3*dmats1[3][20] + coeff0_4*dmats1[4][20] + coeff0_5*dmats1[5][20] + coeff0_6*dmats1[6][20] + coeff0_7*dmats1[7][20] + coeff0_8*dmats1[8][20] + coeff0_9*dmats1[9][20] + coeff0_10*dmats1[10][20] + coeff0_11*dmats1[11][20] + coeff0_12*dmats1[12][20] + coeff0_13*dmats1[13][20] + coeff0_14*dmats1[14][20] + coeff0_15*dmats1[15][20] + coeff0_16*dmats1[16][20] + coeff0_17*dmats1[17][20] + coeff0_18*dmats1[18][20] + coeff0_19*dmats1[19][20] + coeff0_20*dmats1[20][20] + coeff0_21*dmats1[21][20] + coeff0_22*dmats1[22][20] + coeff0_23*dmats1[23][20] + coeff0_24*dmats1[24][20] + coeff0_25*dmats1[25][20] + coeff0_26*dmats1[26][20] + coeff0_27*dmats1[27][20] + coeff0_28*dmats1[28][20] + coeff0_29*dmats1[29][20] + coeff0_30*dmats1[30][20] + coeff0_31*dmats1[31][20] + coeff0_32*dmats1[32][20] + coeff0_33*dmats1[33][20] + coeff0_34*dmats1[34][20] + coeff0_35*dmats1[35][20] + coeff0_36*dmats1[36][20] + coeff0_37*dmats1[37][20] + coeff0_38*dmats1[38][20] + coeff0_39*dmats1[39][20] + coeff0_40*dmats1[40][20] + coeff0_41*dmats1[41][20] + coeff0_42*dmats1[42][20] + coeff0_43*dmats1[43][20] + coeff0_44*dmats1[44][20] + coeff0_45*dmats1[45][20] + coeff0_46*dmats1[46][20] + coeff0_47*dmats1[47][20] + coeff0_48*dmats1[48][20] + coeff0_49*dmats1[49][20] + coeff0_50*dmats1[50][20] + coeff0_51*dmats1[51][20] + coeff0_52*dmats1[52][20] + coeff0_53*dmats1[53][20] + coeff0_54*dmats1[54][20] + coeff0_55*dmats1[55][20];
          new_coeff0_21 = coeff0_0*dmats1[0][21] + coeff0_1*dmats1[1][21] + coeff0_2*dmats1[2][21] + coeff0_3*dmats1[3][21] + coeff0_4*dmats1[4][21] + coeff0_5*dmats1[5][21] + coeff0_6*dmats1[6][21] + coeff0_7*dmats1[7][21] + coeff0_8*dmats1[8][21] + coeff0_9*dmats1[9][21] + coeff0_10*dmats1[10][21] + coeff0_11*dmats1[11][21] + coeff0_12*dmats1[12][21] + coeff0_13*dmats1[13][21] + coeff0_14*dmats1[14][21] + coeff0_15*dmats1[15][21] + coeff0_16*dmats1[16][21] + coeff0_17*dmats1[17][21] + coeff0_18*dmats1[18][21] + coeff0_19*dmats1[19][21] + coeff0_20*dmats1[20][21] + coeff0_21*dmats1[21][21] + coeff0_22*dmats1[22][21] + coeff0_23*dmats1[23][21] + coeff0_24*dmats1[24][21] + coeff0_25*dmats1[25][21] + coeff0_26*dmats1[26][21] + coeff0_27*dmats1[27][21] + coeff0_28*dmats1[28][21] + coeff0_29*dmats1[29][21] + coeff0_30*dmats1[30][21] + coeff0_31*dmats1[31][21] + coeff0_32*dmats1[32][21] + coeff0_33*dmats1[33][21] + coeff0_34*dmats1[34][21] + coeff0_35*dmats1[35][21] + coeff0_36*dmats1[36][21] + coeff0_37*dmats1[37][21] + coeff0_38*dmats1[38][21] + coeff0_39*dmats1[39][21] + coeff0_40*dmats1[40][21] + coeff0_41*dmats1[41][21] + coeff0_42*dmats1[42][21] + coeff0_43*dmats1[43][21] + coeff0_44*dmats1[44][21] + coeff0_45*dmats1[45][21] + coeff0_46*dmats1[46][21] + coeff0_47*dmats1[47][21] + coeff0_48*dmats1[48][21] + coeff0_49*dmats1[49][21] + coeff0_50*dmats1[50][21] + coeff0_51*dmats1[51][21] + coeff0_52*dmats1[52][21] + coeff0_53*dmats1[53][21] + coeff0_54*dmats1[54][21] + coeff0_55*dmats1[55][21];
          new_coeff0_22 = coeff0_0*dmats1[0][22] + coeff0_1*dmats1[1][22] + coeff0_2*dmats1[2][22] + coeff0_3*dmats1[3][22] + coeff0_4*dmats1[4][22] + coeff0_5*dmats1[5][22] + coeff0_6*dmats1[6][22] + coeff0_7*dmats1[7][22] + coeff0_8*dmats1[8][22] + coeff0_9*dmats1[9][22] + coeff0_10*dmats1[10][22] + coeff0_11*dmats1[11][22] + coeff0_12*dmats1[12][22] + coeff0_13*dmats1[13][22] + coeff0_14*dmats1[14][22] + coeff0_15*dmats1[15][22] + coeff0_16*dmats1[16][22] + coeff0_17*dmats1[17][22] + coeff0_18*dmats1[18][22] + coeff0_19*dmats1[19][22] + coeff0_20*dmats1[20][22] + coeff0_21*dmats1[21][22] + coeff0_22*dmats1[22][22] + coeff0_23*dmats1[23][22] + coeff0_24*dmats1[24][22] + coeff0_25*dmats1[25][22] + coeff0_26*dmats1[26][22] + coeff0_27*dmats1[27][22] + coeff0_28*dmats1[28][22] + coeff0_29*dmats1[29][22] + coeff0_30*dmats1[30][22] + coeff0_31*dmats1[31][22] + coeff0_32*dmats1[32][22] + coeff0_33*dmats1[33][22] + coeff0_34*dmats1[34][22] + coeff0_35*dmats1[35][22] + coeff0_36*dmats1[36][22] + coeff0_37*dmats1[37][22] + coeff0_38*dmats1[38][22] + coeff0_39*dmats1[39][22] + coeff0_40*dmats1[40][22] + coeff0_41*dmats1[41][22] + coeff0_42*dmats1[42][22] + coeff0_43*dmats1[43][22] + coeff0_44*dmats1[44][22] + coeff0_45*dmats1[45][22] + coeff0_46*dmats1[46][22] + coeff0_47*dmats1[47][22] + coeff0_48*dmats1[48][22] + coeff0_49*dmats1[49][22] + coeff0_50*dmats1[50][22] + coeff0_51*dmats1[51][22] + coeff0_52*dmats1[52][22] + coeff0_53*dmats1[53][22] + coeff0_54*dmats1[54][22] + coeff0_55*dmats1[55][22];
          new_coeff0_23 = coeff0_0*dmats1[0][23] + coeff0_1*dmats1[1][23] + coeff0_2*dmats1[2][23] + coeff0_3*dmats1[3][23] + coeff0_4*dmats1[4][23] + coeff0_5*dmats1[5][23] + coeff0_6*dmats1[6][23] + coeff0_7*dmats1[7][23] + coeff0_8*dmats1[8][23] + coeff0_9*dmats1[9][23] + coeff0_10*dmats1[10][23] + coeff0_11*dmats1[11][23] + coeff0_12*dmats1[12][23] + coeff0_13*dmats1[13][23] + coeff0_14*dmats1[14][23] + coeff0_15*dmats1[15][23] + coeff0_16*dmats1[16][23] + coeff0_17*dmats1[17][23] + coeff0_18*dmats1[18][23] + coeff0_19*dmats1[19][23] + coeff0_20*dmats1[20][23] + coeff0_21*dmats1[21][23] + coeff0_22*dmats1[22][23] + coeff0_23*dmats1[23][23] + coeff0_24*dmats1[24][23] + coeff0_25*dmats1[25][23] + coeff0_26*dmats1[26][23] + coeff0_27*dmats1[27][23] + coeff0_28*dmats1[28][23] + coeff0_29*dmats1[29][23] + coeff0_30*dmats1[30][23] + coeff0_31*dmats1[31][23] + coeff0_32*dmats1[32][23] + coeff0_33*dmats1[33][23] + coeff0_34*dmats1[34][23] + coeff0_35*dmats1[35][23] + coeff0_36*dmats1[36][23] + coeff0_37*dmats1[37][23] + coeff0_38*dmats1[38][23] + coeff0_39*dmats1[39][23] + coeff0_40*dmats1[40][23] + coeff0_41*dmats1[41][23] + coeff0_42*dmats1[42][23] + coeff0_43*dmats1[43][23] + coeff0_44*dmats1[44][23] + coeff0_45*dmats1[45][23] + coeff0_46*dmats1[46][23] + coeff0_47*dmats1[47][23] + coeff0_48*dmats1[48][23] + coeff0_49*dmats1[49][23] + coeff0_50*dmats1[50][23] + coeff0_51*dmats1[51][23] + coeff0_52*dmats1[52][23] + coeff0_53*dmats1[53][23] + coeff0_54*dmats1[54][23] + coeff0_55*dmats1[55][23];
          new_coeff0_24 = coeff0_0*dmats1[0][24] + coeff0_1*dmats1[1][24] + coeff0_2*dmats1[2][24] + coeff0_3*dmats1[3][24] + coeff0_4*dmats1[4][24] + coeff0_5*dmats1[5][24] + coeff0_6*dmats1[6][24] + coeff0_7*dmats1[7][24] + coeff0_8*dmats1[8][24] + coeff0_9*dmats1[9][24] + coeff0_10*dmats1[10][24] + coeff0_11*dmats1[11][24] + coeff0_12*dmats1[12][24] + coeff0_13*dmats1[13][24] + coeff0_14*dmats1[14][24] + coeff0_15*dmats1[15][24] + coeff0_16*dmats1[16][24] + coeff0_17*dmats1[17][24] + coeff0_18*dmats1[18][24] + coeff0_19*dmats1[19][24] + coeff0_20*dmats1[20][24] + coeff0_21*dmats1[21][24] + coeff0_22*dmats1[22][24] + coeff0_23*dmats1[23][24] + coeff0_24*dmats1[24][24] + coeff0_25*dmats1[25][24] + coeff0_26*dmats1[26][24] + coeff0_27*dmats1[27][24] + coeff0_28*dmats1[28][24] + coeff0_29*dmats1[29][24] + coeff0_30*dmats1[30][24] + coeff0_31*dmats1[31][24] + coeff0_32*dmats1[32][24] + coeff0_33*dmats1[33][24] + coeff0_34*dmats1[34][24] + coeff0_35*dmats1[35][24] + coeff0_36*dmats1[36][24] + coeff0_37*dmats1[37][24] + coeff0_38*dmats1[38][24] + coeff0_39*dmats1[39][24] + coeff0_40*dmats1[40][24] + coeff0_41*dmats1[41][24] + coeff0_42*dmats1[42][24] + coeff0_43*dmats1[43][24] + coeff0_44*dmats1[44][24] + coeff0_45*dmats1[45][24] + coeff0_46*dmats1[46][24] + coeff0_47*dmats1[47][24] + coeff0_48*dmats1[48][24] + coeff0_49*dmats1[49][24] + coeff0_50*dmats1[50][24] + coeff0_51*dmats1[51][24] + coeff0_52*dmats1[52][24] + coeff0_53*dmats1[53][24] + coeff0_54*dmats1[54][24] + coeff0_55*dmats1[55][24];
          new_coeff0_25 = coeff0_0*dmats1[0][25] + coeff0_1*dmats1[1][25] + coeff0_2*dmats1[2][25] + coeff0_3*dmats1[3][25] + coeff0_4*dmats1[4][25] + coeff0_5*dmats1[5][25] + coeff0_6*dmats1[6][25] + coeff0_7*dmats1[7][25] + coeff0_8*dmats1[8][25] + coeff0_9*dmats1[9][25] + coeff0_10*dmats1[10][25] + coeff0_11*dmats1[11][25] + coeff0_12*dmats1[12][25] + coeff0_13*dmats1[13][25] + coeff0_14*dmats1[14][25] + coeff0_15*dmats1[15][25] + coeff0_16*dmats1[16][25] + coeff0_17*dmats1[17][25] + coeff0_18*dmats1[18][25] + coeff0_19*dmats1[19][25] + coeff0_20*dmats1[20][25] + coeff0_21*dmats1[21][25] + coeff0_22*dmats1[22][25] + coeff0_23*dmats1[23][25] + coeff0_24*dmats1[24][25] + coeff0_25*dmats1[25][25] + coeff0_26*dmats1[26][25] + coeff0_27*dmats1[27][25] + coeff0_28*dmats1[28][25] + coeff0_29*dmats1[29][25] + coeff0_30*dmats1[30][25] + coeff0_31*dmats1[31][25] + coeff0_32*dmats1[32][25] + coeff0_33*dmats1[33][25] + coeff0_34*dmats1[34][25] + coeff0_35*dmats1[35][25] + coeff0_36*dmats1[36][25] + coeff0_37*dmats1[37][25] + coeff0_38*dmats1[38][25] + coeff0_39*dmats1[39][25] + coeff0_40*dmats1[40][25] + coeff0_41*dmats1[41][25] + coeff0_42*dmats1[42][25] + coeff0_43*dmats1[43][25] + coeff0_44*dmats1[44][25] + coeff0_45*dmats1[45][25] + coeff0_46*dmats1[46][25] + coeff0_47*dmats1[47][25] + coeff0_48*dmats1[48][25] + coeff0_49*dmats1[49][25] + coeff0_50*dmats1[50][25] + coeff0_51*dmats1[51][25] + coeff0_52*dmats1[52][25] + coeff0_53*dmats1[53][25] + coeff0_54*dmats1[54][25] + coeff0_55*dmats1[55][25];
          new_coeff0_26 = coeff0_0*dmats1[0][26] + coeff0_1*dmats1[1][26] + coeff0_2*dmats1[2][26] + coeff0_3*dmats1[3][26] + coeff0_4*dmats1[4][26] + coeff0_5*dmats1[5][26] + coeff0_6*dmats1[6][26] + coeff0_7*dmats1[7][26] + coeff0_8*dmats1[8][26] + coeff0_9*dmats1[9][26] + coeff0_10*dmats1[10][26] + coeff0_11*dmats1[11][26] + coeff0_12*dmats1[12][26] + coeff0_13*dmats1[13][26] + coeff0_14*dmats1[14][26] + coeff0_15*dmats1[15][26] + coeff0_16*dmats1[16][26] + coeff0_17*dmats1[17][26] + coeff0_18*dmats1[18][26] + coeff0_19*dmats1[19][26] + coeff0_20*dmats1[20][26] + coeff0_21*dmats1[21][26] + coeff0_22*dmats1[22][26] + coeff0_23*dmats1[23][26] + coeff0_24*dmats1[24][26] + coeff0_25*dmats1[25][26] + coeff0_26*dmats1[26][26] + coeff0_27*dmats1[27][26] + coeff0_28*dmats1[28][26] + coeff0_29*dmats1[29][26] + coeff0_30*dmats1[30][26] + coeff0_31*dmats1[31][26] + coeff0_32*dmats1[32][26] + coeff0_33*dmats1[33][26] + coeff0_34*dmats1[34][26] + coeff0_35*dmats1[35][26] + coeff0_36*dmats1[36][26] + coeff0_37*dmats1[37][26] + coeff0_38*dmats1[38][26] + coeff0_39*dmats1[39][26] + coeff0_40*dmats1[40][26] + coeff0_41*dmats1[41][26] + coeff0_42*dmats1[42][26] + coeff0_43*dmats1[43][26] + coeff0_44*dmats1[44][26] + coeff0_45*dmats1[45][26] + coeff0_46*dmats1[46][26] + coeff0_47*dmats1[47][26] + coeff0_48*dmats1[48][26] + coeff0_49*dmats1[49][26] + coeff0_50*dmats1[50][26] + coeff0_51*dmats1[51][26] + coeff0_52*dmats1[52][26] + coeff0_53*dmats1[53][26] + coeff0_54*dmats1[54][26] + coeff0_55*dmats1[55][26];
          new_coeff0_27 = coeff0_0*dmats1[0][27] + coeff0_1*dmats1[1][27] + coeff0_2*dmats1[2][27] + coeff0_3*dmats1[3][27] + coeff0_4*dmats1[4][27] + coeff0_5*dmats1[5][27] + coeff0_6*dmats1[6][27] + coeff0_7*dmats1[7][27] + coeff0_8*dmats1[8][27] + coeff0_9*dmats1[9][27] + coeff0_10*dmats1[10][27] + coeff0_11*dmats1[11][27] + coeff0_12*dmats1[12][27] + coeff0_13*dmats1[13][27] + coeff0_14*dmats1[14][27] + coeff0_15*dmats1[15][27] + coeff0_16*dmats1[16][27] + coeff0_17*dmats1[17][27] + coeff0_18*dmats1[18][27] + coeff0_19*dmats1[19][27] + coeff0_20*dmats1[20][27] + coeff0_21*dmats1[21][27] + coeff0_22*dmats1[22][27] + coeff0_23*dmats1[23][27] + coeff0_24*dmats1[24][27] + coeff0_25*dmats1[25][27] + coeff0_26*dmats1[26][27] + coeff0_27*dmats1[27][27] + coeff0_28*dmats1[28][27] + coeff0_29*dmats1[29][27] + coeff0_30*dmats1[30][27] + coeff0_31*dmats1[31][27] + coeff0_32*dmats1[32][27] + coeff0_33*dmats1[33][27] + coeff0_34*dmats1[34][27] + coeff0_35*dmats1[35][27] + coeff0_36*dmats1[36][27] + coeff0_37*dmats1[37][27] + coeff0_38*dmats1[38][27] + coeff0_39*dmats1[39][27] + coeff0_40*dmats1[40][27] + coeff0_41*dmats1[41][27] + coeff0_42*dmats1[42][27] + coeff0_43*dmats1[43][27] + coeff0_44*dmats1[44][27] + coeff0_45*dmats1[45][27] + coeff0_46*dmats1[46][27] + coeff0_47*dmats1[47][27] + coeff0_48*dmats1[48][27] + coeff0_49*dmats1[49][27] + coeff0_50*dmats1[50][27] + coeff0_51*dmats1[51][27] + coeff0_52*dmats1[52][27] + coeff0_53*dmats1[53][27] + coeff0_54*dmats1[54][27] + coeff0_55*dmats1[55][27];
          new_coeff0_28 = coeff0_0*dmats1[0][28] + coeff0_1*dmats1[1][28] + coeff0_2*dmats1[2][28] + coeff0_3*dmats1[3][28] + coeff0_4*dmats1[4][28] + coeff0_5*dmats1[5][28] + coeff0_6*dmats1[6][28] + coeff0_7*dmats1[7][28] + coeff0_8*dmats1[8][28] + coeff0_9*dmats1[9][28] + coeff0_10*dmats1[10][28] + coeff0_11*dmats1[11][28] + coeff0_12*dmats1[12][28] + coeff0_13*dmats1[13][28] + coeff0_14*dmats1[14][28] + coeff0_15*dmats1[15][28] + coeff0_16*dmats1[16][28] + coeff0_17*dmats1[17][28] + coeff0_18*dmats1[18][28] + coeff0_19*dmats1[19][28] + coeff0_20*dmats1[20][28] + coeff0_21*dmats1[21][28] + coeff0_22*dmats1[22][28] + coeff0_23*dmats1[23][28] + coeff0_24*dmats1[24][28] + coeff0_25*dmats1[25][28] + coeff0_26*dmats1[26][28] + coeff0_27*dmats1[27][28] + coeff0_28*dmats1[28][28] + coeff0_29*dmats1[29][28] + coeff0_30*dmats1[30][28] + coeff0_31*dmats1[31][28] + coeff0_32*dmats1[32][28] + coeff0_33*dmats1[33][28] + coeff0_34*dmats1[34][28] + coeff0_35*dmats1[35][28] + coeff0_36*dmats1[36][28] + coeff0_37*dmats1[37][28] + coeff0_38*dmats1[38][28] + coeff0_39*dmats1[39][28] + coeff0_40*dmats1[40][28] + coeff0_41*dmats1[41][28] + coeff0_42*dmats1[42][28] + coeff0_43*dmats1[43][28] + coeff0_44*dmats1[44][28] + coeff0_45*dmats1[45][28] + coeff0_46*dmats1[46][28] + coeff0_47*dmats1[47][28] + coeff0_48*dmats1[48][28] + coeff0_49*dmats1[49][28] + coeff0_50*dmats1[50][28] + coeff0_51*dmats1[51][28] + coeff0_52*dmats1[52][28] + coeff0_53*dmats1[53][28] + coeff0_54*dmats1[54][28] + coeff0_55*dmats1[55][28];
          new_coeff0_29 = coeff0_0*dmats1[0][29] + coeff0_1*dmats1[1][29] + coeff0_2*dmats1[2][29] + coeff0_3*dmats1[3][29] + coeff0_4*dmats1[4][29] + coeff0_5*dmats1[5][29] + coeff0_6*dmats1[6][29] + coeff0_7*dmats1[7][29] + coeff0_8*dmats1[8][29] + coeff0_9*dmats1[9][29] + coeff0_10*dmats1[10][29] + coeff0_11*dmats1[11][29] + coeff0_12*dmats1[12][29] + coeff0_13*dmats1[13][29] + coeff0_14*dmats1[14][29] + coeff0_15*dmats1[15][29] + coeff0_16*dmats1[16][29] + coeff0_17*dmats1[17][29] + coeff0_18*dmats1[18][29] + coeff0_19*dmats1[19][29] + coeff0_20*dmats1[20][29] + coeff0_21*dmats1[21][29] + coeff0_22*dmats1[22][29] + coeff0_23*dmats1[23][29] + coeff0_24*dmats1[24][29] + coeff0_25*dmats1[25][29] + coeff0_26*dmats1[26][29] + coeff0_27*dmats1[27][29] + coeff0_28*dmats1[28][29] + coeff0_29*dmats1[29][29] + coeff0_30*dmats1[30][29] + coeff0_31*dmats1[31][29] + coeff0_32*dmats1[32][29] + coeff0_33*dmats1[33][29] + coeff0_34*dmats1[34][29] + coeff0_35*dmats1[35][29] + coeff0_36*dmats1[36][29] + coeff0_37*dmats1[37][29] + coeff0_38*dmats1[38][29] + coeff0_39*dmats1[39][29] + coeff0_40*dmats1[40][29] + coeff0_41*dmats1[41][29] + coeff0_42*dmats1[42][29] + coeff0_43*dmats1[43][29] + coeff0_44*dmats1[44][29] + coeff0_45*dmats1[45][29] + coeff0_46*dmats1[46][29] + coeff0_47*dmats1[47][29] + coeff0_48*dmats1[48][29] + coeff0_49*dmats1[49][29] + coeff0_50*dmats1[50][29] + coeff0_51*dmats1[51][29] + coeff0_52*dmats1[52][29] + coeff0_53*dmats1[53][29] + coeff0_54*dmats1[54][29] + coeff0_55*dmats1[55][29];
          new_coeff0_30 = coeff0_0*dmats1[0][30] + coeff0_1*dmats1[1][30] + coeff0_2*dmats1[2][30] + coeff0_3*dmats1[3][30] + coeff0_4*dmats1[4][30] + coeff0_5*dmats1[5][30] + coeff0_6*dmats1[6][30] + coeff0_7*dmats1[7][30] + coeff0_8*dmats1[8][30] + coeff0_9*dmats1[9][30] + coeff0_10*dmats1[10][30] + coeff0_11*dmats1[11][30] + coeff0_12*dmats1[12][30] + coeff0_13*dmats1[13][30] + coeff0_14*dmats1[14][30] + coeff0_15*dmats1[15][30] + coeff0_16*dmats1[16][30] + coeff0_17*dmats1[17][30] + coeff0_18*dmats1[18][30] + coeff0_19*dmats1[19][30] + coeff0_20*dmats1[20][30] + coeff0_21*dmats1[21][30] + coeff0_22*dmats1[22][30] + coeff0_23*dmats1[23][30] + coeff0_24*dmats1[24][30] + coeff0_25*dmats1[25][30] + coeff0_26*dmats1[26][30] + coeff0_27*dmats1[27][30] + coeff0_28*dmats1[28][30] + coeff0_29*dmats1[29][30] + coeff0_30*dmats1[30][30] + coeff0_31*dmats1[31][30] + coeff0_32*dmats1[32][30] + coeff0_33*dmats1[33][30] + coeff0_34*dmats1[34][30] + coeff0_35*dmats1[35][30] + coeff0_36*dmats1[36][30] + coeff0_37*dmats1[37][30] + coeff0_38*dmats1[38][30] + coeff0_39*dmats1[39][30] + coeff0_40*dmats1[40][30] + coeff0_41*dmats1[41][30] + coeff0_42*dmats1[42][30] + coeff0_43*dmats1[43][30] + coeff0_44*dmats1[44][30] + coeff0_45*dmats1[45][30] + coeff0_46*dmats1[46][30] + coeff0_47*dmats1[47][30] + coeff0_48*dmats1[48][30] + coeff0_49*dmats1[49][30] + coeff0_50*dmats1[50][30] + coeff0_51*dmats1[51][30] + coeff0_52*dmats1[52][30] + coeff0_53*dmats1[53][30] + coeff0_54*dmats1[54][30] + coeff0_55*dmats1[55][30];
          new_coeff0_31 = coeff0_0*dmats1[0][31] + coeff0_1*dmats1[1][31] + coeff0_2*dmats1[2][31] + coeff0_3*dmats1[3][31] + coeff0_4*dmats1[4][31] + coeff0_5*dmats1[5][31] + coeff0_6*dmats1[6][31] + coeff0_7*dmats1[7][31] + coeff0_8*dmats1[8][31] + coeff0_9*dmats1[9][31] + coeff0_10*dmats1[10][31] + coeff0_11*dmats1[11][31] + coeff0_12*dmats1[12][31] + coeff0_13*dmats1[13][31] + coeff0_14*dmats1[14][31] + coeff0_15*dmats1[15][31] + coeff0_16*dmats1[16][31] + coeff0_17*dmats1[17][31] + coeff0_18*dmats1[18][31] + coeff0_19*dmats1[19][31] + coeff0_20*dmats1[20][31] + coeff0_21*dmats1[21][31] + coeff0_22*dmats1[22][31] + coeff0_23*dmats1[23][31] + coeff0_24*dmats1[24][31] + coeff0_25*dmats1[25][31] + coeff0_26*dmats1[26][31] + coeff0_27*dmats1[27][31] + coeff0_28*dmats1[28][31] + coeff0_29*dmats1[29][31] + coeff0_30*dmats1[30][31] + coeff0_31*dmats1[31][31] + coeff0_32*dmats1[32][31] + coeff0_33*dmats1[33][31] + coeff0_34*dmats1[34][31] + coeff0_35*dmats1[35][31] + coeff0_36*dmats1[36][31] + coeff0_37*dmats1[37][31] + coeff0_38*dmats1[38][31] + coeff0_39*dmats1[39][31] + coeff0_40*dmats1[40][31] + coeff0_41*dmats1[41][31] + coeff0_42*dmats1[42][31] + coeff0_43*dmats1[43][31] + coeff0_44*dmats1[44][31] + coeff0_45*dmats1[45][31] + coeff0_46*dmats1[46][31] + coeff0_47*dmats1[47][31] + coeff0_48*dmats1[48][31] + coeff0_49*dmats1[49][31] + coeff0_50*dmats1[50][31] + coeff0_51*dmats1[51][31] + coeff0_52*dmats1[52][31] + coeff0_53*dmats1[53][31] + coeff0_54*dmats1[54][31] + coeff0_55*dmats1[55][31];
          new_coeff0_32 = coeff0_0*dmats1[0][32] + coeff0_1*dmats1[1][32] + coeff0_2*dmats1[2][32] + coeff0_3*dmats1[3][32] + coeff0_4*dmats1[4][32] + coeff0_5*dmats1[5][32] + coeff0_6*dmats1[6][32] + coeff0_7*dmats1[7][32] + coeff0_8*dmats1[8][32] + coeff0_9*dmats1[9][32] + coeff0_10*dmats1[10][32] + coeff0_11*dmats1[11][32] + coeff0_12*dmats1[12][32] + coeff0_13*dmats1[13][32] + coeff0_14*dmats1[14][32] + coeff0_15*dmats1[15][32] + coeff0_16*dmats1[16][32] + coeff0_17*dmats1[17][32] + coeff0_18*dmats1[18][32] + coeff0_19*dmats1[19][32] + coeff0_20*dmats1[20][32] + coeff0_21*dmats1[21][32] + coeff0_22*dmats1[22][32] + coeff0_23*dmats1[23][32] + coeff0_24*dmats1[24][32] + coeff0_25*dmats1[25][32] + coeff0_26*dmats1[26][32] + coeff0_27*dmats1[27][32] + coeff0_28*dmats1[28][32] + coeff0_29*dmats1[29][32] + coeff0_30*dmats1[30][32] + coeff0_31*dmats1[31][32] + coeff0_32*dmats1[32][32] + coeff0_33*dmats1[33][32] + coeff0_34*dmats1[34][32] + coeff0_35*dmats1[35][32] + coeff0_36*dmats1[36][32] + coeff0_37*dmats1[37][32] + coeff0_38*dmats1[38][32] + coeff0_39*dmats1[39][32] + coeff0_40*dmats1[40][32] + coeff0_41*dmats1[41][32] + coeff0_42*dmats1[42][32] + coeff0_43*dmats1[43][32] + coeff0_44*dmats1[44][32] + coeff0_45*dmats1[45][32] + coeff0_46*dmats1[46][32] + coeff0_47*dmats1[47][32] + coeff0_48*dmats1[48][32] + coeff0_49*dmats1[49][32] + coeff0_50*dmats1[50][32] + coeff0_51*dmats1[51][32] + coeff0_52*dmats1[52][32] + coeff0_53*dmats1[53][32] + coeff0_54*dmats1[54][32] + coeff0_55*dmats1[55][32];
          new_coeff0_33 = coeff0_0*dmats1[0][33] + coeff0_1*dmats1[1][33] + coeff0_2*dmats1[2][33] + coeff0_3*dmats1[3][33] + coeff0_4*dmats1[4][33] + coeff0_5*dmats1[5][33] + coeff0_6*dmats1[6][33] + coeff0_7*dmats1[7][33] + coeff0_8*dmats1[8][33] + coeff0_9*dmats1[9][33] + coeff0_10*dmats1[10][33] + coeff0_11*dmats1[11][33] + coeff0_12*dmats1[12][33] + coeff0_13*dmats1[13][33] + coeff0_14*dmats1[14][33] + coeff0_15*dmats1[15][33] + coeff0_16*dmats1[16][33] + coeff0_17*dmats1[17][33] + coeff0_18*dmats1[18][33] + coeff0_19*dmats1[19][33] + coeff0_20*dmats1[20][33] + coeff0_21*dmats1[21][33] + coeff0_22*dmats1[22][33] + coeff0_23*dmats1[23][33] + coeff0_24*dmats1[24][33] + coeff0_25*dmats1[25][33] + coeff0_26*dmats1[26][33] + coeff0_27*dmats1[27][33] + coeff0_28*dmats1[28][33] + coeff0_29*dmats1[29][33] + coeff0_30*dmats1[30][33] + coeff0_31*dmats1[31][33] + coeff0_32*dmats1[32][33] + coeff0_33*dmats1[33][33] + coeff0_34*dmats1[34][33] + coeff0_35*dmats1[35][33] + coeff0_36*dmats1[36][33] + coeff0_37*dmats1[37][33] + coeff0_38*dmats1[38][33] + coeff0_39*dmats1[39][33] + coeff0_40*dmats1[40][33] + coeff0_41*dmats1[41][33] + coeff0_42*dmats1[42][33] + coeff0_43*dmats1[43][33] + coeff0_44*dmats1[44][33] + coeff0_45*dmats1[45][33] + coeff0_46*dmats1[46][33] + coeff0_47*dmats1[47][33] + coeff0_48*dmats1[48][33] + coeff0_49*dmats1[49][33] + coeff0_50*dmats1[50][33] + coeff0_51*dmats1[51][33] + coeff0_52*dmats1[52][33] + coeff0_53*dmats1[53][33] + coeff0_54*dmats1[54][33] + coeff0_55*dmats1[55][33];
          new_coeff0_34 = coeff0_0*dmats1[0][34] + coeff0_1*dmats1[1][34] + coeff0_2*dmats1[2][34] + coeff0_3*dmats1[3][34] + coeff0_4*dmats1[4][34] + coeff0_5*dmats1[5][34] + coeff0_6*dmats1[6][34] + coeff0_7*dmats1[7][34] + coeff0_8*dmats1[8][34] + coeff0_9*dmats1[9][34] + coeff0_10*dmats1[10][34] + coeff0_11*dmats1[11][34] + coeff0_12*dmats1[12][34] + coeff0_13*dmats1[13][34] + coeff0_14*dmats1[14][34] + coeff0_15*dmats1[15][34] + coeff0_16*dmats1[16][34] + coeff0_17*dmats1[17][34] + coeff0_18*dmats1[18][34] + coeff0_19*dmats1[19][34] + coeff0_20*dmats1[20][34] + coeff0_21*dmats1[21][34] + coeff0_22*dmats1[22][34] + coeff0_23*dmats1[23][34] + coeff0_24*dmats1[24][34] + coeff0_25*dmats1[25][34] + coeff0_26*dmats1[26][34] + coeff0_27*dmats1[27][34] + coeff0_28*dmats1[28][34] + coeff0_29*dmats1[29][34] + coeff0_30*dmats1[30][34] + coeff0_31*dmats1[31][34] + coeff0_32*dmats1[32][34] + coeff0_33*dmats1[33][34] + coeff0_34*dmats1[34][34] + coeff0_35*dmats1[35][34] + coeff0_36*dmats1[36][34] + coeff0_37*dmats1[37][34] + coeff0_38*dmats1[38][34] + coeff0_39*dmats1[39][34] + coeff0_40*dmats1[40][34] + coeff0_41*dmats1[41][34] + coeff0_42*dmats1[42][34] + coeff0_43*dmats1[43][34] + coeff0_44*dmats1[44][34] + coeff0_45*dmats1[45][34] + coeff0_46*dmats1[46][34] + coeff0_47*dmats1[47][34] + coeff0_48*dmats1[48][34] + coeff0_49*dmats1[49][34] + coeff0_50*dmats1[50][34] + coeff0_51*dmats1[51][34] + coeff0_52*dmats1[52][34] + coeff0_53*dmats1[53][34] + coeff0_54*dmats1[54][34] + coeff0_55*dmats1[55][34];
          new_coeff0_35 = coeff0_0*dmats1[0][35] + coeff0_1*dmats1[1][35] + coeff0_2*dmats1[2][35] + coeff0_3*dmats1[3][35] + coeff0_4*dmats1[4][35] + coeff0_5*dmats1[5][35] + coeff0_6*dmats1[6][35] + coeff0_7*dmats1[7][35] + coeff0_8*dmats1[8][35] + coeff0_9*dmats1[9][35] + coeff0_10*dmats1[10][35] + coeff0_11*dmats1[11][35] + coeff0_12*dmats1[12][35] + coeff0_13*dmats1[13][35] + coeff0_14*dmats1[14][35] + coeff0_15*dmats1[15][35] + coeff0_16*dmats1[16][35] + coeff0_17*dmats1[17][35] + coeff0_18*dmats1[18][35] + coeff0_19*dmats1[19][35] + coeff0_20*dmats1[20][35] + coeff0_21*dmats1[21][35] + coeff0_22*dmats1[22][35] + coeff0_23*dmats1[23][35] + coeff0_24*dmats1[24][35] + coeff0_25*dmats1[25][35] + coeff0_26*dmats1[26][35] + coeff0_27*dmats1[27][35] + coeff0_28*dmats1[28][35] + coeff0_29*dmats1[29][35] + coeff0_30*dmats1[30][35] + coeff0_31*dmats1[31][35] + coeff0_32*dmats1[32][35] + coeff0_33*dmats1[33][35] + coeff0_34*dmats1[34][35] + coeff0_35*dmats1[35][35] + coeff0_36*dmats1[36][35] + coeff0_37*dmats1[37][35] + coeff0_38*dmats1[38][35] + coeff0_39*dmats1[39][35] + coeff0_40*dmats1[40][35] + coeff0_41*dmats1[41][35] + coeff0_42*dmats1[42][35] + coeff0_43*dmats1[43][35] + coeff0_44*dmats1[44][35] + coeff0_45*dmats1[45][35] + coeff0_46*dmats1[46][35] + coeff0_47*dmats1[47][35] + coeff0_48*dmats1[48][35] + coeff0_49*dmats1[49][35] + coeff0_50*dmats1[50][35] + coeff0_51*dmats1[51][35] + coeff0_52*dmats1[52][35] + coeff0_53*dmats1[53][35] + coeff0_54*dmats1[54][35] + coeff0_55*dmats1[55][35];
          new_coeff0_36 = coeff0_0*dmats1[0][36] + coeff0_1*dmats1[1][36] + coeff0_2*dmats1[2][36] + coeff0_3*dmats1[3][36] + coeff0_4*dmats1[4][36] + coeff0_5*dmats1[5][36] + coeff0_6*dmats1[6][36] + coeff0_7*dmats1[7][36] + coeff0_8*dmats1[8][36] + coeff0_9*dmats1[9][36] + coeff0_10*dmats1[10][36] + coeff0_11*dmats1[11][36] + coeff0_12*dmats1[12][36] + coeff0_13*dmats1[13][36] + coeff0_14*dmats1[14][36] + coeff0_15*dmats1[15][36] + coeff0_16*dmats1[16][36] + coeff0_17*dmats1[17][36] + coeff0_18*dmats1[18][36] + coeff0_19*dmats1[19][36] + coeff0_20*dmats1[20][36] + coeff0_21*dmats1[21][36] + coeff0_22*dmats1[22][36] + coeff0_23*dmats1[23][36] + coeff0_24*dmats1[24][36] + coeff0_25*dmats1[25][36] + coeff0_26*dmats1[26][36] + coeff0_27*dmats1[27][36] + coeff0_28*dmats1[28][36] + coeff0_29*dmats1[29][36] + coeff0_30*dmats1[30][36] + coeff0_31*dmats1[31][36] + coeff0_32*dmats1[32][36] + coeff0_33*dmats1[33][36] + coeff0_34*dmats1[34][36] + coeff0_35*dmats1[35][36] + coeff0_36*dmats1[36][36] + coeff0_37*dmats1[37][36] + coeff0_38*dmats1[38][36] + coeff0_39*dmats1[39][36] + coeff0_40*dmats1[40][36] + coeff0_41*dmats1[41][36] + coeff0_42*dmats1[42][36] + coeff0_43*dmats1[43][36] + coeff0_44*dmats1[44][36] + coeff0_45*dmats1[45][36] + coeff0_46*dmats1[46][36] + coeff0_47*dmats1[47][36] + coeff0_48*dmats1[48][36] + coeff0_49*dmats1[49][36] + coeff0_50*dmats1[50][36] + coeff0_51*dmats1[51][36] + coeff0_52*dmats1[52][36] + coeff0_53*dmats1[53][36] + coeff0_54*dmats1[54][36] + coeff0_55*dmats1[55][36];
          new_coeff0_37 = coeff0_0*dmats1[0][37] + coeff0_1*dmats1[1][37] + coeff0_2*dmats1[2][37] + coeff0_3*dmats1[3][37] + coeff0_4*dmats1[4][37] + coeff0_5*dmats1[5][37] + coeff0_6*dmats1[6][37] + coeff0_7*dmats1[7][37] + coeff0_8*dmats1[8][37] + coeff0_9*dmats1[9][37] + coeff0_10*dmats1[10][37] + coeff0_11*dmats1[11][37] + coeff0_12*dmats1[12][37] + coeff0_13*dmats1[13][37] + coeff0_14*dmats1[14][37] + coeff0_15*dmats1[15][37] + coeff0_16*dmats1[16][37] + coeff0_17*dmats1[17][37] + coeff0_18*dmats1[18][37] + coeff0_19*dmats1[19][37] + coeff0_20*dmats1[20][37] + coeff0_21*dmats1[21][37] + coeff0_22*dmats1[22][37] + coeff0_23*dmats1[23][37] + coeff0_24*dmats1[24][37] + coeff0_25*dmats1[25][37] + coeff0_26*dmats1[26][37] + coeff0_27*dmats1[27][37] + coeff0_28*dmats1[28][37] + coeff0_29*dmats1[29][37] + coeff0_30*dmats1[30][37] + coeff0_31*dmats1[31][37] + coeff0_32*dmats1[32][37] + coeff0_33*dmats1[33][37] + coeff0_34*dmats1[34][37] + coeff0_35*dmats1[35][37] + coeff0_36*dmats1[36][37] + coeff0_37*dmats1[37][37] + coeff0_38*dmats1[38][37] + coeff0_39*dmats1[39][37] + coeff0_40*dmats1[40][37] + coeff0_41*dmats1[41][37] + coeff0_42*dmats1[42][37] + coeff0_43*dmats1[43][37] + coeff0_44*dmats1[44][37] + coeff0_45*dmats1[45][37] + coeff0_46*dmats1[46][37] + coeff0_47*dmats1[47][37] + coeff0_48*dmats1[48][37] + coeff0_49*dmats1[49][37] + coeff0_50*dmats1[50][37] + coeff0_51*dmats1[51][37] + coeff0_52*dmats1[52][37] + coeff0_53*dmats1[53][37] + coeff0_54*dmats1[54][37] + coeff0_55*dmats1[55][37];
          new_coeff0_38 = coeff0_0*dmats1[0][38] + coeff0_1*dmats1[1][38] + coeff0_2*dmats1[2][38] + coeff0_3*dmats1[3][38] + coeff0_4*dmats1[4][38] + coeff0_5*dmats1[5][38] + coeff0_6*dmats1[6][38] + coeff0_7*dmats1[7][38] + coeff0_8*dmats1[8][38] + coeff0_9*dmats1[9][38] + coeff0_10*dmats1[10][38] + coeff0_11*dmats1[11][38] + coeff0_12*dmats1[12][38] + coeff0_13*dmats1[13][38] + coeff0_14*dmats1[14][38] + coeff0_15*dmats1[15][38] + coeff0_16*dmats1[16][38] + coeff0_17*dmats1[17][38] + coeff0_18*dmats1[18][38] + coeff0_19*dmats1[19][38] + coeff0_20*dmats1[20][38] + coeff0_21*dmats1[21][38] + coeff0_22*dmats1[22][38] + coeff0_23*dmats1[23][38] + coeff0_24*dmats1[24][38] + coeff0_25*dmats1[25][38] + coeff0_26*dmats1[26][38] + coeff0_27*dmats1[27][38] + coeff0_28*dmats1[28][38] + coeff0_29*dmats1[29][38] + coeff0_30*dmats1[30][38] + coeff0_31*dmats1[31][38] + coeff0_32*dmats1[32][38] + coeff0_33*dmats1[33][38] + coeff0_34*dmats1[34][38] + coeff0_35*dmats1[35][38] + coeff0_36*dmats1[36][38] + coeff0_37*dmats1[37][38] + coeff0_38*dmats1[38][38] + coeff0_39*dmats1[39][38] + coeff0_40*dmats1[40][38] + coeff0_41*dmats1[41][38] + coeff0_42*dmats1[42][38] + coeff0_43*dmats1[43][38] + coeff0_44*dmats1[44][38] + coeff0_45*dmats1[45][38] + coeff0_46*dmats1[46][38] + coeff0_47*dmats1[47][38] + coeff0_48*dmats1[48][38] + coeff0_49*dmats1[49][38] + coeff0_50*dmats1[50][38] + coeff0_51*dmats1[51][38] + coeff0_52*dmats1[52][38] + coeff0_53*dmats1[53][38] + coeff0_54*dmats1[54][38] + coeff0_55*dmats1[55][38];
          new_coeff0_39 = coeff0_0*dmats1[0][39] + coeff0_1*dmats1[1][39] + coeff0_2*dmats1[2][39] + coeff0_3*dmats1[3][39] + coeff0_4*dmats1[4][39] + coeff0_5*dmats1[5][39] + coeff0_6*dmats1[6][39] + coeff0_7*dmats1[7][39] + coeff0_8*dmats1[8][39] + coeff0_9*dmats1[9][39] + coeff0_10*dmats1[10][39] + coeff0_11*dmats1[11][39] + coeff0_12*dmats1[12][39] + coeff0_13*dmats1[13][39] + coeff0_14*dmats1[14][39] + coeff0_15*dmats1[15][39] + coeff0_16*dmats1[16][39] + coeff0_17*dmats1[17][39] + coeff0_18*dmats1[18][39] + coeff0_19*dmats1[19][39] + coeff0_20*dmats1[20][39] + coeff0_21*dmats1[21][39] + coeff0_22*dmats1[22][39] + coeff0_23*dmats1[23][39] + coeff0_24*dmats1[24][39] + coeff0_25*dmats1[25][39] + coeff0_26*dmats1[26][39] + coeff0_27*dmats1[27][39] + coeff0_28*dmats1[28][39] + coeff0_29*dmats1[29][39] + coeff0_30*dmats1[30][39] + coeff0_31*dmats1[31][39] + coeff0_32*dmats1[32][39] + coeff0_33*dmats1[33][39] + coeff0_34*dmats1[34][39] + coeff0_35*dmats1[35][39] + coeff0_36*dmats1[36][39] + coeff0_37*dmats1[37][39] + coeff0_38*dmats1[38][39] + coeff0_39*dmats1[39][39] + coeff0_40*dmats1[40][39] + coeff0_41*dmats1[41][39] + coeff0_42*dmats1[42][39] + coeff0_43*dmats1[43][39] + coeff0_44*dmats1[44][39] + coeff0_45*dmats1[45][39] + coeff0_46*dmats1[46][39] + coeff0_47*dmats1[47][39] + coeff0_48*dmats1[48][39] + coeff0_49*dmats1[49][39] + coeff0_50*dmats1[50][39] + coeff0_51*dmats1[51][39] + coeff0_52*dmats1[52][39] + coeff0_53*dmats1[53][39] + coeff0_54*dmats1[54][39] + coeff0_55*dmats1[55][39];
          new_coeff0_40 = coeff0_0*dmats1[0][40] + coeff0_1*dmats1[1][40] + coeff0_2*dmats1[2][40] + coeff0_3*dmats1[3][40] + coeff0_4*dmats1[4][40] + coeff0_5*dmats1[5][40] + coeff0_6*dmats1[6][40] + coeff0_7*dmats1[7][40] + coeff0_8*dmats1[8][40] + coeff0_9*dmats1[9][40] + coeff0_10*dmats1[10][40] + coeff0_11*dmats1[11][40] + coeff0_12*dmats1[12][40] + coeff0_13*dmats1[13][40] + coeff0_14*dmats1[14][40] + coeff0_15*dmats1[15][40] + coeff0_16*dmats1[16][40] + coeff0_17*dmats1[17][40] + coeff0_18*dmats1[18][40] + coeff0_19*dmats1[19][40] + coeff0_20*dmats1[20][40] + coeff0_21*dmats1[21][40] + coeff0_22*dmats1[22][40] + coeff0_23*dmats1[23][40] + coeff0_24*dmats1[24][40] + coeff0_25*dmats1[25][40] + coeff0_26*dmats1[26][40] + coeff0_27*dmats1[27][40] + coeff0_28*dmats1[28][40] + coeff0_29*dmats1[29][40] + coeff0_30*dmats1[30][40] + coeff0_31*dmats1[31][40] + coeff0_32*dmats1[32][40] + coeff0_33*dmats1[33][40] + coeff0_34*dmats1[34][40] + coeff0_35*dmats1[35][40] + coeff0_36*dmats1[36][40] + coeff0_37*dmats1[37][40] + coeff0_38*dmats1[38][40] + coeff0_39*dmats1[39][40] + coeff0_40*dmats1[40][40] + coeff0_41*dmats1[41][40] + coeff0_42*dmats1[42][40] + coeff0_43*dmats1[43][40] + coeff0_44*dmats1[44][40] + coeff0_45*dmats1[45][40] + coeff0_46*dmats1[46][40] + coeff0_47*dmats1[47][40] + coeff0_48*dmats1[48][40] + coeff0_49*dmats1[49][40] + coeff0_50*dmats1[50][40] + coeff0_51*dmats1[51][40] + coeff0_52*dmats1[52][40] + coeff0_53*dmats1[53][40] + coeff0_54*dmats1[54][40] + coeff0_55*dmats1[55][40];
          new_coeff0_41 = coeff0_0*dmats1[0][41] + coeff0_1*dmats1[1][41] + coeff0_2*dmats1[2][41] + coeff0_3*dmats1[3][41] + coeff0_4*dmats1[4][41] + coeff0_5*dmats1[5][41] + coeff0_6*dmats1[6][41] + coeff0_7*dmats1[7][41] + coeff0_8*dmats1[8][41] + coeff0_9*dmats1[9][41] + coeff0_10*dmats1[10][41] + coeff0_11*dmats1[11][41] + coeff0_12*dmats1[12][41] + coeff0_13*dmats1[13][41] + coeff0_14*dmats1[14][41] + coeff0_15*dmats1[15][41] + coeff0_16*dmats1[16][41] + coeff0_17*dmats1[17][41] + coeff0_18*dmats1[18][41] + coeff0_19*dmats1[19][41] + coeff0_20*dmats1[20][41] + coeff0_21*dmats1[21][41] + coeff0_22*dmats1[22][41] + coeff0_23*dmats1[23][41] + coeff0_24*dmats1[24][41] + coeff0_25*dmats1[25][41] + coeff0_26*dmats1[26][41] + coeff0_27*dmats1[27][41] + coeff0_28*dmats1[28][41] + coeff0_29*dmats1[29][41] + coeff0_30*dmats1[30][41] + coeff0_31*dmats1[31][41] + coeff0_32*dmats1[32][41] + coeff0_33*dmats1[33][41] + coeff0_34*dmats1[34][41] + coeff0_35*dmats1[35][41] + coeff0_36*dmats1[36][41] + coeff0_37*dmats1[37][41] + coeff0_38*dmats1[38][41] + coeff0_39*dmats1[39][41] + coeff0_40*dmats1[40][41] + coeff0_41*dmats1[41][41] + coeff0_42*dmats1[42][41] + coeff0_43*dmats1[43][41] + coeff0_44*dmats1[44][41] + coeff0_45*dmats1[45][41] + coeff0_46*dmats1[46][41] + coeff0_47*dmats1[47][41] + coeff0_48*dmats1[48][41] + coeff0_49*dmats1[49][41] + coeff0_50*dmats1[50][41] + coeff0_51*dmats1[51][41] + coeff0_52*dmats1[52][41] + coeff0_53*dmats1[53][41] + coeff0_54*dmats1[54][41] + coeff0_55*dmats1[55][41];
          new_coeff0_42 = coeff0_0*dmats1[0][42] + coeff0_1*dmats1[1][42] + coeff0_2*dmats1[2][42] + coeff0_3*dmats1[3][42] + coeff0_4*dmats1[4][42] + coeff0_5*dmats1[5][42] + coeff0_6*dmats1[6][42] + coeff0_7*dmats1[7][42] + coeff0_8*dmats1[8][42] + coeff0_9*dmats1[9][42] + coeff0_10*dmats1[10][42] + coeff0_11*dmats1[11][42] + coeff0_12*dmats1[12][42] + coeff0_13*dmats1[13][42] + coeff0_14*dmats1[14][42] + coeff0_15*dmats1[15][42] + coeff0_16*dmats1[16][42] + coeff0_17*dmats1[17][42] + coeff0_18*dmats1[18][42] + coeff0_19*dmats1[19][42] + coeff0_20*dmats1[20][42] + coeff0_21*dmats1[21][42] + coeff0_22*dmats1[22][42] + coeff0_23*dmats1[23][42] + coeff0_24*dmats1[24][42] + coeff0_25*dmats1[25][42] + coeff0_26*dmats1[26][42] + coeff0_27*dmats1[27][42] + coeff0_28*dmats1[28][42] + coeff0_29*dmats1[29][42] + coeff0_30*dmats1[30][42] + coeff0_31*dmats1[31][42] + coeff0_32*dmats1[32][42] + coeff0_33*dmats1[33][42] + coeff0_34*dmats1[34][42] + coeff0_35*dmats1[35][42] + coeff0_36*dmats1[36][42] + coeff0_37*dmats1[37][42] + coeff0_38*dmats1[38][42] + coeff0_39*dmats1[39][42] + coeff0_40*dmats1[40][42] + coeff0_41*dmats1[41][42] + coeff0_42*dmats1[42][42] + coeff0_43*dmats1[43][42] + coeff0_44*dmats1[44][42] + coeff0_45*dmats1[45][42] + coeff0_46*dmats1[46][42] + coeff0_47*dmats1[47][42] + coeff0_48*dmats1[48][42] + coeff0_49*dmats1[49][42] + coeff0_50*dmats1[50][42] + coeff0_51*dmats1[51][42] + coeff0_52*dmats1[52][42] + coeff0_53*dmats1[53][42] + coeff0_54*dmats1[54][42] + coeff0_55*dmats1[55][42];
          new_coeff0_43 = coeff0_0*dmats1[0][43] + coeff0_1*dmats1[1][43] + coeff0_2*dmats1[2][43] + coeff0_3*dmats1[3][43] + coeff0_4*dmats1[4][43] + coeff0_5*dmats1[5][43] + coeff0_6*dmats1[6][43] + coeff0_7*dmats1[7][43] + coeff0_8*dmats1[8][43] + coeff0_9*dmats1[9][43] + coeff0_10*dmats1[10][43] + coeff0_11*dmats1[11][43] + coeff0_12*dmats1[12][43] + coeff0_13*dmats1[13][43] + coeff0_14*dmats1[14][43] + coeff0_15*dmats1[15][43] + coeff0_16*dmats1[16][43] + coeff0_17*dmats1[17][43] + coeff0_18*dmats1[18][43] + coeff0_19*dmats1[19][43] + coeff0_20*dmats1[20][43] + coeff0_21*dmats1[21][43] + coeff0_22*dmats1[22][43] + coeff0_23*dmats1[23][43] + coeff0_24*dmats1[24][43] + coeff0_25*dmats1[25][43] + coeff0_26*dmats1[26][43] + coeff0_27*dmats1[27][43] + coeff0_28*dmats1[28][43] + coeff0_29*dmats1[29][43] + coeff0_30*dmats1[30][43] + coeff0_31*dmats1[31][43] + coeff0_32*dmats1[32][43] + coeff0_33*dmats1[33][43] + coeff0_34*dmats1[34][43] + coeff0_35*dmats1[35][43] + coeff0_36*dmats1[36][43] + coeff0_37*dmats1[37][43] + coeff0_38*dmats1[38][43] + coeff0_39*dmats1[39][43] + coeff0_40*dmats1[40][43] + coeff0_41*dmats1[41][43] + coeff0_42*dmats1[42][43] + coeff0_43*dmats1[43][43] + coeff0_44*dmats1[44][43] + coeff0_45*dmats1[45][43] + coeff0_46*dmats1[46][43] + coeff0_47*dmats1[47][43] + coeff0_48*dmats1[48][43] + coeff0_49*dmats1[49][43] + coeff0_50*dmats1[50][43] + coeff0_51*dmats1[51][43] + coeff0_52*dmats1[52][43] + coeff0_53*dmats1[53][43] + coeff0_54*dmats1[54][43] + coeff0_55*dmats1[55][43];
          new_coeff0_44 = coeff0_0*dmats1[0][44] + coeff0_1*dmats1[1][44] + coeff0_2*dmats1[2][44] + coeff0_3*dmats1[3][44] + coeff0_4*dmats1[4][44] + coeff0_5*dmats1[5][44] + coeff0_6*dmats1[6][44] + coeff0_7*dmats1[7][44] + coeff0_8*dmats1[8][44] + coeff0_9*dmats1[9][44] + coeff0_10*dmats1[10][44] + coeff0_11*dmats1[11][44] + coeff0_12*dmats1[12][44] + coeff0_13*dmats1[13][44] + coeff0_14*dmats1[14][44] + coeff0_15*dmats1[15][44] + coeff0_16*dmats1[16][44] + coeff0_17*dmats1[17][44] + coeff0_18*dmats1[18][44] + coeff0_19*dmats1[19][44] + coeff0_20*dmats1[20][44] + coeff0_21*dmats1[21][44] + coeff0_22*dmats1[22][44] + coeff0_23*dmats1[23][44] + coeff0_24*dmats1[24][44] + coeff0_25*dmats1[25][44] + coeff0_26*dmats1[26][44] + coeff0_27*dmats1[27][44] + coeff0_28*dmats1[28][44] + coeff0_29*dmats1[29][44] + coeff0_30*dmats1[30][44] + coeff0_31*dmats1[31][44] + coeff0_32*dmats1[32][44] + coeff0_33*dmats1[33][44] + coeff0_34*dmats1[34][44] + coeff0_35*dmats1[35][44] + coeff0_36*dmats1[36][44] + coeff0_37*dmats1[37][44] + coeff0_38*dmats1[38][44] + coeff0_39*dmats1[39][44] + coeff0_40*dmats1[40][44] + coeff0_41*dmats1[41][44] + coeff0_42*dmats1[42][44] + coeff0_43*dmats1[43][44] + coeff0_44*dmats1[44][44] + coeff0_45*dmats1[45][44] + coeff0_46*dmats1[46][44] + coeff0_47*dmats1[47][44] + coeff0_48*dmats1[48][44] + coeff0_49*dmats1[49][44] + coeff0_50*dmats1[50][44] + coeff0_51*dmats1[51][44] + coeff0_52*dmats1[52][44] + coeff0_53*dmats1[53][44] + coeff0_54*dmats1[54][44] + coeff0_55*dmats1[55][44];
          new_coeff0_45 = coeff0_0*dmats1[0][45] + coeff0_1*dmats1[1][45] + coeff0_2*dmats1[2][45] + coeff0_3*dmats1[3][45] + coeff0_4*dmats1[4][45] + coeff0_5*dmats1[5][45] + coeff0_6*dmats1[6][45] + coeff0_7*dmats1[7][45] + coeff0_8*dmats1[8][45] + coeff0_9*dmats1[9][45] + coeff0_10*dmats1[10][45] + coeff0_11*dmats1[11][45] + coeff0_12*dmats1[12][45] + coeff0_13*dmats1[13][45] + coeff0_14*dmats1[14][45] + coeff0_15*dmats1[15][45] + coeff0_16*dmats1[16][45] + coeff0_17*dmats1[17][45] + coeff0_18*dmats1[18][45] + coeff0_19*dmats1[19][45] + coeff0_20*dmats1[20][45] + coeff0_21*dmats1[21][45] + coeff0_22*dmats1[22][45] + coeff0_23*dmats1[23][45] + coeff0_24*dmats1[24][45] + coeff0_25*dmats1[25][45] + coeff0_26*dmats1[26][45] + coeff0_27*dmats1[27][45] + coeff0_28*dmats1[28][45] + coeff0_29*dmats1[29][45] + coeff0_30*dmats1[30][45] + coeff0_31*dmats1[31][45] + coeff0_32*dmats1[32][45] + coeff0_33*dmats1[33][45] + coeff0_34*dmats1[34][45] + coeff0_35*dmats1[35][45] + coeff0_36*dmats1[36][45] + coeff0_37*dmats1[37][45] + coeff0_38*dmats1[38][45] + coeff0_39*dmats1[39][45] + coeff0_40*dmats1[40][45] + coeff0_41*dmats1[41][45] + coeff0_42*dmats1[42][45] + coeff0_43*dmats1[43][45] + coeff0_44*dmats1[44][45] + coeff0_45*dmats1[45][45] + coeff0_46*dmats1[46][45] + coeff0_47*dmats1[47][45] + coeff0_48*dmats1[48][45] + coeff0_49*dmats1[49][45] + coeff0_50*dmats1[50][45] + coeff0_51*dmats1[51][45] + coeff0_52*dmats1[52][45] + coeff0_53*dmats1[53][45] + coeff0_54*dmats1[54][45] + coeff0_55*dmats1[55][45];
          new_coeff0_46 = coeff0_0*dmats1[0][46] + coeff0_1*dmats1[1][46] + coeff0_2*dmats1[2][46] + coeff0_3*dmats1[3][46] + coeff0_4*dmats1[4][46] + coeff0_5*dmats1[5][46] + coeff0_6*dmats1[6][46] + coeff0_7*dmats1[7][46] + coeff0_8*dmats1[8][46] + coeff0_9*dmats1[9][46] + coeff0_10*dmats1[10][46] + coeff0_11*dmats1[11][46] + coeff0_12*dmats1[12][46] + coeff0_13*dmats1[13][46] + coeff0_14*dmats1[14][46] + coeff0_15*dmats1[15][46] + coeff0_16*dmats1[16][46] + coeff0_17*dmats1[17][46] + coeff0_18*dmats1[18][46] + coeff0_19*dmats1[19][46] + coeff0_20*dmats1[20][46] + coeff0_21*dmats1[21][46] + coeff0_22*dmats1[22][46] + coeff0_23*dmats1[23][46] + coeff0_24*dmats1[24][46] + coeff0_25*dmats1[25][46] + coeff0_26*dmats1[26][46] + coeff0_27*dmats1[27][46] + coeff0_28*dmats1[28][46] + coeff0_29*dmats1[29][46] + coeff0_30*dmats1[30][46] + coeff0_31*dmats1[31][46] + coeff0_32*dmats1[32][46] + coeff0_33*dmats1[33][46] + coeff0_34*dmats1[34][46] + coeff0_35*dmats1[35][46] + coeff0_36*dmats1[36][46] + coeff0_37*dmats1[37][46] + coeff0_38*dmats1[38][46] + coeff0_39*dmats1[39][46] + coeff0_40*dmats1[40][46] + coeff0_41*dmats1[41][46] + coeff0_42*dmats1[42][46] + coeff0_43*dmats1[43][46] + coeff0_44*dmats1[44][46] + coeff0_45*dmats1[45][46] + coeff0_46*dmats1[46][46] + coeff0_47*dmats1[47][46] + coeff0_48*dmats1[48][46] + coeff0_49*dmats1[49][46] + coeff0_50*dmats1[50][46] + coeff0_51*dmats1[51][46] + coeff0_52*dmats1[52][46] + coeff0_53*dmats1[53][46] + coeff0_54*dmats1[54][46] + coeff0_55*dmats1[55][46];
          new_coeff0_47 = coeff0_0*dmats1[0][47] + coeff0_1*dmats1[1][47] + coeff0_2*dmats1[2][47] + coeff0_3*dmats1[3][47] + coeff0_4*dmats1[4][47] + coeff0_5*dmats1[5][47] + coeff0_6*dmats1[6][47] + coeff0_7*dmats1[7][47] + coeff0_8*dmats1[8][47] + coeff0_9*dmats1[9][47] + coeff0_10*dmats1[10][47] + coeff0_11*dmats1[11][47] + coeff0_12*dmats1[12][47] + coeff0_13*dmats1[13][47] + coeff0_14*dmats1[14][47] + coeff0_15*dmats1[15][47] + coeff0_16*dmats1[16][47] + coeff0_17*dmats1[17][47] + coeff0_18*dmats1[18][47] + coeff0_19*dmats1[19][47] + coeff0_20*dmats1[20][47] + coeff0_21*dmats1[21][47] + coeff0_22*dmats1[22][47] + coeff0_23*dmats1[23][47] + coeff0_24*dmats1[24][47] + coeff0_25*dmats1[25][47] + coeff0_26*dmats1[26][47] + coeff0_27*dmats1[27][47] + coeff0_28*dmats1[28][47] + coeff0_29*dmats1[29][47] + coeff0_30*dmats1[30][47] + coeff0_31*dmats1[31][47] + coeff0_32*dmats1[32][47] + coeff0_33*dmats1[33][47] + coeff0_34*dmats1[34][47] + coeff0_35*dmats1[35][47] + coeff0_36*dmats1[36][47] + coeff0_37*dmats1[37][47] + coeff0_38*dmats1[38][47] + coeff0_39*dmats1[39][47] + coeff0_40*dmats1[40][47] + coeff0_41*dmats1[41][47] + coeff0_42*dmats1[42][47] + coeff0_43*dmats1[43][47] + coeff0_44*dmats1[44][47] + coeff0_45*dmats1[45][47] + coeff0_46*dmats1[46][47] + coeff0_47*dmats1[47][47] + coeff0_48*dmats1[48][47] + coeff0_49*dmats1[49][47] + coeff0_50*dmats1[50][47] + coeff0_51*dmats1[51][47] + coeff0_52*dmats1[52][47] + coeff0_53*dmats1[53][47] + coeff0_54*dmats1[54][47] + coeff0_55*dmats1[55][47];
          new_coeff0_48 = coeff0_0*dmats1[0][48] + coeff0_1*dmats1[1][48] + coeff0_2*dmats1[2][48] + coeff0_3*dmats1[3][48] + coeff0_4*dmats1[4][48] + coeff0_5*dmats1[5][48] + coeff0_6*dmats1[6][48] + coeff0_7*dmats1[7][48] + coeff0_8*dmats1[8][48] + coeff0_9*dmats1[9][48] + coeff0_10*dmats1[10][48] + coeff0_11*dmats1[11][48] + coeff0_12*dmats1[12][48] + coeff0_13*dmats1[13][48] + coeff0_14*dmats1[14][48] + coeff0_15*dmats1[15][48] + coeff0_16*dmats1[16][48] + coeff0_17*dmats1[17][48] + coeff0_18*dmats1[18][48] + coeff0_19*dmats1[19][48] + coeff0_20*dmats1[20][48] + coeff0_21*dmats1[21][48] + coeff0_22*dmats1[22][48] + coeff0_23*dmats1[23][48] + coeff0_24*dmats1[24][48] + coeff0_25*dmats1[25][48] + coeff0_26*dmats1[26][48] + coeff0_27*dmats1[27][48] + coeff0_28*dmats1[28][48] + coeff0_29*dmats1[29][48] + coeff0_30*dmats1[30][48] + coeff0_31*dmats1[31][48] + coeff0_32*dmats1[32][48] + coeff0_33*dmats1[33][48] + coeff0_34*dmats1[34][48] + coeff0_35*dmats1[35][48] + coeff0_36*dmats1[36][48] + coeff0_37*dmats1[37][48] + coeff0_38*dmats1[38][48] + coeff0_39*dmats1[39][48] + coeff0_40*dmats1[40][48] + coeff0_41*dmats1[41][48] + coeff0_42*dmats1[42][48] + coeff0_43*dmats1[43][48] + coeff0_44*dmats1[44][48] + coeff0_45*dmats1[45][48] + coeff0_46*dmats1[46][48] + coeff0_47*dmats1[47][48] + coeff0_48*dmats1[48][48] + coeff0_49*dmats1[49][48] + coeff0_50*dmats1[50][48] + coeff0_51*dmats1[51][48] + coeff0_52*dmats1[52][48] + coeff0_53*dmats1[53][48] + coeff0_54*dmats1[54][48] + coeff0_55*dmats1[55][48];
          new_coeff0_49 = coeff0_0*dmats1[0][49] + coeff0_1*dmats1[1][49] + coeff0_2*dmats1[2][49] + coeff0_3*dmats1[3][49] + coeff0_4*dmats1[4][49] + coeff0_5*dmats1[5][49] + coeff0_6*dmats1[6][49] + coeff0_7*dmats1[7][49] + coeff0_8*dmats1[8][49] + coeff0_9*dmats1[9][49] + coeff0_10*dmats1[10][49] + coeff0_11*dmats1[11][49] + coeff0_12*dmats1[12][49] + coeff0_13*dmats1[13][49] + coeff0_14*dmats1[14][49] + coeff0_15*dmats1[15][49] + coeff0_16*dmats1[16][49] + coeff0_17*dmats1[17][49] + coeff0_18*dmats1[18][49] + coeff0_19*dmats1[19][49] + coeff0_20*dmats1[20][49] + coeff0_21*dmats1[21][49] + coeff0_22*dmats1[22][49] + coeff0_23*dmats1[23][49] + coeff0_24*dmats1[24][49] + coeff0_25*dmats1[25][49] + coeff0_26*dmats1[26][49] + coeff0_27*dmats1[27][49] + coeff0_28*dmats1[28][49] + coeff0_29*dmats1[29][49] + coeff0_30*dmats1[30][49] + coeff0_31*dmats1[31][49] + coeff0_32*dmats1[32][49] + coeff0_33*dmats1[33][49] + coeff0_34*dmats1[34][49] + coeff0_35*dmats1[35][49] + coeff0_36*dmats1[36][49] + coeff0_37*dmats1[37][49] + coeff0_38*dmats1[38][49] + coeff0_39*dmats1[39][49] + coeff0_40*dmats1[40][49] + coeff0_41*dmats1[41][49] + coeff0_42*dmats1[42][49] + coeff0_43*dmats1[43][49] + coeff0_44*dmats1[44][49] + coeff0_45*dmats1[45][49] + coeff0_46*dmats1[46][49] + coeff0_47*dmats1[47][49] + coeff0_48*dmats1[48][49] + coeff0_49*dmats1[49][49] + coeff0_50*dmats1[50][49] + coeff0_51*dmats1[51][49] + coeff0_52*dmats1[52][49] + coeff0_53*dmats1[53][49] + coeff0_54*dmats1[54][49] + coeff0_55*dmats1[55][49];
          new_coeff0_50 = coeff0_0*dmats1[0][50] + coeff0_1*dmats1[1][50] + coeff0_2*dmats1[2][50] + coeff0_3*dmats1[3][50] + coeff0_4*dmats1[4][50] + coeff0_5*dmats1[5][50] + coeff0_6*dmats1[6][50] + coeff0_7*dmats1[7][50] + coeff0_8*dmats1[8][50] + coeff0_9*dmats1[9][50] + coeff0_10*dmats1[10][50] + coeff0_11*dmats1[11][50] + coeff0_12*dmats1[12][50] + coeff0_13*dmats1[13][50] + coeff0_14*dmats1[14][50] + coeff0_15*dmats1[15][50] + coeff0_16*dmats1[16][50] + coeff0_17*dmats1[17][50] + coeff0_18*dmats1[18][50] + coeff0_19*dmats1[19][50] + coeff0_20*dmats1[20][50] + coeff0_21*dmats1[21][50] + coeff0_22*dmats1[22][50] + coeff0_23*dmats1[23][50] + coeff0_24*dmats1[24][50] + coeff0_25*dmats1[25][50] + coeff0_26*dmats1[26][50] + coeff0_27*dmats1[27][50] + coeff0_28*dmats1[28][50] + coeff0_29*dmats1[29][50] + coeff0_30*dmats1[30][50] + coeff0_31*dmats1[31][50] + coeff0_32*dmats1[32][50] + coeff0_33*dmats1[33][50] + coeff0_34*dmats1[34][50] + coeff0_35*dmats1[35][50] + coeff0_36*dmats1[36][50] + coeff0_37*dmats1[37][50] + coeff0_38*dmats1[38][50] + coeff0_39*dmats1[39][50] + coeff0_40*dmats1[40][50] + coeff0_41*dmats1[41][50] + coeff0_42*dmats1[42][50] + coeff0_43*dmats1[43][50] + coeff0_44*dmats1[44][50] + coeff0_45*dmats1[45][50] + coeff0_46*dmats1[46][50] + coeff0_47*dmats1[47][50] + coeff0_48*dmats1[48][50] + coeff0_49*dmats1[49][50] + coeff0_50*dmats1[50][50] + coeff0_51*dmats1[51][50] + coeff0_52*dmats1[52][50] + coeff0_53*dmats1[53][50] + coeff0_54*dmats1[54][50] + coeff0_55*dmats1[55][50];
          new_coeff0_51 = coeff0_0*dmats1[0][51] + coeff0_1*dmats1[1][51] + coeff0_2*dmats1[2][51] + coeff0_3*dmats1[3][51] + coeff0_4*dmats1[4][51] + coeff0_5*dmats1[5][51] + coeff0_6*dmats1[6][51] + coeff0_7*dmats1[7][51] + coeff0_8*dmats1[8][51] + coeff0_9*dmats1[9][51] + coeff0_10*dmats1[10][51] + coeff0_11*dmats1[11][51] + coeff0_12*dmats1[12][51] + coeff0_13*dmats1[13][51] + coeff0_14*dmats1[14][51] + coeff0_15*dmats1[15][51] + coeff0_16*dmats1[16][51] + coeff0_17*dmats1[17][51] + coeff0_18*dmats1[18][51] + coeff0_19*dmats1[19][51] + coeff0_20*dmats1[20][51] + coeff0_21*dmats1[21][51] + coeff0_22*dmats1[22][51] + coeff0_23*dmats1[23][51] + coeff0_24*dmats1[24][51] + coeff0_25*dmats1[25][51] + coeff0_26*dmats1[26][51] + coeff0_27*dmats1[27][51] + coeff0_28*dmats1[28][51] + coeff0_29*dmats1[29][51] + coeff0_30*dmats1[30][51] + coeff0_31*dmats1[31][51] + coeff0_32*dmats1[32][51] + coeff0_33*dmats1[33][51] + coeff0_34*dmats1[34][51] + coeff0_35*dmats1[35][51] + coeff0_36*dmats1[36][51] + coeff0_37*dmats1[37][51] + coeff0_38*dmats1[38][51] + coeff0_39*dmats1[39][51] + coeff0_40*dmats1[40][51] + coeff0_41*dmats1[41][51] + coeff0_42*dmats1[42][51] + coeff0_43*dmats1[43][51] + coeff0_44*dmats1[44][51] + coeff0_45*dmats1[45][51] + coeff0_46*dmats1[46][51] + coeff0_47*dmats1[47][51] + coeff0_48*dmats1[48][51] + coeff0_49*dmats1[49][51] + coeff0_50*dmats1[50][51] + coeff0_51*dmats1[51][51] + coeff0_52*dmats1[52][51] + coeff0_53*dmats1[53][51] + coeff0_54*dmats1[54][51] + coeff0_55*dmats1[55][51];
          new_coeff0_52 = coeff0_0*dmats1[0][52] + coeff0_1*dmats1[1][52] + coeff0_2*dmats1[2][52] + coeff0_3*dmats1[3][52] + coeff0_4*dmats1[4][52] + coeff0_5*dmats1[5][52] + coeff0_6*dmats1[6][52] + coeff0_7*dmats1[7][52] + coeff0_8*dmats1[8][52] + coeff0_9*dmats1[9][52] + coeff0_10*dmats1[10][52] + coeff0_11*dmats1[11][52] + coeff0_12*dmats1[12][52] + coeff0_13*dmats1[13][52] + coeff0_14*dmats1[14][52] + coeff0_15*dmats1[15][52] + coeff0_16*dmats1[16][52] + coeff0_17*dmats1[17][52] + coeff0_18*dmats1[18][52] + coeff0_19*dmats1[19][52] + coeff0_20*dmats1[20][52] + coeff0_21*dmats1[21][52] + coeff0_22*dmats1[22][52] + coeff0_23*dmats1[23][52] + coeff0_24*dmats1[24][52] + coeff0_25*dmats1[25][52] + coeff0_26*dmats1[26][52] + coeff0_27*dmats1[27][52] + coeff0_28*dmats1[28][52] + coeff0_29*dmats1[29][52] + coeff0_30*dmats1[30][52] + coeff0_31*dmats1[31][52] + coeff0_32*dmats1[32][52] + coeff0_33*dmats1[33][52] + coeff0_34*dmats1[34][52] + coeff0_35*dmats1[35][52] + coeff0_36*dmats1[36][52] + coeff0_37*dmats1[37][52] + coeff0_38*dmats1[38][52] + coeff0_39*dmats1[39][52] + coeff0_40*dmats1[40][52] + coeff0_41*dmats1[41][52] + coeff0_42*dmats1[42][52] + coeff0_43*dmats1[43][52] + coeff0_44*dmats1[44][52] + coeff0_45*dmats1[45][52] + coeff0_46*dmats1[46][52] + coeff0_47*dmats1[47][52] + coeff0_48*dmats1[48][52] + coeff0_49*dmats1[49][52] + coeff0_50*dmats1[50][52] + coeff0_51*dmats1[51][52] + coeff0_52*dmats1[52][52] + coeff0_53*dmats1[53][52] + coeff0_54*dmats1[54][52] + coeff0_55*dmats1[55][52];
          new_coeff0_53 = coeff0_0*dmats1[0][53] + coeff0_1*dmats1[1][53] + coeff0_2*dmats1[2][53] + coeff0_3*dmats1[3][53] + coeff0_4*dmats1[4][53] + coeff0_5*dmats1[5][53] + coeff0_6*dmats1[6][53] + coeff0_7*dmats1[7][53] + coeff0_8*dmats1[8][53] + coeff0_9*dmats1[9][53] + coeff0_10*dmats1[10][53] + coeff0_11*dmats1[11][53] + coeff0_12*dmats1[12][53] + coeff0_13*dmats1[13][53] + coeff0_14*dmats1[14][53] + coeff0_15*dmats1[15][53] + coeff0_16*dmats1[16][53] + coeff0_17*dmats1[17][53] + coeff0_18*dmats1[18][53] + coeff0_19*dmats1[19][53] + coeff0_20*dmats1[20][53] + coeff0_21*dmats1[21][53] + coeff0_22*dmats1[22][53] + coeff0_23*dmats1[23][53] + coeff0_24*dmats1[24][53] + coeff0_25*dmats1[25][53] + coeff0_26*dmats1[26][53] + coeff0_27*dmats1[27][53] + coeff0_28*dmats1[28][53] + coeff0_29*dmats1[29][53] + coeff0_30*dmats1[30][53] + coeff0_31*dmats1[31][53] + coeff0_32*dmats1[32][53] + coeff0_33*dmats1[33][53] + coeff0_34*dmats1[34][53] + coeff0_35*dmats1[35][53] + coeff0_36*dmats1[36][53] + coeff0_37*dmats1[37][53] + coeff0_38*dmats1[38][53] + coeff0_39*dmats1[39][53] + coeff0_40*dmats1[40][53] + coeff0_41*dmats1[41][53] + coeff0_42*dmats1[42][53] + coeff0_43*dmats1[43][53] + coeff0_44*dmats1[44][53] + coeff0_45*dmats1[45][53] + coeff0_46*dmats1[46][53] + coeff0_47*dmats1[47][53] + coeff0_48*dmats1[48][53] + coeff0_49*dmats1[49][53] + coeff0_50*dmats1[50][53] + coeff0_51*dmats1[51][53] + coeff0_52*dmats1[52][53] + coeff0_53*dmats1[53][53] + coeff0_54*dmats1[54][53] + coeff0_55*dmats1[55][53];
          new_coeff0_54 = coeff0_0*dmats1[0][54] + coeff0_1*dmats1[1][54] + coeff0_2*dmats1[2][54] + coeff0_3*dmats1[3][54] + coeff0_4*dmats1[4][54] + coeff0_5*dmats1[5][54] + coeff0_6*dmats1[6][54] + coeff0_7*dmats1[7][54] + coeff0_8*dmats1[8][54] + coeff0_9*dmats1[9][54] + coeff0_10*dmats1[10][54] + coeff0_11*dmats1[11][54] + coeff0_12*dmats1[12][54] + coeff0_13*dmats1[13][54] + coeff0_14*dmats1[14][54] + coeff0_15*dmats1[15][54] + coeff0_16*dmats1[16][54] + coeff0_17*dmats1[17][54] + coeff0_18*dmats1[18][54] + coeff0_19*dmats1[19][54] + coeff0_20*dmats1[20][54] + coeff0_21*dmats1[21][54] + coeff0_22*dmats1[22][54] + coeff0_23*dmats1[23][54] + coeff0_24*dmats1[24][54] + coeff0_25*dmats1[25][54] + coeff0_26*dmats1[26][54] + coeff0_27*dmats1[27][54] + coeff0_28*dmats1[28][54] + coeff0_29*dmats1[29][54] + coeff0_30*dmats1[30][54] + coeff0_31*dmats1[31][54] + coeff0_32*dmats1[32][54] + coeff0_33*dmats1[33][54] + coeff0_34*dmats1[34][54] + coeff0_35*dmats1[35][54] + coeff0_36*dmats1[36][54] + coeff0_37*dmats1[37][54] + coeff0_38*dmats1[38][54] + coeff0_39*dmats1[39][54] + coeff0_40*dmats1[40][54] + coeff0_41*dmats1[41][54] + coeff0_42*dmats1[42][54] + coeff0_43*dmats1[43][54] + coeff0_44*dmats1[44][54] + coeff0_45*dmats1[45][54] + coeff0_46*dmats1[46][54] + coeff0_47*dmats1[47][54] + coeff0_48*dmats1[48][54] + coeff0_49*dmats1[49][54] + coeff0_50*dmats1[50][54] + coeff0_51*dmats1[51][54] + coeff0_52*dmats1[52][54] + coeff0_53*dmats1[53][54] + coeff0_54*dmats1[54][54] + coeff0_55*dmats1[55][54];
          new_coeff0_55 = coeff0_0*dmats1[0][55] + coeff0_1*dmats1[1][55] + coeff0_2*dmats1[2][55] + coeff0_3*dmats1[3][55] + coeff0_4*dmats1[4][55] + coeff0_5*dmats1[5][55] + coeff0_6*dmats1[6][55] + coeff0_7*dmats1[7][55] + coeff0_8*dmats1[8][55] + coeff0_9*dmats1[9][55] + coeff0_10*dmats1[10][55] + coeff0_11*dmats1[11][55] + coeff0_12*dmats1[12][55] + coeff0_13*dmats1[13][55] + coeff0_14*dmats1[14][55] + coeff0_15*dmats1[15][55] + coeff0_16*dmats1[16][55] + coeff0_17*dmats1[17][55] + coeff0_18*dmats1[18][55] + coeff0_19*dmats1[19][55] + coeff0_20*dmats1[20][55] + coeff0_21*dmats1[21][55] + coeff0_22*dmats1[22][55] + coeff0_23*dmats1[23][55] + coeff0_24*dmats1[24][55] + coeff0_25*dmats1[25][55] + coeff0_26*dmats1[26][55] + coeff0_27*dmats1[27][55] + coeff0_28*dmats1[28][55] + coeff0_29*dmats1[29][55] + coeff0_30*dmats1[30][55] + coeff0_31*dmats1[31][55] + coeff0_32*dmats1[32][55] + coeff0_33*dmats1[33][55] + coeff0_34*dmats1[34][55] + coeff0_35*dmats1[35][55] + coeff0_36*dmats1[36][55] + coeff0_37*dmats1[37][55] + coeff0_38*dmats1[38][55] + coeff0_39*dmats1[39][55] + coeff0_40*dmats1[40][55] + coeff0_41*dmats1[41][55] + coeff0_42*dmats1[42][55] + coeff0_43*dmats1[43][55] + coeff0_44*dmats1[44][55] + coeff0_45*dmats1[45][55] + coeff0_46*dmats1[46][55] + coeff0_47*dmats1[47][55] + coeff0_48*dmats1[48][55] + coeff0_49*dmats1[49][55] + coeff0_50*dmats1[50][55] + coeff0_51*dmats1[51][55] + coeff0_52*dmats1[52][55] + coeff0_53*dmats1[53][55] + coeff0_54*dmats1[54][55] + coeff0_55*dmats1[55][55];
        }
        if(combinations[deriv_num][j] == 2)
        {
          new_coeff0_0 = coeff0_0*dmats2[0][0] + coeff0_1*dmats2[1][0] + coeff0_2*dmats2[2][0] + coeff0_3*dmats2[3][0] + coeff0_4*dmats2[4][0] + coeff0_5*dmats2[5][0] + coeff0_6*dmats2[6][0] + coeff0_7*dmats2[7][0] + coeff0_8*dmats2[8][0] + coeff0_9*dmats2[9][0] + coeff0_10*dmats2[10][0] + coeff0_11*dmats2[11][0] + coeff0_12*dmats2[12][0] + coeff0_13*dmats2[13][0] + coeff0_14*dmats2[14][0] + coeff0_15*dmats2[15][0] + coeff0_16*dmats2[16][0] + coeff0_17*dmats2[17][0] + coeff0_18*dmats2[18][0] + coeff0_19*dmats2[19][0] + coeff0_20*dmats2[20][0] + coeff0_21*dmats2[21][0] + coeff0_22*dmats2[22][0] + coeff0_23*dmats2[23][0] + coeff0_24*dmats2[24][0] + coeff0_25*dmats2[25][0] + coeff0_26*dmats2[26][0] + coeff0_27*dmats2[27][0] + coeff0_28*dmats2[28][0] + coeff0_29*dmats2[29][0] + coeff0_30*dmats2[30][0] + coeff0_31*dmats2[31][0] + coeff0_32*dmats2[32][0] + coeff0_33*dmats2[33][0] + coeff0_34*dmats2[34][0] + coeff0_35*dmats2[35][0] + coeff0_36*dmats2[36][0] + coeff0_37*dmats2[37][0] + coeff0_38*dmats2[38][0] + coeff0_39*dmats2[39][0] + coeff0_40*dmats2[40][0] + coeff0_41*dmats2[41][0] + coeff0_42*dmats2[42][0] + coeff0_43*dmats2[43][0] + coeff0_44*dmats2[44][0] + coeff0_45*dmats2[45][0] + coeff0_46*dmats2[46][0] + coeff0_47*dmats2[47][0] + coeff0_48*dmats2[48][0] + coeff0_49*dmats2[49][0] + coeff0_50*dmats2[50][0] + coeff0_51*dmats2[51][0] + coeff0_52*dmats2[52][0] + coeff0_53*dmats2[53][0] + coeff0_54*dmats2[54][0] + coeff0_55*dmats2[55][0];
          new_coeff0_1 = coeff0_0*dmats2[0][1] + coeff0_1*dmats2[1][1] + coeff0_2*dmats2[2][1] + coeff0_3*dmats2[3][1] + coeff0_4*dmats2[4][1] + coeff0_5*dmats2[5][1] + coeff0_6*dmats2[6][1] + coeff0_7*dmats2[7][1] + coeff0_8*dmats2[8][1] + coeff0_9*dmats2[9][1] + coeff0_10*dmats2[10][1] + coeff0_11*dmats2[11][1] + coeff0_12*dmats2[12][1] + coeff0_13*dmats2[13][1] + coeff0_14*dmats2[14][1] + coeff0_15*dmats2[15][1] + coeff0_16*dmats2[16][1] + coeff0_17*dmats2[17][1] + coeff0_18*dmats2[18][1] + coeff0_19*dmats2[19][1] + coeff0_20*dmats2[20][1] + coeff0_21*dmats2[21][1] + coeff0_22*dmats2[22][1] + coeff0_23*dmats2[23][1] + coeff0_24*dmats2[24][1] + coeff0_25*dmats2[25][1] + coeff0_26*dmats2[26][1] + coeff0_27*dmats2[27][1] + coeff0_28*dmats2[28][1] + coeff0_29*dmats2[29][1] + coeff0_30*dmats2[30][1] + coeff0_31*dmats2[31][1] + coeff0_32*dmats2[32][1] + coeff0_33*dmats2[33][1] + coeff0_34*dmats2[34][1] + coeff0_35*dmats2[35][1] + coeff0_36*dmats2[36][1] + coeff0_37*dmats2[37][1] + coeff0_38*dmats2[38][1] + coeff0_39*dmats2[39][1] + coeff0_40*dmats2[40][1] + coeff0_41*dmats2[41][1] + coeff0_42*dmats2[42][1] + coeff0_43*dmats2[43][1] + coeff0_44*dmats2[44][1] + coeff0_45*dmats2[45][1] + coeff0_46*dmats2[46][1] + coeff0_47*dmats2[47][1] + coeff0_48*dmats2[48][1] + coeff0_49*dmats2[49][1] + coeff0_50*dmats2[50][1] + coeff0_51*dmats2[51][1] + coeff0_52*dmats2[52][1] + coeff0_53*dmats2[53][1] + coeff0_54*dmats2[54][1] + coeff0_55*dmats2[55][1];
          new_coeff0_2 = coeff0_0*dmats2[0][2] + coeff0_1*dmats2[1][2] + coeff0_2*dmats2[2][2] + coeff0_3*dmats2[3][2] + coeff0_4*dmats2[4][2] + coeff0_5*dmats2[5][2] + coeff0_6*dmats2[6][2] + coeff0_7*dmats2[7][2] + coeff0_8*dmats2[8][2] + coeff0_9*dmats2[9][2] + coeff0_10*dmats2[10][2] + coeff0_11*dmats2[11][2] + coeff0_12*dmats2[12][2] + coeff0_13*dmats2[13][2] + coeff0_14*dmats2[14][2] + coeff0_15*dmats2[15][2] + coeff0_16*dmats2[16][2] + coeff0_17*dmats2[17][2] + coeff0_18*dmats2[18][2] + coeff0_19*dmats2[19][2] + coeff0_20*dmats2[20][2] + coeff0_21*dmats2[21][2] + coeff0_22*dmats2[22][2] + coeff0_23*dmats2[23][2] + coeff0_24*dmats2[24][2] + coeff0_25*dmats2[25][2] + coeff0_26*dmats2[26][2] + coeff0_27*dmats2[27][2] + coeff0_28*dmats2[28][2] + coeff0_29*dmats2[29][2] + coeff0_30*dmats2[30][2] + coeff0_31*dmats2[31][2] + coeff0_32*dmats2[32][2] + coeff0_33*dmats2[33][2] + coeff0_34*dmats2[34][2] + coeff0_35*dmats2[35][2] + coeff0_36*dmats2[36][2] + coeff0_37*dmats2[37][2] + coeff0_38*dmats2[38][2] + coeff0_39*dmats2[39][2] + coeff0_40*dmats2[40][2] + coeff0_41*dmats2[41][2] + coeff0_42*dmats2[42][2] + coeff0_43*dmats2[43][2] + coeff0_44*dmats2[44][2] + coeff0_45*dmats2[45][2] + coeff0_46*dmats2[46][2] + coeff0_47*dmats2[47][2] + coeff0_48*dmats2[48][2] + coeff0_49*dmats2[49][2] + coeff0_50*dmats2[50][2] + coeff0_51*dmats2[51][2] + coeff0_52*dmats2[52][2] + coeff0_53*dmats2[53][2] + coeff0_54*dmats2[54][2] + coeff0_55*dmats2[55][2];
          new_coeff0_3 = coeff0_0*dmats2[0][3] + coeff0_1*dmats2[1][3] + coeff0_2*dmats2[2][3] + coeff0_3*dmats2[3][3] + coeff0_4*dmats2[4][3] + coeff0_5*dmats2[5][3] + coeff0_6*dmats2[6][3] + coeff0_7*dmats2[7][3] + coeff0_8*dmats2[8][3] + coeff0_9*dmats2[9][3] + coeff0_10*dmats2[10][3] + coeff0_11*dmats2[11][3] + coeff0_12*dmats2[12][3] + coeff0_13*dmats2[13][3] + coeff0_14*dmats2[14][3] + coeff0_15*dmats2[15][3] + coeff0_16*dmats2[16][3] + coeff0_17*dmats2[17][3] + coeff0_18*dmats2[18][3] + coeff0_19*dmats2[19][3] + coeff0_20*dmats2[20][3] + coeff0_21*dmats2[21][3] + coeff0_22*dmats2[22][3] + coeff0_23*dmats2[23][3] + coeff0_24*dmats2[24][3] + coeff0_25*dmats2[25][3] + coeff0_26*dmats2[26][3] + coeff0_27*dmats2[27][3] + coeff0_28*dmats2[28][3] + coeff0_29*dmats2[29][3] + coeff0_30*dmats2[30][3] + coeff0_31*dmats2[31][3] + coeff0_32*dmats2[32][3] + coeff0_33*dmats2[33][3] + coeff0_34*dmats2[34][3] + coeff0_35*dmats2[35][3] + coeff0_36*dmats2[36][3] + coeff0_37*dmats2[37][3] + coeff0_38*dmats2[38][3] + coeff0_39*dmats2[39][3] + coeff0_40*dmats2[40][3] + coeff0_41*dmats2[41][3] + coeff0_42*dmats2[42][3] + coeff0_43*dmats2[43][3] + coeff0_44*dmats2[44][3] + coeff0_45*dmats2[45][3] + coeff0_46*dmats2[46][3] + coeff0_47*dmats2[47][3] + coeff0_48*dmats2[48][3] + coeff0_49*dmats2[49][3] + coeff0_50*dmats2[50][3] + coeff0_51*dmats2[51][3] + coeff0_52*dmats2[52][3] + coeff0_53*dmats2[53][3] + coeff0_54*dmats2[54][3] + coeff0_55*dmats2[55][3];
          new_coeff0_4 = coeff0_0*dmats2[0][4] + coeff0_1*dmats2[1][4] + coeff0_2*dmats2[2][4] + coeff0_3*dmats2[3][4] + coeff0_4*dmats2[4][4] + coeff0_5*dmats2[5][4] + coeff0_6*dmats2[6][4] + coeff0_7*dmats2[7][4] + coeff0_8*dmats2[8][4] + coeff0_9*dmats2[9][4] + coeff0_10*dmats2[10][4] + coeff0_11*dmats2[11][4] + coeff0_12*dmats2[12][4] + coeff0_13*dmats2[13][4] + coeff0_14*dmats2[14][4] + coeff0_15*dmats2[15][4] + coeff0_16*dmats2[16][4] + coeff0_17*dmats2[17][4] + coeff0_18*dmats2[18][4] + coeff0_19*dmats2[19][4] + coeff0_20*dmats2[20][4] + coeff0_21*dmats2[21][4] + coeff0_22*dmats2[22][4] + coeff0_23*dmats2[23][4] + coeff0_24*dmats2[24][4] + coeff0_25*dmats2[25][4] + coeff0_26*dmats2[26][4] + coeff0_27*dmats2[27][4] + coeff0_28*dmats2[28][4] + coeff0_29*dmats2[29][4] + coeff0_30*dmats2[30][4] + coeff0_31*dmats2[31][4] + coeff0_32*dmats2[32][4] + coeff0_33*dmats2[33][4] + coeff0_34*dmats2[34][4] + coeff0_35*dmats2[35][4] + coeff0_36*dmats2[36][4] + coeff0_37*dmats2[37][4] + coeff0_38*dmats2[38][4] + coeff0_39*dmats2[39][4] + coeff0_40*dmats2[40][4] + coeff0_41*dmats2[41][4] + coeff0_42*dmats2[42][4] + coeff0_43*dmats2[43][4] + coeff0_44*dmats2[44][4] + coeff0_45*dmats2[45][4] + coeff0_46*dmats2[46][4] + coeff0_47*dmats2[47][4] + coeff0_48*dmats2[48][4] + coeff0_49*dmats2[49][4] + coeff0_50*dmats2[50][4] + coeff0_51*dmats2[51][4] + coeff0_52*dmats2[52][4] + coeff0_53*dmats2[53][4] + coeff0_54*dmats2[54][4] + coeff0_55*dmats2[55][4];
          new_coeff0_5 = coeff0_0*dmats2[0][5] + coeff0_1*dmats2[1][5] + coeff0_2*dmats2[2][5] + coeff0_3*dmats2[3][5] + coeff0_4*dmats2[4][5] + coeff0_5*dmats2[5][5] + coeff0_6*dmats2[6][5] + coeff0_7*dmats2[7][5] + coeff0_8*dmats2[8][5] + coeff0_9*dmats2[9][5] + coeff0_10*dmats2[10][5] + coeff0_11*dmats2[11][5] + coeff0_12*dmats2[12][5] + coeff0_13*dmats2[13][5] + coeff0_14*dmats2[14][5] + coeff0_15*dmats2[15][5] + coeff0_16*dmats2[16][5] + coeff0_17*dmats2[17][5] + coeff0_18*dmats2[18][5] + coeff0_19*dmats2[19][5] + coeff0_20*dmats2[20][5] + coeff0_21*dmats2[21][5] + coeff0_22*dmats2[22][5] + coeff0_23*dmats2[23][5] + coeff0_24*dmats2[24][5] + coeff0_25*dmats2[25][5] + coeff0_26*dmats2[26][5] + coeff0_27*dmats2[27][5] + coeff0_28*dmats2[28][5] + coeff0_29*dmats2[29][5] + coeff0_30*dmats2[30][5] + coeff0_31*dmats2[31][5] + coeff0_32*dmats2[32][5] + coeff0_33*dmats2[33][5] + coeff0_34*dmats2[34][5] + coeff0_35*dmats2[35][5] + coeff0_36*dmats2[36][5] + coeff0_37*dmats2[37][5] + coeff0_38*dmats2[38][5] + coeff0_39*dmats2[39][5] + coeff0_40*dmats2[40][5] + coeff0_41*dmats2[41][5] + coeff0_42*dmats2[42][5] + coeff0_43*dmats2[43][5] + coeff0_44*dmats2[44][5] + coeff0_45*dmats2[45][5] + coeff0_46*dmats2[46][5] + coeff0_47*dmats2[47][5] + coeff0_48*dmats2[48][5] + coeff0_49*dmats2[49][5] + coeff0_50*dmats2[50][5] + coeff0_51*dmats2[51][5] + coeff0_52*dmats2[52][5] + coeff0_53*dmats2[53][5] + coeff0_54*dmats2[54][5] + coeff0_55*dmats2[55][5];
          new_coeff0_6 = coeff0_0*dmats2[0][6] + coeff0_1*dmats2[1][6] + coeff0_2*dmats2[2][6] + coeff0_3*dmats2[3][6] + coeff0_4*dmats2[4][6] + coeff0_5*dmats2[5][6] + coeff0_6*dmats2[6][6] + coeff0_7*dmats2[7][6] + coeff0_8*dmats2[8][6] + coeff0_9*dmats2[9][6] + coeff0_10*dmats2[10][6] + coeff0_11*dmats2[11][6] + coeff0_12*dmats2[12][6] + coeff0_13*dmats2[13][6] + coeff0_14*dmats2[14][6] + coeff0_15*dmats2[15][6] + coeff0_16*dmats2[16][6] + coeff0_17*dmats2[17][6] + coeff0_18*dmats2[18][6] + coeff0_19*dmats2[19][6] + coeff0_20*dmats2[20][6] + coeff0_21*dmats2[21][6] + coeff0_22*dmats2[22][6] + coeff0_23*dmats2[23][6] + coeff0_24*dmats2[24][6] + coeff0_25*dmats2[25][6] + coeff0_26*dmats2[26][6] + coeff0_27*dmats2[27][6] + coeff0_28*dmats2[28][6] + coeff0_29*dmats2[29][6] + coeff0_30*dmats2[30][6] + coeff0_31*dmats2[31][6] + coeff0_32*dmats2[32][6] + coeff0_33*dmats2[33][6] + coeff0_34*dmats2[34][6] + coeff0_35*dmats2[35][6] + coeff0_36*dmats2[36][6] + coeff0_37*dmats2[37][6] + coeff0_38*dmats2[38][6] + coeff0_39*dmats2[39][6] + coeff0_40*dmats2[40][6] + coeff0_41*dmats2[41][6] + coeff0_42*dmats2[42][6] + coeff0_43*dmats2[43][6] + coeff0_44*dmats2[44][6] + coeff0_45*dmats2[45][6] + coeff0_46*dmats2[46][6] + coeff0_47*dmats2[47][6] + coeff0_48*dmats2[48][6] + coeff0_49*dmats2[49][6] + coeff0_50*dmats2[50][6] + coeff0_51*dmats2[51][6] + coeff0_52*dmats2[52][6] + coeff0_53*dmats2[53][6] + coeff0_54*dmats2[54][6] + coeff0_55*dmats2[55][6];
          new_coeff0_7 = coeff0_0*dmats2[0][7] + coeff0_1*dmats2[1][7] + coeff0_2*dmats2[2][7] + coeff0_3*dmats2[3][7] + coeff0_4*dmats2[4][7] + coeff0_5*dmats2[5][7] + coeff0_6*dmats2[6][7] + coeff0_7*dmats2[7][7] + coeff0_8*dmats2[8][7] + coeff0_9*dmats2[9][7] + coeff0_10*dmats2[10][7] + coeff0_11*dmats2[11][7] + coeff0_12*dmats2[12][7] + coeff0_13*dmats2[13][7] + coeff0_14*dmats2[14][7] + coeff0_15*dmats2[15][7] + coeff0_16*dmats2[16][7] + coeff0_17*dmats2[17][7] + coeff0_18*dmats2[18][7] + coeff0_19*dmats2[19][7] + coeff0_20*dmats2[20][7] + coeff0_21*dmats2[21][7] + coeff0_22*dmats2[22][7] + coeff0_23*dmats2[23][7] + coeff0_24*dmats2[24][7] + coeff0_25*dmats2[25][7] + coeff0_26*dmats2[26][7] + coeff0_27*dmats2[27][7] + coeff0_28*dmats2[28][7] + coeff0_29*dmats2[29][7] + coeff0_30*dmats2[30][7] + coeff0_31*dmats2[31][7] + coeff0_32*dmats2[32][7] + coeff0_33*dmats2[33][7] + coeff0_34*dmats2[34][7] + coeff0_35*dmats2[35][7] + coeff0_36*dmats2[36][7] + coeff0_37*dmats2[37][7] + coeff0_38*dmats2[38][7] + coeff0_39*dmats2[39][7] + coeff0_40*dmats2[40][7] + coeff0_41*dmats2[41][7] + coeff0_42*dmats2[42][7] + coeff0_43*dmats2[43][7] + coeff0_44*dmats2[44][7] + coeff0_45*dmats2[45][7] + coeff0_46*dmats2[46][7] + coeff0_47*dmats2[47][7] + coeff0_48*dmats2[48][7] + coeff0_49*dmats2[49][7] + coeff0_50*dmats2[50][7] + coeff0_51*dmats2[51][7] + coeff0_52*dmats2[52][7] + coeff0_53*dmats2[53][7] + coeff0_54*dmats2[54][7] + coeff0_55*dmats2[55][7];
          new_coeff0_8 = coeff0_0*dmats2[0][8] + coeff0_1*dmats2[1][8] + coeff0_2*dmats2[2][8] + coeff0_3*dmats2[3][8] + coeff0_4*dmats2[4][8] + coeff0_5*dmats2[5][8] + coeff0_6*dmats2[6][8] + coeff0_7*dmats2[7][8] + coeff0_8*dmats2[8][8] + coeff0_9*dmats2[9][8] + coeff0_10*dmats2[10][8] + coeff0_11*dmats2[11][8] + coeff0_12*dmats2[12][8] + coeff0_13*dmats2[13][8] + coeff0_14*dmats2[14][8] + coeff0_15*dmats2[15][8] + coeff0_16*dmats2[16][8] + coeff0_17*dmats2[17][8] + coeff0_18*dmats2[18][8] + coeff0_19*dmats2[19][8] + coeff0_20*dmats2[20][8] + coeff0_21*dmats2[21][8] + coeff0_22*dmats2[22][8] + coeff0_23*dmats2[23][8] + coeff0_24*dmats2[24][8] + coeff0_25*dmats2[25][8] + coeff0_26*dmats2[26][8] + coeff0_27*dmats2[27][8] + coeff0_28*dmats2[28][8] + coeff0_29*dmats2[29][8] + coeff0_30*dmats2[30][8] + coeff0_31*dmats2[31][8] + coeff0_32*dmats2[32][8] + coeff0_33*dmats2[33][8] + coeff0_34*dmats2[34][8] + coeff0_35*dmats2[35][8] + coeff0_36*dmats2[36][8] + coeff0_37*dmats2[37][8] + coeff0_38*dmats2[38][8] + coeff0_39*dmats2[39][8] + coeff0_40*dmats2[40][8] + coeff0_41*dmats2[41][8] + coeff0_42*dmats2[42][8] + coeff0_43*dmats2[43][8] + coeff0_44*dmats2[44][8] + coeff0_45*dmats2[45][8] + coeff0_46*dmats2[46][8] + coeff0_47*dmats2[47][8] + coeff0_48*dmats2[48][8] + coeff0_49*dmats2[49][8] + coeff0_50*dmats2[50][8] + coeff0_51*dmats2[51][8] + coeff0_52*dmats2[52][8] + coeff0_53*dmats2[53][8] + coeff0_54*dmats2[54][8] + coeff0_55*dmats2[55][8];
          new_coeff0_9 = coeff0_0*dmats2[0][9] + coeff0_1*dmats2[1][9] + coeff0_2*dmats2[2][9] + coeff0_3*dmats2[3][9] + coeff0_4*dmats2[4][9] + coeff0_5*dmats2[5][9] + coeff0_6*dmats2[6][9] + coeff0_7*dmats2[7][9] + coeff0_8*dmats2[8][9] + coeff0_9*dmats2[9][9] + coeff0_10*dmats2[10][9] + coeff0_11*dmats2[11][9] + coeff0_12*dmats2[12][9] + coeff0_13*dmats2[13][9] + coeff0_14*dmats2[14][9] + coeff0_15*dmats2[15][9] + coeff0_16*dmats2[16][9] + coeff0_17*dmats2[17][9] + coeff0_18*dmats2[18][9] + coeff0_19*dmats2[19][9] + coeff0_20*dmats2[20][9] + coeff0_21*dmats2[21][9] + coeff0_22*dmats2[22][9] + coeff0_23*dmats2[23][9] + coeff0_24*dmats2[24][9] + coeff0_25*dmats2[25][9] + coeff0_26*dmats2[26][9] + coeff0_27*dmats2[27][9] + coeff0_28*dmats2[28][9] + coeff0_29*dmats2[29][9] + coeff0_30*dmats2[30][9] + coeff0_31*dmats2[31][9] + coeff0_32*dmats2[32][9] + coeff0_33*dmats2[33][9] + coeff0_34*dmats2[34][9] + coeff0_35*dmats2[35][9] + coeff0_36*dmats2[36][9] + coeff0_37*dmats2[37][9] + coeff0_38*dmats2[38][9] + coeff0_39*dmats2[39][9] + coeff0_40*dmats2[40][9] + coeff0_41*dmats2[41][9] + coeff0_42*dmats2[42][9] + coeff0_43*dmats2[43][9] + coeff0_44*dmats2[44][9] + coeff0_45*dmats2[45][9] + coeff0_46*dmats2[46][9] + coeff0_47*dmats2[47][9] + coeff0_48*dmats2[48][9] + coeff0_49*dmats2[49][9] + coeff0_50*dmats2[50][9] + coeff0_51*dmats2[51][9] + coeff0_52*dmats2[52][9] + coeff0_53*dmats2[53][9] + coeff0_54*dmats2[54][9] + coeff0_55*dmats2[55][9];
          new_coeff0_10 = coeff0_0*dmats2[0][10] + coeff0_1*dmats2[1][10] + coeff0_2*dmats2[2][10] + coeff0_3*dmats2[3][10] + coeff0_4*dmats2[4][10] + coeff0_5*dmats2[5][10] + coeff0_6*dmats2[6][10] + coeff0_7*dmats2[7][10] + coeff0_8*dmats2[8][10] + coeff0_9*dmats2[9][10] + coeff0_10*dmats2[10][10] + coeff0_11*dmats2[11][10] + coeff0_12*dmats2[12][10] + coeff0_13*dmats2[13][10] + coeff0_14*dmats2[14][10] + coeff0_15*dmats2[15][10] + coeff0_16*dmats2[16][10] + coeff0_17*dmats2[17][10] + coeff0_18*dmats2[18][10] + coeff0_19*dmats2[19][10] + coeff0_20*dmats2[20][10] + coeff0_21*dmats2[21][10] + coeff0_22*dmats2[22][10] + coeff0_23*dmats2[23][10] + coeff0_24*dmats2[24][10] + coeff0_25*dmats2[25][10] + coeff0_26*dmats2[26][10] + coeff0_27*dmats2[27][10] + coeff0_28*dmats2[28][10] + coeff0_29*dmats2[29][10] + coeff0_30*dmats2[30][10] + coeff0_31*dmats2[31][10] + coeff0_32*dmats2[32][10] + coeff0_33*dmats2[33][10] + coeff0_34*dmats2[34][10] + coeff0_35*dmats2[35][10] + coeff0_36*dmats2[36][10] + coeff0_37*dmats2[37][10] + coeff0_38*dmats2[38][10] + coeff0_39*dmats2[39][10] + coeff0_40*dmats2[40][10] + coeff0_41*dmats2[41][10] + coeff0_42*dmats2[42][10] + coeff0_43*dmats2[43][10] + coeff0_44*dmats2[44][10] + coeff0_45*dmats2[45][10] + coeff0_46*dmats2[46][10] + coeff0_47*dmats2[47][10] + coeff0_48*dmats2[48][10] + coeff0_49*dmats2[49][10] + coeff0_50*dmats2[50][10] + coeff0_51*dmats2[51][10] + coeff0_52*dmats2[52][10] + coeff0_53*dmats2[53][10] + coeff0_54*dmats2[54][10] + coeff0_55*dmats2[55][10];
          new_coeff0_11 = coeff0_0*dmats2[0][11] + coeff0_1*dmats2[1][11] + coeff0_2*dmats2[2][11] + coeff0_3*dmats2[3][11] + coeff0_4*dmats2[4][11] + coeff0_5*dmats2[5][11] + coeff0_6*dmats2[6][11] + coeff0_7*dmats2[7][11] + coeff0_8*dmats2[8][11] + coeff0_9*dmats2[9][11] + coeff0_10*dmats2[10][11] + coeff0_11*dmats2[11][11] + coeff0_12*dmats2[12][11] + coeff0_13*dmats2[13][11] + coeff0_14*dmats2[14][11] + coeff0_15*dmats2[15][11] + coeff0_16*dmats2[16][11] + coeff0_17*dmats2[17][11] + coeff0_18*dmats2[18][11] + coeff0_19*dmats2[19][11] + coeff0_20*dmats2[20][11] + coeff0_21*dmats2[21][11] + coeff0_22*dmats2[22][11] + coeff0_23*dmats2[23][11] + coeff0_24*dmats2[24][11] + coeff0_25*dmats2[25][11] + coeff0_26*dmats2[26][11] + coeff0_27*dmats2[27][11] + coeff0_28*dmats2[28][11] + coeff0_29*dmats2[29][11] + coeff0_30*dmats2[30][11] + coeff0_31*dmats2[31][11] + coeff0_32*dmats2[32][11] + coeff0_33*dmats2[33][11] + coeff0_34*dmats2[34][11] + coeff0_35*dmats2[35][11] + coeff0_36*dmats2[36][11] + coeff0_37*dmats2[37][11] + coeff0_38*dmats2[38][11] + coeff0_39*dmats2[39][11] + coeff0_40*dmats2[40][11] + coeff0_41*dmats2[41][11] + coeff0_42*dmats2[42][11] + coeff0_43*dmats2[43][11] + coeff0_44*dmats2[44][11] + coeff0_45*dmats2[45][11] + coeff0_46*dmats2[46][11] + coeff0_47*dmats2[47][11] + coeff0_48*dmats2[48][11] + coeff0_49*dmats2[49][11] + coeff0_50*dmats2[50][11] + coeff0_51*dmats2[51][11] + coeff0_52*dmats2[52][11] + coeff0_53*dmats2[53][11] + coeff0_54*dmats2[54][11] + coeff0_55*dmats2[55][11];
          new_coeff0_12 = coeff0_0*dmats2[0][12] + coeff0_1*dmats2[1][12] + coeff0_2*dmats2[2][12] + coeff0_3*dmats2[3][12] + coeff0_4*dmats2[4][12] + coeff0_5*dmats2[5][12] + coeff0_6*dmats2[6][12] + coeff0_7*dmats2[7][12] + coeff0_8*dmats2[8][12] + coeff0_9*dmats2[9][12] + coeff0_10*dmats2[10][12] + coeff0_11*dmats2[11][12] + coeff0_12*dmats2[12][12] + coeff0_13*dmats2[13][12] + coeff0_14*dmats2[14][12] + coeff0_15*dmats2[15][12] + coeff0_16*dmats2[16][12] + coeff0_17*dmats2[17][12] + coeff0_18*dmats2[18][12] + coeff0_19*dmats2[19][12] + coeff0_20*dmats2[20][12] + coeff0_21*dmats2[21][12] + coeff0_22*dmats2[22][12] + coeff0_23*dmats2[23][12] + coeff0_24*dmats2[24][12] + coeff0_25*dmats2[25][12] + coeff0_26*dmats2[26][12] + coeff0_27*dmats2[27][12] + coeff0_28*dmats2[28][12] + coeff0_29*dmats2[29][12] + coeff0_30*dmats2[30][12] + coeff0_31*dmats2[31][12] + coeff0_32*dmats2[32][12] + coeff0_33*dmats2[33][12] + coeff0_34*dmats2[34][12] + coeff0_35*dmats2[35][12] + coeff0_36*dmats2[36][12] + coeff0_37*dmats2[37][12] + coeff0_38*dmats2[38][12] + coeff0_39*dmats2[39][12] + coeff0_40*dmats2[40][12] + coeff0_41*dmats2[41][12] + coeff0_42*dmats2[42][12] + coeff0_43*dmats2[43][12] + coeff0_44*dmats2[44][12] + coeff0_45*dmats2[45][12] + coeff0_46*dmats2[46][12] + coeff0_47*dmats2[47][12] + coeff0_48*dmats2[48][12] + coeff0_49*dmats2[49][12] + coeff0_50*dmats2[50][12] + coeff0_51*dmats2[51][12] + coeff0_52*dmats2[52][12] + coeff0_53*dmats2[53][12] + coeff0_54*dmats2[54][12] + coeff0_55*dmats2[55][12];
          new_coeff0_13 = coeff0_0*dmats2[0][13] + coeff0_1*dmats2[1][13] + coeff0_2*dmats2[2][13] + coeff0_3*dmats2[3][13] + coeff0_4*dmats2[4][13] + coeff0_5*dmats2[5][13] + coeff0_6*dmats2[6][13] + coeff0_7*dmats2[7][13] + coeff0_8*dmats2[8][13] + coeff0_9*dmats2[9][13] + coeff0_10*dmats2[10][13] + coeff0_11*dmats2[11][13] + coeff0_12*dmats2[12][13] + coeff0_13*dmats2[13][13] + coeff0_14*dmats2[14][13] + coeff0_15*dmats2[15][13] + coeff0_16*dmats2[16][13] + coeff0_17*dmats2[17][13] + coeff0_18*dmats2[18][13] + coeff0_19*dmats2[19][13] + coeff0_20*dmats2[20][13] + coeff0_21*dmats2[21][13] + coeff0_22*dmats2[22][13] + coeff0_23*dmats2[23][13] + coeff0_24*dmats2[24][13] + coeff0_25*dmats2[25][13] + coeff0_26*dmats2[26][13] + coeff0_27*dmats2[27][13] + coeff0_28*dmats2[28][13] + coeff0_29*dmats2[29][13] + coeff0_30*dmats2[30][13] + coeff0_31*dmats2[31][13] + coeff0_32*dmats2[32][13] + coeff0_33*dmats2[33][13] + coeff0_34*dmats2[34][13] + coeff0_35*dmats2[35][13] + coeff0_36*dmats2[36][13] + coeff0_37*dmats2[37][13] + coeff0_38*dmats2[38][13] + coeff0_39*dmats2[39][13] + coeff0_40*dmats2[40][13] + coeff0_41*dmats2[41][13] + coeff0_42*dmats2[42][13] + coeff0_43*dmats2[43][13] + coeff0_44*dmats2[44][13] + coeff0_45*dmats2[45][13] + coeff0_46*dmats2[46][13] + coeff0_47*dmats2[47][13] + coeff0_48*dmats2[48][13] + coeff0_49*dmats2[49][13] + coeff0_50*dmats2[50][13] + coeff0_51*dmats2[51][13] + coeff0_52*dmats2[52][13] + coeff0_53*dmats2[53][13] + coeff0_54*dmats2[54][13] + coeff0_55*dmats2[55][13];
          new_coeff0_14 = coeff0_0*dmats2[0][14] + coeff0_1*dmats2[1][14] + coeff0_2*dmats2[2][14] + coeff0_3*dmats2[3][14] + coeff0_4*dmats2[4][14] + coeff0_5*dmats2[5][14] + coeff0_6*dmats2[6][14] + coeff0_7*dmats2[7][14] + coeff0_8*dmats2[8][14] + coeff0_9*dmats2[9][14] + coeff0_10*dmats2[10][14] + coeff0_11*dmats2[11][14] + coeff0_12*dmats2[12][14] + coeff0_13*dmats2[13][14] + coeff0_14*dmats2[14][14] + coeff0_15*dmats2[15][14] + coeff0_16*dmats2[16][14] + coeff0_17*dmats2[17][14] + coeff0_18*dmats2[18][14] + coeff0_19*dmats2[19][14] + coeff0_20*dmats2[20][14] + coeff0_21*dmats2[21][14] + coeff0_22*dmats2[22][14] + coeff0_23*dmats2[23][14] + coeff0_24*dmats2[24][14] + coeff0_25*dmats2[25][14] + coeff0_26*dmats2[26][14] + coeff0_27*dmats2[27][14] + coeff0_28*dmats2[28][14] + coeff0_29*dmats2[29][14] + coeff0_30*dmats2[30][14] + coeff0_31*dmats2[31][14] + coeff0_32*dmats2[32][14] + coeff0_33*dmats2[33][14] + coeff0_34*dmats2[34][14] + coeff0_35*dmats2[35][14] + coeff0_36*dmats2[36][14] + coeff0_37*dmats2[37][14] + coeff0_38*dmats2[38][14] + coeff0_39*dmats2[39][14] + coeff0_40*dmats2[40][14] + coeff0_41*dmats2[41][14] + coeff0_42*dmats2[42][14] + coeff0_43*dmats2[43][14] + coeff0_44*dmats2[44][14] + coeff0_45*dmats2[45][14] + coeff0_46*dmats2[46][14] + coeff0_47*dmats2[47][14] + coeff0_48*dmats2[48][14] + coeff0_49*dmats2[49][14] + coeff0_50*dmats2[50][14] + coeff0_51*dmats2[51][14] + coeff0_52*dmats2[52][14] + coeff0_53*dmats2[53][14] + coeff0_54*dmats2[54][14] + coeff0_55*dmats2[55][14];
          new_coeff0_15 = coeff0_0*dmats2[0][15] + coeff0_1*dmats2[1][15] + coeff0_2*dmats2[2][15] + coeff0_3*dmats2[3][15] + coeff0_4*dmats2[4][15] + coeff0_5*dmats2[5][15] + coeff0_6*dmats2[6][15] + coeff0_7*dmats2[7][15] + coeff0_8*dmats2[8][15] + coeff0_9*dmats2[9][15] + coeff0_10*dmats2[10][15] + coeff0_11*dmats2[11][15] + coeff0_12*dmats2[12][15] + coeff0_13*dmats2[13][15] + coeff0_14*dmats2[14][15] + coeff0_15*dmats2[15][15] + coeff0_16*dmats2[16][15] + coeff0_17*dmats2[17][15] + coeff0_18*dmats2[18][15] + coeff0_19*dmats2[19][15] + coeff0_20*dmats2[20][15] + coeff0_21*dmats2[21][15] + coeff0_22*dmats2[22][15] + coeff0_23*dmats2[23][15] + coeff0_24*dmats2[24][15] + coeff0_25*dmats2[25][15] + coeff0_26*dmats2[26][15] + coeff0_27*dmats2[27][15] + coeff0_28*dmats2[28][15] + coeff0_29*dmats2[29][15] + coeff0_30*dmats2[30][15] + coeff0_31*dmats2[31][15] + coeff0_32*dmats2[32][15] + coeff0_33*dmats2[33][15] + coeff0_34*dmats2[34][15] + coeff0_35*dmats2[35][15] + coeff0_36*dmats2[36][15] + coeff0_37*dmats2[37][15] + coeff0_38*dmats2[38][15] + coeff0_39*dmats2[39][15] + coeff0_40*dmats2[40][15] + coeff0_41*dmats2[41][15] + coeff0_42*dmats2[42][15] + coeff0_43*dmats2[43][15] + coeff0_44*dmats2[44][15] + coeff0_45*dmats2[45][15] + coeff0_46*dmats2[46][15] + coeff0_47*dmats2[47][15] + coeff0_48*dmats2[48][15] + coeff0_49*dmats2[49][15] + coeff0_50*dmats2[50][15] + coeff0_51*dmats2[51][15] + coeff0_52*dmats2[52][15] + coeff0_53*dmats2[53][15] + coeff0_54*dmats2[54][15] + coeff0_55*dmats2[55][15];
          new_coeff0_16 = coeff0_0*dmats2[0][16] + coeff0_1*dmats2[1][16] + coeff0_2*dmats2[2][16] + coeff0_3*dmats2[3][16] + coeff0_4*dmats2[4][16] + coeff0_5*dmats2[5][16] + coeff0_6*dmats2[6][16] + coeff0_7*dmats2[7][16] + coeff0_8*dmats2[8][16] + coeff0_9*dmats2[9][16] + coeff0_10*dmats2[10][16] + coeff0_11*dmats2[11][16] + coeff0_12*dmats2[12][16] + coeff0_13*dmats2[13][16] + coeff0_14*dmats2[14][16] + coeff0_15*dmats2[15][16] + coeff0_16*dmats2[16][16] + coeff0_17*dmats2[17][16] + coeff0_18*dmats2[18][16] + coeff0_19*dmats2[19][16] + coeff0_20*dmats2[20][16] + coeff0_21*dmats2[21][16] + coeff0_22*dmats2[22][16] + coeff0_23*dmats2[23][16] + coeff0_24*dmats2[24][16] + coeff0_25*dmats2[25][16] + coeff0_26*dmats2[26][16] + coeff0_27*dmats2[27][16] + coeff0_28*dmats2[28][16] + coeff0_29*dmats2[29][16] + coeff0_30*dmats2[30][16] + coeff0_31*dmats2[31][16] + coeff0_32*dmats2[32][16] + coeff0_33*dmats2[33][16] + coeff0_34*dmats2[34][16] + coeff0_35*dmats2[35][16] + coeff0_36*dmats2[36][16] + coeff0_37*dmats2[37][16] + coeff0_38*dmats2[38][16] + coeff0_39*dmats2[39][16] + coeff0_40*dmats2[40][16] + coeff0_41*dmats2[41][16] + coeff0_42*dmats2[42][16] + coeff0_43*dmats2[43][16] + coeff0_44*dmats2[44][16] + coeff0_45*dmats2[45][16] + coeff0_46*dmats2[46][16] + coeff0_47*dmats2[47][16] + coeff0_48*dmats2[48][16] + coeff0_49*dmats2[49][16] + coeff0_50*dmats2[50][16] + coeff0_51*dmats2[51][16] + coeff0_52*dmats2[52][16] + coeff0_53*dmats2[53][16] + coeff0_54*dmats2[54][16] + coeff0_55*dmats2[55][16];
          new_coeff0_17 = coeff0_0*dmats2[0][17] + coeff0_1*dmats2[1][17] + coeff0_2*dmats2[2][17] + coeff0_3*dmats2[3][17] + coeff0_4*dmats2[4][17] + coeff0_5*dmats2[5][17] + coeff0_6*dmats2[6][17] + coeff0_7*dmats2[7][17] + coeff0_8*dmats2[8][17] + coeff0_9*dmats2[9][17] + coeff0_10*dmats2[10][17] + coeff0_11*dmats2[11][17] + coeff0_12*dmats2[12][17] + coeff0_13*dmats2[13][17] + coeff0_14*dmats2[14][17] + coeff0_15*dmats2[15][17] + coeff0_16*dmats2[16][17] + coeff0_17*dmats2[17][17] + coeff0_18*dmats2[18][17] + coeff0_19*dmats2[19][17] + coeff0_20*dmats2[20][17] + coeff0_21*dmats2[21][17] + coeff0_22*dmats2[22][17] + coeff0_23*dmats2[23][17] + coeff0_24*dmats2[24][17] + coeff0_25*dmats2[25][17] + coeff0_26*dmats2[26][17] + coeff0_27*dmats2[27][17] + coeff0_28*dmats2[28][17] + coeff0_29*dmats2[29][17] + coeff0_30*dmats2[30][17] + coeff0_31*dmats2[31][17] + coeff0_32*dmats2[32][17] + coeff0_33*dmats2[33][17] + coeff0_34*dmats2[34][17] + coeff0_35*dmats2[35][17] + coeff0_36*dmats2[36][17] + coeff0_37*dmats2[37][17] + coeff0_38*dmats2[38][17] + coeff0_39*dmats2[39][17] + coeff0_40*dmats2[40][17] + coeff0_41*dmats2[41][17] + coeff0_42*dmats2[42][17] + coeff0_43*dmats2[43][17] + coeff0_44*dmats2[44][17] + coeff0_45*dmats2[45][17] + coeff0_46*dmats2[46][17] + coeff0_47*dmats2[47][17] + coeff0_48*dmats2[48][17] + coeff0_49*dmats2[49][17] + coeff0_50*dmats2[50][17] + coeff0_51*dmats2[51][17] + coeff0_52*dmats2[52][17] + coeff0_53*dmats2[53][17] + coeff0_54*dmats2[54][17] + coeff0_55*dmats2[55][17];
          new_coeff0_18 = coeff0_0*dmats2[0][18] + coeff0_1*dmats2[1][18] + coeff0_2*dmats2[2][18] + coeff0_3*dmats2[3][18] + coeff0_4*dmats2[4][18] + coeff0_5*dmats2[5][18] + coeff0_6*dmats2[6][18] + coeff0_7*dmats2[7][18] + coeff0_8*dmats2[8][18] + coeff0_9*dmats2[9][18] + coeff0_10*dmats2[10][18] + coeff0_11*dmats2[11][18] + coeff0_12*dmats2[12][18] + coeff0_13*dmats2[13][18] + coeff0_14*dmats2[14][18] + coeff0_15*dmats2[15][18] + coeff0_16*dmats2[16][18] + coeff0_17*dmats2[17][18] + coeff0_18*dmats2[18][18] + coeff0_19*dmats2[19][18] + coeff0_20*dmats2[20][18] + coeff0_21*dmats2[21][18] + coeff0_22*dmats2[22][18] + coeff0_23*dmats2[23][18] + coeff0_24*dmats2[24][18] + coeff0_25*dmats2[25][18] + coeff0_26*dmats2[26][18] + coeff0_27*dmats2[27][18] + coeff0_28*dmats2[28][18] + coeff0_29*dmats2[29][18] + coeff0_30*dmats2[30][18] + coeff0_31*dmats2[31][18] + coeff0_32*dmats2[32][18] + coeff0_33*dmats2[33][18] + coeff0_34*dmats2[34][18] + coeff0_35*dmats2[35][18] + coeff0_36*dmats2[36][18] + coeff0_37*dmats2[37][18] + coeff0_38*dmats2[38][18] + coeff0_39*dmats2[39][18] + coeff0_40*dmats2[40][18] + coeff0_41*dmats2[41][18] + coeff0_42*dmats2[42][18] + coeff0_43*dmats2[43][18] + coeff0_44*dmats2[44][18] + coeff0_45*dmats2[45][18] + coeff0_46*dmats2[46][18] + coeff0_47*dmats2[47][18] + coeff0_48*dmats2[48][18] + coeff0_49*dmats2[49][18] + coeff0_50*dmats2[50][18] + coeff0_51*dmats2[51][18] + coeff0_52*dmats2[52][18] + coeff0_53*dmats2[53][18] + coeff0_54*dmats2[54][18] + coeff0_55*dmats2[55][18];
          new_coeff0_19 = coeff0_0*dmats2[0][19] + coeff0_1*dmats2[1][19] + coeff0_2*dmats2[2][19] + coeff0_3*dmats2[3][19] + coeff0_4*dmats2[4][19] + coeff0_5*dmats2[5][19] + coeff0_6*dmats2[6][19] + coeff0_7*dmats2[7][19] + coeff0_8*dmats2[8][19] + coeff0_9*dmats2[9][19] + coeff0_10*dmats2[10][19] + coeff0_11*dmats2[11][19] + coeff0_12*dmats2[12][19] + coeff0_13*dmats2[13][19] + coeff0_14*dmats2[14][19] + coeff0_15*dmats2[15][19] + coeff0_16*dmats2[16][19] + coeff0_17*dmats2[17][19] + coeff0_18*dmats2[18][19] + coeff0_19*dmats2[19][19] + coeff0_20*dmats2[20][19] + coeff0_21*dmats2[21][19] + coeff0_22*dmats2[22][19] + coeff0_23*dmats2[23][19] + coeff0_24*dmats2[24][19] + coeff0_25*dmats2[25][19] + coeff0_26*dmats2[26][19] + coeff0_27*dmats2[27][19] + coeff0_28*dmats2[28][19] + coeff0_29*dmats2[29][19] + coeff0_30*dmats2[30][19] + coeff0_31*dmats2[31][19] + coeff0_32*dmats2[32][19] + coeff0_33*dmats2[33][19] + coeff0_34*dmats2[34][19] + coeff0_35*dmats2[35][19] + coeff0_36*dmats2[36][19] + coeff0_37*dmats2[37][19] + coeff0_38*dmats2[38][19] + coeff0_39*dmats2[39][19] + coeff0_40*dmats2[40][19] + coeff0_41*dmats2[41][19] + coeff0_42*dmats2[42][19] + coeff0_43*dmats2[43][19] + coeff0_44*dmats2[44][19] + coeff0_45*dmats2[45][19] + coeff0_46*dmats2[46][19] + coeff0_47*dmats2[47][19] + coeff0_48*dmats2[48][19] + coeff0_49*dmats2[49][19] + coeff0_50*dmats2[50][19] + coeff0_51*dmats2[51][19] + coeff0_52*dmats2[52][19] + coeff0_53*dmats2[53][19] + coeff0_54*dmats2[54][19] + coeff0_55*dmats2[55][19];
          new_coeff0_20 = coeff0_0*dmats2[0][20] + coeff0_1*dmats2[1][20] + coeff0_2*dmats2[2][20] + coeff0_3*dmats2[3][20] + coeff0_4*dmats2[4][20] + coeff0_5*dmats2[5][20] + coeff0_6*dmats2[6][20] + coeff0_7*dmats2[7][20] + coeff0_8*dmats2[8][20] + coeff0_9*dmats2[9][20] + coeff0_10*dmats2[10][20] + coeff0_11*dmats2[11][20] + coeff0_12*dmats2[12][20] + coeff0_13*dmats2[13][20] + coeff0_14*dmats2[14][20] + coeff0_15*dmats2[15][20] + coeff0_16*dmats2[16][20] + coeff0_17*dmats2[17][20] + coeff0_18*dmats2[18][20] + coeff0_19*dmats2[19][20] + coeff0_20*dmats2[20][20] + coeff0_21*dmats2[21][20] + coeff0_22*dmats2[22][20] + coeff0_23*dmats2[23][20] + coeff0_24*dmats2[24][20] + coeff0_25*dmats2[25][20] + coeff0_26*dmats2[26][20] + coeff0_27*dmats2[27][20] + coeff0_28*dmats2[28][20] + coeff0_29*dmats2[29][20] + coeff0_30*dmats2[30][20] + coeff0_31*dmats2[31][20] + coeff0_32*dmats2[32][20] + coeff0_33*dmats2[33][20] + coeff0_34*dmats2[34][20] + coeff0_35*dmats2[35][20] + coeff0_36*dmats2[36][20] + coeff0_37*dmats2[37][20] + coeff0_38*dmats2[38][20] + coeff0_39*dmats2[39][20] + coeff0_40*dmats2[40][20] + coeff0_41*dmats2[41][20] + coeff0_42*dmats2[42][20] + coeff0_43*dmats2[43][20] + coeff0_44*dmats2[44][20] + coeff0_45*dmats2[45][20] + coeff0_46*dmats2[46][20] + coeff0_47*dmats2[47][20] + coeff0_48*dmats2[48][20] + coeff0_49*dmats2[49][20] + coeff0_50*dmats2[50][20] + coeff0_51*dmats2[51][20] + coeff0_52*dmats2[52][20] + coeff0_53*dmats2[53][20] + coeff0_54*dmats2[54][20] + coeff0_55*dmats2[55][20];
          new_coeff0_21 = coeff0_0*dmats2[0][21] + coeff0_1*dmats2[1][21] + coeff0_2*dmats2[2][21] + coeff0_3*dmats2[3][21] + coeff0_4*dmats2[4][21] + coeff0_5*dmats2[5][21] + coeff0_6*dmats2[6][21] + coeff0_7*dmats2[7][21] + coeff0_8*dmats2[8][21] + coeff0_9*dmats2[9][21] + coeff0_10*dmats2[10][21] + coeff0_11*dmats2[11][21] + coeff0_12*dmats2[12][21] + coeff0_13*dmats2[13][21] + coeff0_14*dmats2[14][21] + coeff0_15*dmats2[15][21] + coeff0_16*dmats2[16][21] + coeff0_17*dmats2[17][21] + coeff0_18*dmats2[18][21] + coeff0_19*dmats2[19][21] + coeff0_20*dmats2[20][21] + coeff0_21*dmats2[21][21] + coeff0_22*dmats2[22][21] + coeff0_23*dmats2[23][21] + coeff0_24*dmats2[24][21] + coeff0_25*dmats2[25][21] + coeff0_26*dmats2[26][21] + coeff0_27*dmats2[27][21] + coeff0_28*dmats2[28][21] + coeff0_29*dmats2[29][21] + coeff0_30*dmats2[30][21] + coeff0_31*dmats2[31][21] + coeff0_32*dmats2[32][21] + coeff0_33*dmats2[33][21] + coeff0_34*dmats2[34][21] + coeff0_35*dmats2[35][21] + coeff0_36*dmats2[36][21] + coeff0_37*dmats2[37][21] + coeff0_38*dmats2[38][21] + coeff0_39*dmats2[39][21] + coeff0_40*dmats2[40][21] + coeff0_41*dmats2[41][21] + coeff0_42*dmats2[42][21] + coeff0_43*dmats2[43][21] + coeff0_44*dmats2[44][21] + coeff0_45*dmats2[45][21] + coeff0_46*dmats2[46][21] + coeff0_47*dmats2[47][21] + coeff0_48*dmats2[48][21] + coeff0_49*dmats2[49][21] + coeff0_50*dmats2[50][21] + coeff0_51*dmats2[51][21] + coeff0_52*dmats2[52][21] + coeff0_53*dmats2[53][21] + coeff0_54*dmats2[54][21] + coeff0_55*dmats2[55][21];
          new_coeff0_22 = coeff0_0*dmats2[0][22] + coeff0_1*dmats2[1][22] + coeff0_2*dmats2[2][22] + coeff0_3*dmats2[3][22] + coeff0_4*dmats2[4][22] + coeff0_5*dmats2[5][22] + coeff0_6*dmats2[6][22] + coeff0_7*dmats2[7][22] + coeff0_8*dmats2[8][22] + coeff0_9*dmats2[9][22] + coeff0_10*dmats2[10][22] + coeff0_11*dmats2[11][22] + coeff0_12*dmats2[12][22] + coeff0_13*dmats2[13][22] + coeff0_14*dmats2[14][22] + coeff0_15*dmats2[15][22] + coeff0_16*dmats2[16][22] + coeff0_17*dmats2[17][22] + coeff0_18*dmats2[18][22] + coeff0_19*dmats2[19][22] + coeff0_20*dmats2[20][22] + coeff0_21*dmats2[21][22] + coeff0_22*dmats2[22][22] + coeff0_23*dmats2[23][22] + coeff0_24*dmats2[24][22] + coeff0_25*dmats2[25][22] + coeff0_26*dmats2[26][22] + coeff0_27*dmats2[27][22] + coeff0_28*dmats2[28][22] + coeff0_29*dmats2[29][22] + coeff0_30*dmats2[30][22] + coeff0_31*dmats2[31][22] + coeff0_32*dmats2[32][22] + coeff0_33*dmats2[33][22] + coeff0_34*dmats2[34][22] + coeff0_35*dmats2[35][22] + coeff0_36*dmats2[36][22] + coeff0_37*dmats2[37][22] + coeff0_38*dmats2[38][22] + coeff0_39*dmats2[39][22] + coeff0_40*dmats2[40][22] + coeff0_41*dmats2[41][22] + coeff0_42*dmats2[42][22] + coeff0_43*dmats2[43][22] + coeff0_44*dmats2[44][22] + coeff0_45*dmats2[45][22] + coeff0_46*dmats2[46][22] + coeff0_47*dmats2[47][22] + coeff0_48*dmats2[48][22] + coeff0_49*dmats2[49][22] + coeff0_50*dmats2[50][22] + coeff0_51*dmats2[51][22] + coeff0_52*dmats2[52][22] + coeff0_53*dmats2[53][22] + coeff0_54*dmats2[54][22] + coeff0_55*dmats2[55][22];
          new_coeff0_23 = coeff0_0*dmats2[0][23] + coeff0_1*dmats2[1][23] + coeff0_2*dmats2[2][23] + coeff0_3*dmats2[3][23] + coeff0_4*dmats2[4][23] + coeff0_5*dmats2[5][23] + coeff0_6*dmats2[6][23] + coeff0_7*dmats2[7][23] + coeff0_8*dmats2[8][23] + coeff0_9*dmats2[9][23] + coeff0_10*dmats2[10][23] + coeff0_11*dmats2[11][23] + coeff0_12*dmats2[12][23] + coeff0_13*dmats2[13][23] + coeff0_14*dmats2[14][23] + coeff0_15*dmats2[15][23] + coeff0_16*dmats2[16][23] + coeff0_17*dmats2[17][23] + coeff0_18*dmats2[18][23] + coeff0_19*dmats2[19][23] + coeff0_20*dmats2[20][23] + coeff0_21*dmats2[21][23] + coeff0_22*dmats2[22][23] + coeff0_23*dmats2[23][23] + coeff0_24*dmats2[24][23] + coeff0_25*dmats2[25][23] + coeff0_26*dmats2[26][23] + coeff0_27*dmats2[27][23] + coeff0_28*dmats2[28][23] + coeff0_29*dmats2[29][23] + coeff0_30*dmats2[30][23] + coeff0_31*dmats2[31][23] + coeff0_32*dmats2[32][23] + coeff0_33*dmats2[33][23] + coeff0_34*dmats2[34][23] + coeff0_35*dmats2[35][23] + coeff0_36*dmats2[36][23] + coeff0_37*dmats2[37][23] + coeff0_38*dmats2[38][23] + coeff0_39*dmats2[39][23] + coeff0_40*dmats2[40][23] + coeff0_41*dmats2[41][23] + coeff0_42*dmats2[42][23] + coeff0_43*dmats2[43][23] + coeff0_44*dmats2[44][23] + coeff0_45*dmats2[45][23] + coeff0_46*dmats2[46][23] + coeff0_47*dmats2[47][23] + coeff0_48*dmats2[48][23] + coeff0_49*dmats2[49][23] + coeff0_50*dmats2[50][23] + coeff0_51*dmats2[51][23] + coeff0_52*dmats2[52][23] + coeff0_53*dmats2[53][23] + coeff0_54*dmats2[54][23] + coeff0_55*dmats2[55][23];
          new_coeff0_24 = coeff0_0*dmats2[0][24] + coeff0_1*dmats2[1][24] + coeff0_2*dmats2[2][24] + coeff0_3*dmats2[3][24] + coeff0_4*dmats2[4][24] + coeff0_5*dmats2[5][24] + coeff0_6*dmats2[6][24] + coeff0_7*dmats2[7][24] + coeff0_8*dmats2[8][24] + coeff0_9*dmats2[9][24] + coeff0_10*dmats2[10][24] + coeff0_11*dmats2[11][24] + coeff0_12*dmats2[12][24] + coeff0_13*dmats2[13][24] + coeff0_14*dmats2[14][24] + coeff0_15*dmats2[15][24] + coeff0_16*dmats2[16][24] + coeff0_17*dmats2[17][24] + coeff0_18*dmats2[18][24] + coeff0_19*dmats2[19][24] + coeff0_20*dmats2[20][24] + coeff0_21*dmats2[21][24] + coeff0_22*dmats2[22][24] + coeff0_23*dmats2[23][24] + coeff0_24*dmats2[24][24] + coeff0_25*dmats2[25][24] + coeff0_26*dmats2[26][24] + coeff0_27*dmats2[27][24] + coeff0_28*dmats2[28][24] + coeff0_29*dmats2[29][24] + coeff0_30*dmats2[30][24] + coeff0_31*dmats2[31][24] + coeff0_32*dmats2[32][24] + coeff0_33*dmats2[33][24] + coeff0_34*dmats2[34][24] + coeff0_35*dmats2[35][24] + coeff0_36*dmats2[36][24] + coeff0_37*dmats2[37][24] + coeff0_38*dmats2[38][24] + coeff0_39*dmats2[39][24] + coeff0_40*dmats2[40][24] + coeff0_41*dmats2[41][24] + coeff0_42*dmats2[42][24] + coeff0_43*dmats2[43][24] + coeff0_44*dmats2[44][24] + coeff0_45*dmats2[45][24] + coeff0_46*dmats2[46][24] + coeff0_47*dmats2[47][24] + coeff0_48*dmats2[48][24] + coeff0_49*dmats2[49][24] + coeff0_50*dmats2[50][24] + coeff0_51*dmats2[51][24] + coeff0_52*dmats2[52][24] + coeff0_53*dmats2[53][24] + coeff0_54*dmats2[54][24] + coeff0_55*dmats2[55][24];
          new_coeff0_25 = coeff0_0*dmats2[0][25] + coeff0_1*dmats2[1][25] + coeff0_2*dmats2[2][25] + coeff0_3*dmats2[3][25] + coeff0_4*dmats2[4][25] + coeff0_5*dmats2[5][25] + coeff0_6*dmats2[6][25] + coeff0_7*dmats2[7][25] + coeff0_8*dmats2[8][25] + coeff0_9*dmats2[9][25] + coeff0_10*dmats2[10][25] + coeff0_11*dmats2[11][25] + coeff0_12*dmats2[12][25] + coeff0_13*dmats2[13][25] + coeff0_14*dmats2[14][25] + coeff0_15*dmats2[15][25] + coeff0_16*dmats2[16][25] + coeff0_17*dmats2[17][25] + coeff0_18*dmats2[18][25] + coeff0_19*dmats2[19][25] + coeff0_20*dmats2[20][25] + coeff0_21*dmats2[21][25] + coeff0_22*dmats2[22][25] + coeff0_23*dmats2[23][25] + coeff0_24*dmats2[24][25] + coeff0_25*dmats2[25][25] + coeff0_26*dmats2[26][25] + coeff0_27*dmats2[27][25] + coeff0_28*dmats2[28][25] + coeff0_29*dmats2[29][25] + coeff0_30*dmats2[30][25] + coeff0_31*dmats2[31][25] + coeff0_32*dmats2[32][25] + coeff0_33*dmats2[33][25] + coeff0_34*dmats2[34][25] + coeff0_35*dmats2[35][25] + coeff0_36*dmats2[36][25] + coeff0_37*dmats2[37][25] + coeff0_38*dmats2[38][25] + coeff0_39*dmats2[39][25] + coeff0_40*dmats2[40][25] + coeff0_41*dmats2[41][25] + coeff0_42*dmats2[42][25] + coeff0_43*dmats2[43][25] + coeff0_44*dmats2[44][25] + coeff0_45*dmats2[45][25] + coeff0_46*dmats2[46][25] + coeff0_47*dmats2[47][25] + coeff0_48*dmats2[48][25] + coeff0_49*dmats2[49][25] + coeff0_50*dmats2[50][25] + coeff0_51*dmats2[51][25] + coeff0_52*dmats2[52][25] + coeff0_53*dmats2[53][25] + coeff0_54*dmats2[54][25] + coeff0_55*dmats2[55][25];
          new_coeff0_26 = coeff0_0*dmats2[0][26] + coeff0_1*dmats2[1][26] + coeff0_2*dmats2[2][26] + coeff0_3*dmats2[3][26] + coeff0_4*dmats2[4][26] + coeff0_5*dmats2[5][26] + coeff0_6*dmats2[6][26] + coeff0_7*dmats2[7][26] + coeff0_8*dmats2[8][26] + coeff0_9*dmats2[9][26] + coeff0_10*dmats2[10][26] + coeff0_11*dmats2[11][26] + coeff0_12*dmats2[12][26] + coeff0_13*dmats2[13][26] + coeff0_14*dmats2[14][26] + coeff0_15*dmats2[15][26] + coeff0_16*dmats2[16][26] + coeff0_17*dmats2[17][26] + coeff0_18*dmats2[18][26] + coeff0_19*dmats2[19][26] + coeff0_20*dmats2[20][26] + coeff0_21*dmats2[21][26] + coeff0_22*dmats2[22][26] + coeff0_23*dmats2[23][26] + coeff0_24*dmats2[24][26] + coeff0_25*dmats2[25][26] + coeff0_26*dmats2[26][26] + coeff0_27*dmats2[27][26] + coeff0_28*dmats2[28][26] + coeff0_29*dmats2[29][26] + coeff0_30*dmats2[30][26] + coeff0_31*dmats2[31][26] + coeff0_32*dmats2[32][26] + coeff0_33*dmats2[33][26] + coeff0_34*dmats2[34][26] + coeff0_35*dmats2[35][26] + coeff0_36*dmats2[36][26] + coeff0_37*dmats2[37][26] + coeff0_38*dmats2[38][26] + coeff0_39*dmats2[39][26] + coeff0_40*dmats2[40][26] + coeff0_41*dmats2[41][26] + coeff0_42*dmats2[42][26] + coeff0_43*dmats2[43][26] + coeff0_44*dmats2[44][26] + coeff0_45*dmats2[45][26] + coeff0_46*dmats2[46][26] + coeff0_47*dmats2[47][26] + coeff0_48*dmats2[48][26] + coeff0_49*dmats2[49][26] + coeff0_50*dmats2[50][26] + coeff0_51*dmats2[51][26] + coeff0_52*dmats2[52][26] + coeff0_53*dmats2[53][26] + coeff0_54*dmats2[54][26] + coeff0_55*dmats2[55][26];
          new_coeff0_27 = coeff0_0*dmats2[0][27] + coeff0_1*dmats2[1][27] + coeff0_2*dmats2[2][27] + coeff0_3*dmats2[3][27] + coeff0_4*dmats2[4][27] + coeff0_5*dmats2[5][27] + coeff0_6*dmats2[6][27] + coeff0_7*dmats2[7][27] + coeff0_8*dmats2[8][27] + coeff0_9*dmats2[9][27] + coeff0_10*dmats2[10][27] + coeff0_11*dmats2[11][27] + coeff0_12*dmats2[12][27] + coeff0_13*dmats2[13][27] + coeff0_14*dmats2[14][27] + coeff0_15*dmats2[15][27] + coeff0_16*dmats2[16][27] + coeff0_17*dmats2[17][27] + coeff0_18*dmats2[18][27] + coeff0_19*dmats2[19][27] + coeff0_20*dmats2[20][27] + coeff0_21*dmats2[21][27] + coeff0_22*dmats2[22][27] + coeff0_23*dmats2[23][27] + coeff0_24*dmats2[24][27] + coeff0_25*dmats2[25][27] + coeff0_26*dmats2[26][27] + coeff0_27*dmats2[27][27] + coeff0_28*dmats2[28][27] + coeff0_29*dmats2[29][27] + coeff0_30*dmats2[30][27] + coeff0_31*dmats2[31][27] + coeff0_32*dmats2[32][27] + coeff0_33*dmats2[33][27] + coeff0_34*dmats2[34][27] + coeff0_35*dmats2[35][27] + coeff0_36*dmats2[36][27] + coeff0_37*dmats2[37][27] + coeff0_38*dmats2[38][27] + coeff0_39*dmats2[39][27] + coeff0_40*dmats2[40][27] + coeff0_41*dmats2[41][27] + coeff0_42*dmats2[42][27] + coeff0_43*dmats2[43][27] + coeff0_44*dmats2[44][27] + coeff0_45*dmats2[45][27] + coeff0_46*dmats2[46][27] + coeff0_47*dmats2[47][27] + coeff0_48*dmats2[48][27] + coeff0_49*dmats2[49][27] + coeff0_50*dmats2[50][27] + coeff0_51*dmats2[51][27] + coeff0_52*dmats2[52][27] + coeff0_53*dmats2[53][27] + coeff0_54*dmats2[54][27] + coeff0_55*dmats2[55][27];
          new_coeff0_28 = coeff0_0*dmats2[0][28] + coeff0_1*dmats2[1][28] + coeff0_2*dmats2[2][28] + coeff0_3*dmats2[3][28] + coeff0_4*dmats2[4][28] + coeff0_5*dmats2[5][28] + coeff0_6*dmats2[6][28] + coeff0_7*dmats2[7][28] + coeff0_8*dmats2[8][28] + coeff0_9*dmats2[9][28] + coeff0_10*dmats2[10][28] + coeff0_11*dmats2[11][28] + coeff0_12*dmats2[12][28] + coeff0_13*dmats2[13][28] + coeff0_14*dmats2[14][28] + coeff0_15*dmats2[15][28] + coeff0_16*dmats2[16][28] + coeff0_17*dmats2[17][28] + coeff0_18*dmats2[18][28] + coeff0_19*dmats2[19][28] + coeff0_20*dmats2[20][28] + coeff0_21*dmats2[21][28] + coeff0_22*dmats2[22][28] + coeff0_23*dmats2[23][28] + coeff0_24*dmats2[24][28] + coeff0_25*dmats2[25][28] + coeff0_26*dmats2[26][28] + coeff0_27*dmats2[27][28] + coeff0_28*dmats2[28][28] + coeff0_29*dmats2[29][28] + coeff0_30*dmats2[30][28] + coeff0_31*dmats2[31][28] + coeff0_32*dmats2[32][28] + coeff0_33*dmats2[33][28] + coeff0_34*dmats2[34][28] + coeff0_35*dmats2[35][28] + coeff0_36*dmats2[36][28] + coeff0_37*dmats2[37][28] + coeff0_38*dmats2[38][28] + coeff0_39*dmats2[39][28] + coeff0_40*dmats2[40][28] + coeff0_41*dmats2[41][28] + coeff0_42*dmats2[42][28] + coeff0_43*dmats2[43][28] + coeff0_44*dmats2[44][28] + coeff0_45*dmats2[45][28] + coeff0_46*dmats2[46][28] + coeff0_47*dmats2[47][28] + coeff0_48*dmats2[48][28] + coeff0_49*dmats2[49][28] + coeff0_50*dmats2[50][28] + coeff0_51*dmats2[51][28] + coeff0_52*dmats2[52][28] + coeff0_53*dmats2[53][28] + coeff0_54*dmats2[54][28] + coeff0_55*dmats2[55][28];
          new_coeff0_29 = coeff0_0*dmats2[0][29] + coeff0_1*dmats2[1][29] + coeff0_2*dmats2[2][29] + coeff0_3*dmats2[3][29] + coeff0_4*dmats2[4][29] + coeff0_5*dmats2[5][29] + coeff0_6*dmats2[6][29] + coeff0_7*dmats2[7][29] + coeff0_8*dmats2[8][29] + coeff0_9*dmats2[9][29] + coeff0_10*dmats2[10][29] + coeff0_11*dmats2[11][29] + coeff0_12*dmats2[12][29] + coeff0_13*dmats2[13][29] + coeff0_14*dmats2[14][29] + coeff0_15*dmats2[15][29] + coeff0_16*dmats2[16][29] + coeff0_17*dmats2[17][29] + coeff0_18*dmats2[18][29] + coeff0_19*dmats2[19][29] + coeff0_20*dmats2[20][29] + coeff0_21*dmats2[21][29] + coeff0_22*dmats2[22][29] + coeff0_23*dmats2[23][29] + coeff0_24*dmats2[24][29] + coeff0_25*dmats2[25][29] + coeff0_26*dmats2[26][29] + coeff0_27*dmats2[27][29] + coeff0_28*dmats2[28][29] + coeff0_29*dmats2[29][29] + coeff0_30*dmats2[30][29] + coeff0_31*dmats2[31][29] + coeff0_32*dmats2[32][29] + coeff0_33*dmats2[33][29] + coeff0_34*dmats2[34][29] + coeff0_35*dmats2[35][29] + coeff0_36*dmats2[36][29] + coeff0_37*dmats2[37][29] + coeff0_38*dmats2[38][29] + coeff0_39*dmats2[39][29] + coeff0_40*dmats2[40][29] + coeff0_41*dmats2[41][29] + coeff0_42*dmats2[42][29] + coeff0_43*dmats2[43][29] + coeff0_44*dmats2[44][29] + coeff0_45*dmats2[45][29] + coeff0_46*dmats2[46][29] + coeff0_47*dmats2[47][29] + coeff0_48*dmats2[48][29] + coeff0_49*dmats2[49][29] + coeff0_50*dmats2[50][29] + coeff0_51*dmats2[51][29] + coeff0_52*dmats2[52][29] + coeff0_53*dmats2[53][29] + coeff0_54*dmats2[54][29] + coeff0_55*dmats2[55][29];
          new_coeff0_30 = coeff0_0*dmats2[0][30] + coeff0_1*dmats2[1][30] + coeff0_2*dmats2[2][30] + coeff0_3*dmats2[3][30] + coeff0_4*dmats2[4][30] + coeff0_5*dmats2[5][30] + coeff0_6*dmats2[6][30] + coeff0_7*dmats2[7][30] + coeff0_8*dmats2[8][30] + coeff0_9*dmats2[9][30] + coeff0_10*dmats2[10][30] + coeff0_11*dmats2[11][30] + coeff0_12*dmats2[12][30] + coeff0_13*dmats2[13][30] + coeff0_14*dmats2[14][30] + coeff0_15*dmats2[15][30] + coeff0_16*dmats2[16][30] + coeff0_17*dmats2[17][30] + coeff0_18*dmats2[18][30] + coeff0_19*dmats2[19][30] + coeff0_20*dmats2[20][30] + coeff0_21*dmats2[21][30] + coeff0_22*dmats2[22][30] + coeff0_23*dmats2[23][30] + coeff0_24*dmats2[24][30] + coeff0_25*dmats2[25][30] + coeff0_26*dmats2[26][30] + coeff0_27*dmats2[27][30] + coeff0_28*dmats2[28][30] + coeff0_29*dmats2[29][30] + coeff0_30*dmats2[30][30] + coeff0_31*dmats2[31][30] + coeff0_32*dmats2[32][30] + coeff0_33*dmats2[33][30] + coeff0_34*dmats2[34][30] + coeff0_35*dmats2[35][30] + coeff0_36*dmats2[36][30] + coeff0_37*dmats2[37][30] + coeff0_38*dmats2[38][30] + coeff0_39*dmats2[39][30] + coeff0_40*dmats2[40][30] + coeff0_41*dmats2[41][30] + coeff0_42*dmats2[42][30] + coeff0_43*dmats2[43][30] + coeff0_44*dmats2[44][30] + coeff0_45*dmats2[45][30] + coeff0_46*dmats2[46][30] + coeff0_47*dmats2[47][30] + coeff0_48*dmats2[48][30] + coeff0_49*dmats2[49][30] + coeff0_50*dmats2[50][30] + coeff0_51*dmats2[51][30] + coeff0_52*dmats2[52][30] + coeff0_53*dmats2[53][30] + coeff0_54*dmats2[54][30] + coeff0_55*dmats2[55][30];
          new_coeff0_31 = coeff0_0*dmats2[0][31] + coeff0_1*dmats2[1][31] + coeff0_2*dmats2[2][31] + coeff0_3*dmats2[3][31] + coeff0_4*dmats2[4][31] + coeff0_5*dmats2[5][31] + coeff0_6*dmats2[6][31] + coeff0_7*dmats2[7][31] + coeff0_8*dmats2[8][31] + coeff0_9*dmats2[9][31] + coeff0_10*dmats2[10][31] + coeff0_11*dmats2[11][31] + coeff0_12*dmats2[12][31] + coeff0_13*dmats2[13][31] + coeff0_14*dmats2[14][31] + coeff0_15*dmats2[15][31] + coeff0_16*dmats2[16][31] + coeff0_17*dmats2[17][31] + coeff0_18*dmats2[18][31] + coeff0_19*dmats2[19][31] + coeff0_20*dmats2[20][31] + coeff0_21*dmats2[21][31] + coeff0_22*dmats2[22][31] + coeff0_23*dmats2[23][31] + coeff0_24*dmats2[24][31] + coeff0_25*dmats2[25][31] + coeff0_26*dmats2[26][31] + coeff0_27*dmats2[27][31] + coeff0_28*dmats2[28][31] + coeff0_29*dmats2[29][31] + coeff0_30*dmats2[30][31] + coeff0_31*dmats2[31][31] + coeff0_32*dmats2[32][31] + coeff0_33*dmats2[33][31] + coeff0_34*dmats2[34][31] + coeff0_35*dmats2[35][31] + coeff0_36*dmats2[36][31] + coeff0_37*dmats2[37][31] + coeff0_38*dmats2[38][31] + coeff0_39*dmats2[39][31] + coeff0_40*dmats2[40][31] + coeff0_41*dmats2[41][31] + coeff0_42*dmats2[42][31] + coeff0_43*dmats2[43][31] + coeff0_44*dmats2[44][31] + coeff0_45*dmats2[45][31] + coeff0_46*dmats2[46][31] + coeff0_47*dmats2[47][31] + coeff0_48*dmats2[48][31] + coeff0_49*dmats2[49][31] + coeff0_50*dmats2[50][31] + coeff0_51*dmats2[51][31] + coeff0_52*dmats2[52][31] + coeff0_53*dmats2[53][31] + coeff0_54*dmats2[54][31] + coeff0_55*dmats2[55][31];
          new_coeff0_32 = coeff0_0*dmats2[0][32] + coeff0_1*dmats2[1][32] + coeff0_2*dmats2[2][32] + coeff0_3*dmats2[3][32] + coeff0_4*dmats2[4][32] + coeff0_5*dmats2[5][32] + coeff0_6*dmats2[6][32] + coeff0_7*dmats2[7][32] + coeff0_8*dmats2[8][32] + coeff0_9*dmats2[9][32] + coeff0_10*dmats2[10][32] + coeff0_11*dmats2[11][32] + coeff0_12*dmats2[12][32] + coeff0_13*dmats2[13][32] + coeff0_14*dmats2[14][32] + coeff0_15*dmats2[15][32] + coeff0_16*dmats2[16][32] + coeff0_17*dmats2[17][32] + coeff0_18*dmats2[18][32] + coeff0_19*dmats2[19][32] + coeff0_20*dmats2[20][32] + coeff0_21*dmats2[21][32] + coeff0_22*dmats2[22][32] + coeff0_23*dmats2[23][32] + coeff0_24*dmats2[24][32] + coeff0_25*dmats2[25][32] + coeff0_26*dmats2[26][32] + coeff0_27*dmats2[27][32] + coeff0_28*dmats2[28][32] + coeff0_29*dmats2[29][32] + coeff0_30*dmats2[30][32] + coeff0_31*dmats2[31][32] + coeff0_32*dmats2[32][32] + coeff0_33*dmats2[33][32] + coeff0_34*dmats2[34][32] + coeff0_35*dmats2[35][32] + coeff0_36*dmats2[36][32] + coeff0_37*dmats2[37][32] + coeff0_38*dmats2[38][32] + coeff0_39*dmats2[39][32] + coeff0_40*dmats2[40][32] + coeff0_41*dmats2[41][32] + coeff0_42*dmats2[42][32] + coeff0_43*dmats2[43][32] + coeff0_44*dmats2[44][32] + coeff0_45*dmats2[45][32] + coeff0_46*dmats2[46][32] + coeff0_47*dmats2[47][32] + coeff0_48*dmats2[48][32] + coeff0_49*dmats2[49][32] + coeff0_50*dmats2[50][32] + coeff0_51*dmats2[51][32] + coeff0_52*dmats2[52][32] + coeff0_53*dmats2[53][32] + coeff0_54*dmats2[54][32] + coeff0_55*dmats2[55][32];
          new_coeff0_33 = coeff0_0*dmats2[0][33] + coeff0_1*dmats2[1][33] + coeff0_2*dmats2[2][33] + coeff0_3*dmats2[3][33] + coeff0_4*dmats2[4][33] + coeff0_5*dmats2[5][33] + coeff0_6*dmats2[6][33] + coeff0_7*dmats2[7][33] + coeff0_8*dmats2[8][33] + coeff0_9*dmats2[9][33] + coeff0_10*dmats2[10][33] + coeff0_11*dmats2[11][33] + coeff0_12*dmats2[12][33] + coeff0_13*dmats2[13][33] + coeff0_14*dmats2[14][33] + coeff0_15*dmats2[15][33] + coeff0_16*dmats2[16][33] + coeff0_17*dmats2[17][33] + coeff0_18*dmats2[18][33] + coeff0_19*dmats2[19][33] + coeff0_20*dmats2[20][33] + coeff0_21*dmats2[21][33] + coeff0_22*dmats2[22][33] + coeff0_23*dmats2[23][33] + coeff0_24*dmats2[24][33] + coeff0_25*dmats2[25][33] + coeff0_26*dmats2[26][33] + coeff0_27*dmats2[27][33] + coeff0_28*dmats2[28][33] + coeff0_29*dmats2[29][33] + coeff0_30*dmats2[30][33] + coeff0_31*dmats2[31][33] + coeff0_32*dmats2[32][33] + coeff0_33*dmats2[33][33] + coeff0_34*dmats2[34][33] + coeff0_35*dmats2[35][33] + coeff0_36*dmats2[36][33] + coeff0_37*dmats2[37][33] + coeff0_38*dmats2[38][33] + coeff0_39*dmats2[39][33] + coeff0_40*dmats2[40][33] + coeff0_41*dmats2[41][33] + coeff0_42*dmats2[42][33] + coeff0_43*dmats2[43][33] + coeff0_44*dmats2[44][33] + coeff0_45*dmats2[45][33] + coeff0_46*dmats2[46][33] + coeff0_47*dmats2[47][33] + coeff0_48*dmats2[48][33] + coeff0_49*dmats2[49][33] + coeff0_50*dmats2[50][33] + coeff0_51*dmats2[51][33] + coeff0_52*dmats2[52][33] + coeff0_53*dmats2[53][33] + coeff0_54*dmats2[54][33] + coeff0_55*dmats2[55][33];
          new_coeff0_34 = coeff0_0*dmats2[0][34] + coeff0_1*dmats2[1][34] + coeff0_2*dmats2[2][34] + coeff0_3*dmats2[3][34] + coeff0_4*dmats2[4][34] + coeff0_5*dmats2[5][34] + coeff0_6*dmats2[6][34] + coeff0_7*dmats2[7][34] + coeff0_8*dmats2[8][34] + coeff0_9*dmats2[9][34] + coeff0_10*dmats2[10][34] + coeff0_11*dmats2[11][34] + coeff0_12*dmats2[12][34] + coeff0_13*dmats2[13][34] + coeff0_14*dmats2[14][34] + coeff0_15*dmats2[15][34] + coeff0_16*dmats2[16][34] + coeff0_17*dmats2[17][34] + coeff0_18*dmats2[18][34] + coeff0_19*dmats2[19][34] + coeff0_20*dmats2[20][34] + coeff0_21*dmats2[21][34] + coeff0_22*dmats2[22][34] + coeff0_23*dmats2[23][34] + coeff0_24*dmats2[24][34] + coeff0_25*dmats2[25][34] + coeff0_26*dmats2[26][34] + coeff0_27*dmats2[27][34] + coeff0_28*dmats2[28][34] + coeff0_29*dmats2[29][34] + coeff0_30*dmats2[30][34] + coeff0_31*dmats2[31][34] + coeff0_32*dmats2[32][34] + coeff0_33*dmats2[33][34] + coeff0_34*dmats2[34][34] + coeff0_35*dmats2[35][34] + coeff0_36*dmats2[36][34] + coeff0_37*dmats2[37][34] + coeff0_38*dmats2[38][34] + coeff0_39*dmats2[39][34] + coeff0_40*dmats2[40][34] + coeff0_41*dmats2[41][34] + coeff0_42*dmats2[42][34] + coeff0_43*dmats2[43][34] + coeff0_44*dmats2[44][34] + coeff0_45*dmats2[45][34] + coeff0_46*dmats2[46][34] + coeff0_47*dmats2[47][34] + coeff0_48*dmats2[48][34] + coeff0_49*dmats2[49][34] + coeff0_50*dmats2[50][34] + coeff0_51*dmats2[51][34] + coeff0_52*dmats2[52][34] + coeff0_53*dmats2[53][34] + coeff0_54*dmats2[54][34] + coeff0_55*dmats2[55][34];
          new_coeff0_35 = coeff0_0*dmats2[0][35] + coeff0_1*dmats2[1][35] + coeff0_2*dmats2[2][35] + coeff0_3*dmats2[3][35] + coeff0_4*dmats2[4][35] + coeff0_5*dmats2[5][35] + coeff0_6*dmats2[6][35] + coeff0_7*dmats2[7][35] + coeff0_8*dmats2[8][35] + coeff0_9*dmats2[9][35] + coeff0_10*dmats2[10][35] + coeff0_11*dmats2[11][35] + coeff0_12*dmats2[12][35] + coeff0_13*dmats2[13][35] + coeff0_14*dmats2[14][35] + coeff0_15*dmats2[15][35] + coeff0_16*dmats2[16][35] + coeff0_17*dmats2[17][35] + coeff0_18*dmats2[18][35] + coeff0_19*dmats2[19][35] + coeff0_20*dmats2[20][35] + coeff0_21*dmats2[21][35] + coeff0_22*dmats2[22][35] + coeff0_23*dmats2[23][35] + coeff0_24*dmats2[24][35] + coeff0_25*dmats2[25][35] + coeff0_26*dmats2[26][35] + coeff0_27*dmats2[27][35] + coeff0_28*dmats2[28][35] + coeff0_29*dmats2[29][35] + coeff0_30*dmats2[30][35] + coeff0_31*dmats2[31][35] + coeff0_32*dmats2[32][35] + coeff0_33*dmats2[33][35] + coeff0_34*dmats2[34][35] + coeff0_35*dmats2[35][35] + coeff0_36*dmats2[36][35] + coeff0_37*dmats2[37][35] + coeff0_38*dmats2[38][35] + coeff0_39*dmats2[39][35] + coeff0_40*dmats2[40][35] + coeff0_41*dmats2[41][35] + coeff0_42*dmats2[42][35] + coeff0_43*dmats2[43][35] + coeff0_44*dmats2[44][35] + coeff0_45*dmats2[45][35] + coeff0_46*dmats2[46][35] + coeff0_47*dmats2[47][35] + coeff0_48*dmats2[48][35] + coeff0_49*dmats2[49][35] + coeff0_50*dmats2[50][35] + coeff0_51*dmats2[51][35] + coeff0_52*dmats2[52][35] + coeff0_53*dmats2[53][35] + coeff0_54*dmats2[54][35] + coeff0_55*dmats2[55][35];
          new_coeff0_36 = coeff0_0*dmats2[0][36] + coeff0_1*dmats2[1][36] + coeff0_2*dmats2[2][36] + coeff0_3*dmats2[3][36] + coeff0_4*dmats2[4][36] + coeff0_5*dmats2[5][36] + coeff0_6*dmats2[6][36] + coeff0_7*dmats2[7][36] + coeff0_8*dmats2[8][36] + coeff0_9*dmats2[9][36] + coeff0_10*dmats2[10][36] + coeff0_11*dmats2[11][36] + coeff0_12*dmats2[12][36] + coeff0_13*dmats2[13][36] + coeff0_14*dmats2[14][36] + coeff0_15*dmats2[15][36] + coeff0_16*dmats2[16][36] + coeff0_17*dmats2[17][36] + coeff0_18*dmats2[18][36] + coeff0_19*dmats2[19][36] + coeff0_20*dmats2[20][36] + coeff0_21*dmats2[21][36] + coeff0_22*dmats2[22][36] + coeff0_23*dmats2[23][36] + coeff0_24*dmats2[24][36] + coeff0_25*dmats2[25][36] + coeff0_26*dmats2[26][36] + coeff0_27*dmats2[27][36] + coeff0_28*dmats2[28][36] + coeff0_29*dmats2[29][36] + coeff0_30*dmats2[30][36] + coeff0_31*dmats2[31][36] + coeff0_32*dmats2[32][36] + coeff0_33*dmats2[33][36] + coeff0_34*dmats2[34][36] + coeff0_35*dmats2[35][36] + coeff0_36*dmats2[36][36] + coeff0_37*dmats2[37][36] + coeff0_38*dmats2[38][36] + coeff0_39*dmats2[39][36] + coeff0_40*dmats2[40][36] + coeff0_41*dmats2[41][36] + coeff0_42*dmats2[42][36] + coeff0_43*dmats2[43][36] + coeff0_44*dmats2[44][36] + coeff0_45*dmats2[45][36] + coeff0_46*dmats2[46][36] + coeff0_47*dmats2[47][36] + coeff0_48*dmats2[48][36] + coeff0_49*dmats2[49][36] + coeff0_50*dmats2[50][36] + coeff0_51*dmats2[51][36] + coeff0_52*dmats2[52][36] + coeff0_53*dmats2[53][36] + coeff0_54*dmats2[54][36] + coeff0_55*dmats2[55][36];
          new_coeff0_37 = coeff0_0*dmats2[0][37] + coeff0_1*dmats2[1][37] + coeff0_2*dmats2[2][37] + coeff0_3*dmats2[3][37] + coeff0_4*dmats2[4][37] + coeff0_5*dmats2[5][37] + coeff0_6*dmats2[6][37] + coeff0_7*dmats2[7][37] + coeff0_8*dmats2[8][37] + coeff0_9*dmats2[9][37] + coeff0_10*dmats2[10][37] + coeff0_11*dmats2[11][37] + coeff0_12*dmats2[12][37] + coeff0_13*dmats2[13][37] + coeff0_14*dmats2[14][37] + coeff0_15*dmats2[15][37] + coeff0_16*dmats2[16][37] + coeff0_17*dmats2[17][37] + coeff0_18*dmats2[18][37] + coeff0_19*dmats2[19][37] + coeff0_20*dmats2[20][37] + coeff0_21*dmats2[21][37] + coeff0_22*dmats2[22][37] + coeff0_23*dmats2[23][37] + coeff0_24*dmats2[24][37] + coeff0_25*dmats2[25][37] + coeff0_26*dmats2[26][37] + coeff0_27*dmats2[27][37] + coeff0_28*dmats2[28][37] + coeff0_29*dmats2[29][37] + coeff0_30*dmats2[30][37] + coeff0_31*dmats2[31][37] + coeff0_32*dmats2[32][37] + coeff0_33*dmats2[33][37] + coeff0_34*dmats2[34][37] + coeff0_35*dmats2[35][37] + coeff0_36*dmats2[36][37] + coeff0_37*dmats2[37][37] + coeff0_38*dmats2[38][37] + coeff0_39*dmats2[39][37] + coeff0_40*dmats2[40][37] + coeff0_41*dmats2[41][37] + coeff0_42*dmats2[42][37] + coeff0_43*dmats2[43][37] + coeff0_44*dmats2[44][37] + coeff0_45*dmats2[45][37] + coeff0_46*dmats2[46][37] + coeff0_47*dmats2[47][37] + coeff0_48*dmats2[48][37] + coeff0_49*dmats2[49][37] + coeff0_50*dmats2[50][37] + coeff0_51*dmats2[51][37] + coeff0_52*dmats2[52][37] + coeff0_53*dmats2[53][37] + coeff0_54*dmats2[54][37] + coeff0_55*dmats2[55][37];
          new_coeff0_38 = coeff0_0*dmats2[0][38] + coeff0_1*dmats2[1][38] + coeff0_2*dmats2[2][38] + coeff0_3*dmats2[3][38] + coeff0_4*dmats2[4][38] + coeff0_5*dmats2[5][38] + coeff0_6*dmats2[6][38] + coeff0_7*dmats2[7][38] + coeff0_8*dmats2[8][38] + coeff0_9*dmats2[9][38] + coeff0_10*dmats2[10][38] + coeff0_11*dmats2[11][38] + coeff0_12*dmats2[12][38] + coeff0_13*dmats2[13][38] + coeff0_14*dmats2[14][38] + coeff0_15*dmats2[15][38] + coeff0_16*dmats2[16][38] + coeff0_17*dmats2[17][38] + coeff0_18*dmats2[18][38] + coeff0_19*dmats2[19][38] + coeff0_20*dmats2[20][38] + coeff0_21*dmats2[21][38] + coeff0_22*dmats2[22][38] + coeff0_23*dmats2[23][38] + coeff0_24*dmats2[24][38] + coeff0_25*dmats2[25][38] + coeff0_26*dmats2[26][38] + coeff0_27*dmats2[27][38] + coeff0_28*dmats2[28][38] + coeff0_29*dmats2[29][38] + coeff0_30*dmats2[30][38] + coeff0_31*dmats2[31][38] + coeff0_32*dmats2[32][38] + coeff0_33*dmats2[33][38] + coeff0_34*dmats2[34][38] + coeff0_35*dmats2[35][38] + coeff0_36*dmats2[36][38] + coeff0_37*dmats2[37][38] + coeff0_38*dmats2[38][38] + coeff0_39*dmats2[39][38] + coeff0_40*dmats2[40][38] + coeff0_41*dmats2[41][38] + coeff0_42*dmats2[42][38] + coeff0_43*dmats2[43][38] + coeff0_44*dmats2[44][38] + coeff0_45*dmats2[45][38] + coeff0_46*dmats2[46][38] + coeff0_47*dmats2[47][38] + coeff0_48*dmats2[48][38] + coeff0_49*dmats2[49][38] + coeff0_50*dmats2[50][38] + coeff0_51*dmats2[51][38] + coeff0_52*dmats2[52][38] + coeff0_53*dmats2[53][38] + coeff0_54*dmats2[54][38] + coeff0_55*dmats2[55][38];
          new_coeff0_39 = coeff0_0*dmats2[0][39] + coeff0_1*dmats2[1][39] + coeff0_2*dmats2[2][39] + coeff0_3*dmats2[3][39] + coeff0_4*dmats2[4][39] + coeff0_5*dmats2[5][39] + coeff0_6*dmats2[6][39] + coeff0_7*dmats2[7][39] + coeff0_8*dmats2[8][39] + coeff0_9*dmats2[9][39] + coeff0_10*dmats2[10][39] + coeff0_11*dmats2[11][39] + coeff0_12*dmats2[12][39] + coeff0_13*dmats2[13][39] + coeff0_14*dmats2[14][39] + coeff0_15*dmats2[15][39] + coeff0_16*dmats2[16][39] + coeff0_17*dmats2[17][39] + coeff0_18*dmats2[18][39] + coeff0_19*dmats2[19][39] + coeff0_20*dmats2[20][39] + coeff0_21*dmats2[21][39] + coeff0_22*dmats2[22][39] + coeff0_23*dmats2[23][39] + coeff0_24*dmats2[24][39] + coeff0_25*dmats2[25][39] + coeff0_26*dmats2[26][39] + coeff0_27*dmats2[27][39] + coeff0_28*dmats2[28][39] + coeff0_29*dmats2[29][39] + coeff0_30*dmats2[30][39] + coeff0_31*dmats2[31][39] + coeff0_32*dmats2[32][39] + coeff0_33*dmats2[33][39] + coeff0_34*dmats2[34][39] + coeff0_35*dmats2[35][39] + coeff0_36*dmats2[36][39] + coeff0_37*dmats2[37][39] + coeff0_38*dmats2[38][39] + coeff0_39*dmats2[39][39] + coeff0_40*dmats2[40][39] + coeff0_41*dmats2[41][39] + coeff0_42*dmats2[42][39] + coeff0_43*dmats2[43][39] + coeff0_44*dmats2[44][39] + coeff0_45*dmats2[45][39] + coeff0_46*dmats2[46][39] + coeff0_47*dmats2[47][39] + coeff0_48*dmats2[48][39] + coeff0_49*dmats2[49][39] + coeff0_50*dmats2[50][39] + coeff0_51*dmats2[51][39] + coeff0_52*dmats2[52][39] + coeff0_53*dmats2[53][39] + coeff0_54*dmats2[54][39] + coeff0_55*dmats2[55][39];
          new_coeff0_40 = coeff0_0*dmats2[0][40] + coeff0_1*dmats2[1][40] + coeff0_2*dmats2[2][40] + coeff0_3*dmats2[3][40] + coeff0_4*dmats2[4][40] + coeff0_5*dmats2[5][40] + coeff0_6*dmats2[6][40] + coeff0_7*dmats2[7][40] + coeff0_8*dmats2[8][40] + coeff0_9*dmats2[9][40] + coeff0_10*dmats2[10][40] + coeff0_11*dmats2[11][40] + coeff0_12*dmats2[12][40] + coeff0_13*dmats2[13][40] + coeff0_14*dmats2[14][40] + coeff0_15*dmats2[15][40] + coeff0_16*dmats2[16][40] + coeff0_17*dmats2[17][40] + coeff0_18*dmats2[18][40] + coeff0_19*dmats2[19][40] + coeff0_20*dmats2[20][40] + coeff0_21*dmats2[21][40] + coeff0_22*dmats2[22][40] + coeff0_23*dmats2[23][40] + coeff0_24*dmats2[24][40] + coeff0_25*dmats2[25][40] + coeff0_26*dmats2[26][40] + coeff0_27*dmats2[27][40] + coeff0_28*dmats2[28][40] + coeff0_29*dmats2[29][40] + coeff0_30*dmats2[30][40] + coeff0_31*dmats2[31][40] + coeff0_32*dmats2[32][40] + coeff0_33*dmats2[33][40] + coeff0_34*dmats2[34][40] + coeff0_35*dmats2[35][40] + coeff0_36*dmats2[36][40] + coeff0_37*dmats2[37][40] + coeff0_38*dmats2[38][40] + coeff0_39*dmats2[39][40] + coeff0_40*dmats2[40][40] + coeff0_41*dmats2[41][40] + coeff0_42*dmats2[42][40] + coeff0_43*dmats2[43][40] + coeff0_44*dmats2[44][40] + coeff0_45*dmats2[45][40] + coeff0_46*dmats2[46][40] + coeff0_47*dmats2[47][40] + coeff0_48*dmats2[48][40] + coeff0_49*dmats2[49][40] + coeff0_50*dmats2[50][40] + coeff0_51*dmats2[51][40] + coeff0_52*dmats2[52][40] + coeff0_53*dmats2[53][40] + coeff0_54*dmats2[54][40] + coeff0_55*dmats2[55][40];
          new_coeff0_41 = coeff0_0*dmats2[0][41] + coeff0_1*dmats2[1][41] + coeff0_2*dmats2[2][41] + coeff0_3*dmats2[3][41] + coeff0_4*dmats2[4][41] + coeff0_5*dmats2[5][41] + coeff0_6*dmats2[6][41] + coeff0_7*dmats2[7][41] + coeff0_8*dmats2[8][41] + coeff0_9*dmats2[9][41] + coeff0_10*dmats2[10][41] + coeff0_11*dmats2[11][41] + coeff0_12*dmats2[12][41] + coeff0_13*dmats2[13][41] + coeff0_14*dmats2[14][41] + coeff0_15*dmats2[15][41] + coeff0_16*dmats2[16][41] + coeff0_17*dmats2[17][41] + coeff0_18*dmats2[18][41] + coeff0_19*dmats2[19][41] + coeff0_20*dmats2[20][41] + coeff0_21*dmats2[21][41] + coeff0_22*dmats2[22][41] + coeff0_23*dmats2[23][41] + coeff0_24*dmats2[24][41] + coeff0_25*dmats2[25][41] + coeff0_26*dmats2[26][41] + coeff0_27*dmats2[27][41] + coeff0_28*dmats2[28][41] + coeff0_29*dmats2[29][41] + coeff0_30*dmats2[30][41] + coeff0_31*dmats2[31][41] + coeff0_32*dmats2[32][41] + coeff0_33*dmats2[33][41] + coeff0_34*dmats2[34][41] + coeff0_35*dmats2[35][41] + coeff0_36*dmats2[36][41] + coeff0_37*dmats2[37][41] + coeff0_38*dmats2[38][41] + coeff0_39*dmats2[39][41] + coeff0_40*dmats2[40][41] + coeff0_41*dmats2[41][41] + coeff0_42*dmats2[42][41] + coeff0_43*dmats2[43][41] + coeff0_44*dmats2[44][41] + coeff0_45*dmats2[45][41] + coeff0_46*dmats2[46][41] + coeff0_47*dmats2[47][41] + coeff0_48*dmats2[48][41] + coeff0_49*dmats2[49][41] + coeff0_50*dmats2[50][41] + coeff0_51*dmats2[51][41] + coeff0_52*dmats2[52][41] + coeff0_53*dmats2[53][41] + coeff0_54*dmats2[54][41] + coeff0_55*dmats2[55][41];
          new_coeff0_42 = coeff0_0*dmats2[0][42] + coeff0_1*dmats2[1][42] + coeff0_2*dmats2[2][42] + coeff0_3*dmats2[3][42] + coeff0_4*dmats2[4][42] + coeff0_5*dmats2[5][42] + coeff0_6*dmats2[6][42] + coeff0_7*dmats2[7][42] + coeff0_8*dmats2[8][42] + coeff0_9*dmats2[9][42] + coeff0_10*dmats2[10][42] + coeff0_11*dmats2[11][42] + coeff0_12*dmats2[12][42] + coeff0_13*dmats2[13][42] + coeff0_14*dmats2[14][42] + coeff0_15*dmats2[15][42] + coeff0_16*dmats2[16][42] + coeff0_17*dmats2[17][42] + coeff0_18*dmats2[18][42] + coeff0_19*dmats2[19][42] + coeff0_20*dmats2[20][42] + coeff0_21*dmats2[21][42] + coeff0_22*dmats2[22][42] + coeff0_23*dmats2[23][42] + coeff0_24*dmats2[24][42] + coeff0_25*dmats2[25][42] + coeff0_26*dmats2[26][42] + coeff0_27*dmats2[27][42] + coeff0_28*dmats2[28][42] + coeff0_29*dmats2[29][42] + coeff0_30*dmats2[30][42] + coeff0_31*dmats2[31][42] + coeff0_32*dmats2[32][42] + coeff0_33*dmats2[33][42] + coeff0_34*dmats2[34][42] + coeff0_35*dmats2[35][42] + coeff0_36*dmats2[36][42] + coeff0_37*dmats2[37][42] + coeff0_38*dmats2[38][42] + coeff0_39*dmats2[39][42] + coeff0_40*dmats2[40][42] + coeff0_41*dmats2[41][42] + coeff0_42*dmats2[42][42] + coeff0_43*dmats2[43][42] + coeff0_44*dmats2[44][42] + coeff0_45*dmats2[45][42] + coeff0_46*dmats2[46][42] + coeff0_47*dmats2[47][42] + coeff0_48*dmats2[48][42] + coeff0_49*dmats2[49][42] + coeff0_50*dmats2[50][42] + coeff0_51*dmats2[51][42] + coeff0_52*dmats2[52][42] + coeff0_53*dmats2[53][42] + coeff0_54*dmats2[54][42] + coeff0_55*dmats2[55][42];
          new_coeff0_43 = coeff0_0*dmats2[0][43] + coeff0_1*dmats2[1][43] + coeff0_2*dmats2[2][43] + coeff0_3*dmats2[3][43] + coeff0_4*dmats2[4][43] + coeff0_5*dmats2[5][43] + coeff0_6*dmats2[6][43] + coeff0_7*dmats2[7][43] + coeff0_8*dmats2[8][43] + coeff0_9*dmats2[9][43] + coeff0_10*dmats2[10][43] + coeff0_11*dmats2[11][43] + coeff0_12*dmats2[12][43] + coeff0_13*dmats2[13][43] + coeff0_14*dmats2[14][43] + coeff0_15*dmats2[15][43] + coeff0_16*dmats2[16][43] + coeff0_17*dmats2[17][43] + coeff0_18*dmats2[18][43] + coeff0_19*dmats2[19][43] + coeff0_20*dmats2[20][43] + coeff0_21*dmats2[21][43] + coeff0_22*dmats2[22][43] + coeff0_23*dmats2[23][43] + coeff0_24*dmats2[24][43] + coeff0_25*dmats2[25][43] + coeff0_26*dmats2[26][43] + coeff0_27*dmats2[27][43] + coeff0_28*dmats2[28][43] + coeff0_29*dmats2[29][43] + coeff0_30*dmats2[30][43] + coeff0_31*dmats2[31][43] + coeff0_32*dmats2[32][43] + coeff0_33*dmats2[33][43] + coeff0_34*dmats2[34][43] + coeff0_35*dmats2[35][43] + coeff0_36*dmats2[36][43] + coeff0_37*dmats2[37][43] + coeff0_38*dmats2[38][43] + coeff0_39*dmats2[39][43] + coeff0_40*dmats2[40][43] + coeff0_41*dmats2[41][43] + coeff0_42*dmats2[42][43] + coeff0_43*dmats2[43][43] + coeff0_44*dmats2[44][43] + coeff0_45*dmats2[45][43] + coeff0_46*dmats2[46][43] + coeff0_47*dmats2[47][43] + coeff0_48*dmats2[48][43] + coeff0_49*dmats2[49][43] + coeff0_50*dmats2[50][43] + coeff0_51*dmats2[51][43] + coeff0_52*dmats2[52][43] + coeff0_53*dmats2[53][43] + coeff0_54*dmats2[54][43] + coeff0_55*dmats2[55][43];
          new_coeff0_44 = coeff0_0*dmats2[0][44] + coeff0_1*dmats2[1][44] + coeff0_2*dmats2[2][44] + coeff0_3*dmats2[3][44] + coeff0_4*dmats2[4][44] + coeff0_5*dmats2[5][44] + coeff0_6*dmats2[6][44] + coeff0_7*dmats2[7][44] + coeff0_8*dmats2[8][44] + coeff0_9*dmats2[9][44] + coeff0_10*dmats2[10][44] + coeff0_11*dmats2[11][44] + coeff0_12*dmats2[12][44] + coeff0_13*dmats2[13][44] + coeff0_14*dmats2[14][44] + coeff0_15*dmats2[15][44] + coeff0_16*dmats2[16][44] + coeff0_17*dmats2[17][44] + coeff0_18*dmats2[18][44] + coeff0_19*dmats2[19][44] + coeff0_20*dmats2[20][44] + coeff0_21*dmats2[21][44] + coeff0_22*dmats2[22][44] + coeff0_23*dmats2[23][44] + coeff0_24*dmats2[24][44] + coeff0_25*dmats2[25][44] + coeff0_26*dmats2[26][44] + coeff0_27*dmats2[27][44] + coeff0_28*dmats2[28][44] + coeff0_29*dmats2[29][44] + coeff0_30*dmats2[30][44] + coeff0_31*dmats2[31][44] + coeff0_32*dmats2[32][44] + coeff0_33*dmats2[33][44] + coeff0_34*dmats2[34][44] + coeff0_35*dmats2[35][44] + coeff0_36*dmats2[36][44] + coeff0_37*dmats2[37][44] + coeff0_38*dmats2[38][44] + coeff0_39*dmats2[39][44] + coeff0_40*dmats2[40][44] + coeff0_41*dmats2[41][44] + coeff0_42*dmats2[42][44] + coeff0_43*dmats2[43][44] + coeff0_44*dmats2[44][44] + coeff0_45*dmats2[45][44] + coeff0_46*dmats2[46][44] + coeff0_47*dmats2[47][44] + coeff0_48*dmats2[48][44] + coeff0_49*dmats2[49][44] + coeff0_50*dmats2[50][44] + coeff0_51*dmats2[51][44] + coeff0_52*dmats2[52][44] + coeff0_53*dmats2[53][44] + coeff0_54*dmats2[54][44] + coeff0_55*dmats2[55][44];
          new_coeff0_45 = coeff0_0*dmats2[0][45] + coeff0_1*dmats2[1][45] + coeff0_2*dmats2[2][45] + coeff0_3*dmats2[3][45] + coeff0_4*dmats2[4][45] + coeff0_5*dmats2[5][45] + coeff0_6*dmats2[6][45] + coeff0_7*dmats2[7][45] + coeff0_8*dmats2[8][45] + coeff0_9*dmats2[9][45] + coeff0_10*dmats2[10][45] + coeff0_11*dmats2[11][45] + coeff0_12*dmats2[12][45] + coeff0_13*dmats2[13][45] + coeff0_14*dmats2[14][45] + coeff0_15*dmats2[15][45] + coeff0_16*dmats2[16][45] + coeff0_17*dmats2[17][45] + coeff0_18*dmats2[18][45] + coeff0_19*dmats2[19][45] + coeff0_20*dmats2[20][45] + coeff0_21*dmats2[21][45] + coeff0_22*dmats2[22][45] + coeff0_23*dmats2[23][45] + coeff0_24*dmats2[24][45] + coeff0_25*dmats2[25][45] + coeff0_26*dmats2[26][45] + coeff0_27*dmats2[27][45] + coeff0_28*dmats2[28][45] + coeff0_29*dmats2[29][45] + coeff0_30*dmats2[30][45] + coeff0_31*dmats2[31][45] + coeff0_32*dmats2[32][45] + coeff0_33*dmats2[33][45] + coeff0_34*dmats2[34][45] + coeff0_35*dmats2[35][45] + coeff0_36*dmats2[36][45] + coeff0_37*dmats2[37][45] + coeff0_38*dmats2[38][45] + coeff0_39*dmats2[39][45] + coeff0_40*dmats2[40][45] + coeff0_41*dmats2[41][45] + coeff0_42*dmats2[42][45] + coeff0_43*dmats2[43][45] + coeff0_44*dmats2[44][45] + coeff0_45*dmats2[45][45] + coeff0_46*dmats2[46][45] + coeff0_47*dmats2[47][45] + coeff0_48*dmats2[48][45] + coeff0_49*dmats2[49][45] + coeff0_50*dmats2[50][45] + coeff0_51*dmats2[51][45] + coeff0_52*dmats2[52][45] + coeff0_53*dmats2[53][45] + coeff0_54*dmats2[54][45] + coeff0_55*dmats2[55][45];
          new_coeff0_46 = coeff0_0*dmats2[0][46] + coeff0_1*dmats2[1][46] + coeff0_2*dmats2[2][46] + coeff0_3*dmats2[3][46] + coeff0_4*dmats2[4][46] + coeff0_5*dmats2[5][46] + coeff0_6*dmats2[6][46] + coeff0_7*dmats2[7][46] + coeff0_8*dmats2[8][46] + coeff0_9*dmats2[9][46] + coeff0_10*dmats2[10][46] + coeff0_11*dmats2[11][46] + coeff0_12*dmats2[12][46] + coeff0_13*dmats2[13][46] + coeff0_14*dmats2[14][46] + coeff0_15*dmats2[15][46] + coeff0_16*dmats2[16][46] + coeff0_17*dmats2[17][46] + coeff0_18*dmats2[18][46] + coeff0_19*dmats2[19][46] + coeff0_20*dmats2[20][46] + coeff0_21*dmats2[21][46] + coeff0_22*dmats2[22][46] + coeff0_23*dmats2[23][46] + coeff0_24*dmats2[24][46] + coeff0_25*dmats2[25][46] + coeff0_26*dmats2[26][46] + coeff0_27*dmats2[27][46] + coeff0_28*dmats2[28][46] + coeff0_29*dmats2[29][46] + coeff0_30*dmats2[30][46] + coeff0_31*dmats2[31][46] + coeff0_32*dmats2[32][46] + coeff0_33*dmats2[33][46] + coeff0_34*dmats2[34][46] + coeff0_35*dmats2[35][46] + coeff0_36*dmats2[36][46] + coeff0_37*dmats2[37][46] + coeff0_38*dmats2[38][46] + coeff0_39*dmats2[39][46] + coeff0_40*dmats2[40][46] + coeff0_41*dmats2[41][46] + coeff0_42*dmats2[42][46] + coeff0_43*dmats2[43][46] + coeff0_44*dmats2[44][46] + coeff0_45*dmats2[45][46] + coeff0_46*dmats2[46][46] + coeff0_47*dmats2[47][46] + coeff0_48*dmats2[48][46] + coeff0_49*dmats2[49][46] + coeff0_50*dmats2[50][46] + coeff0_51*dmats2[51][46] + coeff0_52*dmats2[52][46] + coeff0_53*dmats2[53][46] + coeff0_54*dmats2[54][46] + coeff0_55*dmats2[55][46];
          new_coeff0_47 = coeff0_0*dmats2[0][47] + coeff0_1*dmats2[1][47] + coeff0_2*dmats2[2][47] + coeff0_3*dmats2[3][47] + coeff0_4*dmats2[4][47] + coeff0_5*dmats2[5][47] + coeff0_6*dmats2[6][47] + coeff0_7*dmats2[7][47] + coeff0_8*dmats2[8][47] + coeff0_9*dmats2[9][47] + coeff0_10*dmats2[10][47] + coeff0_11*dmats2[11][47] + coeff0_12*dmats2[12][47] + coeff0_13*dmats2[13][47] + coeff0_14*dmats2[14][47] + coeff0_15*dmats2[15][47] + coeff0_16*dmats2[16][47] + coeff0_17*dmats2[17][47] + coeff0_18*dmats2[18][47] + coeff0_19*dmats2[19][47] + coeff0_20*dmats2[20][47] + coeff0_21*dmats2[21][47] + coeff0_22*dmats2[22][47] + coeff0_23*dmats2[23][47] + coeff0_24*dmats2[24][47] + coeff0_25*dmats2[25][47] + coeff0_26*dmats2[26][47] + coeff0_27*dmats2[27][47] + coeff0_28*dmats2[28][47] + coeff0_29*dmats2[29][47] + coeff0_30*dmats2[30][47] + coeff0_31*dmats2[31][47] + coeff0_32*dmats2[32][47] + coeff0_33*dmats2[33][47] + coeff0_34*dmats2[34][47] + coeff0_35*dmats2[35][47] + coeff0_36*dmats2[36][47] + coeff0_37*dmats2[37][47] + coeff0_38*dmats2[38][47] + coeff0_39*dmats2[39][47] + coeff0_40*dmats2[40][47] + coeff0_41*dmats2[41][47] + coeff0_42*dmats2[42][47] + coeff0_43*dmats2[43][47] + coeff0_44*dmats2[44][47] + coeff0_45*dmats2[45][47] + coeff0_46*dmats2[46][47] + coeff0_47*dmats2[47][47] + coeff0_48*dmats2[48][47] + coeff0_49*dmats2[49][47] + coeff0_50*dmats2[50][47] + coeff0_51*dmats2[51][47] + coeff0_52*dmats2[52][47] + coeff0_53*dmats2[53][47] + coeff0_54*dmats2[54][47] + coeff0_55*dmats2[55][47];
          new_coeff0_48 = coeff0_0*dmats2[0][48] + coeff0_1*dmats2[1][48] + coeff0_2*dmats2[2][48] + coeff0_3*dmats2[3][48] + coeff0_4*dmats2[4][48] + coeff0_5*dmats2[5][48] + coeff0_6*dmats2[6][48] + coeff0_7*dmats2[7][48] + coeff0_8*dmats2[8][48] + coeff0_9*dmats2[9][48] + coeff0_10*dmats2[10][48] + coeff0_11*dmats2[11][48] + coeff0_12*dmats2[12][48] + coeff0_13*dmats2[13][48] + coeff0_14*dmats2[14][48] + coeff0_15*dmats2[15][48] + coeff0_16*dmats2[16][48] + coeff0_17*dmats2[17][48] + coeff0_18*dmats2[18][48] + coeff0_19*dmats2[19][48] + coeff0_20*dmats2[20][48] + coeff0_21*dmats2[21][48] + coeff0_22*dmats2[22][48] + coeff0_23*dmats2[23][48] + coeff0_24*dmats2[24][48] + coeff0_25*dmats2[25][48] + coeff0_26*dmats2[26][48] + coeff0_27*dmats2[27][48] + coeff0_28*dmats2[28][48] + coeff0_29*dmats2[29][48] + coeff0_30*dmats2[30][48] + coeff0_31*dmats2[31][48] + coeff0_32*dmats2[32][48] + coeff0_33*dmats2[33][48] + coeff0_34*dmats2[34][48] + coeff0_35*dmats2[35][48] + coeff0_36*dmats2[36][48] + coeff0_37*dmats2[37][48] + coeff0_38*dmats2[38][48] + coeff0_39*dmats2[39][48] + coeff0_40*dmats2[40][48] + coeff0_41*dmats2[41][48] + coeff0_42*dmats2[42][48] + coeff0_43*dmats2[43][48] + coeff0_44*dmats2[44][48] + coeff0_45*dmats2[45][48] + coeff0_46*dmats2[46][48] + coeff0_47*dmats2[47][48] + coeff0_48*dmats2[48][48] + coeff0_49*dmats2[49][48] + coeff0_50*dmats2[50][48] + coeff0_51*dmats2[51][48] + coeff0_52*dmats2[52][48] + coeff0_53*dmats2[53][48] + coeff0_54*dmats2[54][48] + coeff0_55*dmats2[55][48];
          new_coeff0_49 = coeff0_0*dmats2[0][49] + coeff0_1*dmats2[1][49] + coeff0_2*dmats2[2][49] + coeff0_3*dmats2[3][49] + coeff0_4*dmats2[4][49] + coeff0_5*dmats2[5][49] + coeff0_6*dmats2[6][49] + coeff0_7*dmats2[7][49] + coeff0_8*dmats2[8][49] + coeff0_9*dmats2[9][49] + coeff0_10*dmats2[10][49] + coeff0_11*dmats2[11][49] + coeff0_12*dmats2[12][49] + coeff0_13*dmats2[13][49] + coeff0_14*dmats2[14][49] + coeff0_15*dmats2[15][49] + coeff0_16*dmats2[16][49] + coeff0_17*dmats2[17][49] + coeff0_18*dmats2[18][49] + coeff0_19*dmats2[19][49] + coeff0_20*dmats2[20][49] + coeff0_21*dmats2[21][49] + coeff0_22*dmats2[22][49] + coeff0_23*dmats2[23][49] + coeff0_24*dmats2[24][49] + coeff0_25*dmats2[25][49] + coeff0_26*dmats2[26][49] + coeff0_27*dmats2[27][49] + coeff0_28*dmats2[28][49] + coeff0_29*dmats2[29][49] + coeff0_30*dmats2[30][49] + coeff0_31*dmats2[31][49] + coeff0_32*dmats2[32][49] + coeff0_33*dmats2[33][49] + coeff0_34*dmats2[34][49] + coeff0_35*dmats2[35][49] + coeff0_36*dmats2[36][49] + coeff0_37*dmats2[37][49] + coeff0_38*dmats2[38][49] + coeff0_39*dmats2[39][49] + coeff0_40*dmats2[40][49] + coeff0_41*dmats2[41][49] + coeff0_42*dmats2[42][49] + coeff0_43*dmats2[43][49] + coeff0_44*dmats2[44][49] + coeff0_45*dmats2[45][49] + coeff0_46*dmats2[46][49] + coeff0_47*dmats2[47][49] + coeff0_48*dmats2[48][49] + coeff0_49*dmats2[49][49] + coeff0_50*dmats2[50][49] + coeff0_51*dmats2[51][49] + coeff0_52*dmats2[52][49] + coeff0_53*dmats2[53][49] + coeff0_54*dmats2[54][49] + coeff0_55*dmats2[55][49];
          new_coeff0_50 = coeff0_0*dmats2[0][50] + coeff0_1*dmats2[1][50] + coeff0_2*dmats2[2][50] + coeff0_3*dmats2[3][50] + coeff0_4*dmats2[4][50] + coeff0_5*dmats2[5][50] + coeff0_6*dmats2[6][50] + coeff0_7*dmats2[7][50] + coeff0_8*dmats2[8][50] + coeff0_9*dmats2[9][50] + coeff0_10*dmats2[10][50] + coeff0_11*dmats2[11][50] + coeff0_12*dmats2[12][50] + coeff0_13*dmats2[13][50] + coeff0_14*dmats2[14][50] + coeff0_15*dmats2[15][50] + coeff0_16*dmats2[16][50] + coeff0_17*dmats2[17][50] + coeff0_18*dmats2[18][50] + coeff0_19*dmats2[19][50] + coeff0_20*dmats2[20][50] + coeff0_21*dmats2[21][50] + coeff0_22*dmats2[22][50] + coeff0_23*dmats2[23][50] + coeff0_24*dmats2[24][50] + coeff0_25*dmats2[25][50] + coeff0_26*dmats2[26][50] + coeff0_27*dmats2[27][50] + coeff0_28*dmats2[28][50] + coeff0_29*dmats2[29][50] + coeff0_30*dmats2[30][50] + coeff0_31*dmats2[31][50] + coeff0_32*dmats2[32][50] + coeff0_33*dmats2[33][50] + coeff0_34*dmats2[34][50] + coeff0_35*dmats2[35][50] + coeff0_36*dmats2[36][50] + coeff0_37*dmats2[37][50] + coeff0_38*dmats2[38][50] + coeff0_39*dmats2[39][50] + coeff0_40*dmats2[40][50] + coeff0_41*dmats2[41][50] + coeff0_42*dmats2[42][50] + coeff0_43*dmats2[43][50] + coeff0_44*dmats2[44][50] + coeff0_45*dmats2[45][50] + coeff0_46*dmats2[46][50] + coeff0_47*dmats2[47][50] + coeff0_48*dmats2[48][50] + coeff0_49*dmats2[49][50] + coeff0_50*dmats2[50][50] + coeff0_51*dmats2[51][50] + coeff0_52*dmats2[52][50] + coeff0_53*dmats2[53][50] + coeff0_54*dmats2[54][50] + coeff0_55*dmats2[55][50];
          new_coeff0_51 = coeff0_0*dmats2[0][51] + coeff0_1*dmats2[1][51] + coeff0_2*dmats2[2][51] + coeff0_3*dmats2[3][51] + coeff0_4*dmats2[4][51] + coeff0_5*dmats2[5][51] + coeff0_6*dmats2[6][51] + coeff0_7*dmats2[7][51] + coeff0_8*dmats2[8][51] + coeff0_9*dmats2[9][51] + coeff0_10*dmats2[10][51] + coeff0_11*dmats2[11][51] + coeff0_12*dmats2[12][51] + coeff0_13*dmats2[13][51] + coeff0_14*dmats2[14][51] + coeff0_15*dmats2[15][51] + coeff0_16*dmats2[16][51] + coeff0_17*dmats2[17][51] + coeff0_18*dmats2[18][51] + coeff0_19*dmats2[19][51] + coeff0_20*dmats2[20][51] + coeff0_21*dmats2[21][51] + coeff0_22*dmats2[22][51] + coeff0_23*dmats2[23][51] + coeff0_24*dmats2[24][51] + coeff0_25*dmats2[25][51] + coeff0_26*dmats2[26][51] + coeff0_27*dmats2[27][51] + coeff0_28*dmats2[28][51] + coeff0_29*dmats2[29][51] + coeff0_30*dmats2[30][51] + coeff0_31*dmats2[31][51] + coeff0_32*dmats2[32][51] + coeff0_33*dmats2[33][51] + coeff0_34*dmats2[34][51] + coeff0_35*dmats2[35][51] + coeff0_36*dmats2[36][51] + coeff0_37*dmats2[37][51] + coeff0_38*dmats2[38][51] + coeff0_39*dmats2[39][51] + coeff0_40*dmats2[40][51] + coeff0_41*dmats2[41][51] + coeff0_42*dmats2[42][51] + coeff0_43*dmats2[43][51] + coeff0_44*dmats2[44][51] + coeff0_45*dmats2[45][51] + coeff0_46*dmats2[46][51] + coeff0_47*dmats2[47][51] + coeff0_48*dmats2[48][51] + coeff0_49*dmats2[49][51] + coeff0_50*dmats2[50][51] + coeff0_51*dmats2[51][51] + coeff0_52*dmats2[52][51] + coeff0_53*dmats2[53][51] + coeff0_54*dmats2[54][51] + coeff0_55*dmats2[55][51];
          new_coeff0_52 = coeff0_0*dmats2[0][52] + coeff0_1*dmats2[1][52] + coeff0_2*dmats2[2][52] + coeff0_3*dmats2[3][52] + coeff0_4*dmats2[4][52] + coeff0_5*dmats2[5][52] + coeff0_6*dmats2[6][52] + coeff0_7*dmats2[7][52] + coeff0_8*dmats2[8][52] + coeff0_9*dmats2[9][52] + coeff0_10*dmats2[10][52] + coeff0_11*dmats2[11][52] + coeff0_12*dmats2[12][52] + coeff0_13*dmats2[13][52] + coeff0_14*dmats2[14][52] + coeff0_15*dmats2[15][52] + coeff0_16*dmats2[16][52] + coeff0_17*dmats2[17][52] + coeff0_18*dmats2[18][52] + coeff0_19*dmats2[19][52] + coeff0_20*dmats2[20][52] + coeff0_21*dmats2[21][52] + coeff0_22*dmats2[22][52] + coeff0_23*dmats2[23][52] + coeff0_24*dmats2[24][52] + coeff0_25*dmats2[25][52] + coeff0_26*dmats2[26][52] + coeff0_27*dmats2[27][52] + coeff0_28*dmats2[28][52] + coeff0_29*dmats2[29][52] + coeff0_30*dmats2[30][52] + coeff0_31*dmats2[31][52] + coeff0_32*dmats2[32][52] + coeff0_33*dmats2[33][52] + coeff0_34*dmats2[34][52] + coeff0_35*dmats2[35][52] + coeff0_36*dmats2[36][52] + coeff0_37*dmats2[37][52] + coeff0_38*dmats2[38][52] + coeff0_39*dmats2[39][52] + coeff0_40*dmats2[40][52] + coeff0_41*dmats2[41][52] + coeff0_42*dmats2[42][52] + coeff0_43*dmats2[43][52] + coeff0_44*dmats2[44][52] + coeff0_45*dmats2[45][52] + coeff0_46*dmats2[46][52] + coeff0_47*dmats2[47][52] + coeff0_48*dmats2[48][52] + coeff0_49*dmats2[49][52] + coeff0_50*dmats2[50][52] + coeff0_51*dmats2[51][52] + coeff0_52*dmats2[52][52] + coeff0_53*dmats2[53][52] + coeff0_54*dmats2[54][52] + coeff0_55*dmats2[55][52];
          new_coeff0_53 = coeff0_0*dmats2[0][53] + coeff0_1*dmats2[1][53] + coeff0_2*dmats2[2][53] + coeff0_3*dmats2[3][53] + coeff0_4*dmats2[4][53] + coeff0_5*dmats2[5][53] + coeff0_6*dmats2[6][53] + coeff0_7*dmats2[7][53] + coeff0_8*dmats2[8][53] + coeff0_9*dmats2[9][53] + coeff0_10*dmats2[10][53] + coeff0_11*dmats2[11][53] + coeff0_12*dmats2[12][53] + coeff0_13*dmats2[13][53] + coeff0_14*dmats2[14][53] + coeff0_15*dmats2[15][53] + coeff0_16*dmats2[16][53] + coeff0_17*dmats2[17][53] + coeff0_18*dmats2[18][53] + coeff0_19*dmats2[19][53] + coeff0_20*dmats2[20][53] + coeff0_21*dmats2[21][53] + coeff0_22*dmats2[22][53] + coeff0_23*dmats2[23][53] + coeff0_24*dmats2[24][53] + coeff0_25*dmats2[25][53] + coeff0_26*dmats2[26][53] + coeff0_27*dmats2[27][53] + coeff0_28*dmats2[28][53] + coeff0_29*dmats2[29][53] + coeff0_30*dmats2[30][53] + coeff0_31*dmats2[31][53] + coeff0_32*dmats2[32][53] + coeff0_33*dmats2[33][53] + coeff0_34*dmats2[34][53] + coeff0_35*dmats2[35][53] + coeff0_36*dmats2[36][53] + coeff0_37*dmats2[37][53] + coeff0_38*dmats2[38][53] + coeff0_39*dmats2[39][53] + coeff0_40*dmats2[40][53] + coeff0_41*dmats2[41][53] + coeff0_42*dmats2[42][53] + coeff0_43*dmats2[43][53] + coeff0_44*dmats2[44][53] + coeff0_45*dmats2[45][53] + coeff0_46*dmats2[46][53] + coeff0_47*dmats2[47][53] + coeff0_48*dmats2[48][53] + coeff0_49*dmats2[49][53] + coeff0_50*dmats2[50][53] + coeff0_51*dmats2[51][53] + coeff0_52*dmats2[52][53] + coeff0_53*dmats2[53][53] + coeff0_54*dmats2[54][53] + coeff0_55*dmats2[55][53];
          new_coeff0_54 = coeff0_0*dmats2[0][54] + coeff0_1*dmats2[1][54] + coeff0_2*dmats2[2][54] + coeff0_3*dmats2[3][54] + coeff0_4*dmats2[4][54] + coeff0_5*dmats2[5][54] + coeff0_6*dmats2[6][54] + coeff0_7*dmats2[7][54] + coeff0_8*dmats2[8][54] + coeff0_9*dmats2[9][54] + coeff0_10*dmats2[10][54] + coeff0_11*dmats2[11][54] + coeff0_12*dmats2[12][54] + coeff0_13*dmats2[13][54] + coeff0_14*dmats2[14][54] + coeff0_15*dmats2[15][54] + coeff0_16*dmats2[16][54] + coeff0_17*dmats2[17][54] + coeff0_18*dmats2[18][54] + coeff0_19*dmats2[19][54] + coeff0_20*dmats2[20][54] + coeff0_21*dmats2[21][54] + coeff0_22*dmats2[22][54] + coeff0_23*dmats2[23][54] + coeff0_24*dmats2[24][54] + coeff0_25*dmats2[25][54] + coeff0_26*dmats2[26][54] + coeff0_27*dmats2[27][54] + coeff0_28*dmats2[28][54] + coeff0_29*dmats2[29][54] + coeff0_30*dmats2[30][54] + coeff0_31*dmats2[31][54] + coeff0_32*dmats2[32][54] + coeff0_33*dmats2[33][54] + coeff0_34*dmats2[34][54] + coeff0_35*dmats2[35][54] + coeff0_36*dmats2[36][54] + coeff0_37*dmats2[37][54] + coeff0_38*dmats2[38][54] + coeff0_39*dmats2[39][54] + coeff0_40*dmats2[40][54] + coeff0_41*dmats2[41][54] + coeff0_42*dmats2[42][54] + coeff0_43*dmats2[43][54] + coeff0_44*dmats2[44][54] + coeff0_45*dmats2[45][54] + coeff0_46*dmats2[46][54] + coeff0_47*dmats2[47][54] + coeff0_48*dmats2[48][54] + coeff0_49*dmats2[49][54] + coeff0_50*dmats2[50][54] + coeff0_51*dmats2[51][54] + coeff0_52*dmats2[52][54] + coeff0_53*dmats2[53][54] + coeff0_54*dmats2[54][54] + coeff0_55*dmats2[55][54];
          new_coeff0_55 = coeff0_0*dmats2[0][55] + coeff0_1*dmats2[1][55] + coeff0_2*dmats2[2][55] + coeff0_3*dmats2[3][55] + coeff0_4*dmats2[4][55] + coeff0_5*dmats2[5][55] + coeff0_6*dmats2[6][55] + coeff0_7*dmats2[7][55] + coeff0_8*dmats2[8][55] + coeff0_9*dmats2[9][55] + coeff0_10*dmats2[10][55] + coeff0_11*dmats2[11][55] + coeff0_12*dmats2[12][55] + coeff0_13*dmats2[13][55] + coeff0_14*dmats2[14][55] + coeff0_15*dmats2[15][55] + coeff0_16*dmats2[16][55] + coeff0_17*dmats2[17][55] + coeff0_18*dmats2[18][55] + coeff0_19*dmats2[19][55] + coeff0_20*dmats2[20][55] + coeff0_21*dmats2[21][55] + coeff0_22*dmats2[22][55] + coeff0_23*dmats2[23][55] + coeff0_24*dmats2[24][55] + coeff0_25*dmats2[25][55] + coeff0_26*dmats2[26][55] + coeff0_27*dmats2[27][55] + coeff0_28*dmats2[28][55] + coeff0_29*dmats2[29][55] + coeff0_30*dmats2[30][55] + coeff0_31*dmats2[31][55] + coeff0_32*dmats2[32][55] + coeff0_33*dmats2[33][55] + coeff0_34*dmats2[34][55] + coeff0_35*dmats2[35][55] + coeff0_36*dmats2[36][55] + coeff0_37*dmats2[37][55] + coeff0_38*dmats2[38][55] + coeff0_39*dmats2[39][55] + coeff0_40*dmats2[40][55] + coeff0_41*dmats2[41][55] + coeff0_42*dmats2[42][55] + coeff0_43*dmats2[43][55] + coeff0_44*dmats2[44][55] + coeff0_45*dmats2[45][55] + coeff0_46*dmats2[46][55] + coeff0_47*dmats2[47][55] + coeff0_48*dmats2[48][55] + coeff0_49*dmats2[49][55] + coeff0_50*dmats2[50][55] + coeff0_51*dmats2[51][55] + coeff0_52*dmats2[52][55] + coeff0_53*dmats2[53][55] + coeff0_54*dmats2[54][55] + coeff0_55*dmats2[55][55];
        }
    
      }
      // Compute derivatives on reference element as dot product of coefficients and basisvalues
      derivatives[deriv_num] = new_coeff0_0*basisvalue0 + new_coeff0_1*basisvalue1 + new_coeff0_2*basisvalue2 + new_coeff0_3*basisvalue3 + new_coeff0_4*basisvalue4 + new_coeff0_5*basisvalue5 + new_coeff0_6*basisvalue6 + new_coeff0_7*basisvalue7 + new_coeff0_8*basisvalue8 + new_coeff0_9*basisvalue9 + new_coeff0_10*basisvalue10 + new_coeff0_11*basisvalue11 + new_coeff0_12*basisvalue12 + new_coeff0_13*basisvalue13 + new_coeff0_14*basisvalue14 + new_coeff0_15*basisvalue15 + new_coeff0_16*basisvalue16 + new_coeff0_17*basisvalue17 + new_coeff0_18*basisvalue18 + new_coeff0_19*basisvalue19 + new_coeff0_20*basisvalue20 + new_coeff0_21*basisvalue21 + new_coeff0_22*basisvalue22 + new_coeff0_23*basisvalue23 + new_coeff0_24*basisvalue24 + new_coeff0_25*basisvalue25 + new_coeff0_26*basisvalue26 + new_coeff0_27*basisvalue27 + new_coeff0_28*basisvalue28 + new_coeff0_29*basisvalue29 + new_coeff0_30*basisvalue30 + new_coeff0_31*basisvalue31 + new_coeff0_32*basisvalue32 + new_coeff0_33*basisvalue33 + new_coeff0_34*basisvalue34 + new_coeff0_35*basisvalue35 + new_coeff0_36*basisvalue36 + new_coeff0_37*basisvalue37 + new_coeff0_38*basisvalue38 + new_coeff0_39*basisvalue39 + new_coeff0_40*basisvalue40 + new_coeff0_41*basisvalue41 + new_coeff0_42*basisvalue42 + new_coeff0_43*basisvalue43 + new_coeff0_44*basisvalue44 + new_coeff0_45*basisvalue45 + new_coeff0_46*basisvalue46 + new_coeff0_47*basisvalue47 + new_coeff0_48*basisvalue48 + new_coeff0_49*basisvalue49 + new_coeff0_50*basisvalue50 + new_coeff0_51*basisvalue51 + new_coeff0_52*basisvalue52 + new_coeff0_53*basisvalue53 + new_coeff0_54*basisvalue54 + new_coeff0_55*basisvalue55;
    }
    
    // Transform derivatives back to physical element
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      for (unsigned int col = 0; col < num_derivatives; col++)
      {
        values[row] += transform[row][col]*derivatives[col];
      }
    }
    // Delete pointer to array of derivatives on FIAT element
    delete [] derivatives;
    
    // Delete pointer to array of combinations of derivatives and transform
    for (unsigned int row = 0; row < num_derivatives; row++)
    {
      delete [] combinations[row];
      delete [] transform[row];
    }
    
    delete [] combinations;
    delete [] transform;
  }

  /// Evaluate order n derivatives of all basis functions at given point in cell
  virtual void evaluate_basis_derivatives_all(unsigned int n,
                                              double* values,
                                              const double* coordinates,
                                              const ufc::cell& c) const
  {
    throw std::runtime_error("The vectorised version of evaluate_basis_derivatives() is not yet implemented.");
  }

  /// Evaluate linear functional for dof i on the function f
  virtual double evaluate_dof(unsigned int i,
                              const ufc::function& f,
                              const ufc::cell& c) const
  {
    // The reference points, direction and weights:
    const static double X[56][1][3] = {{{0, 0, 0}}, {{1, 0, 0}}, {{0, 1, 0}}, {{0, 0, 1}}, {{0, 0.8, 0.2}}, {{0, 0.6, 0.4}}, {{0, 0.4, 0.6}}, {{0, 0.2, 0.8}}, {{0.8, 0, 0.2}}, {{0.6, 0, 0.4}}, {{0.4, 0, 0.6}}, {{0.2, 0, 0.8}}, {{0.8, 0.2, 0}}, {{0.6, 0.4, 0}}, {{0.4, 0.6, 0}}, {{0.2, 0.8, 0}}, {{0, 0, 0.2}}, {{0, 0, 0.4}}, {{0, 0, 0.6}}, {{0, 0, 0.8}}, {{0, 0.2, 0}}, {{0, 0.4, 0}}, {{0, 0.6, 0}}, {{0, 0.8, 0}}, {{0.2, 0, 0}}, {{0.4, 0, 0}}, {{0.6, 0, 0}}, {{0.8, 0, 0}}, {{0.6, 0.2, 0.2}}, {{0.4, 0.4, 0.2}}, {{0.2, 0.6, 0.2}}, {{0.4, 0.2, 0.4}}, {{0.2, 0.4, 0.4}}, {{0.2, 0.2, 0.6}}, {{0, 0.2, 0.2}}, {{0, 0.4, 0.2}}, {{0, 0.6, 0.2}}, {{0, 0.2, 0.4}}, {{0, 0.4, 0.4}}, {{0, 0.2, 0.6}}, {{0.2, 0, 0.2}}, {{0.4, 0, 0.2}}, {{0.6, 0, 0.2}}, {{0.2, 0, 0.4}}, {{0.4, 0, 0.4}}, {{0.2, 0, 0.6}}, {{0.2, 0.2, 0}}, {{0.4, 0.2, 0}}, {{0.6, 0.2, 0}}, {{0.2, 0.4, 0}}, {{0.4, 0.4, 0}}, {{0.2, 0.6, 0}}, {{0.2, 0.2, 0.2}}, {{0.4, 0.2, 0.2}}, {{0.2, 0.4, 0.2}}, {{0.2, 0.2, 0.4}}};
    const static double W[56][1] = {{1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}, {1}};
    const static double D[56][1][1] = {{{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}, {{1}}};
    
    const double * const * x = c.coordinates;
    double result = 0.0;
    // Iterate over the points:
    // Evaluate basis functions for affine mapping
    const double w0 = 1.0 - X[i][0][0] - X[i][0][1] - X[i][0][2];
    const double w1 = X[i][0][0];
    const double w2 = X[i][0][1];
    const double w3 = X[i][0][2];
    
    // Compute affine mapping y = F(X)
    double y[3];
    y[0] = w0*x[0][0] + w1*x[1][0] + w2*x[2][0] + w3*x[3][0];
    y[1] = w0*x[0][1] + w1*x[1][1] + w2*x[2][1] + w3*x[3][1];
    y[2] = w0*x[0][2] + w1*x[1][2] + w2*x[2][2] + w3*x[3][2];
    
    // Evaluate function at physical points
    double values[1];
    f.evaluate(values, y, c);
    
    // Map function values using appropriate mapping
    // Affine map: Do nothing
    
    // Note that we do not map the weights (yet).
    
    // Take directional components
    for(int k = 0; k < 1; k++)
      result += values[k]*D[i][0][k];
    // Multiply by weights 
    result *= W[i][0];
    
    return result;
  }

  /// Evaluate linear functionals for all dofs on the function f
  virtual void evaluate_dofs(double* values,
                             const ufc::function& f,
                             const ufc::cell& c) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Interpolate vertex values from dof values
  virtual void interpolate_vertex_values(double* vertex_values,
                                         const double* dof_values,
                                         const ufc::cell& c) const
  {
    // Evaluate at vertices and use affine mapping
    vertex_values[0] = dof_values[0];
    vertex_values[1] = dof_values[1];
    vertex_values[2] = dof_values[2];
    vertex_values[3] = dof_values[3];
  }

  /// Return the number of sub elements (for a mixed element)
  virtual unsigned int num_sub_elements() const
  {
    return 1;
  }

  /// Create a new finite element for sub element i (for a mixed element)
  virtual ufc::finite_element* create_sub_element(unsigned int i) const
  {
    return new poisson3d_5_1_finite_element_1();
  }

};

/// This class defines the interface for a local-to-global mapping of
/// degrees of freedom (dofs).

class poisson3d_5_1_dof_map_0: public ufc::dof_map
{
private:

  unsigned int __global_dimension;

public:

  /// Constructor
  poisson3d_5_1_dof_map_0() : ufc::dof_map()
  {
    __global_dimension = 0;
  }

  /// Destructor
  virtual ~poisson3d_5_1_dof_map_0()
  {
    // Do nothing
  }

  /// Return a string identifying the dof map
  virtual const char* signature() const
  {
    return "FFC dof map for FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return true iff mesh entities of topological dimension d are needed
  virtual bool needs_mesh_entities(unsigned int d) const
  {
    switch ( d )
    {
    case 0:
      return true;
      break;
    case 1:
      return true;
      break;
    case 2:
      return true;
      break;
    case 3:
      return true;
      break;
    }
    return false;
  }

  /// Initialize dof map for mesh (return true iff init_cell() is needed)
  virtual bool init_mesh(const ufc::mesh& m)
  {
    __global_dimension = m.num_entities[0] + 4*m.num_entities[1] + 6*m.num_entities[2] + 4*m.num_entities[3];
    return false;
  }

  /// Initialize dof map for given cell
  virtual void init_cell(const ufc::mesh& m,
                         const ufc::cell& c)
  {
    // Do nothing
  }

  /// Finish initialization of dof map for cells
  virtual void init_cell_finalize()
  {
    // Do nothing
  }

  /// Return the dimension of the global finite element function space
  virtual unsigned int global_dimension() const
  {
    return __global_dimension;
  }

  /// Return the dimension of the local finite element function space for a cell
  virtual unsigned int local_dimension(const ufc::cell& c) const
  {
    return 56;
  }

  /// Return the maximum dimension of the local finite element function space
  virtual unsigned int max_local_dimension() const
  {
    return 56;
  }

  // Return the geometric dimension of the coordinates this dof map provides
  virtual unsigned int geometric_dimension() const
  {
    return 3;
  }

  /// Return the number of dofs on each cell facet
  virtual unsigned int num_facet_dofs() const
  {
    return 21;
  }

  /// Return the number of dofs associated with each cell entity of dimension d
  virtual unsigned int num_entity_dofs(unsigned int d) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the local-to-global mapping of dofs on a cell
  virtual void tabulate_dofs(unsigned int* dofs,
                             const ufc::mesh& m,
                             const ufc::cell& c) const
  {
    dofs[0] = c.entity_indices[0][0];
    dofs[1] = c.entity_indices[0][1];
    dofs[2] = c.entity_indices[0][2];
    dofs[3] = c.entity_indices[0][3];
    unsigned int offset = m.num_entities[0];
    dofs[4] = offset + 4*c.entity_indices[1][0];
    dofs[5] = offset + 4*c.entity_indices[1][0] + 1;
    dofs[6] = offset + 4*c.entity_indices[1][0] + 2;
    dofs[7] = offset + 4*c.entity_indices[1][0] + 3;
    dofs[8] = offset + 4*c.entity_indices[1][1];
    dofs[9] = offset + 4*c.entity_indices[1][1] + 1;
    dofs[10] = offset + 4*c.entity_indices[1][1] + 2;
    dofs[11] = offset + 4*c.entity_indices[1][1] + 3;
    dofs[12] = offset + 4*c.entity_indices[1][2];
    dofs[13] = offset + 4*c.entity_indices[1][2] + 1;
    dofs[14] = offset + 4*c.entity_indices[1][2] + 2;
    dofs[15] = offset + 4*c.entity_indices[1][2] + 3;
    dofs[16] = offset + 4*c.entity_indices[1][3];
    dofs[17] = offset + 4*c.entity_indices[1][3] + 1;
    dofs[18] = offset + 4*c.entity_indices[1][3] + 2;
    dofs[19] = offset + 4*c.entity_indices[1][3] + 3;
    dofs[20] = offset + 4*c.entity_indices[1][4];
    dofs[21] = offset + 4*c.entity_indices[1][4] + 1;
    dofs[22] = offset + 4*c.entity_indices[1][4] + 2;
    dofs[23] = offset + 4*c.entity_indices[1][4] + 3;
    dofs[24] = offset + 4*c.entity_indices[1][5];
    dofs[25] = offset + 4*c.entity_indices[1][5] + 1;
    dofs[26] = offset + 4*c.entity_indices[1][5] + 2;
    dofs[27] = offset + 4*c.entity_indices[1][5] + 3;
    offset = offset + 4*m.num_entities[1];
    dofs[28] = offset + 6*c.entity_indices[2][0];
    dofs[29] = offset + 6*c.entity_indices[2][0] + 1;
    dofs[30] = offset + 6*c.entity_indices[2][0] + 2;
    dofs[31] = offset + 6*c.entity_indices[2][0] + 3;
    dofs[32] = offset + 6*c.entity_indices[2][0] + 4;
    dofs[33] = offset + 6*c.entity_indices[2][0] + 5;
    dofs[34] = offset + 6*c.entity_indices[2][1];
    dofs[35] = offset + 6*c.entity_indices[2][1] + 1;
    dofs[36] = offset + 6*c.entity_indices[2][1] + 2;
    dofs[37] = offset + 6*c.entity_indices[2][1] + 3;
    dofs[38] = offset + 6*c.entity_indices[2][1] + 4;
    dofs[39] = offset + 6*c.entity_indices[2][1] + 5;
    dofs[40] = offset + 6*c.entity_indices[2][2];
    dofs[41] = offset + 6*c.entity_indices[2][2] + 1;
    dofs[42] = offset + 6*c.entity_indices[2][2] + 2;
    dofs[43] = offset + 6*c.entity_indices[2][2] + 3;
    dofs[44] = offset + 6*c.entity_indices[2][2] + 4;
    dofs[45] = offset + 6*c.entity_indices[2][2] + 5;
    dofs[46] = offset + 6*c.entity_indices[2][3];
    dofs[47] = offset + 6*c.entity_indices[2][3] + 1;
    dofs[48] = offset + 6*c.entity_indices[2][3] + 2;
    dofs[49] = offset + 6*c.entity_indices[2][3] + 3;
    dofs[50] = offset + 6*c.entity_indices[2][3] + 4;
    dofs[51] = offset + 6*c.entity_indices[2][3] + 5;
    offset = offset + 6*m.num_entities[2];
    dofs[52] = offset + 4*c.entity_indices[3][0];
    dofs[53] = offset + 4*c.entity_indices[3][0] + 1;
    dofs[54] = offset + 4*c.entity_indices[3][0] + 2;
    dofs[55] = offset + 4*c.entity_indices[3][0] + 3;
  }

  /// Tabulate the local-to-local mapping from facet dofs to cell dofs
  virtual void tabulate_facet_dofs(unsigned int* dofs,
                                   unsigned int facet) const
  {
    switch ( facet )
    {
    case 0:
      dofs[0] = 1;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 8;
      dofs[8] = 9;
      dofs[9] = 10;
      dofs[10] = 11;
      dofs[11] = 12;
      dofs[12] = 13;
      dofs[13] = 14;
      dofs[14] = 15;
      dofs[15] = 28;
      dofs[16] = 29;
      dofs[17] = 30;
      dofs[18] = 31;
      dofs[19] = 32;
      dofs[20] = 33;
      break;
    case 1:
      dofs[0] = 0;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 20;
      dofs[12] = 21;
      dofs[13] = 22;
      dofs[14] = 23;
      dofs[15] = 34;
      dofs[16] = 35;
      dofs[17] = 36;
      dofs[18] = 37;
      dofs[19] = 38;
      dofs[20] = 39;
      break;
    case 2:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 3;
      dofs[3] = 8;
      dofs[4] = 9;
      dofs[5] = 10;
      dofs[6] = 11;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 40;
      dofs[16] = 41;
      dofs[17] = 42;
      dofs[18] = 43;
      dofs[19] = 44;
      dofs[20] = 45;
      break;
    case 3:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 2;
      dofs[3] = 12;
      dofs[4] = 13;
      dofs[5] = 14;
      dofs[6] = 15;
      dofs[7] = 20;
      dofs[8] = 21;
      dofs[9] = 22;
      dofs[10] = 23;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 46;
      dofs[16] = 47;
      dofs[17] = 48;
      dofs[18] = 49;
      dofs[19] = 50;
      dofs[20] = 51;
      break;
    }
  }

  /// Tabulate the local-to-local mapping of dofs on entity (d, i)
  virtual void tabulate_entity_dofs(unsigned int* dofs,
                                    unsigned int d, unsigned int i) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the coordinates of all dofs on a cell
  virtual void tabulate_coordinates(double** coordinates,
                                    const ufc::cell& c) const
  {
    const double * const * x = c.coordinates;
    coordinates[0][0] = x[0][0];
    coordinates[0][1] = x[0][1];
    coordinates[0][2] = x[0][2];
    coordinates[1][0] = x[1][0];
    coordinates[1][1] = x[1][1];
    coordinates[1][2] = x[1][2];
    coordinates[2][0] = x[2][0];
    coordinates[2][1] = x[2][1];
    coordinates[2][2] = x[2][2];
    coordinates[3][0] = x[3][0];
    coordinates[3][1] = x[3][1];
    coordinates[3][2] = x[3][2];
    coordinates[4][0] = 0.8*x[2][0] + 0.2*x[3][0];
    coordinates[4][1] = 0.8*x[2][1] + 0.2*x[3][1];
    coordinates[4][2] = 0.8*x[2][2] + 0.2*x[3][2];
    coordinates[5][0] = 0.6*x[2][0] + 0.4*x[3][0];
    coordinates[5][1] = 0.6*x[2][1] + 0.4*x[3][1];
    coordinates[5][2] = 0.6*x[2][2] + 0.4*x[3][2];
    coordinates[6][0] = 0.4*x[2][0] + 0.6*x[3][0];
    coordinates[6][1] = 0.4*x[2][1] + 0.6*x[3][1];
    coordinates[6][2] = 0.4*x[2][2] + 0.6*x[3][2];
    coordinates[7][0] = 0.2*x[2][0] + 0.8*x[3][0];
    coordinates[7][1] = 0.2*x[2][1] + 0.8*x[3][1];
    coordinates[7][2] = 0.2*x[2][2] + 0.8*x[3][2];
    coordinates[8][0] = 0.8*x[1][0] + 0.2*x[3][0];
    coordinates[8][1] = 0.8*x[1][1] + 0.2*x[3][1];
    coordinates[8][2] = 0.8*x[1][2] + 0.2*x[3][2];
    coordinates[9][0] = 0.6*x[1][0] + 0.4*x[3][0];
    coordinates[9][1] = 0.6*x[1][1] + 0.4*x[3][1];
    coordinates[9][2] = 0.6*x[1][2] + 0.4*x[3][2];
    coordinates[10][0] = 0.4*x[1][0] + 0.6*x[3][0];
    coordinates[10][1] = 0.4*x[1][1] + 0.6*x[3][1];
    coordinates[10][2] = 0.4*x[1][2] + 0.6*x[3][2];
    coordinates[11][0] = 0.2*x[1][0] + 0.8*x[3][0];
    coordinates[11][1] = 0.2*x[1][1] + 0.8*x[3][1];
    coordinates[11][2] = 0.2*x[1][2] + 0.8*x[3][2];
    coordinates[12][0] = 0.8*x[1][0] + 0.2*x[2][0];
    coordinates[12][1] = 0.8*x[1][1] + 0.2*x[2][1];
    coordinates[12][2] = 0.8*x[1][2] + 0.2*x[2][2];
    coordinates[13][0] = 0.6*x[1][0] + 0.4*x[2][0];
    coordinates[13][1] = 0.6*x[1][1] + 0.4*x[2][1];
    coordinates[13][2] = 0.6*x[1][2] + 0.4*x[2][2];
    coordinates[14][0] = 0.4*x[1][0] + 0.6*x[2][0];
    coordinates[14][1] = 0.4*x[1][1] + 0.6*x[2][1];
    coordinates[14][2] = 0.4*x[1][2] + 0.6*x[2][2];
    coordinates[15][0] = 0.2*x[1][0] + 0.8*x[2][0];
    coordinates[15][1] = 0.2*x[1][1] + 0.8*x[2][1];
    coordinates[15][2] = 0.2*x[1][2] + 0.8*x[2][2];
    coordinates[16][0] = 0.8*x[0][0] + 0.2*x[3][0];
    coordinates[16][1] = 0.8*x[0][1] + 0.2*x[3][1];
    coordinates[16][2] = 0.8*x[0][2] + 0.2*x[3][2];
    coordinates[17][0] = 0.6*x[0][0] + 0.4*x[3][0];
    coordinates[17][1] = 0.6*x[0][1] + 0.4*x[3][1];
    coordinates[17][2] = 0.6*x[0][2] + 0.4*x[3][2];
    coordinates[18][0] = 0.4*x[0][0] + 0.6*x[3][0];
    coordinates[18][1] = 0.4*x[0][1] + 0.6*x[3][1];
    coordinates[18][2] = 0.4*x[0][2] + 0.6*x[3][2];
    coordinates[19][0] = 0.2*x[0][0] + 0.8*x[3][0];
    coordinates[19][1] = 0.2*x[0][1] + 0.8*x[3][1];
    coordinates[19][2] = 0.2*x[0][2] + 0.8*x[3][2];
    coordinates[20][0] = 0.8*x[0][0] + 0.2*x[2][0];
    coordinates[20][1] = 0.8*x[0][1] + 0.2*x[2][1];
    coordinates[20][2] = 0.8*x[0][2] + 0.2*x[2][2];
    coordinates[21][0] = 0.6*x[0][0] + 0.4*x[2][0];
    coordinates[21][1] = 0.6*x[0][1] + 0.4*x[2][1];
    coordinates[21][2] = 0.6*x[0][2] + 0.4*x[2][2];
    coordinates[22][0] = 0.4*x[0][0] + 0.6*x[2][0];
    coordinates[22][1] = 0.4*x[0][1] + 0.6*x[2][1];
    coordinates[22][2] = 0.4*x[0][2] + 0.6*x[2][2];
    coordinates[23][0] = 0.2*x[0][0] + 0.8*x[2][0];
    coordinates[23][1] = 0.2*x[0][1] + 0.8*x[2][1];
    coordinates[23][2] = 0.2*x[0][2] + 0.8*x[2][2];
    coordinates[24][0] = 0.8*x[0][0] + 0.2*x[1][0];
    coordinates[24][1] = 0.8*x[0][1] + 0.2*x[1][1];
    coordinates[24][2] = 0.8*x[0][2] + 0.2*x[1][2];
    coordinates[25][0] = 0.6*x[0][0] + 0.4*x[1][0];
    coordinates[25][1] = 0.6*x[0][1] + 0.4*x[1][1];
    coordinates[25][2] = 0.6*x[0][2] + 0.4*x[1][2];
    coordinates[26][0] = 0.4*x[0][0] + 0.6*x[1][0];
    coordinates[26][1] = 0.4*x[0][1] + 0.6*x[1][1];
    coordinates[26][2] = 0.4*x[0][2] + 0.6*x[1][2];
    coordinates[27][0] = 0.2*x[0][0] + 0.8*x[1][0];
    coordinates[27][1] = 0.2*x[0][1] + 0.8*x[1][1];
    coordinates[27][2] = 0.2*x[0][2] + 0.8*x[1][2];
    coordinates[28][0] = 0.6*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[28][1] = 0.6*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[28][2] = 0.6*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[29][0] = 0.4*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[29][1] = 0.4*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[29][2] = 0.4*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[30][0] = 0.2*x[1][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[30][1] = 0.2*x[1][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[30][2] = 0.2*x[1][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[31][0] = 0.4*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[31][1] = 0.4*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[31][2] = 0.4*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[32][0] = 0.2*x[1][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[32][1] = 0.2*x[1][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[32][2] = 0.2*x[1][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[33][0] = 0.2*x[1][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[33][1] = 0.2*x[1][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[33][2] = 0.2*x[1][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[34][0] = 0.6*x[0][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[34][1] = 0.6*x[0][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[34][2] = 0.6*x[0][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[35][0] = 0.4*x[0][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[35][1] = 0.4*x[0][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[35][2] = 0.4*x[0][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[36][0] = 0.2*x[0][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[36][1] = 0.2*x[0][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[36][2] = 0.2*x[0][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[37][0] = 0.4*x[0][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[37][1] = 0.4*x[0][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[37][2] = 0.4*x[0][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[38][0] = 0.2*x[0][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[38][1] = 0.2*x[0][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[38][2] = 0.2*x[0][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[39][0] = 0.2*x[0][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[39][1] = 0.2*x[0][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[39][2] = 0.2*x[0][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[40][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[3][0];
    coordinates[40][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[3][1];
    coordinates[40][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[3][2];
    coordinates[41][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[3][0];
    coordinates[41][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[3][1];
    coordinates[41][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[3][2];
    coordinates[42][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[3][0];
    coordinates[42][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[3][1];
    coordinates[42][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[3][2];
    coordinates[43][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[3][0];
    coordinates[43][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[3][1];
    coordinates[43][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[3][2];
    coordinates[44][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[3][0];
    coordinates[44][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[3][1];
    coordinates[44][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[3][2];
    coordinates[45][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[3][0];
    coordinates[45][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[3][1];
    coordinates[45][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[3][2];
    coordinates[46][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0];
    coordinates[46][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1];
    coordinates[46][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2];
    coordinates[47][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0];
    coordinates[47][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1];
    coordinates[47][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2];
    coordinates[48][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[2][0];
    coordinates[48][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[2][1];
    coordinates[48][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[2][2];
    coordinates[49][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0];
    coordinates[49][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1];
    coordinates[49][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2];
    coordinates[50][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[2][0];
    coordinates[50][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[2][1];
    coordinates[50][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[2][2];
    coordinates[51][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[2][0];
    coordinates[51][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[2][1];
    coordinates[51][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[2][2];
    coordinates[52][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[52][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[52][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[53][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[53][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[53][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[54][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[54][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[54][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[55][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[55][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[55][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
  }

  /// Return the number of sub dof maps (for a mixed element)
  virtual unsigned int num_sub_dof_maps() const
  {
    return 1;
  }

  /// Create a new dof_map for sub dof map i (for a mixed element)
  virtual ufc::dof_map* create_sub_dof_map(unsigned int i) const
  {
    return new poisson3d_5_1_dof_map_0();
  }

};

/// This class defines the interface for a local-to-global mapping of
/// degrees of freedom (dofs).

class poisson3d_5_1_dof_map_1: public ufc::dof_map
{
private:

  unsigned int __global_dimension;

public:

  /// Constructor
  poisson3d_5_1_dof_map_1() : ufc::dof_map()
  {
    __global_dimension = 0;
  }

  /// Destructor
  virtual ~poisson3d_5_1_dof_map_1()
  {
    // Do nothing
  }

  /// Return a string identifying the dof map
  virtual const char* signature() const
  {
    return "FFC dof map for FiniteElement('Lagrange', 'tetrahedron', 5)";
  }

  /// Return true iff mesh entities of topological dimension d are needed
  virtual bool needs_mesh_entities(unsigned int d) const
  {
    switch ( d )
    {
    case 0:
      return true;
      break;
    case 1:
      return true;
      break;
    case 2:
      return true;
      break;
    case 3:
      return true;
      break;
    }
    return false;
  }

  /// Initialize dof map for mesh (return true iff init_cell() is needed)
  virtual bool init_mesh(const ufc::mesh& m)
  {
    __global_dimension = m.num_entities[0] + 4*m.num_entities[1] + 6*m.num_entities[2] + 4*m.num_entities[3];
    return false;
  }

  /// Initialize dof map for given cell
  virtual void init_cell(const ufc::mesh& m,
                         const ufc::cell& c)
  {
    // Do nothing
  }

  /// Finish initialization of dof map for cells
  virtual void init_cell_finalize()
  {
    // Do nothing
  }

  /// Return the dimension of the global finite element function space
  virtual unsigned int global_dimension() const
  {
    return __global_dimension;
  }

  /// Return the dimension of the local finite element function space for a cell
  virtual unsigned int local_dimension(const ufc::cell& c) const
  {
    return 56;
  }

  /// Return the maximum dimension of the local finite element function space
  virtual unsigned int max_local_dimension() const
  {
    return 56;
  }

  // Return the geometric dimension of the coordinates this dof map provides
  virtual unsigned int geometric_dimension() const
  {
    return 3;
  }

  /// Return the number of dofs on each cell facet
  virtual unsigned int num_facet_dofs() const
  {
    return 21;
  }

  /// Return the number of dofs associated with each cell entity of dimension d
  virtual unsigned int num_entity_dofs(unsigned int d) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the local-to-global mapping of dofs on a cell
  virtual void tabulate_dofs(unsigned int* dofs,
                             const ufc::mesh& m,
                             const ufc::cell& c) const
  {
    dofs[0] = c.entity_indices[0][0];
    dofs[1] = c.entity_indices[0][1];
    dofs[2] = c.entity_indices[0][2];
    dofs[3] = c.entity_indices[0][3];
    unsigned int offset = m.num_entities[0];
    dofs[4] = offset + 4*c.entity_indices[1][0];
    dofs[5] = offset + 4*c.entity_indices[1][0] + 1;
    dofs[6] = offset + 4*c.entity_indices[1][0] + 2;
    dofs[7] = offset + 4*c.entity_indices[1][0] + 3;
    dofs[8] = offset + 4*c.entity_indices[1][1];
    dofs[9] = offset + 4*c.entity_indices[1][1] + 1;
    dofs[10] = offset + 4*c.entity_indices[1][1] + 2;
    dofs[11] = offset + 4*c.entity_indices[1][1] + 3;
    dofs[12] = offset + 4*c.entity_indices[1][2];
    dofs[13] = offset + 4*c.entity_indices[1][2] + 1;
    dofs[14] = offset + 4*c.entity_indices[1][2] + 2;
    dofs[15] = offset + 4*c.entity_indices[1][2] + 3;
    dofs[16] = offset + 4*c.entity_indices[1][3];
    dofs[17] = offset + 4*c.entity_indices[1][3] + 1;
    dofs[18] = offset + 4*c.entity_indices[1][3] + 2;
    dofs[19] = offset + 4*c.entity_indices[1][3] + 3;
    dofs[20] = offset + 4*c.entity_indices[1][4];
    dofs[21] = offset + 4*c.entity_indices[1][4] + 1;
    dofs[22] = offset + 4*c.entity_indices[1][4] + 2;
    dofs[23] = offset + 4*c.entity_indices[1][4] + 3;
    dofs[24] = offset + 4*c.entity_indices[1][5];
    dofs[25] = offset + 4*c.entity_indices[1][5] + 1;
    dofs[26] = offset + 4*c.entity_indices[1][5] + 2;
    dofs[27] = offset + 4*c.entity_indices[1][5] + 3;
    offset = offset + 4*m.num_entities[1];
    dofs[28] = offset + 6*c.entity_indices[2][0];
    dofs[29] = offset + 6*c.entity_indices[2][0] + 1;
    dofs[30] = offset + 6*c.entity_indices[2][0] + 2;
    dofs[31] = offset + 6*c.entity_indices[2][0] + 3;
    dofs[32] = offset + 6*c.entity_indices[2][0] + 4;
    dofs[33] = offset + 6*c.entity_indices[2][0] + 5;
    dofs[34] = offset + 6*c.entity_indices[2][1];
    dofs[35] = offset + 6*c.entity_indices[2][1] + 1;
    dofs[36] = offset + 6*c.entity_indices[2][1] + 2;
    dofs[37] = offset + 6*c.entity_indices[2][1] + 3;
    dofs[38] = offset + 6*c.entity_indices[2][1] + 4;
    dofs[39] = offset + 6*c.entity_indices[2][1] + 5;
    dofs[40] = offset + 6*c.entity_indices[2][2];
    dofs[41] = offset + 6*c.entity_indices[2][2] + 1;
    dofs[42] = offset + 6*c.entity_indices[2][2] + 2;
    dofs[43] = offset + 6*c.entity_indices[2][2] + 3;
    dofs[44] = offset + 6*c.entity_indices[2][2] + 4;
    dofs[45] = offset + 6*c.entity_indices[2][2] + 5;
    dofs[46] = offset + 6*c.entity_indices[2][3];
    dofs[47] = offset + 6*c.entity_indices[2][3] + 1;
    dofs[48] = offset + 6*c.entity_indices[2][3] + 2;
    dofs[49] = offset + 6*c.entity_indices[2][3] + 3;
    dofs[50] = offset + 6*c.entity_indices[2][3] + 4;
    dofs[51] = offset + 6*c.entity_indices[2][3] + 5;
    offset = offset + 6*m.num_entities[2];
    dofs[52] = offset + 4*c.entity_indices[3][0];
    dofs[53] = offset + 4*c.entity_indices[3][0] + 1;
    dofs[54] = offset + 4*c.entity_indices[3][0] + 2;
    dofs[55] = offset + 4*c.entity_indices[3][0] + 3;
  }

  /// Tabulate the local-to-local mapping from facet dofs to cell dofs
  virtual void tabulate_facet_dofs(unsigned int* dofs,
                                   unsigned int facet) const
  {
    switch ( facet )
    {
    case 0:
      dofs[0] = 1;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 8;
      dofs[8] = 9;
      dofs[9] = 10;
      dofs[10] = 11;
      dofs[11] = 12;
      dofs[12] = 13;
      dofs[13] = 14;
      dofs[14] = 15;
      dofs[15] = 28;
      dofs[16] = 29;
      dofs[17] = 30;
      dofs[18] = 31;
      dofs[19] = 32;
      dofs[20] = 33;
      break;
    case 1:
      dofs[0] = 0;
      dofs[1] = 2;
      dofs[2] = 3;
      dofs[3] = 4;
      dofs[4] = 5;
      dofs[5] = 6;
      dofs[6] = 7;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 20;
      dofs[12] = 21;
      dofs[13] = 22;
      dofs[14] = 23;
      dofs[15] = 34;
      dofs[16] = 35;
      dofs[17] = 36;
      dofs[18] = 37;
      dofs[19] = 38;
      dofs[20] = 39;
      break;
    case 2:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 3;
      dofs[3] = 8;
      dofs[4] = 9;
      dofs[5] = 10;
      dofs[6] = 11;
      dofs[7] = 16;
      dofs[8] = 17;
      dofs[9] = 18;
      dofs[10] = 19;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 40;
      dofs[16] = 41;
      dofs[17] = 42;
      dofs[18] = 43;
      dofs[19] = 44;
      dofs[20] = 45;
      break;
    case 3:
      dofs[0] = 0;
      dofs[1] = 1;
      dofs[2] = 2;
      dofs[3] = 12;
      dofs[4] = 13;
      dofs[5] = 14;
      dofs[6] = 15;
      dofs[7] = 20;
      dofs[8] = 21;
      dofs[9] = 22;
      dofs[10] = 23;
      dofs[11] = 24;
      dofs[12] = 25;
      dofs[13] = 26;
      dofs[14] = 27;
      dofs[15] = 46;
      dofs[16] = 47;
      dofs[17] = 48;
      dofs[18] = 49;
      dofs[19] = 50;
      dofs[20] = 51;
      break;
    }
  }

  /// Tabulate the local-to-local mapping of dofs on entity (d, i)
  virtual void tabulate_entity_dofs(unsigned int* dofs,
                                    unsigned int d, unsigned int i) const
  {
    throw std::runtime_error("Not implemented (introduced in UFC v1.1).");
  }

  /// Tabulate the coordinates of all dofs on a cell
  virtual void tabulate_coordinates(double** coordinates,
                                    const ufc::cell& c) const
  {
    const double * const * x = c.coordinates;
    coordinates[0][0] = x[0][0];
    coordinates[0][1] = x[0][1];
    coordinates[0][2] = x[0][2];
    coordinates[1][0] = x[1][0];
    coordinates[1][1] = x[1][1];
    coordinates[1][2] = x[1][2];
    coordinates[2][0] = x[2][0];
    coordinates[2][1] = x[2][1];
    coordinates[2][2] = x[2][2];
    coordinates[3][0] = x[3][0];
    coordinates[3][1] = x[3][1];
    coordinates[3][2] = x[3][2];
    coordinates[4][0] = 0.8*x[2][0] + 0.2*x[3][0];
    coordinates[4][1] = 0.8*x[2][1] + 0.2*x[3][1];
    coordinates[4][2] = 0.8*x[2][2] + 0.2*x[3][2];
    coordinates[5][0] = 0.6*x[2][0] + 0.4*x[3][0];
    coordinates[5][1] = 0.6*x[2][1] + 0.4*x[3][1];
    coordinates[5][2] = 0.6*x[2][2] + 0.4*x[3][2];
    coordinates[6][0] = 0.4*x[2][0] + 0.6*x[3][0];
    coordinates[6][1] = 0.4*x[2][1] + 0.6*x[3][1];
    coordinates[6][2] = 0.4*x[2][2] + 0.6*x[3][2];
    coordinates[7][0] = 0.2*x[2][0] + 0.8*x[3][0];
    coordinates[7][1] = 0.2*x[2][1] + 0.8*x[3][1];
    coordinates[7][2] = 0.2*x[2][2] + 0.8*x[3][2];
    coordinates[8][0] = 0.8*x[1][0] + 0.2*x[3][0];
    coordinates[8][1] = 0.8*x[1][1] + 0.2*x[3][1];
    coordinates[8][2] = 0.8*x[1][2] + 0.2*x[3][2];
    coordinates[9][0] = 0.6*x[1][0] + 0.4*x[3][0];
    coordinates[9][1] = 0.6*x[1][1] + 0.4*x[3][1];
    coordinates[9][2] = 0.6*x[1][2] + 0.4*x[3][2];
    coordinates[10][0] = 0.4*x[1][0] + 0.6*x[3][0];
    coordinates[10][1] = 0.4*x[1][1] + 0.6*x[3][1];
    coordinates[10][2] = 0.4*x[1][2] + 0.6*x[3][2];
    coordinates[11][0] = 0.2*x[1][0] + 0.8*x[3][0];
    coordinates[11][1] = 0.2*x[1][1] + 0.8*x[3][1];
    coordinates[11][2] = 0.2*x[1][2] + 0.8*x[3][2];
    coordinates[12][0] = 0.8*x[1][0] + 0.2*x[2][0];
    coordinates[12][1] = 0.8*x[1][1] + 0.2*x[2][1];
    coordinates[12][2] = 0.8*x[1][2] + 0.2*x[2][2];
    coordinates[13][0] = 0.6*x[1][0] + 0.4*x[2][0];
    coordinates[13][1] = 0.6*x[1][1] + 0.4*x[2][1];
    coordinates[13][2] = 0.6*x[1][2] + 0.4*x[2][2];
    coordinates[14][0] = 0.4*x[1][0] + 0.6*x[2][0];
    coordinates[14][1] = 0.4*x[1][1] + 0.6*x[2][1];
    coordinates[14][2] = 0.4*x[1][2] + 0.6*x[2][2];
    coordinates[15][0] = 0.2*x[1][0] + 0.8*x[2][0];
    coordinates[15][1] = 0.2*x[1][1] + 0.8*x[2][1];
    coordinates[15][2] = 0.2*x[1][2] + 0.8*x[2][2];
    coordinates[16][0] = 0.8*x[0][0] + 0.2*x[3][0];
    coordinates[16][1] = 0.8*x[0][1] + 0.2*x[3][1];
    coordinates[16][2] = 0.8*x[0][2] + 0.2*x[3][2];
    coordinates[17][0] = 0.6*x[0][0] + 0.4*x[3][0];
    coordinates[17][1] = 0.6*x[0][1] + 0.4*x[3][1];
    coordinates[17][2] = 0.6*x[0][2] + 0.4*x[3][2];
    coordinates[18][0] = 0.4*x[0][0] + 0.6*x[3][0];
    coordinates[18][1] = 0.4*x[0][1] + 0.6*x[3][1];
    coordinates[18][2] = 0.4*x[0][2] + 0.6*x[3][2];
    coordinates[19][0] = 0.2*x[0][0] + 0.8*x[3][0];
    coordinates[19][1] = 0.2*x[0][1] + 0.8*x[3][1];
    coordinates[19][2] = 0.2*x[0][2] + 0.8*x[3][2];
    coordinates[20][0] = 0.8*x[0][0] + 0.2*x[2][0];
    coordinates[20][1] = 0.8*x[0][1] + 0.2*x[2][1];
    coordinates[20][2] = 0.8*x[0][2] + 0.2*x[2][2];
    coordinates[21][0] = 0.6*x[0][0] + 0.4*x[2][0];
    coordinates[21][1] = 0.6*x[0][1] + 0.4*x[2][1];
    coordinates[21][2] = 0.6*x[0][2] + 0.4*x[2][2];
    coordinates[22][0] = 0.4*x[0][0] + 0.6*x[2][0];
    coordinates[22][1] = 0.4*x[0][1] + 0.6*x[2][1];
    coordinates[22][2] = 0.4*x[0][2] + 0.6*x[2][2];
    coordinates[23][0] = 0.2*x[0][0] + 0.8*x[2][0];
    coordinates[23][1] = 0.2*x[0][1] + 0.8*x[2][1];
    coordinates[23][2] = 0.2*x[0][2] + 0.8*x[2][2];
    coordinates[24][0] = 0.8*x[0][0] + 0.2*x[1][0];
    coordinates[24][1] = 0.8*x[0][1] + 0.2*x[1][1];
    coordinates[24][2] = 0.8*x[0][2] + 0.2*x[1][2];
    coordinates[25][0] = 0.6*x[0][0] + 0.4*x[1][0];
    coordinates[25][1] = 0.6*x[0][1] + 0.4*x[1][1];
    coordinates[25][2] = 0.6*x[0][2] + 0.4*x[1][2];
    coordinates[26][0] = 0.4*x[0][0] + 0.6*x[1][0];
    coordinates[26][1] = 0.4*x[0][1] + 0.6*x[1][1];
    coordinates[26][2] = 0.4*x[0][2] + 0.6*x[1][2];
    coordinates[27][0] = 0.2*x[0][0] + 0.8*x[1][0];
    coordinates[27][1] = 0.2*x[0][1] + 0.8*x[1][1];
    coordinates[27][2] = 0.2*x[0][2] + 0.8*x[1][2];
    coordinates[28][0] = 0.6*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[28][1] = 0.6*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[28][2] = 0.6*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[29][0] = 0.4*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[29][1] = 0.4*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[29][2] = 0.4*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[30][0] = 0.2*x[1][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[30][1] = 0.2*x[1][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[30][2] = 0.2*x[1][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[31][0] = 0.4*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[31][1] = 0.4*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[31][2] = 0.4*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[32][0] = 0.2*x[1][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[32][1] = 0.2*x[1][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[32][2] = 0.2*x[1][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[33][0] = 0.2*x[1][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[33][1] = 0.2*x[1][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[33][2] = 0.2*x[1][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[34][0] = 0.6*x[0][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[34][1] = 0.6*x[0][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[34][2] = 0.6*x[0][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[35][0] = 0.4*x[0][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[35][1] = 0.4*x[0][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[35][2] = 0.4*x[0][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[36][0] = 0.2*x[0][0] + 0.6*x[2][0] + 0.2*x[3][0];
    coordinates[36][1] = 0.2*x[0][1] + 0.6*x[2][1] + 0.2*x[3][1];
    coordinates[36][2] = 0.2*x[0][2] + 0.6*x[2][2] + 0.2*x[3][2];
    coordinates[37][0] = 0.4*x[0][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[37][1] = 0.4*x[0][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[37][2] = 0.4*x[0][2] + 0.2*x[2][2] + 0.4*x[3][2];
    coordinates[38][0] = 0.2*x[0][0] + 0.4*x[2][0] + 0.4*x[3][0];
    coordinates[38][1] = 0.2*x[0][1] + 0.4*x[2][1] + 0.4*x[3][1];
    coordinates[38][2] = 0.2*x[0][2] + 0.4*x[2][2] + 0.4*x[3][2];
    coordinates[39][0] = 0.2*x[0][0] + 0.2*x[2][0] + 0.6*x[3][0];
    coordinates[39][1] = 0.2*x[0][1] + 0.2*x[2][1] + 0.6*x[3][1];
    coordinates[39][2] = 0.2*x[0][2] + 0.2*x[2][2] + 0.6*x[3][2];
    coordinates[40][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[3][0];
    coordinates[40][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[3][1];
    coordinates[40][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[3][2];
    coordinates[41][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[3][0];
    coordinates[41][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[3][1];
    coordinates[41][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[3][2];
    coordinates[42][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[3][0];
    coordinates[42][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[3][1];
    coordinates[42][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[3][2];
    coordinates[43][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[3][0];
    coordinates[43][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[3][1];
    coordinates[43][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[3][2];
    coordinates[44][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[3][0];
    coordinates[44][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[3][1];
    coordinates[44][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[3][2];
    coordinates[45][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[3][0];
    coordinates[45][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[3][1];
    coordinates[45][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[3][2];
    coordinates[46][0] = 0.6*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0];
    coordinates[46][1] = 0.6*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1];
    coordinates[46][2] = 0.6*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2];
    coordinates[47][0] = 0.4*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0];
    coordinates[47][1] = 0.4*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1];
    coordinates[47][2] = 0.4*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2];
    coordinates[48][0] = 0.2*x[0][0] + 0.6*x[1][0] + 0.2*x[2][0];
    coordinates[48][1] = 0.2*x[0][1] + 0.6*x[1][1] + 0.2*x[2][1];
    coordinates[48][2] = 0.2*x[0][2] + 0.6*x[1][2] + 0.2*x[2][2];
    coordinates[49][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0];
    coordinates[49][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1];
    coordinates[49][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2];
    coordinates[50][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.4*x[2][0];
    coordinates[50][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.4*x[2][1];
    coordinates[50][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.4*x[2][2];
    coordinates[51][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.6*x[2][0];
    coordinates[51][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.6*x[2][1];
    coordinates[51][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.6*x[2][2];
    coordinates[52][0] = 0.4*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[52][1] = 0.4*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[52][2] = 0.4*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[53][0] = 0.2*x[0][0] + 0.4*x[1][0] + 0.2*x[2][0] + 0.2*x[3][0];
    coordinates[53][1] = 0.2*x[0][1] + 0.4*x[1][1] + 0.2*x[2][1] + 0.2*x[3][1];
    coordinates[53][2] = 0.2*x[0][2] + 0.4*x[1][2] + 0.2*x[2][2] + 0.2*x[3][2];
    coordinates[54][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.4*x[2][0] + 0.2*x[3][0];
    coordinates[54][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.4*x[2][1] + 0.2*x[3][1];
    coordinates[54][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.4*x[2][2] + 0.2*x[3][2];
    coordinates[55][0] = 0.2*x[0][0] + 0.2*x[1][0] + 0.2*x[2][0] + 0.4*x[3][0];
    coordinates[55][1] = 0.2*x[0][1] + 0.2*x[1][1] + 0.2*x[2][1] + 0.4*x[3][1];
    coordinates[55][2] = 0.2*x[0][2] + 0.2*x[1][2] + 0.2*x[2][2] + 0.4*x[3][2];
  }

  /// Return the number of sub dof maps (for a mixed element)
  virtual unsigned int num_sub_dof_maps() const
  {
    return 1;
  }

  /// Create a new dof_map for sub dof map i (for a mixed element)
  virtual ufc::dof_map* create_sub_dof_map(unsigned int i) const
  {
    return new poisson3d_5_1_dof_map_1();
  }

};

/// This class defines the interface for the tabulation of the cell
/// tensor corresponding to the local contribution to a form from
/// the integral over a cell.

class poisson3d_5_1_cell_integral_0_quadrature: public ufc::cell_integral
{
public:

  /// Constructor
  poisson3d_5_1_cell_integral_0_quadrature() : ufc::cell_integral()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_1_cell_integral_0_quadrature()
  {
    // Do nothing
  }

  /// Tabulate the tensor for the contribution from a local cell
  virtual void tabulate_tensor(double* A,
                               const double * const * w,
                               const ufc::cell& c) const
  {
    // Extract vertex coordinates
    const double * const * x = c.coordinates;
    
    // Compute Jacobian of affine map from reference cell
    const double J_00 = x[1][0] - x[0][0];
    const double J_01 = x[2][0] - x[0][0];
    const double J_02 = x[3][0] - x[0][0];
    const double J_10 = x[1][1] - x[0][1];
    const double J_11 = x[2][1] - x[0][1];
    const double J_12 = x[3][1] - x[0][1];
    const double J_20 = x[1][2] - x[0][2];
    const double J_21 = x[2][2] - x[0][2];
    const double J_22 = x[3][2] - x[0][2];
      
    // Compute sub determinants
    const double d_00 = J_11*J_22 - J_12*J_21;
    
    const double d_10 = J_02*J_21 - J_01*J_22;
    
    const double d_20 = J_01*J_12 - J_02*J_11;
      
    // Compute determinant of Jacobian
    double detJ = J_00*d_00 + J_10*d_10 + J_20*d_20;
      
    // Compute inverse of Jacobian
    
    // Set scale factor
    const double det = std::abs(detJ);
    
    
    // Array of quadrature weights
    const static double W216[216] = {0.000387381319499512, 0.000665118532009356, 0.000585836191028465, 0.00031770121340093, 9.73756921862106e-05, 1.13421694285829e-05, 0.000726129045448854, 0.00124673509136236, 0.00109812387115231, 0.000595516787239015, 0.00018252640191439, 2.12603918824395e-05, 0.000754254678618672, 0.00129502570039305, 0.00114065822419689, 0.000618583330037891, 0.000189596316905709, 2.20838846030239e-05, 0.00052854808478811, 0.000907496331275901, 0.000799322479379511, 0.000433475646411833, 0.000132860654397154, 1.54754027286732e-05, 0.000235476865600463, 0.000404304542544008, 0.000356111312225707, 0.000193120530504076, 5.91916068934585e-05, 6.89454646290829e-06, 4.6812880715354e-05, 8.03758801295647e-05, 7.07950496032822e-05, 3.83924269380772e-05, 1.17673115182154e-05, 1.37063817429187e-06, 0.000815716960554665, 0.00140055402785094, 0.00123360754139117, 0.000668990101264451, 0.00020504603516934, 2.38834437972721e-05, 0.00152902514424097, 0.00262527620241696, 0.00231234244244452, 0.00125399217565136, 0.00038434966864935, 4.47684526165347e-05, 0.00158824987927105, 0.00272696274959673, 0.00240190792079416, 0.00130256387809358, 0.000399236936769426, 4.65024984913897e-05, 0.00111297477582909, 0.00191093403786039, 0.00168315009155545, 0.000912778750463146, 0.000279767463547727, 3.25868797532674e-05, 0.000495848569406277, 0.000851352545880463, 0.000749871051095567, 0.00040665794717984, 0.000124641006767853, 1.45179909356304e-05, 9.85748637060563e-05, 0.00016924917475603, 0.00014907461918741, 8.08437377690454e-05, 2.47786744026275e-05, 2.88618152005384e-06, 0.00105799885859761, 0.00181654254419696, 0.00160001009401815, 0.000867691610910741, 0.000265948216917809, 3.09772353632468e-05, 0.00198317178090058, 0.00340502816537243, 0.002999147722918, 0.00162644931353069, 0.000498508098270848, 5.80654492426738e-05, 0.00205998727584867, 0.00353691735740022, 0.00311531568122456, 0.00168944764288879, 0.000517817139813846, 6.03145364200509e-05, 0.00144354733248948, 0.00247851415218444, 0.00218307447537104, 0.00118388966129318, 0.000362863188360062, 4.22657407549443e-05, 0.000643124080823797, 0.00110421882265784, 0.0009725955870956, 0.000527442317324585, 0.000161661518972436, 1.88300827146993e-05, 0.000127853285306839, 0.000219519076308906, 0.000193352332454762, 0.000104855711503479, 3.21383647800037e-05, 3.74342682766598e-06, 0.00105799885859761, 0.00181654254419696, 0.00160001009401815, 0.000867691610910741, 0.000265948216917809, 3.09772353632468e-05, 0.00198317178090058, 0.00340502816537242, 0.002999147722918, 0.00162644931353069, 0.000498508098270848, 5.80654492426738e-05, 0.00205998727584867, 0.00353691735740022, 0.00311531568122456, 0.00168944764288879, 0.000517817139813846, 6.03145364200509e-05, 0.00144354733248948, 0.00247851415218444, 0.00218307447537103, 0.00118388966129318, 0.000362863188360062, 4.22657407549443e-05, 0.000643124080823797, 0.00110421882265784, 0.000972595587095599, 0.000527442317324584, 0.000161661518972436, 1.88300827146993e-05, 0.000127853285306839, 0.000219519076308906, 0.000193352332454762, 0.000104855711503479, 3.21383647800037e-05, 3.74342682766598e-06, 0.000815716960554665, 0.00140055402785094, 0.00123360754139117, 0.000668990101264451, 0.00020504603516934, 2.38834437972721e-05, 0.00152902514424097, 0.00262527620241696, 0.00231234244244452, 0.00125399217565136, 0.00038434966864935, 4.47684526165347e-05, 0.00158824987927105, 0.00272696274959673, 0.00240190792079416, 0.00130256387809358, 0.000399236936769426, 4.65024984913897e-05, 0.00111297477582909, 0.00191093403786039, 0.00168315009155545, 0.000912778750463146, 0.000279767463547727, 3.25868797532674e-05, 0.000495848569406277, 0.000851352545880463, 0.000749871051095567, 0.00040665794717984, 0.000124641006767853, 1.45179909356304e-05, 9.85748637060563e-05, 0.00016924917475603, 0.00014907461918741, 8.08437377690454e-05, 2.47786744026275e-05, 2.88618152005384e-06, 0.000387381319499513, 0.000665118532009358, 0.000585836191028466, 0.00031770121340093, 9.73756921862108e-05, 1.1342169428583e-05, 0.000726129045448856, 0.00124673509136237, 0.00109812387115231, 0.000595516787239017, 0.00018252640191439, 2.12603918824395e-05, 0.000754254678618674, 0.00129502570039306, 0.00114065822419689, 0.000618583330037893, 0.000189596316905709, 2.2083884603024e-05, 0.000528548084788111, 0.000907496331275903, 0.000799322479379513, 0.000433475646411835, 0.000132860654397154, 1.54754027286732e-05, 0.000235476865600464, 0.000404304542544009, 0.000356111312225708, 0.000193120530504076, 5.91916068934587e-05, 6.8945464629083e-06, 4.68128807153541e-05, 8.03758801295649e-05, 7.07950496032824e-05, 3.83924269380773e-05, 1.17673115182155e-05, 1.37063817429188e-06};
    
    
    const static double FE0[216][56] = \
    {{0.310703073843137, 0.0224419087355453, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, -0.00378445250751072, -0.00231961445844557, -0.00235756395016147, -0.00402640927558312, -0.00417195365419322, -0.00251816728181522, -0.00254121852244873, -0.0043200151064959, 0.354215091736513, -0.39327074269067, 0.286443388274844, -0.115220749339439, 0.390484209646641, -0.426933671469902, 0.308757369600584, -0.123622648285321, 0.436556032512803, -0.467925628811811, 0.33533302108994, -0.13347157028838, 0.000760975979021705, 0.000531676205177352, 0.000783336703543834, 0.000539901917789507, 0.000550725217214056, 0.000801136210248206, 0.129016952515557, -0.0645985164753272, 0.0224161618429516, -0.0655979383537513, 0.015759692536057, 0.022925517042575, 0.144239197195841, -0.0708009310625633, 0.0243455865742153, -0.0733376023953634, 0.0172728564941385, 0.0256304160735921, 0.159008269921432, -0.0780504452045668, 0.0268384022973472, -0.0796151059527957, 0.0187513670337174, 0.0276270291882512, 0.0240592369041031, -0.0056665575752353, -0.00578015385508088, -0.00586958024656279},
    {0.0168212127675001, 0.0208311675729529, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, -0.0177608566866898, -0.00425338581439375, -0.00307308040887655, -0.00419601682685225, -0.0034369714294915, -0.00209922099594009, -0.00211619316158225, -0.0035439613540267, 0.762426252400218, -0.486472830393037, 0.315036567668793, -0.120074282056387, 0.147540025395148, -0.240094368128956, 0.21694135572351, -0.101414897218028, 0.164947740605516, -0.263802651514285, 0.236451671291947, -0.109957591036382, 0.00316467178184318, 0.0022300499214286, 0.0032461243592994, 0.000874386037654998, 0.000889697864058069, 0.000912212004253425, 0.361953254691466, -0.228613371439197, 0.0928919182149794, -0.0896376076996033, 0.0254598197962889, 0.0261040901440188, 0.404658813134063, -0.251187955916101, 0.101246022171265, -0.100213625582169, 0.0279738671992901, 0.0291840175456563, 0.0783070774100658, -0.0486083437947555, 0.0195925056820642, -0.0494595496579394, 0.0138062550459613, 0.0200967791728531, 0.074562536030208, -0.0208135617171247, -0.0211780387674463, -0.00830375195874432},
    {-0.015558863517762, 0.0178396083059577, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, -0.0347130258988213, 0.0123225323775472, 0.00318776431988744, 0.00267747665318665, -0.00234721135471129, -0.00146045594323528, -0.0014697995732853, -0.00240441497001842, 0.161426388205, 0.609621358264414, -0.233929227326291, 0.0766193511896091, 0.0109152642713772, -0.0722517992667382, 0.107859002109445, -0.0688053487876894, 0.0122031169159267, -0.0796910370126102, 0.118208186061103, -0.075093352246887, 0.00492003269613232, 0.00351354277547234, 0.00501895556935266, -0.00200454808179175, -0.0020318525272463, -0.000736039572724748, 0.243404271380666, -0.257835982891349, 0.143623705893241, 0.147100706594461, -0.0581440074053689, -0.0210626951480252, 0.272122663056645, -0.284383462616915, 0.157404550542626, 0.164456588164782, -0.0641306693151905, -0.0235478065455437, 0.0184002802424234, -0.0192293260314473, 0.0106433172778929, -0.0194912534396812, 0.00760071179165126, 0.0108573133203485, 0.0656627847324156, -0.0256055314109385, -0.0259543106904581, 0.0148074655791838},
    {0.00894872042728932, 0.01354270014303, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, -0.0439702312640463, 0.0465429183672367, -0.0132189650130186, -0.0032691380424768, -0.00124328365422724, -0.000790403917700945, -0.000793900257330359, -0.00126398002385323, -0.0670830605102294, 0.297174981210494, 0.535772970512814, -0.0935504836114043, -0.00189681223432874, -0.00504670264847047, 0.0321772770214551, -0.0361703730372401, -0.00212061026536672, -0.00559052193272506, 0.0354876359854277, -0.0397758545272402, 0.004335450944221, 0.00314406469764682, 0.00439483944231592, -0.0052348889757811, -0.00528322800716215, 0.00206912152181182, 0.0276817096582158, -0.127430920717604, 0.125763840462251, 0.212173344440878, -0.151186193020126, 0.0592105064091014, 0.0309477746936239, -0.141162538552777, 0.13870227078189, 0.237206911741454, -0.167477615955912, 0.0661965404040856, 0.000875066182395703, -0.00399145221042715, 0.00392188671994377, -0.0040283093309028, 0.00284414833496886, 0.00397561007306033, 0.0220957122063312, -0.0156004611164019, -0.0157445159727601, 0.0262147255291865},
    {-0.0109738205691141, 0.00844321113047122, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, -0.0382116443014455, 0.0667196416010178, -0.0539112807906322, 0.0163532456363013, -0.000445033691819717, -0.000288809823712963, -0.000289536829614319, -0.000449201642483924, 0.0736287355315532, -0.227812559637078, 0.539364215954558, 0.467968625984661, 0.00085752049137497, 0.000986133972089257, 0.00289671851242866, -0.0128544681648158, 0.000958696239860396, 0.00109682745775006, 0.00321378511702098, -0.0142377769749927, 0.00215684627323642, 0.0015871943440184, 0.0021734275571577, -0.00427040450999724, -0.00429242918242197, 0.00471322495942931, -0.00736449804673694, -0.0158793451087479, 0.0621953543792268, 0.0427239595603109, -0.122833242483405, 0.134874841195123, -0.00823340859708787, -0.0176618007484953, 0.0690030817265087, 0.0477648053829498, -0.136621267387051, 0.150788237023003, -9.58907759979192e-05, -0.000205698983515857, 0.000803647599287576, -0.000206759878969787, 0.000591393526743596, 0.000809825837014429, 0.00154409316372142, -0.00441655656921448, -0.00443933502297681, 0.0119441934599608},
    {0.0261188035535261, 0.0035684642286854, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.0198704873172243, 0.0457735732543996, -0.0562285998280998, 0.0410787029080855, -7.43559974856374e-05, -4.90514755034762e-05, -4.90999381121253e-05, -7.46268914879736e-05, -0.166915283235762, 0.464278848231276, -0.769187724303446, 1.17551858417977, -0.000624602315104159, -0.000497526431336818, -0.000671670106946088, -0.0021355420598354, -0.000698296888437413, -0.000555120501094618, -0.000748683496630213, -0.00237884036290428, 0.000442330508822801, 0.000329297655088388, 0.000443650701341714, -0.00114989679790879, -0.00115219045506184, 0.00190118764207891, 0.00448653414127243, 0.00450467759663897, 0.0126956210248065, -0.0157301889762824, -0.0329713743754395, 0.0544048679014512, 0.00501588411531307, 0.0050261427880267, 0.0141512951707227, -0.0175861372125053, -0.036788167848482, 0.0608239019496675, 1.87695983853724e-05, 1.88079866663635e-05, 5.29545980093037e-05, 1.88455022703116e-05, 3.94226140923685e-05, 5.31126478446887e-05, -0.000169942708606267, -0.000355500518009748, -0.000356209621910501, 0.00124387251864918},
    {0.00186778322923258, 0.0206121464512042, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, -0.00345830596482603, -0.00210523271754557, -0.00211720616941674, -0.00353378209371141, -0.0192566655330663, -0.00375432783799067, -0.00258131419735644, -0.00342032226620966, 0.132011178619608, -0.227738706732717, 0.212018681376458, -0.101123604922342, 0.735069464402225, -0.406133611428703, 0.258494822208368, -0.0978768097135355, 0.142792530306415, -0.243344599888119, 0.225266158072228, -0.107046130267053, 0.0034884821852522, 0.000784350551183088, 0.000777623744280604, 0.00244903953872554, 0.000793999307933833, 0.00355148076900442, 0.377375106660751, -0.0785454775264235, 0.0222526783512815, -0.245248734459552, 0.0227212856352968, 0.101630074704723, 0.0733078286669999, -0.0470623884943939, 0.0193921693138192, -0.0476413305733005, 0.0136139979708021, 0.0197423729662323, 0.408195327988216, -0.262054509821074, 0.107980185164327, -0.0849602859197393, 0.0242782715384178, 0.024070054377973, 0.0789442096360895, -0.0225591161468234, -0.00731385603414829, -0.0228366290826983},
    {-0.0295118525675891, 0.0190287287217081, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, -0.0161511787365524, -0.00384447375345892, -0.00275184717215811, -0.00368263832928282, -0.0157869230855841, -0.00392069343601919, -0.0028374251543411, -0.00382121421853439, 0.228014045330252, -0.2717151045485, 0.231653750460453, -0.105383312724627, 0.222871671150234, -0.277102067847941, 0.238857806241638, -0.109348835528473, 0.0432944250827251, -0.131942507994804, 0.157153073341714, -0.087758133526988, 0.0144481437637403, 0.0041263643667389, 0.00426585139537868, 0.00395489410044285, 0.00161349267462739, 0.00404388585725973, 1.02114857456486, -0.347362233990544, 0.122072685786528, -0.332927664119839, 0.0461721157239612, 0.115720863634553, 0.198365455024693, -0.165396976974349, 0.080315975618661, -0.0646735932737137, 0.0219849126185112, 0.0224796100611513, 0.193891742045087, -0.161666798236395, 0.0785046187846286, -0.0659557975662846, 0.0224207806119897, 0.0231786894608931, 0.243053648758977, -0.0826227979472465, -0.0337079263968607, -0.0323072000911187},
    {0.00567780449458316, 0.0161577642134766, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, -0.0313276643913105, 0.0110671468330951, 0.00284192495165225, 0.00234989003992672, -0.0106996359300076, -0.00356839426992841, -0.00278670080802794, -0.00384632070848083, -0.0380248596464322, 0.301987998765445, -0.169129303002116, 0.0672450495550816, -0.012986992883495, -0.0973703756382163, 0.165842790839071, -0.110067289214354, -0.00252281677407695, -0.0351937372957312, 0.0767569359401078, -0.0594783463215323, 0.0223195251484256, 0.00852158369598095, 0.0093678736775926, -0.00902659870223722, -0.00485135103202037, -0.00326290380377051, 0.609030388285103, -0.507138483772255, 0.268073449809222, 0.537193055045899, -0.138827491931281, -0.0933720830549341, 0.118308533258758, -0.183301116519788, 0.124072300702036, 0.104353614600787, -0.0501780777616424, -0.0181381986942383, 0.0404070414401217, -0.0626045781079557, 0.0423755958927611, -0.0336468690624237, 0.0161789816165828, 0.0177857381237385, 0.210453801737447, -0.101195988938319, -0.0543878465817397, 0.0576110360335688},
    {0.000689573107347638, 0.0121457494920626, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, -0.0393358416198599, 0.0414974536399691, -0.0117258358154838, -0.00286916224498869, -0.00561799280287624, -0.00244134318822821, -0.00207073274120003, -0.0029371393688188, -0.00443360677459502, 0.0139910499734395, 0.368517130449206, -0.0821046747156987, -0.000633213118742254, -0.000823109650176534, 0.0650785581277397, -0.0840499253371742, -0.00012300620257975, -0.000233473059959191, 0.0217631516226339, -0.0312299337797291, 0.0195246551264625, 0.00966161533660769, 0.0113416597229396, -0.023454981186099, -0.0160632387501086, 0.00917252921469169, 0.00658282380308271, -0.303643238348031, 0.324555812036961, 0.737138272909101, -0.459669715353957, 0.262483423099521, 0.00127876086944783, -0.0861276695976373, 0.108535861128071, 0.143194411238384, -0.130384202142739, 0.0509892927988105, 0.000182634184634556, -0.0123008586572028, 0.0155012238600132, -0.00842429281329376, 0.00767065339756562, 0.0090044922776178, 0.0673733265593301, -0.0613460913255657, -0.042013118813863, 0.10199297705579},
    {-0.00713114387718269, 0.00750148626092424, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, -0.0339007738939031, 0.0590785907491441, -0.0475981981984885, 0.0143524422502371, -0.00199428872932863, -0.0010641557716322, -0.000972023581156631, -0.00141352907516572, 0.0450881185414649, -0.127068618871477, 0.241702073048267, 0.4107131286806, 0.00265240926107721, 0.0022888292095454, 0.00493590353226533, -0.0404499066305404, 0.000515249575909612, 0.000540144332047427, 0.00127523875639662, -0.011086077739848, 0.00964665779284892, 0.00583119804449712, 0.00725319143528801, -0.0190441299503523, -0.0156762365286427, 0.0208939848046806, -0.0207484211610253, -0.0296106304241312, 0.207559166263658, 0.0967054607656754, -0.448595161601129, 0.597907570023055, -0.00403053003957291, -0.00698785830119739, 0.0536249323623453, 0.0187857312892301, -0.105864663432386, 0.116147845812616, -0.000237104930297345, -0.000411076369401699, 0.00315460639795218, -0.000338378829323267, 0.00190689200901612, 0.00237190585575588, 0.0030674313459014, -0.0172861296713001, -0.0142291329716039, 0.0464709748021343},
    {0.0284903632108099, 0.0031468891813878, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.017513023375429, 0.0403122421171739, -0.0494632043101822, 0.0360527643450903, -0.00033101667426378, -0.00020328633888384, -0.000196366252368405, -0.000291059369223357, -0.178725093630067, 0.48438729810939, -0.768528380851087, 1.03169505116885, -0.00337811380894428, -0.00244266543518649, -0.00305101620671766, -0.00832902875213216, -0.000656222903823798, -0.000509478771102146, -0.000658791463301679, -0.0018400929264185, 0.00196766105572185, 0.00136316239720275, 0.0017702065735656, -0.00510934349238255, -0.00475860988386885, 0.00842806911326783, 0.023643190562458, 0.0211799660893325, 0.0506566804146618, -0.0793857886114539, -0.136173587707136, 0.24117976396593, 0.00459285981587554, 0.00441760993533488, 0.0109380568162513, -0.015421260404849, -0.0284023964650369, 0.0468509037896236, 8.68104352411895e-05, 8.34980070344301e-05, 0.000206742097729591, 7.7766241817313e-05, 0.000143227438854009, 0.000185995560246202, -0.000752719569419469, -0.0013863354276103, -0.00129116969293885, 0.00483950370236174},
    {-0.00652877742132665, 0.0172198053622791, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, -0.00286607158261652, -0.00172596335485682, -0.00170726307853505, -0.00275019694120755, -0.0363180547067537, 0.0161122007935754, 0.00305654953686364, 0.00233062201042277, 0.00480559727387795, -0.0696229490571689, 0.116257872529598, -0.0787003334009246, 0.0608951799214982, 0.649943657200638, -0.208138951111157, 0.066693670734456, 0.00404544389461577, -0.0599894079180594, 0.10126879776982, -0.0690428357230214, 0.0065085739142844, -0.00331084397955432, -0.000888682878661306, 0.00449418520894298, -0.0032347101014882, 0.0062900104675074, 0.262546773541793, 0.225455398280341, -0.0254307747166693, -0.30603626219929, -0.0925652849176252, 0.179996535328407, 0.017441745692269, -0.0208093974068783, 0.012373195733733, -0.0203308788978238, 0.00854372002011944, 0.0119576932991251, 0.221016906233311, -0.26369084359981, 0.156789663691808, 0.189792675603336, -0.0797572741627938, -0.0214081135912333, 0.0766673450374757, -0.0322182004023549, 0.0231891952485375, -0.0314773329510054},
    {0.00858574731449881, 0.0157648753004524, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, -0.0132859312546022, -0.00313228338759675, -0.00220943154814895, -0.00286604561350591, -0.0295531067577097, 0.00943259119854767, 0.00266080533945936, 0.00226463927967879, -0.0231797827124802, -0.0726756131892213, 0.124780298683106, -0.0820154883984918, -0.0515609015277079, 0.218856107347192, -0.150272175335546, 0.064805492171514, -0.0034253406354173, -0.0283345225038208, 0.0689689653012088, -0.0561822573222246, 0.0267888501632131, -0.00978290406589536, -0.00387759279960796, 0.00722618325024979, -0.00370795971687476, 0.00716210674532238, 0.621558100379749, 0.552501249632886, -0.110962179307842, -0.408107372713323, -0.106107915976052, 0.204952663667212, 0.041291912193572, -0.0715303734534461, 0.0509272370439879, -0.0271117596075609, 0.0137374148224588, 0.0136156014808827, 0.0918493604928063, -0.159111523503952, 0.113282090987398, 0.0816446385611458, -0.0413689957486715, -0.0163971882951675, 0.231873293669398, -0.117489224878567, 0.0602870558259823, -0.0445312874461568},
    {0.00728244989005017, 0.0132117409898728, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, -0.0254704298617906, 0.00892944871598932, 0.00226644479881702, 0.00182882255572047, -0.019796806095659, 0.00237595918769125, 0.00101947993108515, 0.00100887627534118, -0.03118591248812, 0.0417262619381514, -0.0868398367617212, 0.0523340502310096, -0.0242391457778129, 0.0111025773900735, -0.0390618253060839, 0.0288702594494079, -0.00161027694513699, -0.00387808858029434, 0.0317985080969107, -0.0376349350795188, 0.0409818725101211, -0.00560828431610179, -0.0033444203034314, -0.0163822876805218, 0.00311575927800615, -0.00577891319567485, 0.191503462471457, 0.214883898684752, -0.0957047798901592, 0.627694611711972, 0.0891613579747629, -0.165370846131076, 0.0127221319331294, -0.07505813869161, 0.0779090376449025, 0.0416995784872783, -0.0311437274442793, -0.0109860662320211, 0.00988823433174064, -0.0583386862978686, 0.0605545379377078, 0.0110954774231801, -0.00828676301457336, -0.00494169284465339, 0.19138099827276, -0.142934721751187, 0.0271848592901342, 0.079409345237163},
    {-0.0111121414793535, 0.00978040546374063, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, -0.0315495982714479, 0.0331063769654702, -0.00927948168620293, -0.00223295070854486, -0.0102542626550717, -0.0012030832973753, -0.000725398750303253, -0.000833886962407466, 0.058257246828833, -0.126131012729572, 0.160899807538944, -0.063898683980483, 0.0189347929379126, 0.00458359170060361, 0.0125779136442868, -0.023862720875306, 0.0012578933601188, 0.00166566730191948, 0.00758070923223652, -0.0194939783441421, 0.0354479766349183, 0.00472287345005598, 0.00390727055762884, -0.0422408716007056, -0.00772207115915271, 0.0162454222693435, -0.135052204499447, -0.0818913657941363, 0.111811445560696, 0.732427557989168, -0.22097674739764, 0.464883125160772, -0.00897191069721773, -0.0297591450597261, 0.0673887642738488, 0.0486572926877848, -0.0803024716569531, 0.0308835379551549, -0.00291605389125918, -0.00967232885842999, 0.0219027222761858, -0.00176820242786555, 0.00291818589781662, 0.00241423827269637, 0.0520988018747549, -0.0859822306134806, -0.0157184470409662, 0.140584097846635},
    {0.0047641258220082, 0.00595231255869337, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.0268382683375482, 0.0466279404547276, -0.0373939339722441, 0.0111699141963799, -0.00359294678603303, -0.00126119637132599, -0.000974613380290933, -0.00126885446246866, -0.0275920932079781, 0.0681032668396038, -0.0986835027874707, 0.319641098476688, -0.00369386434939369, -0.00184206276700015, -0.00257202845525831, -0.0363098612093179, -0.000245394151048771, -0.00022743123124961, -0.000410933730046629, -0.00683041084421036, 0.0173265003015639, 0.00687907171497632, 0.00720440458057813, -0.0340478467842396, -0.0183200746196734, 0.0370052357530363, 0.0253065278441706, 0.0181540378518066, 0.206163069251945, -0.0898530971770406, -0.524251903161903, 1.05895121462285, 0.00168118623991431, 0.00224139766285654, 0.0329387331902803, -0.00596920255192246, -0.064727032084395, 0.0703492087783397, 0.000225067154909248, 0.000300064908350429, 0.00440964052015399, 0.000161455481944518, 0.00175074209144631, 0.00183354017309736, -0.0022180990369156, -0.0240519510403536, -0.0129415977638837, 0.0640542148802876},
    {0.0302538880961418, 0.00246776876963701, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.0137211579663085, 0.0315457931627578, -0.0386364416503144, 0.0280583803965707, -0.000590197519305841, -0.000319772383935452, -0.000291122581602883, -0.000414169528781321, -0.184397876468037, 0.480186648330888, -0.713797405978017, 0.802925731904298, -0.00793163153750736, -0.00486754060925032, -0.00537840791475004, -0.0118519803113754, -0.000526921349425685, -0.000394510258857444, -0.000478814744853815, -0.00112200145901501, 0.00350406908242333, 0.00214037926285281, 0.00261482209238977, -0.00908234190642531, -0.00744444616732405, 0.0149269125729192, 0.0533385602171294, 0.0395429056190286, 0.0748264123822477, -0.167793715365594, -0.213032160197368, 0.427152317178935, 0.003543435671857, 0.00320492075650961, 0.00666144891220982, -0.0111470244813417, -0.0172660855678774, 0.0283769706540019, 0.000152416213593943, 0.000137855440824552, 0.000286533442193607, 0.000112994800092675, 0.000175022302174784, 0.000213818265916782, -0.00123819818524027, -0.00191789619302756, -0.0015720257077527, 0.0066706285242544},
    {0.00254449201900157, 0.0124299526187294, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, -0.00204964204175446, -0.00121893362021495, -0.00118292063155355, -0.00183063682142868, -0.0430586021516741, 0.0506272851755829, -0.0189383076837501, -0.00284867343610868, -0.000856872010173902, -0.00161605386869112, 0.0393067632837014, -0.0523859677188016, -0.0180010510271378, 0.0671213089149897, 0.62929291895221, -0.0815183617627337, -0.000480145834420587, -0.000964790796582444, 0.0241807101537084, -0.0328660874700562, 0.00762045121549465, -0.0102064605800902, 0.00528980646672272, 0.00516240990083403, -0.00957976934285647, 0.00694122508762249, 0.010103142175862, 0.339146109455536, 0.151374443887892, -0.171539508681193, -0.274137109924834, 0.198631858112276, 0.000269483244227716, -0.00487483111382489, 0.00581659421565785, -0.00457550953039682, 0.00394040230937928, 0.00529814948649659, 0.00566126746200268, -0.102409791178523, 0.1221942227509, 0.190039573917173, -0.163660980479209, 0.084822246271929, 0.0286048777260459, -0.0246343550379301, 0.0457134252619631, -0.0231217705022784},
    {-0.00481040329364104, 0.0112741294025221, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, -0.00942285779415139, -0.00219692843858366, -0.00152363049106577, -0.0019077501517671, -0.0347488262460902, 0.0337592671031061, -0.00742856718436098, -0.00228007999607857, 0.00736457670424299, 0.00438882359425981, 0.0397000546457263, -0.0545926623435964, 0.0271584695282763, -0.0674411898835215, 0.193560397279989, -0.0652473476293614, 0.000724403591411487, 0.0011799793927647, 0.0153905329075907, -0.0265233404201762, 0.0311498025027812, -0.0344250066126234, 0.0104494503526853, 0.00826141494223279, -0.0125944886537096, 0.00790361085687712, -0.0622282391086319, 0.896985621982871, 0.299024122342194, -0.215261263528708, -0.360407082565477, 0.226171733444769, -0.00165982695934204, -0.015694037299372, 0.0237762510293563, -0.00574170912796159, 0.00630583373704114, 0.00603272639544609, -0.00612097092715936, -0.057875157105101, 0.0876800683880994, 0.0882304078161751, -0.0968990713114824, 0.0294129801131075, 0.0814105285467179, -0.0894091368997133, 0.136303813341332, -0.0327105924159354},
    {-0.0117698440494142, 0.00930958844834864, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, -0.0178289300066307, 0.0061951305077516, 0.00155135505195025, 0.00121733460618684, -0.0229736761944516, 0.0147838058786252, 0.000390512398712735, 0.00021655888196964, 0.0354164151936633, -0.0239832387341911, -0.0228191073912388, 0.0348355559312484, 0.0456362358439275, -0.0572326192875784, -0.00574410374506561, 0.00619710390792792, 0.00121726495336652, 0.00152574562586522, 0.00579711893708317, -0.0175355170299285, 0.047137220592618, -0.0344284557477549, -0.00124580290150381, -0.0185903243576046, 0.018600463150744, -0.00637721311597528, -0.182482550339248, 0.506413169593175, -0.0356502118925021, 0.273447788383992, 0.532275572502241, -0.18249194844047, -0.00486739559083189, -0.0135003025897688, 0.0359792454393944, 0.00729373058973922, -0.014189759906314, -0.00486764626837002, -0.00627193949230218, -0.0173959727313479, 0.0463614773369989, 0.0174054601488665, -0.033861862257262, -0.00122530056414627, 0.0554961977510377, -0.107966384569833, 0.108025267288505, 0.0583303756759747},
    {-0.00224468746929324, 0.00677269421349492, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, -0.0217460457985155, 0.0226775867458488, -0.00629687867371577, -0.0014863378423011, -0.0117175620738285, 0.00293737332109405, 0.000940361805028289, 0.000794793321731308, 0.00967279417619892, -0.0153043533659059, 0.00875331817503942, -0.0425334207826388, 0.00521205405511997, -0.00198233611792225, -0.00130720099680906, 0.0227440073355647, 0.000139022218178692, 0.000137145944198052, 0.000282495939903845, -0.00894386721374996, 0.0402552930537988, -0.0114231579753207, -0.00496853616119764, -0.0475204821291955, 0.0183210544613897, 0.0179273362417272, -0.0271669660730639, 0.0158793811192679, -0.142180891317948, 0.0660584269543605, 0.524279942561051, 0.513013202099966, -0.000724630221544249, -0.00109859912110435, 0.030726357023354, 0.00176199036837866, -0.0362717841321438, 0.013683709446727, -0.000390457174614245, -0.000591965248075886, 0.0165564810752098, 0.000228226378675326, -0.00469819704416934, -0.00204349462353746, 0.00312773309752846, -0.0643865379587122, 0.0248235963876552, 0.103266475966667},
    {0.022525727078752, 0.00405256796561407, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.0182236775617251, 0.031548126909923, -0.0251644118483799, 0.00743512434099125, -0.00404462887250186, -0.000558857812258985, -0.000340541187058629, -0.000383710664554888, -0.118755279768057, 0.25582760745598, -0.289712660115728, 0.212765404450057, -0.0263569760650689, -0.00453184613547785, -0.00392058013420667, -0.0109803617251883, -0.00070302518705649, -0.00057493029574242, -0.000816247856153994, -0.00308721416081533, 0.0194350005513991, 0.00303184316836324, 0.00248993575190853, -0.0379858317474887, -0.00798650751792727, 0.0408364456798986, 0.157600788983966, 0.0349049822683104, 0.0712526331790851, -0.43732301110713, -0.228543925328445, 1.16858608987676, 0.00420371911717646, 0.00442820236576486, 0.0148344905822271, -0.0116648090026963, -0.0289941058569006, 0.0311699434866482, 0.000932988616355287, 0.000982811240003288, 0.0032924204631315, 0.000206635711155888, 0.000513614726283467, 0.000421811946945231, -0.0071860231210132, -0.0178616139374969, -0.00375539793211271, 0.0470512180454073},
    {0.0278235382849622, 0.00165731029056242, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.00920510912404796, 0.0211331468589337, -0.0258282524616005, 0.018676736758009, -0.000656420170570475, -0.000300087035939484, -0.000253714313457375, -0.000343356021220645, -0.164115051478879, 0.408587395180542, -0.565496681950333, 0.534458237398515, -0.0117031127641394, -0.00580187045310393, -0.00555494811880207, -0.00982556301346896, -0.000312159597513818, -0.000224404254493856, -0.00025412379430533, -0.000501037229845113, 0.00389172137830524, 0.0020043436996065, 0.00226908998258687, -0.0100656565735361, -0.00694151636999078, 0.0164723191745265, 0.0752423816171071, 0.0438841037852108, 0.0649328546150945, -0.220382521134524, -0.198640193522425, 0.471376064563758, 0.00200695593001059, 0.00169734565320807, 0.00297050180073007, -0.00587830951327899, -0.00768298859828471, 0.0125731132868097, 0.000143116864357715, 0.000121038426398265, 0.000211827722239695, 8.34709799706157e-05, 0.000109097111329792, 0.000123507341827686, -0.00108250526785389, -0.00141484139474417, -0.000975708303854636, 0.00489993043832004},
    {-0.00396719586028169, 0.00700570982272353, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, -0.00114511302775327, -0.000673043912202123, -0.000641631662811045, -0.000957221224723092, -0.0331231875874077, 0.061426398524528, -0.0546792511962836, 0.0212151322982278, 0.000881675779233269, 0.000801959357219119, 0.00164117293051679, -0.0273920854159158, 0.0255030826818176, -0.0731920669423039, 0.139859224732048, 0.607097608174253, 0.000258330833524191, 0.000259692769779538, 0.000557467377202732, -0.00960126525101314, 0.00579356513688975, -0.0121650083715792, 0.0147231629685927, 0.00385553391728557, -0.0110070831616924, 0.00499744607324108, -0.00690326988915834, 0.0311157999146768, 0.421321766809783, -0.0098617295007208, -0.314981484277462, 0.143008184695501, -6.99259570599418e-05, -0.000110401968428172, 0.00167935394144989, -9.98933671546898e-05, 0.00111758579171931, 0.00144858658908371, -0.00202265674810749, -0.00319345341606722, 0.048576476103361, 0.00911692338279001, -0.101998203955028, 0.123447196538076, 0.000859882570604187, -0.00962018371015583, 0.0274644613171983, -0.00870448740305289},
    {0.00163104362451014, 0.00630096536900633, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.00522532202805528, -0.00120559810201211, -0.000822987370205683, -0.000997542994527461, -0.0265321488636248, 0.0418649924033506, -0.02853545950724, 0.00502315034416631, -0.00176946150425561, -0.00059599685033843, -0.000775277112656368, -0.0285459434103636, -0.00898463593005344, 0.0206962864077098, -0.0268812006793832, 0.143743744633529, -9.10089387106945e-05, -8.65533292723503e-05, -0.000164932469374737, -0.00769075132780618, 0.0235366042308365, -0.0420202768766619, 0.0388570541739825, 0.00614426323170641, -0.0148820249349658, 0.00569033110762508, 0.0116355043739915, -0.039584275663694, 1.11194332036726, 0.00578806775186377, -0.425867801143153, 0.162835958625975, 0.000117860635943996, 0.000165544232333859, 0.00682244665408614, 5.86296325620587e-05, 0.00178100917684906, 0.00164942997065816, 0.00059845037707407, 0.000840569096452969, 0.0346417252885993, -0.00203594308727168, -0.0618464275405144, 0.0571907222901663, -0.00114461233433286, -0.0347702174190698, 0.0842169716874309, -0.012314322538702},
    {0.0126104679035144, 0.00513339611045792, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.0097696798371992, 0.00336641557499319, 0.000832405683526283, 0.000636531784454402, -0.0173335456893195, 0.0196253949660865, -0.00679385676003022, -0.00110709786801719, -0.029589600960712, 0.0136392839755106, 0.00544335694053327, 0.0182151550335338, -0.0524984143521611, 0.0795137525688747, -0.0444271201886024, -0.031680993464476, -0.000531777248558377, -0.000465575059279192, -0.000751445762371034, -0.00502439475260474, 0.0352681842662437, -0.0451290574006877, 0.0211211319918737, -0.0137344939427511, 0.0237601277454773, -0.00459137662910269, 0.14289168101562, -0.295112794978876, 0.604407671559529, -0.0898140827333987, 0.679925843563978, -0.131387998461278, 0.00144740647712996, 0.00172796720790302, 0.0102230255215699, -0.000909762444964141, -0.00398115426194425, -0.00133088111664927, 0.0025680151980843, 0.00306579120779279, 0.0181378799422369, -0.00530369673915515, -0.0232091739926471, 0.0108622704650948, -0.00953110774137433, -0.0417084816104073, 0.0721540127553239, 0.0219592189204033},
    {0.0253972624653877, 0.00367511242526292, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.01174846789109, 0.0121800061564543, -0.00335222048188704, -0.000777190818575029, -0.00871645838744101, 0.00519517947069498, 0.000292876250127181, 0.000165965533134036, -0.0936105122386032, 0.117950744221066, -0.0442674609131471, -0.022240289639452, -0.0694517908308401, 0.0503099322824041, 0.00386755227615334, 0.00474931180199933, -0.000703504718975498, -0.000562698709719869, -0.000767316927102084, -0.00252659949488245, 0.0297697731931803, -0.0200255369950427, -0.0015199192167782, -0.0348329254516797, 0.031546510726741, 0.0129070725951029, 0.288289419424248, -0.264445516332456, -0.0434943939143451, -0.45998321836361, 0.902742954379207, 0.369352063935649, 0.00292019780295725, 0.00295772910200319, 0.00862922652404651, -0.00465935234926491, -0.0100968590612786, 0.00374131346123166, 0.00216656187585743, 0.00219440720934253, 0.00640222151602397, -0.0019873694118626, -0.00430664765188626, -0.000326870461831684, -0.0113881603082127, -0.0246782473142256, 0.0223499055425409, 0.0388759908814477},
    {0.0300055156673331, 0.00216464827329579, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.00970937438415811, 0.0167516558155945, -0.0132940824930264, 0.00388775028686336, -0.00296712446719293, 0.00018571266497243, 8.46394591315027e-05, 8.15846378219161e-05, -0.145766077772663, 0.28016483684933, -0.262749987106196, 0.111252848540127, -0.0445452074184815, 0.0031059710786577, 0.00167285081968751, 0.00233464669412111, -0.000451216062995031, -0.000332623551692503, -0.000393080450660099, -0.000860066651710821, 0.0142092312311995, -0.00100238451978034, -0.000612533599599499, -0.0276309035962125, 0.00261350337251332, 0.0294008525198292, 0.237643788379267, -0.0198115605034005, -0.0175284168873231, -0.54610911038394, 0.0747886755596983, 0.841342254771774, 0.00240718813093275, 0.00212165260149828, 0.00411876416494382, -0.00553175564855263, -0.00800924228238437, 0.00852228919405439, 0.000735621731929472, 0.000648363848762852, 0.00125866873032954, -6.13263008014005e-05, -8.8792280897128e-05, -5.42588740761064e-05, -0.00469219258024635, -0.00679366725474123, 0.000642587464437821, 0.0177130351991935},
    {0.0191690324088707, 0.000873918129073732, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.00484906798185391, 0.0111175665009621, -0.0135601345036651, 0.00976587416141851, -0.000476116367454645, -0.000179485226862444, -0.000140724751873762, -0.000181253151723277, -0.109706187629544, 0.262185091653747, -0.340572586312384, 0.279462732628028, -0.010771742474417, -0.00423279236974586, -0.0035344039316796, -0.0051867861740599, -0.000109111249280843, -7.56002252730326e-05, -8.05138366820024e-05, -0.000138009650255377, 0.00281896164772159, 0.00119640185951776, 0.00125348284007985, -0.00727633935672291, -0.00412667615030053, 0.0118595097748234, 0.0664794510482461, 0.0300484980775636, 0.0358699829632347, -0.182750526031733, -0.118090011664295, 0.339374740501438, 0.000673396711126592, 0.000536684303255013, 0.000817119380216148, -0.0018511525177472, -0.00210915884939895, 0.00343766126960384, 6.61189319590602e-05, 5.2695524561315e-05, 8.02306572192782e-05, 2.9885544608851e-05, 3.40508738617958e-05, 3.56754594920384e-05, -0.000469376814715843, -0.000534796702578388, -0.000303302620945684, 0.00184464173156601},
    {0.0302387678330057, 0.00234316248688228, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.000380508993873727, -0.00022170412581773, -0.000208599314241434, -0.000303030395125607, -0.0132630858830492, 0.0312018466643443, -0.0394682247241062, 0.0302540966567126, -0.0053561132654389, -0.00351055389355514, -0.00396473437419395, -0.00867159466642658, -0.186693590381845, 0.494062814074892, -0.750151206494619, 0.865758905462842, -0.000496810721561533, -0.000369581508087661, -0.000443618433201196, -0.00100999427280185, 0.00229970513974528, -0.00609865929245082, 0.0103483935384561, 0.00151045400183975, -0.00537329878448927, 0.0019064168838635, 0.0364144726787385, -0.115913919569766, 0.296132254907867, 0.0287083824964374, -0.153763681235287, 0.0545545092110109, 9.69026328638942e-05, 8.67088960805917e-05, 0.00017512432934205, 7.63959394307883e-05, 0.000115022243288039, 0.000145175123742227, 0.0033776545696932, 0.00302233995531932, 0.00610416325940233, -0.0107516916029519, -0.0161878196213957, 0.0274679925437239, -0.000792444136599975, -0.00119310925359821, 0.00424437453528175, -0.00105120358339449},
    {0.0298426277029342, 0.00209472514255057, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.00172706393075763, -0.000395389812588072, -0.000266770877594616, -0.000315795178772714, -0.0105672909703009, 0.0213868154213816, -0.0217703682626918, 0.0112777292031759, -0.0265751876169889, -0.00675219580951283, -0.00535145363896165, -0.00903687495372643, -0.162604137077821, 0.36522935308263, -0.436716022046421, 0.32272636006408, -0.000432706224703824, -0.000317855761650141, -0.000373373839063357, -0.000804707400159051, 0.00930170605810017, -0.0212166270111519, 0.0289520555433689, 0.00239999837307262, -0.00733851328906375, 0.00217073744055722, 0.158848151032727, -0.425607910612668, 0.828499366632536, 0.0481442357685091, -0.210000758077653, 0.0621183733200973, 0.00042271116202697, 0.000370402667393225, 0.000708332127892936, 0.000128116731068725, 0.000182761736816954, 0.000165303339061025, 0.00258641951000172, 0.00226636240431707, 0.00433403278578942, -0.00692989245680946, -0.0098856657580707, 0.0134899078897135, -0.00301399817492402, -0.00429954414710405, 0.0131467846872086, -0.00148714787906017},
    {0.0280378223106106, 0.00169002122151257, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.0032014158128402, 0.00109628782576139, 0.00026854825948324, 0.000201508776833697, -0.00684455236573055, 0.0102186321500795, -0.00632708254785036, 0.000743550878448221, -0.0564738728270902, 0.0210073440323391, 0.00584313287859416, 0.00576642628111646, -0.120739823396357, 0.195812008554932, -0.137666072131895, 0.0212776405782486, -0.000321301008031801, -0.000231343120081739, -0.000262683898321762, -0.000521217969199446, 0.0138399924095756, -0.0232788254452491, 0.0193014916091437, -0.00533944176444626, 0.0120265244814161, -0.00175151023094881, 0.265205427918547, -0.506505871964673, 0.552336380720342, -0.116176763860625, 0.3441540757173, -0.0501216611310329, 0.000705738744092801, 0.000598414007520628, 0.00105392615206972, -0.000309158240324351, -0.000406602630006541, -0.000133378862024143, 0.001508852980326, 0.00127939519584897, 0.00225326954047079, -0.0028817015566566, -0.00378999256368274, 0.00314244848129001, -0.00390294190895962, -0.00513312031819359, 0.0115618073754226, 0.00265192061850382},
    {0.0235888506057284, 0.00119584539165627, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.00381032346110905, 0.00393303420879124, -0.00107536568428446, -0.000246037629294018, -0.00340656404721312, 0.0029025345964174, -0.000401013389645343, -0.000146155552097277, -0.078445661197035, 0.0857621692652028, -0.0255955981627664, -0.00704067522019324, -0.0701331978298506, 0.0632915073048822, -0.00954482528990477, -0.00418242435882037, -0.000186631606087847, -0.000131248572870772, -0.000143263535890453, -0.000259412493288289, 0.0115838154219245, -0.0111148703955158, 0.00205374017223561, -0.0134650954278904, 0.0172791285751942, 0.00492376721147836, 0.252592041211182, -0.264553500667241, 0.0587703498073264, -0.320492997714484, 0.494463927062682, 0.140899771694796, 0.000672173233147303, 0.000548608666298236, 0.000882116525256826, -0.000852864616960336, -0.00102537745625867, 0.000374948690527646, 0.00060094666316622, 0.000490475566622459, 0.000788643397617887, -0.000629404405192889, -0.000756716922147399, 0.000139821688127879, -0.00251190957878626, -0.00302000505476225, 0.0038754315495525, 0.00469488656026294},
    {0.0161601125382384, 0.00069621755786608, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.00311691852162241, 0.00536405680022621, -0.00424076416664773, 0.00123075677299021, -0.00114779903153439, 0.000243419538752937, 8.31834643461069e-05, 7.02142929651446e-05, -0.0741443373095673, 0.131860036949592, -0.10956139003762, 0.0352196480617275, -0.0273035043961888, 0.00598377507353535, 0.00214906927708197, 0.00200927002101712, -7.26574152465036e-05, -4.99388244904222e-05, -5.24846012754078e-05, -8.74057861345095e-05, 0.00548279610120525, -0.00130887565395662, -0.000597423305482677, -0.0106212767903116, 0.00338668826964628, 0.0112157851875393, 0.134778903993248, -0.033815187640404, -0.0170960168773589, -0.274403811056705, 0.0969143307348484, 0.320953754397271, 0.000358660436104022, 0.000282211597182745, 0.000417519173892658, -0.000730216581573638, -0.000808818462207997, 0.000854090737576376, 0.000132075990550824, 0.000103923858030999, 0.000153750603397717, -3.31370434908453e-05, -3.67039769223039e-05, -1.67531660864908e-05, -0.000746380729286214, -0.000826722549058185, 0.000263607814241949, 0.0021391272354127},
    {0.00734348804657573, 0.000278404956314847, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.00154360799326988, 0.00353550741513572, -0.00430576776528935, 0.0030916120844874, -0.000182636570873398, -5.79074942609525e-05, -4.27474677585172e-05, -5.29819689255254e-05, -0.041112154247716, 0.0953904978590436, -0.118457806464409, 0.0884703557588251, -0.0048643068096026, -0.0015623852699814, -0.00117604374843896, -0.00151614546442342, -1.29444174866391e-05, -8.73387187564414e-06, -8.905668760093e-06, -1.39079164693019e-05, 0.00108025695398448, 0.0003854142182657, 0.00037961692094957, -0.00278416799838691, -0.00132537357759305, 0.00452414480070681, 0.0291460988640958, 0.0106032943169837, 0.0108632141195971, -0.0765964287661005, -0.0379272265467476, 0.129464075403039, 7.75607474137723e-05, 5.92733532524989e-05, 8.22624045639264e-05, -0.000203830924063669, -0.00021201655162935, 0.000344517134121651, 9.17683051892079e-06, 7.01310308699294e-06, 9.73312106881813e-06, 3.33851316935608e-06, 3.47258421647061e-06, 3.42035053586834e-06, -6.22795393425835e-05, -6.47806177063614e-05, -3.08381243861602e-05, 0.000222769464589274},
    {-0.0125131983511541, 0.0112128454303619, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, -0.00226985035225307, -0.00179692337955246, -0.00280290297783918, -0.020199909014669, -0.00250226696008482, -0.0019507352378507, -0.00302124952471555, -0.0216728867138269, 0.110772181805886, -0.208071106282044, 0.201984382314542, -0.0990472496003531, 0.12211446906808, -0.22588143914298, 0.217718994875168, -0.10626977667799, 0.684912572298823, -0.294334759695953, 0.183176207073003, -0.0688168296738452, 0.000589501209135609, 0.000632108757277153, 0.00392988617312099, 0.000641888290245382, 0.00276290821881119, 0.00401918370631304, 0.0682600995319013, -0.0455513793747795, 0.0192696123733745, -0.046256117619921, 0.0135475095344599, 0.0197074695465101, 0.382855534749969, -0.0593557148961157, 0.0162123406290092, -0.259440152714044, 0.0176530793252999, 0.110534761061572, 0.422057231279378, -0.0654333199232001, 0.0178723695424867, -0.281647539217126, 0.0191641359271616, 0.119145434915934, 0.0851123010939679, -0.00579129401155831, -0.0249277235077282, -0.025313387352849},
    {-0.0273770165770783, 0.0164398153896086, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, -0.016455224270786, -0.00492616592994077, -0.0051412964693963, -0.0210508054013366, -0.00318431349806175, -0.00243126567889089, -0.00354041384624262, -0.0177795380457134, 0.180416762354003, -0.246495727242803, 0.220428635877593, -0.103219493481902, 0.0349131389634354, -0.121655788733429, 0.151792179115675, -0.0871793205263413, 0.195819938431222, -0.223629290575918, 0.191612435862306, -0.0875743328428926, 0.00366524434684601, 0.00373089742608162, 0.0162853332138361, 0.00146285721496204, 0.00446348462723358, 0.00457643479011281, 0.18340167254765, -0.159958997720859, 0.0798527093604427, -0.0627187368589138, 0.0218860330331134, 0.0224398673581594, 1.02865870250385, -0.29403875930584, 0.100800793821525, -0.351775278729851, 0.0402311973122852, 0.125860165397376, 0.199059686904238, -0.0569005669447604, 0.0195063478381804, -0.173615581371305, 0.0198557520467496, 0.086670176465348, 0.261733439364735, -0.0299334554728396, -0.0913332599904371, -0.035811093976741},
    {0.00769851183855554, 0.0241754756606097, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, -0.0533456433751072, 0.0225203407828073, 0.00770119898836338, 0.01343251047807, -0.00360710415218166, -0.00266909142798141, -0.00355083307641818, -0.0120625997765331, -0.0489992445747, 0.267079884396059, -0.160437252917034, 0.0658643173647257, -0.00331321111484885, -0.0316540782798458, 0.073973663738371, -0.0591471639811747, -0.0185830554278954, -0.0843456371815979, 0.148164197799284, -0.0992018341832284, 0.00899172423205335, 0.00848823481059457, 0.0251793692370998, -0.00484271172850327, -0.0101935082532454, -0.00369260335515124, 0.106637314753757, -0.176833383630821, 0.123463292225494, 0.100887065451003, -0.0499823516793697, -0.0181061313655987, 0.598104697243668, -0.471191240681805, 0.247288544676479, 0.565852843131988, -0.133183258819302, -0.101553215623277, 0.0404424016727429, -0.0318608188635711, 0.0167210568633937, -0.0670643924827068, 0.0157847653325304, 0.0468236851945558, 0.225928762376926, -0.0531762439644613, -0.111931601986109, 0.0638592703693537},
    {-0.000692705759853929, 0.0299005753431563, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, -0.105804882736616, 0.125936349182971, -0.0430093491732373, -0.0164007895111113, -0.0029916940953509, -0.0021386837625817, -0.00258304136084933, -0.00634120372040314, 0.0043623042865788, -0.0132065134800397, 0.346278038065547, -0.0804188321427699, 0.000123346670198206, 0.000224276439037035, 0.0207966526318344, -0.0310931493406901, 0.000691823711102583, 0.000808339326836455, 0.0620609909795394, -0.0822769537703657, 0.0117309116645637, 0.0102295585373869, 0.0220482695108046, -0.017032284117612, -0.0265051855745516, 0.0103804813719163, -0.00123018051608064, -0.0823604990239475, 0.108110410393762, 0.137130787640276, -0.129964235452737, 0.0508991465589971, -0.00689980563393292, -0.296844513069609, 0.32262111230204, 0.769135723398207, -0.468418363737866, 0.285481857011572, -0.000195095984610597, -0.00839344984860786, 0.00912229806172762, -0.0130616624471412, 0.00795480220858041, 0.0171453755662, 0.0716446307025764, -0.0436329501586935, -0.0679004315061565, 0.113054677471619},
    {-0.00630648166263273, 0.0274659679169433, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, -0.130480475709523, 0.243240342500804, -0.217371432971372, 0.0820418520171365, -0.00151964692640047, -0.00105291633395806, -0.00116741866689636, -0.00225357922813264, 0.0395383094710886, -0.109983778158357, 0.203317202134924, 0.402280019603826, 0.00046048475939467, 0.000476087623059346, 0.00109193877884002, -0.0110500905791671, 0.00258275537263001, 0.00213506992707137, 0.00441662708652146, -0.0417930162395376, 0.00786323208030544, 0.00639960141743296, 0.0109037695623235, -0.0172183619845815, -0.0215344921497768, 0.023645563287244, -0.00355544628755466, -0.00598583280785831, 0.053465012374061, 0.0161051023871781, -0.10559117951605, 0.115942502867309, -0.0199416979909374, -0.0268441585068068, 0.216252986347212, 0.0903298944614682, -0.473535838844077, 0.650295403023377, -0.000232251912742798, -0.000312641740036683, 0.00251860045911438, -0.00039101170613943, 0.00204979821318829, 0.00349248740788506, 0.00292009506579956, -0.0153079960375441, -0.019145254397281, 0.0515110081076783},
    {0.0287678230747216, 0.0152327680704991, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.0864392103719315, 0.204225002221374, -0.260674168295516, 0.206085870657986, -0.000323458282953216, -0.00021884980746384, -0.000227625898028499, -0.000374392247515995, -0.179978494886956, 0.485949924576904, -0.76622985466315, 1.01051141642987, -0.000673485269869356, -0.000520749400288648, -0.00066908723600984, -0.00183577670380737, -0.00377742729515863, -0.00269364658708946, -0.00332750776727581, -0.00889568296255182, 0.00197351752822286, 0.00152661443863601, 0.00222573096474407, -0.00533088841509592, -0.00578037173244179, 0.00953798155162817, 0.00469595144355359, 0.0044873551034667, 0.0109135407614042, -0.0156696993884497, -0.0283431930980596, 0.0467680739919019, 0.0263385347137003, 0.0232114501770191, 0.0542752718892442, -0.0878878170391844, -0.146608993334405, 0.262311600776789, 9.85596371986647e-05, 8.68579870968417e-05, 0.000203099798998328, 9.41815724238378e-05, 0.00015710784485105, 0.000229055736824791, -0.000849299280487191, -0.00141674826781009, -0.00153620391228584, 0.00536437454800375},
    {-0.0251141783214144, 0.0170982512251828, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, -0.00335839069175039, -0.00254526063085192, -0.0036702849086762, -0.0177284701790032, -0.0187003136617075, -0.00453904348042331, -0.0044748398526153, -0.0171592587463127, 0.0293790293907047, -0.114578371119061, 0.148172383047726, -0.0869289168370504, 0.163589384055956, -0.204331219412855, 0.180652919655244, -0.0841378732334324, 0.159427677701374, -0.212238483655012, 0.190336131394753, -0.0893615104409751, 0.00421763175802369, 0.00135971169586764, 0.00390122508841129, 0.00424553498359208, 0.00398337890666887, 0.0178172618556883, 0.189862433322843, -0.0548926656233985, 0.0191290770071508, -0.171395695833932, 0.0195319060365618, 0.0873642936180388, 0.185032341811612, -0.0570169166961806, 0.0201544183268212, -0.167035397269227, 0.0202877569663798, 0.0851417500342238, 1.03030384104418, -0.317483677185369, 0.112224567947569, -0.297879486990314, 0.0361797962355781, 0.103805482586355, 0.276786505750101, -0.0336178884956983, -0.0315420290818578, -0.0984861631531846},
    {-0.00383082689433903, 0.021438292355929, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, -0.0209027123750645, -0.00602728243276232, -0.00589038572642271, -0.0184752602365971, -0.0204312959399314, -0.00614677799527294, -0.00607356716536554, -0.019170475293716, 0.0135858929586521, -0.128120058977522, 0.160325430484325, -0.0905906908173123, 0.0132794918987442, -0.130660138804077, 0.165311291244429, -0.0939995744532916, 0.0129416622398114, -0.133170339698606, 0.170518145142878, -0.0976332000889081, 0.0226514859192027, 0.00883256817957503, 0.0214011552624065, 0.00846553253191387, 0.00809465779372041, 0.0202875864800225, 0.481495556956455, -0.240406207919515, 0.1049373819195, -0.230416174847411, 0.0396909506048682, 0.0994771630117902, 0.469246332285472, -0.245024815275158, 0.108242622668801, -0.224554398029832, 0.0404534804829545, 0.0969464685915432, 0.458663474463193, -0.23949879918387, 0.105801439419834, -0.229006363638902, 0.041255502199997, 0.0999613464691264, 0.843911139358477, -0.152030613093807, -0.145370156280726, -0.139329327795018},
    {0.0115162223864432, 0.0272195064369147, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, -0.058857340988391, 0.0241488423712533, 0.00787093469350955, 0.0117890561421181, -0.0201021088746972, -0.00778634204845774, -0.00771798708392575, -0.0192964308977999, -0.0568368116107849, 0.109442245504125, -0.114072987754541, 0.0578058834528902, -0.0194120182105409, -0.035287602815314, 0.111856327157735, -0.0946171790250352, -0.0189181773662324, -0.0353243681982647, 0.112964564404558, -0.0960601434065916, 0.0487018653261889, 0.0236011963360774, 0.0469972581018548, -0.0249998751193354, -0.0243385216796771, -0.0163695132433428, 0.220716232256439, -0.3420507329146, 0.23044406538496, 0.36232170122116, -0.119340321283625, -0.0802654736153619, 0.215101221529172, -0.342407108105344, 0.232727232578612, 0.353104253921159, -0.119464659358852, -0.0782235236836697, 0.0734655711869932, -0.116945564495709, 0.0794855508053785, -0.113851854988648, 0.0385191424984337, 0.0767034880809725, 0.712118434341346, -0.240928805691316, -0.234555210079491, 0.248455666275406},
    {-0.00801784374588152, 0.0302616520385567, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, -0.105632026424746, 0.123383715498899, -0.0408731176137139, -0.0143941691791135, -0.0150864946514284, -0.00725880667245084, -0.00721801875870362, -0.014735200510621, 0.0450891617645783, -0.110330824686386, 0.228755234415404, -0.070579667781574, 0.00643968899227076, 0.00649089001066516, 0.0403972016220275, -0.0722518641953719, 0.00627586360252852, 0.00641766861494253, 0.0401671985659729, -0.0720924778963432, 0.0580523449520112, 0.0336777988542341, 0.0568994552709837, -0.0817577714486637, -0.0805869296995664, 0.0460172433773114, -0.051910927367, -0.188485078243955, 0.278998016488917, 0.457575033785653, -0.395146024404499, 0.225638708936901, -0.0505903157787709, -0.186358845866078, 0.277409530310443, 0.44593434611638, -0.39068852421984, 0.219898470630843, -0.00722537050781885, -0.0266159973122156, 0.0396199669450187, -0.0262348332920278, 0.0229846576996804, 0.0388331348008336, 0.209813218721952, -0.183819922143654, -0.181187462435566, 0.439859006441802},
    {-0.000295237250846836, 0.0258677865545684, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, -0.121961990153499, 0.2250337245264, -0.197896745384657, 0.0720041127838629, -0.0071746864284226, -0.00405343007898561, -0.00404133581582014, -0.0070914695336831, 0.00176428765404614, -0.0045625870305464, 0.00724460448462811, 0.353061458146974, 0.000103788161142466, 8.21838039899694e-05, 0.000147945230318233, -0.034771966172023, 0.000101147795129432, 8.06363412490286e-05, 0.000145593936763928, -0.0342850300686168, 0.036744670189816, 0.0242440923895312, 0.0363882052297271, -0.0791788655558158, -0.0786453959092753, 0.104822079207859, -0.000745002803480235, -0.000887527786824229, 0.178424152469219, 0.00289858008214602, -0.385626002220497, 0.513979475619877, -0.000726049966660536, -0.000870816268069384, 0.175588457403319, 0.0028248403390886, -0.378364938100432, 0.500903861562423, -4.27115106566575e-05, -5.12277116195477e-05, 0.0103293831195581, -5.08825635929779e-05, 0.00681531545619466, 0.0102291763923664, 0.000461254537812507, -0.0617813836177235, -0.0613651299539449, 0.200412591091128},
    {0.0299453386201051, 0.013710902622998, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.0775772130015775, 0.182572154863326, -0.231653156327066, 0.180871468758637, -0.00146630027813821, -0.000920673795231205, -0.000919650531979578, -0.00146020247167441, -0.184439512927778, 0.48729939001709, -0.741538613135988, 0.886876346755305, -0.0034861230333213, -0.0024573505152346, -0.0029438682850975, -0.0071598856496811, -0.00339743622479548, -0.00240040868105136, -0.00287885247894111, -0.0070068775307635, 0.00891143980381022, 0.00638415719932236, 0.0088808686042026, -0.0239288085613579, -0.023873252844257, 0.0422823954558634, 0.0237853312506591, 0.0204361518344422, 0.0435460183840249, -0.0765978577452829, -0.117058944746748, 0.207325437623335, 0.0231802335251376, 0.019962604425603, 0.0425842975405799, -0.0746492117914787, -0.11434644973226, 0.202051088091408, 0.000438133590394971, 0.000377316628029147, 0.000804893149832569, 0.000376440608824254, 0.000576625608242547, 0.000802131918237192, -0.00364366602223473, -0.00558130841108459, -0.00556835024016821, 0.0208710379051663},
    {0.0107425993815027, 0.0254129579368256, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, -0.00476624355041165, -0.00338273614995217, -0.00435470127501964, -0.0137973375736296, -0.0603965005827018, 0.0315784943674165, 0.00779631465864176, 0.0116923912438848, -0.00527925397357761, -0.028919560674281, 0.0792937759693207, -0.0676531927685026, -0.0668972246841806, 0.26996967643304, -0.141961339914384, 0.0573319015009939, -0.0222957897716069, -0.0635582267339031, 0.135372028365772, -0.0987005432142831, 0.0127562315865689, -0.0084449413101164, -0.00445839259329874, 0.0114632796231686, -0.0162280695445272, 0.0315560665716391, 0.109055095339958, 0.15377203670886, -0.0218610650020319, -0.20873228010551, -0.0795719254745862, 0.154730479224276, 0.0363463430762805, -0.0362021324157861, 0.0208463565738799, -0.0695671764823022, 0.0187334020168053, 0.0515692280558872, 0.460570658542209, -0.458743261526413, 0.264159179791141, 0.649423009457742, -0.174879920823443, -0.0923254899097838, 0.262336456257311, -0.0706432910926394, 0.100006654150581, -0.135750409459011},
    {0.0106226666604082, 0.0277849136316368, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, -0.026019057404776, -0.00708763218492729, -0.00629024608249977, -0.0143785334928047, -0.057876558781076, 0.0213437702446786, 0.00757530613557609, 0.011361365492069, -0.0217181624512595, -0.0244158730639452, 0.0837575252759867, -0.070503000519193, -0.0483096864799013, 0.0735262174169138, -0.100868692067401, 0.0557087659591238, -0.0161008564820601, -0.0271010761760102, 0.104754249861408, -0.0945824300406851, 0.0606169663210653, -0.0278519033674184, -0.0194533184251788, 0.0205729256103858, -0.0186022939508755, 0.0359312466038147, 0.208816727025423, 0.370860928123472, -0.095386453682271, -0.273937984971186, -0.091213581742051, 0.176183523808719, 0.0695953213086702, -0.13669587008386, 0.0990608304482567, -0.091299209379899, 0.0336204732668515, 0.0587191894223527, 0.154807210805021, -0.304065071880222, 0.220350026027013, 0.27493940115423, -0.101245047457608, -0.0707151723594294, 0.780836385935845, -0.28753905994854, 0.259996376636919, -0.19204741754843},
    {-0.00262086915298644, 0.0300547935497049, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, -0.0629779646757726, 0.0247338267998051, 0.00750215134912605, 0.00917493645108301, -0.048949411602034, 0.00658120841508754, 0.00337457711054275, 0.00506138536202282, 0.00953046266998935, -0.00904585198043094, -0.0556826593749891, 0.044987936335647, 0.00740752011267504, -0.00240693191785914, -0.0250468724285162, 0.0248177503627263, 0.00246880960967885, 0.00278290510283736, 0.0564773593641095, -0.0799936001014607, 0.113516362413503, -0.0185639631595197, -0.0167784696518063, -0.054226955665696, 0.0156313105845951, -0.0289919659842307, -0.0415161074774569, 0.137785921551927, -0.0822707305417842, 0.402484695490358, 0.0766458066681739, -0.14215779334252, -0.0138366637603083, -0.159308678962164, 0.185509533264767, 0.134141800340848, -0.0886182134630825, -0.0473789501690623, -0.0107545004524866, -0.123822135860404, 0.144186661900358, 0.0356926225918727, -0.0235796481027298, -0.0213117429016787, 0.615646310841459, -0.406714954274354, 0.117238515266377, 0.342463929443951},
    {-0.0112132650061804, 0.0291131058185437, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, -0.0994794309404829, 0.112846675863041, -0.0356794946677952, -0.0112023885451424, -0.0323328431907149, -0.00410083987857548, -0.00278914940712212, -0.00418348946077044, 0.0538868521712186, -0.101042221662702, 0.0849937731483466, -0.0549292461438856, 0.0175143255728477, 0.00367186688349743, 0.00664416170108373, -0.020513118376943, 0.00583724844800669, 0.00513055372915048, 0.0136495564365595, -0.0528386438915603, 0.120828272253816, 0.018159391200534, 0.0196022074155316, -0.162415639580523, -0.0387405065266482, 0.0815009178862218, -0.108188894132857, -0.043258325000982, 0.0961165087027929, 0.386897800957663, -0.189958312030145, 0.399627629543894, -0.0360576518771369, -0.0604431390604203, 0.197458726781112, 0.128946934255838, -0.265421203189447, 0.133189585327345, -0.0117194719847801, -0.0196452524780157, 0.0641781118900006, -0.00468592208119774, 0.00964538694945503, 0.0104117408727183, 0.138067294932718, -0.284194329656931, -0.0677880055845984, 0.606288622857957},
    {0.0122972972658713, 0.0224445447174005, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.104568501634171, 0.189850631265638, -0.162829463999105, 0.0560378329736126, -0.0139990053434686, -0.00513509550091862, -0.0042438908523756, -0.00636565806912715, -0.0683914171489397, 0.159071760349638, -0.206289585296184, 0.274773179699455, -0.00915583372768289, -0.00430258606699971, -0.00537660975155997, -0.0312130576026594, -0.00305149496021591, -0.00231316749585568, -0.00349760168066449, -0.0228773094223896, 0.0705466934159362, 0.0299544723214309, 0.0361434486839318, -0.148259144018291, -0.0919091466194164, 0.185649879114551, 0.0591095569907137, 0.0379494934220749, 0.177224025148591, -0.187830363035947, -0.45066283116216, 0.910306571261336, 0.0197002829695776, 0.0204025052145788, 0.115288086146479, -0.0626008972232353, -0.242286521734026, 0.303390821313914, 0.00263735601303523, 0.00273136532565302, 0.0154340791804502, 0.00169323422072132, 0.00655338578226165, 0.00790739894148366, -0.0232618994971416, -0.090031372841043, -0.0558124539406065, 0.276242777973245},
    {0.0299283676160422, 0.0111030516956888, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.0625327818570342, 0.146258539859399, -0.183841668082121, 0.140764808621599, -0.00268976516544266, -0.00148258887390954, -0.00138523266460863, -0.00207782821502168, -0.179896704701628, 0.459596310372118, -0.662594871472996, 0.690219303679269, -0.00773801956853017, -0.00465882113210352, -0.00499260080123197, -0.0101883216251351, -0.00257895986512173, -0.00179668352082422, -0.00206072672104516, -0.00439564015111298, 0.0162462241769459, 0.0101844496336541, 0.013118181670236, -0.0432160109691642, -0.037347702370065, 0.0748861467390758, 0.0510514100330866, 0.0367063907025685, 0.0643230528044014, -0.155757438084702, -0.183128903994627, 0.367193083012778, 0.0170146296952579, 0.0141558916760697, 0.0265497360935652, -0.0519114972451436, -0.0706240215419473, 0.122379662580786, 0.000731861863459712, 0.00060889701665834, 0.00114200189365371, 0.000526214799612007, 0.000715899315482727, 0.000922121235404444, -0.00576626720338026, -0.00784483208536733, -0.00677958116209394, 0.0287680203061017},
    {-0.00674620730936931, 0.0302500012368685, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, -0.00538804273701246, -0.00355870072593594, -0.0040690243822649, -0.00918403835795028, -0.113191271384467, 0.147807356790049, -0.065144214809081, -0.0142913798085189, 0.00197276041282779, 0.00282759490804089, 0.0246420043988712, -0.04503256618228, 0.0414434833137068, -0.117441550053527, 0.394513248650745, -0.0700756553903235, 0.00554578525152284, 0.00580669741102574, 0.0442577376376677, -0.0742698835373353, 0.0222480575010768, -0.0351083038449275, 0.0265381887482211, 0.0177577186477454, -0.0480603077984889, 0.0348231154916576, -0.0176773769273057, 0.212615825443168, 0.130126061606394, -0.107540712446678, -0.235656571469202, 0.170749967708241, -0.00236550908394886, -0.0105124273528511, 0.014597951055117, -0.0143906266881723, 0.0116516377961438, 0.0228490121220381, -0.0496942941533089, -0.220843648702358, 0.306671776781995, 0.597701424519648, -0.483940043727635, 0.365807823698725, 0.0899663991696786, -0.0728429636639774, 0.197145552539168, -0.0997158754837051},
    {-0.0108682780791436, 0.0300983577029971, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, -0.0269350059128871, -0.00688995031957121, -0.00551966637194167, -0.00957090470710668, -0.0993286602484082, 0.105874942979701, -0.0269115200303894, -0.0114388293177887, 0.0148432501155473, 0.00721310365350019, 0.0237118389394891, -0.0469295077882568, 0.0547376953425479, -0.11084070314001, 0.115608731683716, -0.0560885983076513, 0.00732475842426727, 0.00702557127231348, 0.0288288932084989, -0.0651740009484615, 0.0976912073872445, -0.124711701733312, 0.0524233707828873, 0.0299286831739656, -0.0631847155811978, 0.0396512647545375, -0.102273132930751, 0.535746834338047, 0.257050201911992, -0.128570110450796, -0.309816855637989, 0.194424079547109, -0.0136857422900744, -0.0339579907193822, 0.0640995944875302, -0.0172046885375793, 0.0196375549684062, 0.0260169779825591, -0.0504691348713493, -0.125227435768644, 0.236381119183879, 0.264377148370073, -0.301761974485488, 0.126847598555409, 0.243941787386094, -0.278436906801434, 0.587829296106843, -0.141069013725581},
    {-0.0100304424671004, 0.0286160770881658, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, -0.0578628584901558, 0.0216383431733442, 0.00606898946781372, 0.00610719045242117, -0.0745598627704427, 0.0516368564971357, 0.00152770678244047, 0.0010864443757941, 0.0278670398224957, -0.0165823879066067, -0.0112119814106074, 0.0299457000850141, 0.0359083999511919, -0.0395715317875216, -0.0028223183013287, 0.00532721841410346, 0.00480510466139418, 0.00412692477588743, 0.00994877186000768, -0.0489220790330338, 0.164640818162663, -0.134686083023702, -0.00625001174450575, -0.0727264094622996, 0.0933158150499535, -0.0319935495606552, -0.126171301109485, 0.24882196074617, -0.0306460030495001, 0.134356329875995, 0.457560220603032, -0.15687561199579, -0.016883690387748, -0.0259497034408981, 0.108028244942133, 0.0179789750546523, -0.047719067864404, -0.0209924066648649, -0.0217556766329357, -0.0334377937414931, 0.139201057956504, 0.0429042901956707, -0.113874830422634, -0.00528428039161088, 0.136797588383316, -0.36308262200192, 0.465874103411458, 0.251557919288668},
    {0.00537863848136855, 0.0243807773710822, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, -0.0812967864767637, 0.0892023530796902, -0.0267723918023991, -0.0074567405160752, -0.0438056716503967, 0.011554166457463, 0.00399812922953623, 0.00398736235826692, -0.02207903577152, 0.0324894082074786, -0.0161003738189845, -0.0365630181088647, -0.0118969892080668, 0.00420827497900536, 0.00240439388633063, 0.019551438299029, -0.00159200294020179, -0.0012378602907424, -0.00204387781190565, -0.0287428711768687, 0.15834431170101, -0.0485677550391041, -0.024926422408399, -0.202042477253413, 0.0919140623426248, 0.0899388353673571, 0.0576723909467997, -0.0292076635307709, -0.122223005070747, -0.121504250912767, 0.450686934679816, 0.441001702974336, 0.00771746652451502, 0.00859140789289658, 0.103896823889261, -0.0162591661904661, -0.132569155480525, 0.0590129145694342, 0.00415845224881613, 0.00462936371142349, 0.0559833955320351, -0.00210601072884665, -0.017171364169944, -0.00881285693118508, -0.0288618673204912, -0.235325313207767, 0.107055238101477, 0.445351148958013},
    {0.0265225731168813, 0.0168888172596302, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.0776057232015647, 0.138298675897828, -0.115271030719205, 0.0373009361247862, -0.0172240947344067, -0.0024498853979906, -0.00155992255535771, -0.00192502052858138, -0.136406455745617, 0.28376541171853, -0.302860847075892, 0.182899592666262, -0.030274541866518, -0.00502674905678496, -0.00409850995120626, -0.00943905186116183, -0.00405120647096816, -0.00292119558198589, -0.00374060763022852, -0.011301503148731, 0.0851979215757074, 0.0138880133222226, 0.0124916450858424, -0.174002317425163, -0.0400671452317113, 0.204870501421384, 0.174811675791853, 0.0364890940310537, 0.0612509238451513, -0.457170278774762, -0.196463287614661, 1.00455203413528, 0.0233925320915247, 0.0212049137663457, 0.0559021878246979, -0.0611765225010694, -0.114170745608983, 0.134424749317638, 0.00519182313107993, 0.00470629521224695, 0.0124071336395173, 0.0010837086342457, 0.00202247231023234, 0.00181912313224389, -0.0376873641955269, -0.0703340806951786, -0.0161956798487153, 0.202914971390714},
    {0.0260124381207847, 0.00773818110957636, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.0433476663950504, 0.100657728235379, -0.125149498779013, 0.093698468630728, -0.00309114016851077, -0.00142932235848188, -0.00122935995028967, -0.00172256715936862, -0.152061844875104, 0.37398651422484, -0.507825635341389, 0.459436505525796, -0.010843593574508, -0.00531054391871696, -0.00498843785959982, -0.00844635187532097, -0.00145104215453647, -0.000995259096535659, -0.0010869582021326, -0.0020282360777898, 0.0185363701620085, 0.00971194662742112, 0.0113836940204541, -0.0487726328729603, -0.034824576812883, 0.082639226619067, 0.0688705436214522, 0.0394086713457843, 0.0558182505772273, -0.197907251068727, -0.170757133079533, 0.405209157119218, 0.00921595422346872, 0.00738565375592506, 0.0121625460717833, -0.0264830807255861, -0.0320019178067211, 0.0542233129952791, 0.00065719353913296, 0.000526674049477189, 0.000867316232694469, 0.000376055172972515, 0.000454421706483309, 0.000532642719457735, -0.00487692496111081, -0.00589323248953565, -0.00420787879224268, 0.0211316366719476},
    {0.00349338776214511, 0.0248800215131901, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, -0.00422947460640323, -0.00262076359232665, -0.00270891496297769, -0.00480223949501904, -0.122340482894467, 0.239188061792398, -0.23085120375936, 0.106433229417867, -0.000737780502525434, -0.000621569734380909, -0.00109018984479886, -0.0235470671456198, -0.0213408121217804, 0.0567285276972928, -0.0929049606346437, 0.521879511054613, -0.00108449112971495, -0.000849780857683921, -0.00144195494716553, -0.0304844426488356, 0.0225595452321252, -0.0513596430982692, 0.073863964643945, 0.0162777402116466, -0.0552209333838474, 0.0250714592272948, 0.00535047517400649, -0.0206694422318368, 0.362180965134431, 0.00655089853965174, -0.270767634055307, 0.122934171541447, 0.000271898877740042, 0.000309623694824905, 0.00562132130380552, 0.000332901640170666, 0.00405603955611853, 0.006247232664566, 0.0078648633924415, 0.00895607985992309, 0.162600612797479, -0.0303827855030739, -0.37018075297663, 0.532383334467844, -0.0028656188720214, -0.0349144074259305, 0.118444338190402, -0.0375393217377865},
    {0.0093268697739224, 0.02330143749075, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.0200092686815671, -0.00483826550316684, -0.00354803175299677, -0.00500452794251933, -0.101599268420437, 0.168011170718831, -0.123020984383692, 0.0252004138115013, -0.00968427887924604, -0.0030573908049977, -0.00351420065220278, -0.0245389584623717, -0.0491729940243792, 0.106169413017208, -0.121847957868656, 0.123566481166194, -0.00249885878459794, -0.00191419023133716, -0.00300028765102184, -0.0253162076693629, 0.0944563035738694, -0.181156214573332, 0.19494018247284, 0.0264889132374164, -0.0746609519959465, 0.0285475625477052, 0.059688711549993, -0.179428858511902, 0.955860192068403, 0.0262363368356131, -0.366088874082172, 0.139978727185895, 0.00303324343285033, 0.00323502747564209, 0.0235363446423738, 0.0013332704684372, 0.00660042969678797, 0.00711339789299568, 0.0154016280466347, 0.0164262087773372, 0.119508385589293, -0.0462984786883525, -0.229203196864413, 0.246643004355891, -0.0260291213928503, -0.128858614879587, 0.363197492232308, -0.0531072416281613},
    {0.0190977808372875, 0.0202336576842804, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.039595919990636, 0.0141639916635123, 0.00370744537983258, 0.00319338727160603, -0.0702518096504063, 0.0825726724762286, -0.0302591072534671, -0.00555414878956761, -0.0433432647799654, 0.0190435548721707, 0.0069770474474957, 0.0156582995463821, -0.076900417711456, 0.111019355037725, -0.0569446628060193, -0.0272339425429255, -0.00390790286721711, -0.00289524874373814, -0.0040524758704301, -0.0175051398490236, 0.148388770431383, -0.200999967524955, 0.105961643569102, -0.0611719587217119, 0.119201100977507, -0.023034267957402, 0.19950941508979, -0.378262163481966, 0.519567159982301, -0.115119607905565, 0.584484870331949, -0.112945107132978, 0.0101386109265575, 0.00986461372661266, 0.036975078526123, -0.00585011446225275, -0.0152426492298348, -0.00573961131991799, 0.0179881100148821, 0.0175019791423125, 0.065601864511301, -0.034104763467522, -0.0888609872432726, 0.0468450635759486, -0.0612886051163675, -0.159689304474723, 0.311174291382681, 0.0947022088715306},
    {0.0283483789400611, 0.015605997316105, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.0508705214556543, 0.0541344006325358, -0.015500258893724, -0.00389905316318789, -0.0377420092156798, 0.0230901301043677, 0.0013542240808212, 0.000832624912029263, -0.102213293977142, 0.124878367918978, -0.0445130476343746, -0.0191184272948391, -0.0758343923526163, 0.0532647951908287, 0.00388900865659811, 0.00408265242310408, -0.00385372990326823, -0.00275466521408037, -0.00342928295650854, -0.00940444314233824, 0.13231264484422, -0.0925956420784959, -0.0076252133817465, -0.161063201374778, 0.158264250550675, 0.0647529036970649, 0.305221577224944, -0.265912605385222, -0.0373890997493768, -0.462535110161498, 0.776025214555274, 0.317506232833687, 0.0155106605694834, 0.013752051451918, 0.0329692767107086, -0.0235049735356563, -0.0401332560488802, 0.0161349385942962, 0.0115077156161064, 0.0102029630870849, 0.0244606642480475, -0.0100256563422968, -0.0171181742635493, -0.00140967467297046, -0.0574497025764957, -0.0980917344976779, 0.0963870996787597, 0.167658158602434},
    {0.0290142634016861, 0.00987675823579524, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.0448012227061955, 0.0784639261814979, -0.0636937172730277, 0.019504277059619, -0.0136909752155198, 0.000869868924945503, 0.000405518905339076, 0.000409298247694278, -0.139268112846256, 0.263309019711057, -0.240581629561091, 0.0956363217673718, -0.0425594697223884, 0.00291910365758025, 0.00153171149747902, 0.00200693308424874, -0.00216277464680906, -0.00149776380988465, -0.0016858289147065, -0.00341147704251069, 0.0665553353467771, -0.00480255754658141, -0.003072991872775, -0.132383333906543, 0.0131115658446459, 0.147499795774797, 0.223346204549639, -0.0181400485021902, -0.0150679586141475, -0.500033591404991, 0.0642906130875656, 0.723243311516806, 0.0113499419004009, 0.00930748316716323, 0.0165840632254412, -0.0254105603546718, -0.0329868908038959, 0.0367535664289513, 0.00346847170388691, 0.00284430900906845, 0.00506798665030031, -0.000281707249352385, -0.00036570017124177, -0.000233998998075191, -0.021553960502087, -0.0279804196188504, 0.00277124849002858, 0.0763899465305751},
    {0.0171539738450262, 0.00422403562884659, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.0235420783828847, 0.0542965286233319, -0.0668187951761436, 0.048993968572852, -0.00231153056297333, -0.000876578948905499, -0.00069343400459129, -0.000909320668327572, -0.0977269276576102, 0.232125215917278, -0.298701660335599, 0.240234638216594, -0.00959553257924237, -0.0037474969936805, -0.00309987463794581, -0.00445871865745561, -0.000487622959599529, -0.000329816258202437, -0.000344874274678624, -0.000575980404939043, 0.0137673862153513, 0.00589537889744848, 0.00628854087800149, -0.0358548234884832, -0.0207029333243838, 0.0594974335725778, 0.0588574919775217, 0.0263542534751363, 0.0308349249253131, -0.160282676136513, -0.101513754490211, 0.291736816703684, 0.00299100276046872, 0.00231943115192505, 0.00343051691130132, -0.00814519801425972, -0.00893419973878667, 0.014825395965297, 0.000293678161388905, 0.000227738431127331, 0.000336832821567447, 0.000131498445572927, 0.000144236318875408, 0.00015385541847577, -0.00206529017058821, -0.00226534884361141, -0.0013080350564491, 0.00795527596810692},
    {0.0296266593660006, 0.0106036055567763, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.00174302461810549, -0.001032247516825, -0.000995395188472148, -0.00152025936541927, -0.0607551610563968, 0.145274827975367, -0.188334660306985, 0.151780397361144, -0.00517932982837488, -0.00333411005738367, -0.0036588514416216, -0.00745436569613292, -0.180531596982921, 0.469230738890095, -0.692276345467664, 0.74423260475841, -0.00241016220156656, -0.00167493200389354, -0.00190612042688983, -0.00397712490619118, 0.0107073556307268, -0.0291016110858974, 0.0519163834616732, 0.00720759150771034, -0.0269570575484029, 0.0095642158961828, 0.0345842460403174, -0.106971053214144, 0.25456426498465, 0.026493504172034, -0.132179922471374, 0.0468967101986916, 0.000461712209768714, 0.000381836111040659, 0.000700919724644912, 0.000353697875660693, 0.000471819861893939, 0.000626088065400591, 0.0160935189181036, 0.0133093441036109, 0.0244313765371239, -0.0497781754902046, -0.0664022418603692, 0.118459567099648, -0.00366885739980129, -0.00489411984295737, 0.0183044599731066, -0.00453346276486167},
    {0.0287142087112328, 0.00958841840105437, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.00799167084001721, -0.00185631097078672, -0.00128014616296255, -0.00158429842618404, -0.0488981962979724, 0.100408707642264, -0.104468874747729, 0.056578725162815, -0.0252758904406238, -0.00632110314145244, -0.00488566882918305, -0.00776837170631511, -0.154654198992137, 0.341911353913747, -0.398704725867907, 0.277425364104441, -0.00206468956655644, -0.0014279042234855, -0.00160037367631401, -0.00320095002602278, 0.0436704701359278, -0.101811651647421, 0.145248246697174, 0.0115168069922352, -0.0368162525456524, 0.0108902736390702, 0.148706520787247, -0.388563452590706, 0.712203175478731, 0.0439538129017005, -0.180523018821064, 0.0533988371215843, 0.00198528590849287, 0.00162273463193134, 0.00285873514978343, 0.00058679932067766, 0.000753907637346293, 0.00071289381465036, 0.0121472595661696, 0.00992893703459038, 0.0174915853413359, -0.0317402430744736, -0.0407792081924057, 0.0581771181962358, -0.0138046925395086, -0.0177359836148676, 0.0566973513015156, -0.00641353363141406},
    {0.026266017636219, 0.00787931986789131, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.01505619621431, 0.00521607980877919, 0.00130030386482768, 0.0010109401899062, -0.03218979646575, 0.0486197142564782, -0.0306355733076924, 0.00373028648217923, -0.0524224823609094, 0.0192586102361635, 0.00525321344488672, 0.00495699486804395, -0.112078045039238, 0.179511848166742, -0.123767382336514, 0.0182909049745176, -0.00149628249178236, -0.00102691121281122, -0.00112365340857561, -0.00210719285445268, 0.0658499558828103, -0.112715482697028, 0.0968327727428126, -0.025853441670746, 0.0603353220350683, -0.00878707177583308, 0.243128686850451, -0.455369321869515, 0.474805099586673, -0.10444762263269, 0.295845278163648, -0.0430860995861486, 0.00324585602164101, 0.00260497492156441, 0.0043106378957667, -0.0013944135891991, -0.00169240546797401, -0.000575215033661143, 0.00693956449600738, 0.00556937564640982, 0.00921604331712934, -0.0129974986479507, -0.0157751171905968, 0.0135522494457504, -0.0176036557524686, -0.0213656288798233, 0.0498619145320438, 0.0114367792968683},
    {0.0214698480958178, 0.00569928745007793, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.0182709161061166, 0.0190137982809253, -0.00526293094004185, -0.00123433495846098, -0.0163348457295087, 0.0140319672776632, -0.00196259356847554, -0.00073324112187469, -0.0709478783134302, 0.0769033452699534, -0.0226501029881942, -0.00605237789102629, -0.0634299145349296, 0.0567537957659614, -0.00844642404705175, -0.00359533878904296, -0.000846812331002386, -0.000575990819905168, -0.000612888851787866, -0.00106930375395296, 0.0560006137916713, -0.0543971191883836, 0.0103033153809035, -0.0658993199929182, 0.086686871895592, 0.0247018231068588, 0.226500485285503, -0.234109161969772, 0.0505207745986585, -0.283611242802991, 0.425056183742284, 0.121121715799415, 0.00302386350863148, 0.0023759596398863, 0.0036658850375873, -0.00378631280488681, -0.00431386934521687, 0.00161701877171279, 0.00270344101158918, 0.00212419201925483, 0.00327743098393709, -0.00279425586598694, -0.00318358660367833, 0.000603000624105062, -0.0111516824754385, -0.0127054746021772, 0.0167133416449522, 0.0202473562137979},
    {0.0143344773818662, 0.00339108928439714, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.0152353726346625, 0.0263431259843042, -0.0209745648569959, 0.00617452750875349, -0.00561039559867247, 0.00119544438383658, 0.000411420418441842, 0.000352254883283981, -0.0655314248951063, 0.115979237022268, -0.0956568846043597, 0.0302758773259642, -0.0241318165707197, 0.00526310839581211, 0.00187632953336951, 0.00172722943069828, -0.000322168490867519, -0.000217247209950839, -0.000225042499060212, -0.000367264997427197, 0.0269262600713349, -0.00647362037001899, -0.00299718572753385, -0.0525321970635774, 0.0169905218832956, 0.0562679610565778, 0.118546565081049, -0.0295236807499633, -0.0146962544553078, -0.239579049519497, 0.083310497121199, 0.275901578528233, 0.00158263957699847, 0.00121865954262167, 0.00176263378613847, -0.0031984670777259, -0.00343883722280927, 0.00368338599466451, 0.000582803868995877, 0.00044876894698689, 0.000649086377665843, -0.000145145625740539, -0.000156053562033014, -7.225037646977e-05, -0.00326926866673891, -0.00351495966953635, 0.00113684563986363, 0.00922528597146987},
    {0.00638882353038103, 0.00138044771170163, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.0076646004915091, 0.0175880306956048, -0.0214801029408944, 0.0155101676309963, -0.000906860003956217, -0.000288071461031713, -0.000213253491124168, -0.000265802822928374, -0.0357169332052303, 0.0827155276170138, -0.102424732574839, 0.0760518002123163, -0.0042259551849676, -0.00135478401778056, -0.00101686811553752, -0.00130332461042057, -5.64180322034899e-05, -3.77810915961248e-05, -3.8306559943096e-05, -5.93644300410384e-05, 0.00537393653439491, 0.00192270868623456, 0.00190448281304115, -0.0138893267054968, -0.0066492062394599, 0.02269697566456, 0.025273323859613, 0.00916815545757776, 0.00933834822750551, -0.0662292251284654, -0.0326033938848808, 0.111291244539186, 0.000337408026585792, 0.000255673905629287, 0.000351786028768619, -0.000884184141232312, -0.000909216372899969, 0.00148577842015635, 3.99214342173166e-05, 3.02508185951557e-05, 4.16226103100792e-05, 1.44819065758921e-05, 1.48919053798468e-05, 1.47507410000872e-05, -0.000270158128669223, -0.00027780660430737, -0.000132993732949127, 0.000960724534064054},
    {0.00337366876311372, -0.00634204581202929, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, 0.00186672700723235, 0.00270775846140311, 0.0252970714511431, -0.0453962493417859, 0.00205786663823846, 0.00293953537827717, 0.0272677169715593, -0.0487065445939726, -0.00203791177178526, -0.0492117221773475, 0.0992013086517271, -0.0738509092732363, -0.00224657951086717, -0.0534241146055897, 0.10692910492615, -0.0792361187978446, -0.0283178557954039, 0.628290543629045, -0.135565454749909, 0.0421979810464191, -0.000888311046095779, -0.00570497820444085, 0.00883182654289619, -0.00579324153221629, 0.0062092195721544, 0.00903250928257813, 0.0161444667353697, -0.0223718110929613, 0.0143676720035993, -0.0227179316958211, 0.0101011981811168, 0.014694143970245, 0.203498998675296, 0.263102111421653, -0.0182154333958999, -0.286356708329364, -0.118794431005032, 0.185217860295405, 0.224335855573074, 0.290041905135055, -0.0200805648288412, -0.310868080347518, -0.128962918095965, 0.199646358368677, 0.0939425841553131, 0.0389718679788593, -0.0417702048278282, -0.0424164434544873},
    {0.0115772632577271, -0.0106853276693849, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, 0.0146717000428919, 0.00719541733809583, 0.0244226254420095, -0.0473085106547024, 0.00283917689101551, 0.0035512346657027, 0.016817976125512, -0.0399568305836848, -0.0274010505067601, -0.0481217403864268, 0.105826965373029, -0.0769617882285365, -0.00530248227273663, -0.0237500598790073, 0.0728748586553496, -0.06500202798837, -0.0668371306827621, 0.207386421256723, -0.134368965523375, 0.0582192890483208, -0.00535364888165072, -0.0177228274895518, 0.0365988305517863, -0.0069489892381851, 0.0100310086012752, 0.0102848470593368, 0.0358043028635588, -0.0767957177864589, 0.0595392120224926, -0.0301110314791141, 0.0163185090590719, 0.0167314550889353, 0.451308792072928, 0.670583112662057, -0.109780279168362, -0.379545813158116, -0.142493838383863, 0.210897913990534, 0.0873344935774072, 0.129767107520561, -0.0212440024532162, -0.187321483324289, -0.0703265751992813, 0.145229106953919, 0.282395714198688, 0.106020532605796, -0.153042815009204, -0.0600069529033938},
    {0.00318614435970197, -0.0102352418729336, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, 0.0285443214023187, -0.0170879000112394, -0.0117215303676543, 0.0301875416619842, 0.00193009838737005, 0.00202524321821195, 0.00540450880422611, -0.0271088739443334, -0.0126571512820063, 0.0143537935251021, -0.0723998288978307, 0.0491092861808115, -0.000855846139544826, -0.00170119926809067, 0.0333817769889968, -0.0441008898133744, -0.010787834325671, 0.00689944426242842, -0.0507328584660813, 0.0395780045482835, -0.00682270690696085, -0.0129194301108833, 0.0565868352835748, 0.00737079936166061, -0.0229083726068189, -0.00829856919202066, 0.00573105683907262, -0.0797988402663341, 0.0920558261790192, 0.0455268719942119, -0.037267487325796, -0.0135001655287293, 0.0722392598788914, 0.323635014986764, -0.139904331697434, 0.573860568794342, 0.151143347183347, -0.170167910286462, 0.00488464507640123, 0.0218834216346689, -0.00945999455336028, -0.0680134612436616, -0.0179133795644634, 0.0784602300632858, 0.229126016875703, 0.06034719059046, -0.187558480429118, 0.10700595273598},
    {-0.011801561675532, 0.00496641091476396, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, -0.0204347654762904, 0.0301742710270642, -0.015052523747274, -0.0368583011689746, -0.000577804782105206, -0.000512427300870544, -0.000904019525330758, -0.014250899101052, 0.0594964820405094, -0.120624902691672, 0.125434652322348, -0.0599613204849067, 0.00168229735160544, 0.00204848339993458, 0.00753331313448469, -0.0231834539600412, 0.0212051492401301, 0.00258397885603977, 0.00538637983819933, -0.011848287343186, 0.00281071914707326, 0.00358016746981973, 0.0495501608220378, -0.00596100303954848, -0.0595664075674237, 0.0233285664952788, -0.0112361529233051, -0.029834004541196, 0.0806085190825289, 0.0496738192420159, -0.0969030134598644, 0.0379510614356347, -0.141630312498688, -0.0376329322111704, 0.0576357432941006, 0.62613232396099, -0.122234496933111, 0.478368417328807, -0.0040046787885943, -0.0010640928676904, 0.00162968389014095, -0.0106331416082053, 0.00207581794703578, 0.0287296932280311, 0.0583239313380666, -0.0113860858694688, -0.113777534921341, 0.189440364791816},
    {0.00800383521292122, 0.0263496071105023, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, -0.135681023269177, 0.282736312981598, -0.302623682224074, 0.184376690406239, -0.00158021534532792, -0.00122388284394238, -0.0016252758278492, -0.00506457947298106, -0.0455282927907743, 0.109434345863475, -0.15080433156421, 0.299945181214724, -0.000530247378602411, -0.00047370929127555, -0.000809912274627625, -0.00823909033431859, -0.00668370237087959, -0.00295758720150995, -0.00380781996748508, -0.0324034103825531, 0.00914001856619165, 0.00890950075286585, 0.0245045777907788, -0.0239713380659698, -0.0483955236813236, 0.053139837710913, 0.00353768478630587, 0.00443980886007429, 0.0398642041456056, -0.0119454683360226, -0.078730147984503, 0.0864482284436399, 0.0445920774865158, 0.0277197895493027, 0.187422412635166, -0.150571145206208, -0.491548893679026, 1.08966918597521, 0.000519343703536631, 0.000322839817681871, 0.00218282384204094, 0.000651778469724377, 0.00212777146164374, 0.00585219562230549, -0.00486751435712152, -0.0158903041743697, -0.0320807954006464, 0.0863145549122675},
    {0.0302224845101155, 0.0261153899063016, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.15273114932588, 0.375858140305486, -0.510844558915113, 0.463146916325963, -0.000571524833485284, -0.00040277380705036, -0.000446079687283095, -0.000841390117526058, -0.183081952923273, 0.472755167242471, -0.693290980381532, 0.753450370761892, -0.000685098508853451, -0.000506609750046203, -0.000605395551988734, -0.00136877883379729, -0.00863558164111847, -0.00513542221486778, -0.00554103138111582, -0.0117195126461701, 0.00363208529783297, 0.0029917144634538, 0.00500199470056438, -0.0104469704798224, -0.012990513782195, 0.0214351751990887, 0.00456844460258454, 0.00406019525351194, 0.00813727702558385, -0.0141780709602838, -0.0211330510483065, 0.0348708803444413, 0.0575846769898426, 0.0411575515467006, 0.0744784252336855, -0.178712824081338, -0.214222367041931, 0.439543117114767, 0.000215483698467462, 0.000154012870971472, 0.00027870064337109, 0.000191510670662889, 0.000229563095956075, 0.000383817842058254, -0.00172698194151801, -0.00207012653542035, -0.00257414408714891, 0.00898882818456456},
    {0.0117859544381791, -0.0110271230805097, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, 0.00295045175569065, 0.00361626834906974, 0.016089212404908, -0.0398420632543444, 0.0164288131844466, 0.00644900529020182, 0.0196160926625834, -0.038562846397088, -0.00533638736500255, -0.021589474677939, 0.0708866405450277, -0.0648153237617092, -0.0297142669526367, -0.0385011904458149, 0.0864255424365168, -0.0627342855826572, -0.0650794963063693, 0.175306723361566, -0.129373925944914, 0.0585357554359556, -0.00599234830794813, -0.00596048830774343, 0.00876741507713446, -0.0186109023749111, 0.00895204339478125, 0.0400416091578109, 0.0357749037316651, -0.0262610115094856, 0.0142628870184277, -0.0819968258027645, 0.0145632415484494, 0.0651399463159163, 0.0783533620054191, 0.119573754125016, -0.0213506983799166, -0.179587540573384, -0.0663105251505074, 0.142667995223338, 0.436290050931204, 0.665814943251966, -0.118885738214352, -0.320264119644222, -0.11825364884818, 0.173941927289884, 0.297586072438545, 0.109880054473007, -0.0528534831921596, -0.165028595825849},
    {0.00868942826669693, -0.0116958193796847, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, 0.0148427436855896, 0.00638151686995214, 0.0144742293073116, -0.0415203612920179, 0.0145079970177743, 0.00650803540571885, 0.0149243543543366, -0.0430827522936908, -0.0167229445882328, -0.0161405937908933, 0.0744586814191186, -0.0675455897618916, -0.0163457939686741, -0.0164605936176501, 0.0767742256020668, -0.0700872974533168, -0.0358001777363248, 0.0412250887240752, -0.0838466866383684, 0.0516918998203713, -0.0239827552691316, -0.0217039465904848, 0.0480958691343093, -0.0208020433238823, 0.0181915227080136, 0.0455932912233091, 0.0606589183534297, -0.111649968396047, 0.0782426680475976, -0.107010375739815, 0.0295940856905752, 0.0741714582685036, 0.132853752011542, 0.279624171526345, -0.0854504023725405, -0.234371635813971, -0.0741175462222497, 0.162448602623016, 0.129857516831937, 0.273317840187487, -0.0835232494105542, -0.239018235798383, -0.0755869842279404, 0.167500490591787, 0.880805880216167, 0.278545525839862, -0.243589881034134, -0.233467551046818},
    {-0.005158044328699, -0.00575929267843153, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, 0.0151788194266243, -0.00831999241146486, -0.00467132225531175, 0.0264941258766691, 0.00518416692938192, 0.00268262576567051, 0.00458054935471393, -0.0433658185196246, 0.0180568823364596, -0.0159481203670529, -0.0486788032710566, 0.0431008137183392, 0.00616713919741456, 0.00514217279233527, 0.0477328791988051, -0.0705477914032104, 0.0135071248184838, -0.00305500856414894, -0.0166083283299719, 0.0184711533395948, -0.0167792370213338, -0.0140070776838757, 0.105619250345273, 0.0148371797724691, -0.0546971571990116, -0.0367880124736602, -0.0321631653551497, -0.145964620231556, 0.171822073141542, 0.15461492822938, -0.0889816857642901, -0.0598469743850445, -0.0704430166245736, 0.0867188215718508, -0.059784313307097, 0.338634019363569, 0.0528647758526334, -0.131075451218333, -0.0240590751445701, 0.0296179059986186, -0.0204187065694203, -0.109186198802953, -0.0170452571090386, 0.128528399601263, 0.68293577606614, 0.106614352543, -0.393033048742582, 0.416325384375381},
    {-0.0103543496131472, 0.0114965700457507, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, -0.0456650504879514, 0.064033916478374, -0.0289985647742543, -0.0323487245733811, -0.00652193812105359, -0.00376718935977031, -0.0051210232234847, -0.0331151410630412, 0.0487160015083048, -0.0883080091353923, 0.0683057070994246, -0.0526251123873065, 0.00695767866119281, 0.00519526230305949, 0.012062497405501, -0.0538719236429517, 0.0152385459635856, 0.00364434309255478, 0.00622457516001478, -0.0232376234689826, 0.0301281169318005, 0.0238936466936189, 0.127872945220575, -0.0580053142400196, -0.181106971901399, 0.10341681503917, -0.0415491378876405, -0.0562811451289649, 0.208024526539326, 0.136630693123355, -0.294625982202666, 0.168239137275043, -0.090999955341371, -0.0394797780221855, 0.10734628634863, 0.299245365959432, -0.20667256059336, 0.368473445107362, -0.0129967244405358, -0.00563854997514003, 0.0153313273413632, -0.0176049509478884, 0.0121587857504661, 0.0650708434821411, 0.140795688796734, -0.0972399536775847, -0.30360724338994, 0.737050889895457},
    {0.0142799617871941, 0.0286331249853376, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, -0.144761735858263, 0.294022599521717, -0.301560576395923, 0.161818385181666, -0.00851593238442561, -0.0052960952910996, -0.00615830015627286, -0.0159370083754821, -0.0786155180524533, 0.180183183238993, -0.22752856333055, 0.263247185749172, -0.00462473340853546, -0.00324555768787728, -0.00464646010384153, -0.025926427330224, -0.0101289835370485, -0.00485254778273548, -0.00597444597327724, -0.0303422121712233, 0.0480095304404492, 0.036943823714596, 0.0817770038721055, -0.120654962207571, -0.176743667493169, 0.235571815733862, 0.029421241886308, 0.0278742507862934, 0.133035353826841, -0.0910346124745026, -0.287527730636603, 0.383229739093874, 0.0644377196220509, 0.0416757755850918, 0.171057647372711, -0.199381890716993, -0.429892852309207, 0.839340860388867, 0.00379069275492284, 0.00245167056644496, 0.010062848101595, 0.00359137526936541, 0.00774346432721748, 0.0171405460669789, -0.0325561061198115, -0.0701951279005209, -0.102826639852127, 0.335821880299532},
    {0.029691917178448, 0.0243834140019697, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.141645882360695, 0.345411287467402, -0.462849575846568, 0.406481350416947, -0.00267727324386343, -0.00174183802117235, -0.00183748784347604, -0.00328158485493605, -0.17784500213963, 0.452155668420226, -0.646858537591111, 0.661266465096995, -0.00336147904794575, -0.00228012796141551, -0.00256799349356311, -0.00533850326641944, -0.00736223322060813, -0.00445019405091735, -0.0047511302776932, -0.00953910730364745, 0.0168597007475026, 0.0127557271340271, 0.0199584129431104, -0.0478104381081742, -0.0536515356544616, 0.0950233075549246, 0.0220699483121887, 0.0178268522440286, 0.0324684740451171, -0.0668177993242803, -0.0872806619365437, 0.154584525524274, 0.0483370874319143, 0.034793201585805, 0.0600710050445717, -0.146342789854298, -0.170348282676651, 0.338567432066033, 0.000913627623415208, 0.000657632301918047, 0.00113541242327312, 0.000737976565160036, 0.000859031324028801, 0.00134409443819925, -0.00714306605782547, -0.00831478638071578, -0.00933062058445944, 0.0349726090309802},
    {-4.16214011110053e-06, -0.00888246788236115, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, 0.00207617681188797, 0.00204132940906956, 0.00495444159751796, -0.0310074355429239, 0.026308729862987, -0.0190562037323708, -0.00887004256151624, 0.0262768860950638, 1.34764571136878e-06, 2.34589687826098e-06, 0.0351417498325345, -0.0504430947992082, 1.70769882250297e-05, -2.1899399797727e-05, -0.0629150249458783, 0.0427474066498149, 1.27907673087219e-05, -5.86577422614763e-06, -0.0362041359827394, 0.0320568669764365, -0.00769781311112102, 0.00960799969344625, -0.0100195650228909, -0.0130420310882867, -0.0364701390904392, 0.0709175009299217, -8.84633105603812e-06, 0.0681493393296449, -0.0162998925724397, -0.0925068516383987, -0.0593298559286743, 0.115369044865993, -6.62595538404454e-06, 0.0182538627477392, -0.00937969153956932, -0.069288190527517, -0.0158915560681608, 0.0864121113201358, -8.39622469953886e-05, 0.231307825632447, -0.11885681869661, 0.646818621763509, 0.148350740803414, -0.154705447658132, 0.261284405700932, 0.0599267458324431, 0.167576410526233, -0.227470527214667},
    {-0.00681295111639312, -0.00438186087957974, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, 0.00496290698942552, 0.00178381589036715, 0.00264840080550209, -0.0323135857262808, 0.0110394459580144, -0.00537180196847261, -0.00318945341855547, 0.0255329556369081, 0.0101073362006735, 0.00568346715796636, 0.0351451051021585, -0.0525679482857169, 0.0224826683241413, -0.017115252886681, -0.0423250421086934, 0.0415371758142846, 0.0168396543479754, -0.00265609563809127, -0.0110627097316331, 0.0134514304724192, -0.0152560834038925, 0.0117265687773735, -0.0437183995785952, -0.00866187936743303, -0.0418058504080334, 0.0807500582702354, -0.0486078465011175, 0.155615226861536, -0.0711213725288545, -0.114945842078814, -0.068010025284893, 0.131364712142299, -0.0364075705728992, 0.0241497410540253, -0.0185893518541938, -0.0860951298768103, -0.010554394533443, 0.098392962708179, -0.0809846746389744, 0.0537184681949511, -0.0413499881472977, 0.259267781302797, 0.0317836149105708, -0.118494062764006, 0.736328501815995, 0.0902664474228087, 0.435663605754063, -0.321804755462983},
    {-0.0117909391625216, 0.00649963867312389, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, -0.0157527489567287, 0.00761282852421924, 0.00331676160313942, 0.0206192860832164, -0.0122437712383401, 0.00202563119535567, 0.00149192775061589, 0.0113747003386201, 0.0347177461769008, -0.0226829837593203, -0.0194855585338849, 0.0335435867035136, 0.0269842516546397, -0.006035517463772, -0.00876488846392677, 0.018504435386129, 0.0202113674476524, 0.00308515890396073, 0.00608305867108551, -0.0149188861614174, 0.0349392194237379, -0.00820727779862279, -0.0377070803306022, -0.0239741743450801, 0.0351290133199049, -0.0651550715289333, -0.104103979779745, 0.0482167279666835, -0.0613421198629883, 0.140845268185824, 0.0571481039328642, -0.105994687797817, -0.0779745095406276, -0.0246468125557045, 0.0425730134126713, 0.105493956438009, -0.029212239505768, -0.0793906612641799, -0.0606054257488449, -0.0191566523097158, 0.0330897317403692, 0.0280699674769364, -0.00777283022214881, -0.0357110775063413, 0.484166493457688, -0.13407012159853, 0.196451023490723, 0.57385057542787},
    {-0.000396180986240323, 0.0218166735098089, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, -0.0821315304265297, 0.106627813860814, -0.0421122676094755, -0.0251756789225905, -0.0266944218436793, -0.00387484689204707, -0.00329201428801506, -0.0094017616882311, 0.00168506853674376, -0.00261416436528539, 0.00143665582940331, -0.0409559557664375, 0.000547681628745288, 9.4998540243397e-05, 0.000112306740667788, -0.0152948461494823, 0.00041021684738835, 0.000156669398596605, 0.000218004723301871, -0.0325268279583357, 0.114169552842125, 0.021433407310903, 0.0440530051317886, -0.191698087141148, -0.0870634463072912, 0.183161022520475, -0.00279906307588784, -0.000731198562916104, 0.0716657109865358, 0.0065397612147308, -0.141635372249502, 0.29796752490964, -0.00209651514742656, -0.00120587578307197, 0.139114209894575, 0.00489832064355558, -0.233581784872354, 0.223179475587969, -0.000681410165577424, -0.000391934214268311, 0.0452149544041174, -0.000178004610942419, 0.00848834483592522, 0.0174464607140272, 0.00524477673604118, -0.250102923105532, -0.113589148133033, 1.01592911016151},
    {0.0236731291383539, 0.0302602001667236, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.148692369932632, 0.290316139028518, -0.279210915864665, 0.125936579040831, -0.0199060448288925, -0.0078524948241204, -0.00727718818584329, -0.0143058565620664, -0.123983018812676, 0.264604231380493, -0.294894932128271, 0.204874433632237, -0.0165981047421919, -0.00715703702973116, -0.00768596711021552, -0.0232728591097201, -0.0124320806881217, -0.00659796760180462, -0.00764573936306598, -0.024255273227939, 0.10787872295819, 0.0513642644623301, 0.0812269504449894, -0.254226540885044, -0.206551947025893, 0.417220107102282, 0.0983244220117468, 0.0542495311672531, 0.132140523387534, -0.268507118668092, -0.336020030755683, 0.678736343273606, 0.0736455858695553, 0.0500118481387927, 0.131448910284485, -0.201113453401185, -0.309771944349812, 0.508377620011562, 0.00985923039920357, 0.0066952869974274, 0.0175975936224404, 0.0054397332410744, 0.00837873704784173, 0.0132500536336069, -0.0747318512681792, -0.115108315633292, -0.093522283826684, 0.462886930472144},
    {0.0273991946635941, 0.0208837824772988, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.120035982431373, 0.28854446919111, -0.378174407346313, 0.316347679887784, -0.0051631895232448, -0.00292490831688951, -0.00284951473428284, -0.00466960557446195, -0.161228140099431, 0.400101823491238, -0.550948270007868, 0.514636432413085, -0.00693501587567342, -0.0040557393264644, -0.00415135234621382, -0.0075965442656948, -0.00519436877155119, -0.00321746450671807, -0.00338045124712299, -0.00629128356187379, 0.0320511755142851, 0.0209500829955213, 0.0294811350675107, -0.0888981780171575, -0.083933329001782, 0.16829532188209, 0.0444428333845823, 0.0305213990124239, 0.0479600994071268, -0.129512458891891, -0.13654327736291, 0.273783907869764, 0.0332879505960337, 0.0242129757642641, 0.0390539670767369, -0.0970056138378371, -0.108321347400085, 0.205065800379851, 0.00143183730650093, 0.00104148922898305, 0.0016798549032332, 0.000983323393772549, 0.001098028358663, 0.00154515485006049, -0.0107752678944203, -0.0120322060831622, -0.0113602228338165, 0.048205208161284},
    {-0.0109437322728922, 0.0101644112236962, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, -0.00206888955864452, -0.0016509237082735, -0.00261316748166398, -0.020639741246323, -0.0434629513771954, 0.0685695955840054, -0.0418362555160873, -0.032117720963721, 0.00265561165013081, 0.00277042286983624, 0.00774815294057032, -0.0335768632939073, 0.0557887295356482, -0.115066962106936, 0.124046280414074, -0.0522493142351215, 0.0167773679286115, 0.00365371796926727, 0.00645575293301404, -0.0212633870913167, 0.0103211392078777, -0.0225468980583688, 0.0596405772233312, 0.011404181582465, -0.108008294229385, 0.0782597007030627, -0.017319952436912, 0.0668525135558671, 0.0970236731312838, -0.0338138843694439, -0.175708585038306, 0.127313382496836, -0.00520863652853823, -0.00212276595816234, 0.00504941268934671, -0.0101688635658782, 0.00557926969439197, 0.0382870066797381, -0.109422330078203, -0.0445947794744642, 0.106077377249782, 0.422354381832925, -0.231729827781458, 0.612966832642402, 0.0635730506039553, -0.0348801212954485, 0.33034745863991, -0.167089166495659},
    {-0.00766332463985581, 0.0155122697307478, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, -0.0156006160152443, -0.00470230194600593, -0.00496770894873697, -0.0215091650261775, -0.0575306459131933, 0.0722582786979664, -0.0242204129508015, -0.0257070439035826, 0.00895970133038263, 0.00338168273878033, 0.00558144257295897, -0.034991247469186, 0.03304083660687, -0.0519648837128462, 0.0272127142256639, -0.0418203837218574, 0.00993638458944256, 0.00296439209504616, 0.00463130748587518, -0.0281457276807841, 0.0666729850431345, -0.112240739741459, 0.117813620332084, 0.0269358648165763, -0.141998119943555, 0.0891102380811218, -0.0479481933002692, 0.126107477245156, 0.191659952362795, -0.030263645511063, -0.231003451275631, 0.144965106220525, -0.0144194801926215, -0.00719393524937957, 0.0326184358075965, -0.00910119875154592, 0.0131778377235275, 0.0435954169258846, -0.0531749520918535, -0.0265291922543362, 0.120287537290538, 0.139854259344909, -0.202498240605752, 0.212552508933874, 0.129044050170326, -0.186845886872037, 0.984997691207883, -0.236382660307924},
    {0.00242217246301147, 0.0235602360807905, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, -0.0521782100505413, 0.0221414434455204, 0.00763849492268664, 0.0137249895707229, -0.0672348425655046, 0.0528374343948944, 0.00192278806264413, 0.0024416198975802, -0.00601102036289109, 0.00300848299555973, 0.00140208737896724, 0.0223279009667123, -0.00774557056222433, 0.00717932068418089, 0.00035293822963127, 0.00397204289231737, -0.00232932866944791, -0.000942363494893888, -0.00127304603535354, -0.0328933134587859, 0.168468784091727, -0.169517341690776, -0.0140459588870734, -0.0915342352082089, 0.209713222196366, -0.0719006779748151, 0.0228908053564659, -0.0311158320724682, -0.0228500559069324, -0.016801607807276, 0.341162813456619, -0.11696848358163, 0.00688396145322261, 0.00408428952379172, 0.0824200118822444, -0.005052754531626, -0.0447813094524684, -0.0351759809093124, 0.00887040900954807, 0.00526285901448319, 0.106203269866522, -0.0120576866063494, -0.106864283990075, -0.00885461820277451, -0.038445163448872, -0.340729942564746, 0.780643154897169, 0.421523682717848},
    {0.0189589162037064, 0.0297613960356094, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, -0.105570386298514, 0.126084042471053, -0.0432981721365902, -0.016757899825139, -0.0568851719559672, 0.0163313630643682, 0.00646605237524119, 0.00896099560153879, -0.0724739320858041, 0.0961639620233354, -0.0394468229313448, -0.0272618587998009, -0.0390515961300796, 0.0124558869364595, 0.00589090048204097, 0.0145778050557572, -0.0117440028107332, -0.00592549409332395, -0.00707806935557169, -0.0278299423469547, 0.223813500790995, -0.0785471478787501, -0.0560183754307318, -0.326757131883804, 0.206562994372508, 0.202123969612012, 0.17070195853941, -0.0715604211734564, -0.0911310520484138, -0.297692260133122, 0.336038002649933, 0.328816568729681, 0.0513352712705219, 0.0340426061301111, 0.109496317042074, -0.0895251176953566, -0.159859447182855, 0.0988851440159856, 0.027661315223121, 0.0183433969642291, 0.0590006065325079, -0.0115959733825858, -0.0207062100805642, -0.0147672866726004, -0.158917255565657, -0.283768681645197, 0.179387388583809, 0.746253812808758},
    {0.0300889454319041, 0.0277086251948064, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.131811378803804, 0.246174341648927, -0.220629172869922, 0.0838282289179195, -0.0292546938798931, -0.00436084381177452, -0.00298569745566069, -0.00432619334275602, -0.149068120911646, 0.294363584413148, -0.288327136953214, 0.136372299873129, -0.0330847176025082, -0.00521448988916364, -0.00390183033368273, -0.00703787904698719, -0.00994958093958401, -0.0058000003539919, -0.00633883292814325, -0.0143122788603935, 0.151653962827897, 0.026581708109754, 0.0280730885764979, -0.333041069655042, -0.0900448667383324, 0.460415557245728, 0.181340605155926, 0.0347380525200539, 0.0456694803544958, -0.435231555520939, -0.14648556610804, 0.749006978310935, 0.0545346359098209, 0.0386386245243292, 0.074193694016686, -0.130887367428771, -0.162933739126998, 0.225249181345676, 0.0121036142241401, 0.00857559599677592, 0.0164668166434048, 0.00231859812224148, 0.00288628206839911, 0.00304821841502332, -0.0806322373880539, -0.100374178118915, -0.0271383331252469, 0.34001500036677},
    {0.0220003110095951, 0.0154943147771694, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.0879689972569602, 0.207984322071836, -0.265754984143154, 0.210573178414572, -0.00627310588132724, -0.00295334145686075, -0.00261054608514549, -0.00387120992564296, -0.126842853448363, 0.306175461989327, -0.403856272644198, 0.342561795741952, -0.00904521677844062, -0.00434763868718073, -0.00396713316558126, -0.00629770910904663, -0.00272017181873593, -0.00173022626023816, -0.00178611135162364, -0.00306899265680019, 0.0383008284550467, 0.0206233204859008, 0.0255831356372872, -0.103568695058546, -0.0782629848021481, 0.185719199739326, 0.0563829702642087, 0.0313403617540288, 0.0416188089603942, -0.157388834244543, -0.127318725090268, 0.302129183998959, 0.0169560741910449, 0.0124724984787888, 0.0187379208165114, -0.0473316098422471, -0.0506689302910036, 0.0908594356622281, 0.00120914472199063, 0.000889419068102146, 0.00133620894796094, 0.000672100686121976, 0.000719490060176454, 0.00089252416029498, -0.00871623327667453, -0.00933080910976658, -0.0070509430589669, 0.0354092820333488},
    {0.0174985944065183, 0.029466788535953, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, -0.00534222456152019, -0.00361590696451115, -0.00430211705354469, -0.0107923090820133, -0.154527546186846, 0.330011368059036, -0.366622398302526, 0.239192632867617, -0.00342995289485298, -0.00259182591384817, -0.00371794677692995, -0.0175569975586255, -0.0992137635313649, 0.2365470195983, -0.316839952784666, 0.389120107604863, -0.0113307209892053, -0.00562742560967781, -0.00678487933658837, -0.0287096173150646, 0.031125744023567, -0.0815659404066927, 0.165998121769477, 0.025851215233689, -0.124100720402198, 0.0563443238094873, 0.0223104495607475, -0.0704903705473231, 0.270046808008899, 0.0223409640327256, -0.201887847036957, 0.0916613069592546, 0.00254796784356098, 0.00167695757539999, 0.00578284080485405, 0.00255145275286994, 0.00480288799507104, 0.0104681916872641, 0.073701734940998, 0.0485071595553232, 0.167272676255486, -0.232862300323701, -0.438343036323648, 0.892089521161032, -0.0219629172026517, -0.041343282273483, 0.198471563814312, -0.0629028622529027},
    {0.0217651615841542, 0.0301544408087981, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.0274091197540596, -0.0071634342787703, -0.00594031364386982, -0.011246921862448, -0.139172828321605, 0.248753810380151, -0.205968627929981, 0.0566341297909969, -0.0211833561662754, -0.00609264721184816, -0.00592810457681634, -0.018296564542443, -0.10756082710638, 0.211570198073956, -0.205545302674773, 0.0921327651866988, -0.0122839984890329, -0.00638648725849444, -0.00749348392029716, -0.0258568697967753, 0.139850019066564, -0.303301889052389, 0.438098662911987, 0.0443492233638008, -0.167789230656524, 0.0641563418218738, 0.118945298523638, -0.302678515721806, 0.712701711629256, 0.044258072849825, -0.272960595421595, 0.104369947911726, 0.013584163553306, 0.00913669553498084, 0.0259826848221013, 0.00505449906476699, 0.00823962628291215, 0.0119195837084823, 0.0689750885493812, 0.0463925792045307, 0.131929947642522, -0.175519988457197, -0.286125111813636, 0.413287992708298, -0.0986777798289387, -0.160860258909838, 0.60859282392127, -0.0889892877687576},
    {0.0274003458448221, 0.0298409049274021, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.0610854342286924, 0.0232306873822269, 0.00669126628283969, 0.00717665632659225, -0.108378901130757, 0.135429332788425, -0.0546121987974091, -0.0124821118327559, -0.0591659989897213, 0.024228239884758, 0.0078712098834158, 0.0116750304913959, -0.104973403820015, 0.141244824496285, -0.0642425604898819, -0.0203059794997372, -0.0119885014703203, -0.0066480346895069, -0.0074983662991218, -0.0201356771221164, 0.243375823624968, -0.362768474720545, 0.238132814788186, -0.110404287296158, 0.267886498788715, -0.0517660436411061, 0.253826662117954, -0.426739376810484, 0.387395988763217, -0.129873073436884, 0.435799472520741, -0.0842133314492745, 0.0289883075262095, 0.0200855372261039, 0.0452167068747919, -0.0148321715329215, -0.020511972890468, -0.00961759465884518, 0.0514315884793258, 0.0356361296383089, 0.0802243131397709, -0.0864680007722811, -0.119579879709269, 0.0784960528037532, -0.155388943236062, -0.214893266576778, 0.521420011906789, 0.158688002977296},
    {0.0302582156650969, 0.0265020693494891, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.0891206073830918, 0.0989156565214027, -0.0302223496874193, -0.0087625340027234, -0.0661206272102359, 0.0421908315553682, 0.00264046129850596, 0.00187119892902542, -0.105520857724535, 0.123094447614705, -0.0406925701304423, -0.0142549464553037, -0.0782883499269336, 0.0525038935933199, 0.00355522180364721, 0.00304407840610789, -0.00894093136026364, -0.00529430977445549, -0.00572826125448677, -0.0122845275854093, 0.241764792404171, -0.180542653746287, -0.0171365171848402, -0.314040457459371, 0.355675036688131, 0.145522386249459, 0.300861406780796, -0.243089788685928, -0.027877795946283, -0.422836525655092, 0.578614428417817, 0.236736750281293, 0.0343599167627113, 0.0245123276814268, 0.0449173939628028, -0.0482901013499826, -0.058345463819148, 0.0270365518840591, 0.0254924120689171, 0.0181862593654887, 0.0333252470857066, -0.0205973412450427, -0.0248862892142951, -0.00236212503770431, -0.118028295404669, -0.142605118785308, 0.161511294647257, 0.280936830180622},
    {0.0257416392900364, 0.0190269258810564, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.0878504334226812, 0.157568839051331, -0.132636080114132, 0.0438329214248812, -0.0268465464558911, 0.00174684397405052, 0.000844454371940382, 0.000919836089063092, -0.121303800469526, 0.223660496831054, -0.196471909613941, 0.0713076774021096, -0.0370696875098229, 0.00247955111857617, 0.00125087806345125, 0.00149639524287991, -0.00423354856605206, -0.00264930503155426, -0.00276472412449657, -0.00498781022541953, 0.133654373845705, -0.0100008671933937, -0.00690608582347881, -0.275675643274785, 0.0294662669971706, 0.331483547871064, 0.189715199007309, -0.0148141401162544, -0.0112348646634437, -0.408354348391796, 0.047935911935041, 0.539259559420539, 0.0216664494002772, 0.0158283391111045, 0.0248315981213801, -0.0466361623797636, -0.0512176787686352, 0.0615862093229059, 0.00662113227785823, 0.00483704205785038, 0.00758838205535293, -0.000517019099184856, -0.000567810831510255, -0.000392101030648734, -0.0395581202410414, -0.0434442928364938, 0.00464364975090508, 0.128003012885621},
    {0.0136019878329509, 0.00894945296698989, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.0502269898723961, 0.116925136398512, -0.145927351620368, 0.110106556022686, -0.00493164708263826, -0.00188767340681878, -0.00151440904534075, -0.00204356107550104, -0.0769454525440008, 0.181036347722612, -0.229609921292738, 0.17912205076676, -0.00755505789865085, -0.00292270344760458, -0.00238285241145435, -0.00332447825028214, -0.000862826386782989, -0.000561763579208105, -0.000570886316972343, -0.000916248940524201, 0.0296474480394173, 0.012875075448987, 0.0141325473043701, -0.0783043067552676, -0.0465267206212464, 0.133711509675399, 0.0459034376839122, 0.0202583342166771, 0.0229909184989446, -0.123208195799601, -0.0756899671933489, 0.217522740600862, 0.00524240817331113, 0.00389379030146962, 0.00550818872481631, -0.0140710083006509, -0.0145481290329096, 0.0248422133666611, 0.000514737336232725, 0.000382320334733371, 0.000540833582191016, 0.000227166450212646, 0.00023486922607303, 0.000257808232733769, -0.00356783408859098, -0.00368881245606515, -0.00219181234952845, 0.0133302788979788},
    {0.0267678423103472, 0.0201430117194884, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.00337553010430067, -0.00205150924371657, -0.002058034372102, -0.00341655366698138, -0.117658048548054, 0.288722082265175, -0.389392282440996, 0.341103554416912, -0.00458647086152831, -0.00287261154019162, -0.00301923029022308, -0.00555807139457081, -0.15986680450647, 0.404281086211673, -0.571256238409763, 0.554909447702642, -0.00479647185936972, -0.00298367308690557, -0.00312601768238482, -0.00574276601693966, 0.0212800115225836, -0.0601691836488129, 0.116674242781905, 0.0149020923897653, -0.0605819216858597, 0.021494132932306, 0.0297971880275008, -0.0882709367117857, 0.189806405664418, 0.0218620492158885, -0.0985550583339168, 0.0349667931625684, 0.000894002818805817, 0.000651456689925309, 0.00103865505607177, 0.000655925438529242, 0.000727355508724915, 0.00104910609763193, 0.0311615135421641, 0.0227072846284333, 0.0362035364034469, -0.0923126030276815, -0.102365415934278, 0.198497082175759, -0.00680382061772612, -0.00754475450407269, 0.0306719160336638, -0.00759650869077106},
    {0.0252996401097377, 0.0185719699093626, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.0157466541584321, -0.0037427905172698, -0.00267315597091034, -0.0035604717988888, -0.0963481856909962, 0.202449247313067, -0.218148211810369, 0.127152152668922, -0.0218777468924618, -0.00534047574345143, -0.00397432758406004, -0.00579219833361035, -0.133862165186806, 0.28886877039115, -0.324332910255172, 0.206851936598334, -0.00401625659770309, -0.00251913179137698, -0.00262485806158846, -0.00470265394852327, 0.0880506682779473, -0.212599492451486, 0.326423530855205, 0.0240489893012457, -0.0827389756646379, 0.0244742477384674, 0.125636862646552, -0.31608332487961, 0.5310278913207, 0.0357549512968222, -0.134600295702079, 0.0398148630221872, 0.00376947345663189, 0.00275646118252992, 0.00429766082129862, 0.00107275314758308, 0.00117380595892296, 0.00119456237747515, 0.0230640696685628, 0.0168658072497397, 0.0262958606114859, -0.0580257073642748, -0.0634917000508116, 0.0974846396461411, -0.0252369538466304, -0.0276142623090705, 0.0950050643944841, -0.0107468543355462},
    {0.0222798637815404, 0.0157384636757174, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.0304886776317671, 0.0107584088389603, 0.00275781261113257, 0.00227193562591236, -0.065184081922608, 0.100280437182776, -0.064974943705504, 0.00838325633735896, -0.0438437190827518, 0.0158018985425533, 0.00418435023440377, 0.00369599943203779, -0.093736849167383, 0.147291418079095, -0.0985846245778233, 0.0136379351193379, -0.00281237972201508, -0.00178705171664073, -0.00184603177137815, -0.00318156671073534, 0.135818617311492, -0.239058106385729, 0.217617054249947, -0.0548325275417144, 0.135594537640337, -0.0197476187160157, 0.199489724091347, -0.362716030615443, 0.354020818079539, -0.0831958264843425, 0.220586062558379, -0.0321255526459661, 0.00598527537215435, 0.00440074726428632, 0.00662916434183092, -0.00249611820153075, -0.00267631819221329, -0.00096386056948307, 0.0127963791968912, 0.00940869504609328, 0.0141729988015651, -0.0232666213244205, -0.0249462873527773, 0.0227088620848717, -0.0315120319233673, -0.0337869513785023, 0.0835512469666718, 0.0191640690194894},
    {0.0174601641969976, 0.0118031792992787, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.0382036012222132, 0.0402707906090506, -0.0113654215697486, -0.00277398168006033, -0.0341553717751246, 0.0297193862963568, -0.00423826638234872, -0.00164784884783909, -0.0571355455781426, 0.06111926211102, -0.0176401553036295, -0.00451273116942695, -0.051081200158203, 0.0451053215830698, -0.00657817017556015, -0.00268073106307858, -0.00153258545360956, -0.000988567458496688, -0.0010109629012626, -0.00166708789366009, 0.118608021325498, -0.117471841982964, 0.0231551475671939, -0.142311111700304, 0.194815672108919, 0.0555136223703441, 0.180012228074643, -0.182326851992764, 0.037668942412368, -0.220879630062071, 0.316927383528957, 0.0903099165359302, 0.00540089350611586, 0.00399603386838142, 0.00578913319241685, -0.00662703513197361, -0.00694605618732188, 0.00270956171685484, 0.00482858996842357, 0.00357259572485564, 0.0051756899903913, -0.00489067669414926, -0.0051261106113179, 0.00101041956648666, -0.0195183534360829, -0.0204579539645, 0.0280057544625235, 0.0339275351802637},
    {0.0112160500006484, 0.00727374512952912, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.0328603051059603, 0.0572391342198017, -0.0460842819145469, 0.0138763194503272, -0.0121007418432334, 0.00259749741088061, 0.000903952700718287, 0.000791639729753593, -0.0509893480914854, 0.0895677407263753, -0.0730358568886421, 0.0225740853843905, -0.0187767257796372, 0.00406456138455539, 0.00143261340615371, 0.00128784458422866, -0.000563356708674886, -0.000368625559680005, -0.000373344867856809, -0.000590624525008171, 0.058506185453417, -0.0142235201623363, -0.00673572294370019, -0.115421158702178, 0.0381836357431634, 0.126453757203726, 0.0915504212460301, -0.0225418936754919, -0.0109577172391414, -0.182923176377682, 0.0621173832613313, 0.205715782381084, 0.00274678048751684, 0.00204438250187334, 0.00285562558404523, -0.00548823047180248, -0.00563358576833759, 0.00617207533649791, 0.00101149643840159, 0.000752839780526499, 0.00105157842819895, -0.000249054508513, -0.000255650695047867, -0.000121066531530411, -0.00560971849366775, -0.00575829138967053, 0.00190495835770952, 0.0154583744682551},
    {0.00485293934295204, 0.00304595863694754, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.0169490283234976, 0.0390069530753062, -0.0478485849051355, 0.0348567628001829, -0.00200537469754988, -0.000638888466666485, -0.000475038588243843, -0.000597351761171133, -0.0270708836687129, 0.0625083209661623, -0.0770601206703539, 0.0567052050431296, -0.00320297211812967, -0.00102381350470689, -0.000765049394997481, -0.000971775672177815, -9.60985345168287e-05, -6.36001340201971e-05, -6.39179461700291e-05, -9.78802368936091e-05, 0.0119183832377096, 0.00428298179362935, 0.00428003792419011, -0.030939545772748, -0.0149430883155108, 0.0510080300769961, 0.0190991109554805, 0.00689773991227454, 0.00696279311635655, -0.0498281220951639, -0.0243095118088299, 0.0829801901267496, 0.000573029207156232, 0.000428493256672354, 0.000581723792626195, -0.00149498944557311, -0.00151012679740905, 0.00248964847991291, 6.77996550040366e-05, 5.06984541300058e-05, 6.88283807442449e-05, 2.44861861608296e-05, 2.47341183560108e-05, 2.47171175797194e-05, -0.000456786694266368, -0.000461411837892458, -0.000222851295040695, 0.00160984056801376},
    {-0.00634204581202929, 0.0033736687631136, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, -0.00203791177178532, -0.0492117221773475, 0.0992013086517272, -0.0738509092732363, -0.00224657951086711, -0.0534241146055897, 0.10692910492615, -0.0792361187978445, 0.00186672700723236, 0.00270775846140313, 0.025297071451143, -0.0453962493417858, 0.00205786663823837, 0.00293953537827715, 0.0272677169715592, -0.0487065445939726, 0.0421979810464192, -0.135565454749909, 0.628290543629045, -0.0283178557954035, 0.0161444667353696, -0.0223718110929613, 0.0143676720035994, -0.0227179316958214, 0.0101011981811169, 0.0146941439702451, -0.000888311046095711, -0.00570497820444078, 0.0088318265428962, -0.00579324153221615, 0.00620921957215436, 0.00903250928257802, -0.0182154333958997, 0.263102111421653, 0.203498998675296, -0.118794431005032, -0.286356708329364, 0.185217860295405, -0.0200805648288412, 0.290041905135055, 0.224335855573075, -0.128962918095965, -0.310868080347518, 0.199646358368677, 0.0389718679788593, 0.0939425841553128, -0.0417702048278282, -0.0424164434544873},
    {-0.0106853276693848, 0.0115772632577271, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, -0.0274010505067602, -0.0481217403864267, 0.105826965373029, -0.0769617882285366, -0.00530248227273656, -0.0237500598790072, 0.0728748586553496, -0.0650020279883699, 0.0146717000428919, 0.00719541733809586, 0.0244226254420094, -0.0473085106547024, 0.00283917689101543, 0.00355123466570271, 0.016817976125512, -0.0399568305836849, 0.0582192890483208, -0.134368965523375, 0.207386421256723, -0.066837130682762, 0.0358043028635587, -0.0767957177864589, 0.0595392120224926, -0.0301110314791143, 0.0163185090590721, 0.0167314550889353, -0.0053536488816507, -0.0177228274895518, 0.0365988305517864, -0.00694898923818509, 0.0100310086012753, 0.0102848470593367, -0.109780279168362, 0.670583112662057, 0.451308792072928, -0.142493838383863, -0.379545813158116, 0.210897913990534, -0.0212440024532161, 0.129767107520561, 0.0873344935774072, -0.0703265751992815, -0.187321483324288, 0.145229106953919, 0.106020532605796, 0.282395714198688, -0.153042815009204, -0.0600069529033938},
    {-0.0102352418729336, 0.00318614435970198, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, -0.0126571512820065, 0.0143537935251022, -0.0723998288978307, 0.0491092861808114, -0.000855846139544769, -0.0017011992680907, 0.0333817769889968, -0.0441008898133743, 0.0285443214023187, -0.0170879000112396, -0.0117215303676544, 0.0301875416619842, 0.00193009838736995, 0.00202524321821199, 0.005404508804226, -0.0271088739443334, 0.0395780045482836, -0.0507328584660814, 0.00689944426242851, -0.0107878343256711, 0.0057310568390726, -0.0797988402663342, 0.0920558261790192, 0.0455268719942118, -0.037267487325796, -0.0135001655287294, -0.00682270690696089, -0.0129194301108832, 0.0565868352835748, 0.00737079936166052, -0.0229083726068188, -0.00829856919202062, -0.139904331697434, 0.323635014986764, 0.0722392598788917, 0.151143347183347, 0.573860568794342, -0.170167910286462, -0.00945999455336032, 0.0218834216346689, 0.00488464507640127, -0.0179133795644634, -0.0680134612436615, 0.0784602300632858, 0.0603471905904601, 0.229126016875703, -0.187558480429118, 0.10700595273598},
    {0.00496641091476393, -0.011801561675532, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, 0.0594964820405094, -0.120624902691672, 0.125434652322348, -0.0599613204849069, 0.0016822973516055, 0.00204848339993456, 0.00753331313448478, -0.0231834539600411, -0.0204347654762904, 0.0301742710270641, -0.015052523747274, -0.0368583011689746, -0.000577804782105317, -0.000512427300870537, -0.000904019525330904, -0.0142508991010521, -0.011848287343186, 0.00538637983819935, 0.00258397885603982, 0.0212051492401301, -0.011236152923305, -0.029834004541196, 0.0806085190825289, 0.0496738192420158, -0.0969030134598643, 0.0379510614356348, 0.00281071914707328, 0.00358016746981991, 0.0495501608220377, -0.00596100303954858, -0.0595664075674238, 0.023328566495279, 0.0576357432941007, -0.0376329322111706, -0.141630312498688, -0.122234496933111, 0.626132323960991, 0.478368417328807, 0.00162968389014093, -0.0010640928676904, -0.00400467878859431, 0.0020758179470358, -0.0106331416082053, 0.0287296932280311, -0.0113860858694686, 0.0583239313380665, -0.113777534921341, 0.189440364791817},
    {0.0263496071105022, 0.0080038352129213, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, -0.0455282927907743, 0.109434345863475, -0.15080433156421, 0.299945181214723, -0.000530247378602364, -0.000473709291275503, -0.00080991227462756, -0.00823909033431847, -0.135681023269177, 0.282736312981597, -0.302623682224074, 0.184376690406239, -0.00158021534532798, -0.00122388284394243, -0.00162527582784932, -0.00506457947298115, -0.0324034103825531, -0.00380781996748496, -0.00295758720151005, -0.00668370237087959, 0.00353768478630574, 0.00443980886007427, 0.0398642041456057, -0.0119454683360225, -0.0787301479845029, 0.0864482284436401, 0.00914001856619179, 0.00890950075286595, 0.0245045777907787, -0.0239713380659699, -0.0483955236813238, 0.0531398377109131, 0.187422412635166, 0.0277197895493027, 0.0445920774865157, -0.491548893679026, -0.150571145206208, 1.08966918597521, 0.00218282384204098, 0.000322839817681871, 0.000519343703536577, 0.00212777146164383, 0.000651778469724296, 0.00585219562230549, -0.0158903041743695, -0.00486751435712158, -0.0320807954006464, 0.0863145549122675},
    {0.0261153899063015, 0.0302224845101157, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.183081952923273, 0.472755167242471, -0.693290980381533, 0.753450370761893, -0.000685098508853435, -0.000506609750046169, -0.000605395551988611, -0.00136877883379716, -0.15273114932588, 0.375858140305485, -0.510844558915112, 0.463146916325962, -0.0005715248334853, -0.000402773807050391, -0.000446079687283231, -0.000841390117526165, -0.0117195126461702, -0.00554103138111577, -0.00513542221486781, -0.00863558164111844, 0.00456844460258429, 0.00406019525351191, 0.00813727702558389, -0.0141780709602834, -0.0211330510483065, 0.0348708803444415, 0.00363208529783322, 0.00299171446345384, 0.00500199470056436, -0.0104469704798227, -0.012990513782195, 0.0214351751990885, 0.0744784252336857, 0.0411575515467006, 0.0575846769898423, -0.214222367041932, -0.178712824081337, 0.439543117114766, 0.000278700643371116, 0.000154012870971471, 0.000215483698467461, 0.000229563095956161, 0.000191510670662774, 0.000383817842058254, -0.00207012653542015, -0.00172698194151817, -0.00257414408714891, 0.00898882818456455},
    {-0.0110271230805097, 0.0117859544381791, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, -0.00533638736500259, -0.021589474677939, 0.0708866405450277, -0.0648153237617092, -0.0297142669526367, -0.0385011904458148, 0.0864255424365168, -0.062734285582657, 0.00295045175569068, 0.00361626834906973, 0.0160892124049079, -0.0398420632543444, 0.0164288131844465, 0.00644900529020188, 0.0196160926625833, -0.0385628463970882, 0.0585357554359555, -0.129373925944914, 0.175306723361565, -0.0650794963063691, 0.0357749037316649, -0.0262610115094857, 0.0142628870184277, -0.0819968258027646, 0.0145632415484494, 0.0651399463159163, -0.00599234830794804, -0.00596048830774335, 0.00876741507713451, -0.0186109023749111, 0.00895204339478125, 0.0400416091578108, -0.0213506983799164, 0.119573754125017, 0.078353362005419, -0.0663105251505075, -0.179587540573384, 0.142667995223338, -0.118885738214351, 0.665814943251966, 0.436290050931204, -0.11825364884818, -0.320264119644221, 0.173941927289884, 0.109880054473007, 0.297586072438544, -0.0528534831921596, -0.165028595825849},
    {-0.0116958193796847, 0.00868942826669691, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, -0.0167229445882328, -0.0161405937908932, 0.0744586814191186, -0.0675455897618916, -0.016345793968674, -0.0164605936176501, 0.0767742256020668, -0.0700872974533167, 0.0148427436855896, 0.00638151686995215, 0.0144742293073114, -0.0415203612920179, 0.0145079970177742, 0.00650803540571892, 0.0149243543543365, -0.043082752293691, 0.0516918998203713, -0.0838466866383685, 0.0412250887240751, -0.0358001777363246, 0.0606589183534293, -0.111649968396047, 0.0782426680475976, -0.107010375739815, 0.0295940856905752, 0.0741714582685035, -0.0239827552691315, -0.0217039465904849, 0.0480958691343093, -0.0208020433238823, 0.0181915227080137, 0.0455932912233091, -0.0854504023725404, 0.279624171526345, 0.132853752011542, -0.0741175462222498, -0.23437163581397, 0.162448602623016, -0.0835232494105541, 0.273317840187487, 0.129857516831937, -0.0755869842279408, -0.239018235798383, 0.167500490591787, 0.278545525839862, 0.880805880216167, -0.243589881034134, -0.233467551046818},
    {-0.00575929267843154, -0.00515804432869901, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, 0.0180568823364595, -0.0159481203670528, -0.0486788032710566, 0.0431008137183391, 0.00616713919741464, 0.00514217279233521, 0.0477328791988053, -0.0705477914032103, 0.0151788194266244, -0.00831999241146507, -0.00467132225531181, 0.0264941258766691, 0.00518416692938183, 0.00268262576567057, 0.00458054935471372, -0.0433658185196247, 0.0184711533395948, -0.016608328329972, -0.00305500856414886, 0.0135071248184838, -0.0321631653551498, -0.145964620231556, 0.171822073141542, 0.15461492822938, -0.0889816857642901, -0.0598469743850446, -0.0167792370213337, -0.0140070776838756, 0.105619250345273, 0.0148371797724691, -0.0546971571990115, -0.0367880124736601, -0.0597843133070969, 0.0867188215718506, -0.0704430166245737, 0.0528647758526336, 0.338634019363569, -0.131075451218333, -0.0204187065694203, 0.0296179059986185, -0.0240590751445702, -0.0170452571090387, -0.109186198802953, 0.128528399601263, 0.106614352543, 0.68293577606614, -0.393033048742582, 0.416325384375381},
    {0.0114965700457506, -0.0103543496131472, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, 0.0487160015083047, -0.0883080091353922, 0.0683057070994246, -0.0526251123873067, 0.00695767866119286, 0.00519526230305945, 0.0120624974055011, -0.0538719236429516, -0.0456650504879513, 0.0640339164783737, -0.0289985647742543, -0.032348724573381, -0.00652193812105365, -0.00376718935977029, -0.0051210232234849, -0.0331151410630413, -0.0232376234689825, 0.00622457516001477, 0.00364434309255479, 0.0152385459635856, -0.0415491378876404, -0.0562811451289649, 0.208024526539326, 0.136630693123355, -0.294625982202666, 0.168239137275043, 0.0301281169318005, 0.0238936466936191, 0.127872945220575, -0.0580053142400194, -0.181106971901399, 0.10341681503917, 0.10734628634863, -0.0394797780221855, -0.0909999553413711, -0.20667256059336, 0.299245365959431, 0.368473445107362, 0.0153313273413632, -0.00563854997514003, -0.0129967244405359, 0.0121587857504661, -0.0176049509478884, 0.0650708434821411, -0.0972399536775842, 0.140795688796734, -0.30360724338994, 0.737050889895457},
    {0.0286331249853374, 0.0142799617871943, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, -0.0786155180524536, 0.180183183238994, -0.227528563330551, 0.263247185749171, -0.00462473340853543, -0.00324555768787727, -0.00464646010384143, -0.0259264273302239, -0.144761735858263, 0.294022599521717, -0.301560576395922, 0.161818385181666, -0.00851593238442565, -0.00529609529109963, -0.00615830015627302, -0.0159370083754822, -0.0303422121712233, -0.00597444597327713, -0.0048525477827356, -0.0101289835370485, 0.0294212418863079, 0.0278742507862934, 0.133035353826841, -0.0910346124745027, -0.287527730636603, 0.383229739093874, 0.0480095304404493, 0.036943823714596, 0.0817770038721056, -0.120654962207571, -0.176743667493169, 0.235571815733863, 0.17105764737271, 0.0416757755850919, 0.0644377196220509, -0.429892852309207, -0.199381890716993, 0.839340860388867, 0.0100628481015951, 0.00245167056644496, 0.00379069275492281, 0.00774346432721754, 0.00359137526936533, 0.0171405460669789, -0.0701951279005206, -0.0325561061198117, -0.102826639852127, 0.335821880299532},
    {0.0243834140019696, 0.0296919171784482, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.177845002139631, 0.452155668420226, -0.646858537591112, 0.661266465096996, -0.00336147904794573, -0.00228012796141549, -0.00256799349356297, -0.00533850326641933, -0.141645882360695, 0.345411287467401, -0.462849575846567, 0.406481350416946, -0.00267727324386344, -0.00174183802117237, -0.00183748784347619, -0.00328158485493615, -0.00953910730364748, -0.00475113027769315, -0.00445019405091738, -0.00736223322060809, 0.0220699483121885, 0.0178268522440286, 0.0324684740451171, -0.06681779932428, -0.0872806619365438, 0.154584525524274, 0.0168597007475028, 0.0127557271340272, 0.0199584129431104, -0.0478104381081744, -0.0536515356544616, 0.0950233075549243, 0.0600710050445718, 0.034793201585805, 0.0483370874319141, -0.170348282676652, -0.146342789854298, 0.338567432066033, 0.00113541242327314, 0.000657632301918046, 0.000913627623415216, 0.000859031324028874, 0.000737976565159925, 0.00134409443819925, -0.00831478638071559, -0.00714306605782561, -0.00933062058445944, 0.0349726090309801},
    {-0.00888246788236122, -4.16214011100732e-06, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, 1.34764571131697e-06, 2.34589687829912e-06, 0.0351417498325345, -0.0504430947992083, 1.7076988225013e-05, -2.18993997978407e-05, -0.0629150249458782, 0.0427474066498151, 0.00207617681188802, 0.00204132940906952, 0.00495444159751788, -0.0310074355429239, 0.0263087298629871, -0.0190562037323707, -0.00887004256151647, 0.0262768860950635, 0.0320568669764366, -0.0362041359827395, -5.86577422614717e-06, 1.27907673087719e-05, -8.84633105612432e-06, 0.0681493393296446, -0.0162998925724397, -0.0925068516383988, -0.0593298559286743, 0.115369044865993, -0.00769781311112098, 0.0096079996934464, -0.0100195650228907, -0.0130420310882866, -0.0364701390904392, 0.0709175009299217, -0.00937969153956924, 0.0182538627477392, -6.62595538407099e-06, -0.0158915560681607, -0.069288190527517, 0.0864121113201358, -0.11885681869661, 0.231307825632447, -8.39622469953868e-05, 0.148350740803415, 0.646818621763509, -0.154705447658132, 0.0599267458324432, 0.261284405700932, 0.167576410526233, -0.227470527214667},
    {-0.00438186087957977, -0.00681295111639303, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, 0.0101073362006734, 0.00568346715796637, 0.0351451051021586, -0.052567948285717, 0.0224826683241413, -0.017115252886681, -0.0423250421086932, 0.0415371758142848, 0.00496290698942557, 0.00178381589036712, 0.00264840080550196, -0.0323135857262808, 0.0110394459580144, -0.00537180196847259, -0.00318945341855569, 0.0255329556369079, 0.0134514304724192, -0.0110627097316332, -0.00265609563809122, 0.0168396543479754, -0.0486078465011175, 0.155615226861536, -0.0711213725288546, -0.114945842078815, -0.068010025284893, 0.131364712142299, -0.0152560834038924, 0.0117265687773736, -0.043718399578595, -0.00866187936743286, -0.0418058504080333, 0.0807500582702354, -0.0185893518541937, 0.0241497410540252, -0.0364075705728993, -0.0105543945334429, -0.0860951298768103, 0.098392962708179, -0.0413499881472977, 0.0537184681949509, -0.0809846746389743, 0.0317836149105709, 0.259267781302797, -0.118494062764006, 0.0902664474228084, 0.736328501815995, 0.435663605754063, -0.321804755462983},
    {0.00649963867312387, -0.0117909391625216, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, 0.0347177461769007, -0.0226829837593202, -0.0194855585338849, 0.0335435867035136, 0.0269842516546397, -0.00603551746377197, -0.00876488846392661, 0.0185044353861292, -0.0157527489567286, 0.00761282852421904, 0.00331676160313938, 0.0206192860832164, -0.0122437712383401, 0.00202563119535564, 0.00149192775061567, 0.0113747003386199, -0.0149188861614174, 0.00608305867108542, 0.00308515890396081, 0.0202113674476524, -0.104103979779745, 0.0482167279666835, -0.0613421198629884, 0.140845268185824, 0.0571481039328643, -0.105994687797817, 0.034939219423738, -0.00820727779862269, -0.0377070803306021, -0.02397417434508, 0.0351290133199048, -0.0651550715289333, 0.0425730134126714, -0.0246468125557046, -0.0779745095406277, -0.0292122395057679, 0.105493956438009, -0.0793906612641798, 0.0330897317403691, -0.0191566523097158, -0.0606054257488449, -0.00777283022214874, 0.0280699674769364, -0.0357110775063413, -0.134070121598529, 0.484166493457687, 0.196451023490723, 0.573850575427869},
    {0.0218166735098088, -0.000396180986240282, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, 0.0016850685367437, -0.00261416436528539, 0.00143665582940341, -0.0409559557664377, 0.000547681628745301, 9.49985402434173e-05, 0.000112306740667938, -0.0152948461494822, -0.0821315304265295, 0.106627813860814, -0.0421122676094756, -0.0251756789225904, -0.0266944218436793, -0.00387484689204711, -0.00329201428801527, -0.00940176168823124, -0.0325268279583357, 0.000218004723301907, 0.000156669398596573, 0.000410216847388349, -0.00279906307588788, -0.000731198562916172, 0.0716657109865359, 0.00653976121473069, -0.141635372249502, 0.297967524909641, 0.114169552842125, 0.0214334073109031, 0.0440530051317887, -0.191698087141148, -0.0870634463072912, 0.183161022520475, 0.139114209894575, -0.00120587578307202, -0.00209651514742667, -0.233581784872354, 0.00489832064355577, 0.223179475587969, 0.0452149544041173, -0.000391934214268331, -0.000681410165577478, 0.00848834483592526, -0.000178004610942485, 0.0174464607140272, -0.250102923105532, 0.00524477673604082, -0.113589148133033, 1.01592911016151},
    {0.0302602001667234, 0.0236731291383541, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.123983018812676, 0.264604231380493, -0.294894932128271, 0.204874433632237, -0.0165981047421918, -0.00715703702973115, -0.00768596711021537, -0.02327285910972, -0.148692369932632, 0.290316139028517, -0.279210915864665, 0.125936579040831, -0.0199060448288925, -0.00785249482412042, -0.00727718818584348, -0.0143058565620665, -0.024255273227939, -0.00764573936306587, -0.00659796760180473, -0.0124320806881216, 0.0983244220117467, 0.0542495311672531, 0.132140523387534, -0.268507118668092, -0.336020030755683, 0.678736343273606, 0.10787872295819, 0.0513642644623302, 0.0812269504449894, -0.254226540885044, -0.206551947025893, 0.417220107102281, 0.131448910284485, 0.0500118481387926, 0.0736455858695552, -0.309771944349812, -0.201113453401184, 0.508377620011561, 0.0175975936224404, 0.0066952869974274, 0.00985923039920356, 0.00837873704784178, 0.00543973324107429, 0.0132500536336069, -0.115108315633292, -0.0747318512681794, -0.0935222838266839, 0.462886930472144},
    {0.0208837824772987, 0.0273991946635943, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.161228140099431, 0.400101823491238, -0.550948270007869, 0.514636432413085, -0.00693501587567341, -0.00405573932646439, -0.00415135234621366, -0.00759654426569469, -0.120035982431373, 0.28854446919111, -0.378174407346312, 0.316347679887783, -0.0051631895232448, -0.00292490831688951, -0.00284951473428301, -0.00466960557446205, -0.00629128356187381, -0.00338045124712296, -0.0032174645067181, -0.00519436877155115, 0.0444428333845822, 0.0305213990124239, 0.0479600994071268, -0.129512458891891, -0.13654327736291, 0.273783907869765, 0.0320511755142852, 0.0209500829955213, 0.0294811350675107, -0.0888981780171575, -0.0839333290017818, 0.16829532188209, 0.039053967076737, 0.0242129757642641, 0.0332879505960335, -0.108321347400085, -0.0970056138378367, 0.205065800379851, 0.0016798549032332, 0.00104148922898305, 0.00143183730650096, 0.00109802835866305, 0.000983323393772453, 0.00154515485006049, -0.012032206083162, -0.0107752678944205, -0.0113602228338165, 0.048205208161284},
    {0.0101644112236962, -0.0109437322728922, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, 0.00265561165013074, 0.00277042286983634, 0.00774815294057037, -0.0335768632939073, 0.0557887295356483, -0.115066962106936, 0.124046280414075, -0.0522493142351213, -0.00206888955864445, -0.00165092370827361, -0.00261316748166403, -0.020639741246323, -0.0434629513771955, 0.0685695955840057, -0.0418362555160878, -0.0321177209637213, -0.0212633870913167, 0.00645575293301403, 0.00365371796926726, 0.0167773679286115, -0.017319952436912, 0.066852513555867, 0.0970236731312838, -0.0338138843694442, -0.175708585038306, 0.127313382496836, 0.0103211392078777, -0.0225468980583687, 0.0596405772233313, 0.0114041815824652, -0.108008294229385, 0.0782597007030627, 0.00504941268934679, -0.00212276595816234, -0.00520863652853827, 0.00557926969439204, -0.0101688635658783, 0.0382870066797381, 0.106077377249782, -0.0445947794744644, -0.109422330078203, -0.231729827781459, 0.422354381832925, 0.612966832642402, -0.0348801212954483, 0.0635730506039551, 0.33034745863991, -0.167089166495659},
    {0.0155122697307477, -0.00766332463985574, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, 0.0089597013303825, 0.00338168273878039, 0.00558144257295904, -0.0349912474691861, 0.03304083660687, -0.0519648837128461, 0.0272127142256642, -0.0418203837218571, -0.0156006160152442, -0.00470230194600601, -0.00496770894873703, -0.0215091650261775, -0.0575306459131931, 0.0722582786979664, -0.0242204129508019, -0.0257070439035829, -0.0281457276807841, 0.00463130748587514, 0.00296439209504613, 0.00993638458944254, -0.0479481933002691, 0.126107477245155, 0.191659952362795, -0.0302636455110632, -0.231003451275631, 0.144965106220525, 0.0666729850431344, -0.112240739741459, 0.117813620332084, 0.0269358648165765, -0.141998119943555, 0.0891102380811218, 0.0326184358075965, -0.00719393524937956, -0.0144194801926216, 0.0131778377235275, -0.0091011987515459, 0.0435954169258846, 0.120287537290538, -0.0265291922543362, -0.0531749520918535, -0.202498240605751, 0.139854259344908, 0.212552508933874, -0.186845886872036, 0.129044050170325, 0.984997691207883, -0.236382660307924},
    {0.0235602360807905, 0.00242217246301152, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, -0.00601102036289129, 0.00300848299555989, 0.00140208737896727, 0.0223279009667123, -0.00774557056222443, 0.00717932068418101, 0.00035293822963152, 0.00397204289231763, -0.0521782100505411, 0.0221414434455202, 0.00763849492268663, 0.0137249895707229, -0.0672348425655044, 0.0528374343948943, 0.00192278806264385, 0.00244161989757995, -0.0328933134587859, -0.00127304603535356, -0.000942363494893903, -0.00232932866944796, 0.022890805356466, -0.0311158320724685, -0.0228500559069325, -0.0168016078072763, 0.34116281345662, -0.11696848358163, 0.168468784091727, -0.169517341690776, -0.0140459588870732, -0.0915342352082086, 0.209713222196366, -0.0719006779748152, 0.0824200118822443, 0.00408428952379173, 0.00688396145322257, -0.0447813094524683, -0.00505275453162602, -0.0351759809093124, 0.106203269866522, 0.0052628590144832, 0.00887040900954819, -0.106864283990075, -0.0120576866063496, -0.00885461820277451, -0.340729942564745, -0.0384451634488731, 0.780643154897169, 0.421523682717848},
    {0.0297613960356093, 0.0189589162037066, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, -0.0724739320858042, 0.0961639620233355, -0.0394468229313448, -0.027261858799801, -0.0390515961300796, 0.0124558869364595, 0.00589090048204116, 0.0145778050557574, -0.105570386298514, 0.126084042471053, -0.0432981721365902, -0.016757899825139, -0.0568851719559672, 0.0163313630643682, 0.00646605237524097, 0.00896099560153858, -0.0278299423469547, -0.00707806935557164, -0.00592549409332401, -0.0117440028107332, 0.17070195853941, -0.0715604211734563, -0.0911310520484138, -0.297692260133122, 0.336038002649934, 0.328816568729682, 0.223813500790995, -0.07854714787875, -0.0560183754307317, -0.326757131883804, 0.206562994372507, 0.202123969612012, 0.109496317042074, 0.0340426061301111, 0.0513352712705219, -0.159859447182855, -0.0895251176953565, 0.0988851440159856, 0.0590006065325078, 0.0183433969642291, 0.0276613152231211, -0.0207062100805641, -0.0115959733825859, -0.0147672866726004, -0.283768681645196, -0.158917255565657, 0.179387388583809, 0.746253812808758},
    {0.0277086251948062, 0.0300889454319043, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.149068120911646, 0.294363584413148, -0.288327136953214, 0.136372299873129, -0.0330847176025082, -0.00521448988916363, -0.00390183033368254, -0.00703787904698708, -0.131811378803804, 0.246174341648927, -0.220629172869922, 0.0838282289179195, -0.0292546938798931, -0.00436084381177453, -0.00298569745566091, -0.00432619334275614, -0.0143122788603935, -0.00633883292814316, -0.00580000035399198, -0.00994958093958398, 0.181340605155926, 0.0347380525200539, 0.0456694803544959, -0.43523155552094, -0.14648556610804, 0.749006978310936, 0.151653962827897, 0.026581708109754, 0.028073088576498, -0.333041069655042, -0.0900448667383323, 0.460415557245728, 0.074193694016686, 0.0386386245243292, 0.0545346359098209, -0.162933739126998, -0.130887367428771, 0.225249181345676, 0.0164668166434047, 0.00857559599677592, 0.0121036142241401, 0.00288628206839917, 0.00231859812224139, 0.00304821841502332, -0.100374178118915, -0.0806322373880543, -0.0271383331252469, 0.34001500036677},
    {0.0154943147771693, 0.0220003110095953, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.126842853448363, 0.306175461989327, -0.403856272644199, 0.342561795741953, -0.00904521677844062, -0.00434763868718073, -0.00396713316558107, -0.00629770910904653, -0.0879689972569598, 0.207984322071835, -0.265754984143153, 0.210573178414572, -0.00627310588132723, -0.00295334145686074, -0.00261054608514568, -0.00387120992564306, -0.00306899265680021, -0.00178611135162361, -0.00173022626023818, -0.0027201718187359, 0.0563829702642086, 0.0313403617540288, 0.0416188089603942, -0.157388834244543, -0.127318725090269, 0.302129183998959, 0.0383008284550467, 0.0206233204859008, 0.0255831356372872, -0.103568695058546, -0.0782629848021477, 0.185719199739325, 0.0187379208165115, 0.0124724984787888, 0.0169560741910448, -0.0506689302910037, -0.0473316098422469, 0.090859435662228, 0.00133620894796093, 0.000889419068102144, 0.00120914472199067, 0.000719490060176492, 0.000672100686121903, 0.000892524160294979, -0.00933080910976641, -0.00871623327667468, -0.00705094305896689, 0.0354092820333487},
    {0.0294667885359529, 0.0174985944065183, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, -0.00342995289485306, -0.00259182591384802, -0.00371794677692994, -0.0175569975586256, -0.0992137635313648, 0.2365470195983, -0.316839952784666, 0.389120107604863, -0.00534222456152012, -0.0036159069645113, -0.0043021170535447, -0.0107923090820133, -0.154527546186847, 0.330011368059036, -0.366622398302526, 0.239192632867617, -0.0287096173150646, -0.00678487933658821, -0.005627425609678, -0.0113307209892053, 0.0223104495607475, -0.0704903705473233, 0.270046808008898, 0.0223409640327255, -0.201887847036956, 0.0916613069592546, 0.031125744023567, -0.0815659404066925, 0.165998121769478, 0.0258512152336892, -0.124100720402198, 0.0563443238094873, 0.00578284080485415, 0.00167695757539999, 0.00254796784356089, 0.00480288799507105, 0.00255145275286993, 0.0104681916872641, 0.167272676255486, 0.0485071595553232, 0.0737017349409982, -0.438343036323648, -0.232862300323702, 0.892089521161032, -0.0413432822734825, -0.0219629172026522, 0.198471563814312, -0.0629028622529027},
    {0.0301544408087981, 0.0217651615841542, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.0211833561662755, -0.00609264721184803, -0.00592810457681632, -0.0182965645424431, -0.10756082710638, 0.211570198073956, -0.205545302674773, 0.0921327651866991, -0.0274091197540595, -0.00716343427877044, -0.00594031364386982, -0.011246921862448, -0.139172828321605, 0.248753810380151, -0.205968627929982, 0.0566341297909966, -0.0258568697967753, -0.00749348392029705, -0.00638648725849457, -0.0122839984890328, 0.118945298523638, -0.302678515721806, 0.712701711629257, 0.0442580728498248, -0.272960595421595, 0.104369947911727, 0.139850019066564, -0.303301889052389, 0.438098662911987, 0.0443492233638011, -0.167789230656524, 0.0641563418218738, 0.0259826848221014, 0.00913669553498084, 0.0135841635533059, 0.00823962628291216, 0.005054499064767, 0.0119195837084823, 0.131929947642522, 0.0463925792045307, 0.0689750885493813, -0.286125111813636, -0.175519988457197, 0.413287992708298, -0.160860258909837, -0.0986777798289392, 0.60859282392127, -0.0889892877687576},
    {0.029840904927402, 0.0274003458448222, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.0591659989897215, 0.0242282398847582, 0.00787120988341577, 0.0116750304913959, -0.104973403820015, 0.141244824496285, -0.0642425604898815, -0.020305979499737, -0.0610854342286922, 0.0232306873822267, 0.00669126628283973, 0.00717665632659223, -0.108378901130757, 0.135429332788424, -0.0546121987974095, -0.0124821118327562, -0.0201356771221164, -0.00749836629912174, -0.00664803468950696, -0.0119885014703203, 0.253826662117954, -0.426739376810484, 0.387395988763217, -0.129873073436885, 0.435799472520741, -0.0842133314492743, 0.243375823624968, -0.362768474720545, 0.238132814788185, -0.110404287296157, 0.267886498788714, -0.0517660436411062, 0.0452167068747919, 0.0200855372261039, 0.0289883075262095, -0.0205119728904679, -0.0148321715329214, -0.00961759465884518, 0.0802243131397707, 0.0356361296383089, 0.051431588479326, -0.119579879709269, -0.0864680007722812, 0.0784960528037532, -0.214893266576777, -0.155388943236063, 0.521420011906789, 0.158688002977296},
    {0.0265020693494889, 0.0302582156650971, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.105520857724535, 0.123094447614705, -0.0406925701304423, -0.0142549464553037, -0.0782883499269336, 0.0525038935933199, 0.00355522180364749, 0.00304407840610811, -0.0891206073830917, 0.0989156565214025, -0.0302223496874193, -0.00876253400272341, -0.0661206272102359, 0.0421908315553681, 0.00264046129850569, 0.00187119892902518, -0.0122845275854093, -0.00572826125448673, -0.00529430977445554, -0.00894093136026363, 0.300861406780796, -0.243089788685928, -0.027877795946283, -0.422836525655093, 0.578614428417818, 0.236736750281293, 0.241764792404171, -0.180542653746287, -0.0171365171848403, -0.314040457459371, 0.355675036688131, 0.145522386249459, 0.0449173939628028, 0.0245123276814268, 0.0343599167627112, -0.058345463819148, -0.0482901013499826, 0.0270365518840591, 0.0333252470857065, 0.0181862593654886, 0.0254924120689172, -0.024886289214295, -0.0205973412450427, -0.00236212503770431, -0.142605118785308, -0.118028295404669, 0.161511294647257, 0.280936830180622},
    {0.0190269258810563, 0.0257416392900366, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.121303800469527, 0.223660496831055, -0.196471909613941, 0.0713076774021095, -0.0370696875098229, 0.00247955111857616, 0.00125087806345149, 0.00149639524288004, -0.0878504334226811, 0.157568839051331, -0.132636080114133, 0.0438329214248812, -0.0268465464558911, 0.00174684397405053, 0.000844454371940138, 0.000919836089062941, -0.00498781022541954, -0.00276472412449652, -0.0026493050315543, -0.00423354856605203, 0.189715199007309, -0.0148141401162544, -0.0112348646634437, -0.408354348391796, 0.0479359119350408, 0.53925955942054, 0.133654373845705, -0.0100008671933937, -0.00690608582347873, -0.275675643274785, 0.0294662669971707, 0.331483547871064, 0.0248315981213801, 0.0158283391111045, 0.0216664494002771, -0.0512176787686352, -0.0466361623797635, 0.0615862093229059, 0.00758838205535287, 0.00483704205785038, 0.00662113227785832, -0.000567810831510211, -0.000517019099184909, -0.000392101030648734, -0.0434442928364935, -0.0395581202410417, 0.00464364975090508, 0.128003012885621},
    {0.00894945296698976, 0.0136019878329511, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.0769454525440012, 0.181036347722612, -0.229609921292739, 0.179122050766761, -0.00755505789865087, -0.0029227034476046, -0.00238285241145415, -0.00332447825028202, -0.0502269898723957, 0.116925136398511, -0.145927351620367, 0.110106556022686, -0.00493164708263824, -0.00188767340681876, -0.00151440904534095, -0.00204356107550115, -0.000916248940524214, -0.000570886316972329, -0.000561763579208115, -0.000862826386782971, 0.0459034376839123, 0.0202583342166771, 0.0229909184989446, -0.123208195799601, -0.0756899671933493, 0.217522740600863, 0.0296474480394173, 0.012875075448987, 0.0141325473043701, -0.0783043067552673, -0.0465267206212459, 0.133711509675399, 0.00550818872481641, 0.0038937903014696, 0.005242408173311, -0.0145481290329096, -0.0140710083006508, 0.0248422133666611, 0.000540833582190996, 0.000382320334733371, 0.000514737336232763, 0.000234869226073054, 0.000227166450212601, 0.000257808232733768, -0.00368881245606502, -0.0035678340885911, -0.00219181234952845, 0.0133302788979788},
    {0.0201430117194883, 0.0267678423103474, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.00458647086152834, -0.00287261154019147, -0.0030192302902231, -0.00555807139457083, -0.15986680450647, 0.404281086211673, -0.571256238409763, 0.554909447702643, -0.00337553010430064, -0.00205150924371672, -0.00205803437210197, -0.00341655366698136, -0.117658048548054, 0.288722082265175, -0.389392282440997, 0.341103554416912, -0.00574276601693965, -0.00312601768238468, -0.0029836730869057, -0.00479647185936969, 0.0297971880275009, -0.0882709367117859, 0.189806405664418, 0.0218620492158883, -0.0985550583339168, 0.0349667931625685, 0.0212800115225835, -0.0601691836488126, 0.116674242781906, 0.0149020923897654, -0.0605819216858597, 0.021494132932306, 0.00103865505607183, 0.000651456689925309, 0.000894002818805752, 0.000727355508724904, 0.000655925438529257, 0.00104910609763193, 0.0362035364034465, 0.0227072846284333, 0.0311615135421644, -0.102365415934278, -0.0923126030276816, 0.198497082175759, -0.00754475450407243, -0.0068038206177264, 0.0306719160336638, -0.00759650869077106},
    {0.0185719699093625, 0.0252996401097378, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.0218777468924618, -0.00534047574345127, -0.00397432758406007, -0.00579219833361035, -0.133862165186805, 0.28886877039115, -0.324332910255171, 0.206851936598334, -0.015746654158432, -0.00374279051726997, -0.0026731559709103, -0.0035604717988888, -0.0963481856909964, 0.202449247313067, -0.218148211810369, 0.127152152668922, -0.00470265394852328, -0.00262485806158837, -0.00251913179137707, -0.00401625659770305, 0.125636862646552, -0.316083324879609, 0.531027891320699, 0.035754951296822, -0.134600295702079, 0.0398148630221872, 0.0880506682779474, -0.212599492451486, 0.326423530855206, 0.0240489893012459, -0.0827389756646381, 0.0244742477384673, 0.00429766082129869, 0.00275646118252992, 0.00376947345663181, 0.001173805958923, 0.00107275314758304, 0.00119456237747515, 0.0262958606114856, 0.0168658072497397, 0.0230640696685631, -0.0634917000508116, -0.0580257073642749, 0.0974846396461412, -0.0276142623090702, -0.0252369538466307, 0.0950050643944842, -0.0107468543355462},
    {0.0157384636757173, 0.0222798637815405, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.0438437190827519, 0.0158018985425535, 0.00418435023440369, 0.00369599943203781, -0.093736849167383, 0.147291418079095, -0.0985846245778229, 0.0136379351193382, -0.030488677631767, 0.0107584088389602, 0.00275781261113266, 0.00227193562591234, -0.065184081922608, 0.100280437182776, -0.0649749437055044, 0.00838325633735863, -0.00318156671073534, -0.00184603177137812, -0.00178705171664076, -0.00281237972201507, 0.199489724091347, -0.362716030615443, 0.354020818079539, -0.0831958264843425, 0.220586062558379, -0.0321255526459659, 0.135818617311492, -0.239058106385729, 0.217617054249947, -0.0548325275417143, 0.135594537640337, -0.0197476187160158, 0.006629164341831, 0.00440074726428632, 0.00598527537215425, -0.00267631819221325, -0.00249611820153076, -0.00096386056948307, 0.0141729988015649, 0.00940869504609328, 0.0127963791968914, -0.0249462873527773, -0.0232666213244205, 0.0227088620848717, -0.033786951378502, -0.0315120319233677, 0.0835512469666718, 0.0191640690194894},
    {0.0118031792992786, 0.0174601641969978, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.0571355455781428, 0.0611192621110203, -0.0176401553036296, -0.00451273116942695, -0.0510812001582032, 0.0451053215830699, -0.00657817017555982, -0.00268073106307833, -0.038203601222213, 0.0402707906090503, -0.0113654215697485, -0.00277398168006034, -0.0341553717751245, 0.0297193862963566, -0.00423826638234904, -0.00164784884783936, -0.00166708789366008, -0.00101096290126259, -0.000988567458496704, -0.00153258545360957, 0.180012228074643, -0.182326851992764, 0.0376689424123681, -0.220879630062072, 0.316927383528958, 0.0903099165359305, 0.118608021325498, -0.117471841982963, 0.0231551475671938, -0.142311111700304, 0.194815672108918, 0.0555136223703437, 0.0057891331924169, 0.00399603386838142, 0.00540089350611578, -0.00694605618732182, -0.00662703513197361, 0.00270956171685484, 0.00517568999039113, 0.00357259572485564, 0.00482858996842373, -0.00512611061131783, -0.00489067669414928, 0.00101041956648666, -0.0204579539644997, -0.0195183534360831, 0.0280057544625235, 0.0339275351802637},
    {0.00727374512952904, 0.0112160500006485, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.0509893480914855, 0.0895677407263755, -0.0730358568886421, 0.0225740853843905, -0.0187767257796373, 0.00406456138455537, 0.00143261340615399, 0.00128784458422882, -0.0328603051059602, 0.0572391342198015, -0.0460842819145469, 0.0138763194503272, -0.0121007418432334, 0.00259749741088063, 0.000903952700718012, 0.000791639729753418, -0.000590624525008177, -0.000373344867856799, -0.000368625559680019, -0.000563356708674876, 0.09155042124603, -0.0225418936754919, -0.0109577172391415, -0.182923176377682, 0.0621173832613312, 0.205715782381084, 0.0585061854534171, -0.0142235201623362, -0.00673572294370009, -0.115421158702177, 0.0381836357431634, 0.126453757203726, 0.00285562558404528, 0.00204438250187334, 0.00274678048751679, -0.00563358576833754, -0.00548823047180252, 0.00617207533649791, 0.00105157842819887, 0.000752839780526499, 0.00101149643840168, -0.000255650695047845, -0.00024905450851302, -0.000121066531530411, -0.00575829138967038, -0.00560971849366792, 0.00190495835770952, 0.0154583744682551},
    {0.00304595863694743, 0.00485293934295215, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.0270708836687133, 0.0625083209661633, -0.0770601206703547, 0.0567052050431302, -0.00320297211812971, -0.00102381350470692, -0.000765049394997272, -0.000971775672177693, -0.0169490283234971, 0.0390069530753052, -0.0478485849051347, 0.0348567628001823, -0.00200537469754983, -0.000638888466666462, -0.000475038588244052, -0.000597351761171258, -9.78802368936118e-05, -6.39179461700278e-05, -6.36001340201985e-05, -9.60985345168231e-05, 0.0190991109554806, 0.00689773991227449, 0.00696279311635649, -0.0498281220951644, -0.0243095118088304, 0.0829801901267507, 0.0119183832377095, 0.00428298179362939, 0.00428003792419018, -0.0309395457727475, -0.0149430883155103, 0.051008030076995, 0.0005817237926263, 0.000428493256672348, 0.000573029207156139, -0.00151012679740904, -0.0014949894455731, 0.0024896484799129, 6.88283807442168e-05, 5.06984541300058e-05, 6.77996550040708e-05, 2.47341183560226e-05, 2.44861861608115e-05, 2.47171175797193e-05, -0.000461411837892344, -0.000456786694266479, -0.000222851295040694, 0.00160984056801375},
    {0.011212845430362, -0.012513198351154, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, 0.110772181805886, -0.208071106282044, 0.201984382314542, -0.0990472496003532, 0.12211446906808, -0.225881439142981, 0.217718994875168, -0.10626977667799, -0.0022698503522531, -0.00179692337955245, -0.0028029029778393, -0.020199909014669, -0.00250226696008489, -0.00195073523785067, -0.00302124952471562, -0.0216728867138269, -0.0688168296738457, 0.183176207073004, -0.294334759695954, 0.684912572298823, 0.0682600995319012, -0.0455513793747796, 0.0192696123733746, -0.0462561176199214, 0.0135475095344601, 0.0197074695465102, 0.000589501209135679, 0.000632108757277241, 0.00392988617312106, 0.000641888290245367, 0.00276290821881121, 0.00401918370631291, 0.0162123406290097, -0.0593557148961159, 0.38285553474997, 0.0176530793252999, -0.259440152714044, 0.110534761061572, 0.017872369542487, -0.0654333199232004, 0.422057231279378, 0.0191641359271615, -0.281647539217126, 0.119145434915933, -0.00579129401155838, 0.0851123010939674, -0.0249277235077282, -0.0253133873528489},
    {0.0164398153896087, -0.0273770165770784, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, 0.180416762354003, -0.246495727242803, 0.220428635877593, -0.103219493481902, 0.0349131389634354, -0.121655788733429, 0.151792179115675, -0.0871793205263413, -0.0164552242707861, -0.00492616592994068, -0.00514129646939657, -0.0210508054013366, -0.00318431349806178, -0.00243126567889088, -0.00354041384624268, -0.0177795380457135, -0.0875743328428927, 0.191612435862307, -0.223629290575918, 0.195819938431223, 0.18340167254765, -0.159958997720859, 0.0798527093604429, -0.0627187368589143, 0.0218860330331137, 0.0224398673581592, 0.003665244346846, 0.0037308974260817, 0.0162853332138362, 0.0014628572149619, 0.00446348462723379, 0.00457643479011264, 0.100800793821526, -0.29403875930584, 1.02865870250385, 0.0402311973122853, -0.351775278729851, 0.125860165397376, 0.0195063478381805, -0.0569005669447604, 0.199059686904238, 0.0198557520467495, -0.173615581371304, 0.086670176465348, -0.0299334554728398, 0.261733439364735, -0.0913332599904371, -0.035811093976741},
    {0.0241754756606098, 0.00769851183855555, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, -0.0489992445747, 0.267079884396059, -0.160437252917034, 0.0658643173647256, -0.00331321111484882, -0.0316540782798458, 0.073973663738371, -0.0591471639811746, -0.0533456433751072, 0.0225203407828071, 0.00770119898836324, 0.0134325104780699, -0.00360710415218172, -0.00266909142798139, -0.00355083307641828, -0.0120625997765331, -0.0992018341832287, 0.148164197799285, -0.0843456371815984, -0.0185830554278953, 0.106637314753757, -0.176833383630821, 0.123463292225494, 0.100887065451002, -0.0499823516793695, -0.0181061313655988, 0.00899172423205336, 0.00848823481059474, 0.0251793692370997, -0.00484271172850352, -0.0101935082532451, -0.00369260335515127, 0.247288544676479, -0.471191240681806, 0.598104697243668, -0.133183258819301, 0.565852843131987, -0.101553215623277, 0.0167210568633937, -0.0318608188635711, 0.0404424016727429, 0.0157847653325304, -0.0670643924827068, 0.0468236851945558, -0.0531762439644613, 0.225928762376926, -0.111931601986109, 0.0638592703693536},
    {0.0299005753431563, -0.000692705759853922, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, 0.00436230428657873, -0.0132065134800394, 0.346278038065547, -0.0804188321427703, 0.000123346670198236, 0.000224276439037023, 0.0207966526318344, -0.03109314934069, -0.105804882736616, 0.125936349182971, -0.0430093491732372, -0.0164007895111114, -0.00299169409535099, -0.00213868376258169, -0.0025830413608495, -0.00634120372040313, -0.0822769537703658, 0.0620609909795396, 0.000808339326836309, 0.000691823711102612, -0.00123018051608056, -0.0823604990239475, 0.108110410393762, 0.137130787640276, -0.129964235452736, 0.0508991465589974, 0.0117309116645637, 0.0102295585373871, 0.0220482695108045, -0.0170322841176121, -0.0265051855745516, 0.0103804813719166, 0.32262111230204, -0.296844513069609, -0.00689980563393298, -0.468418363737865, 0.769135723398206, 0.285481857011572, 0.00912229806172759, -0.00839344984860786, -0.000195095984610626, 0.00795480220858043, -0.0130616624471412, 0.0171453755662, -0.0436329501586933, 0.0716446307025765, -0.0679004315061564, 0.113054677471619},
    {0.0274659679169432, -0.0063064816626327, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, 0.0395383094710886, -0.109983778158356, 0.203317202134924, 0.402280019603826, 0.000460484759394707, 0.000476087623059381, 0.00109193877884005, -0.0110500905791669, -0.130480475709523, 0.243240342500804, -0.217371432971372, 0.0820418520171364, -0.00151964692640052, -0.0010529163339581, -0.00116741866689654, -0.00225357922813269, -0.0417930162395376, 0.00441662708652155, 0.0021350699270713, 0.00258275537263003, -0.00355544628755469, -0.00598583280785828, 0.0534650123740611, 0.0161051023871781, -0.10559117951605, 0.115942502867309, 0.00786323208030555, 0.00639960141743317, 0.0109037695623234, -0.0172183619845816, -0.021534492149777, 0.0236455632872443, 0.216252986347212, -0.0268441585068068, -0.0199416979909376, -0.473535838844077, 0.0903298944614684, 0.650295403023377, 0.00251860045911436, -0.000312641740036683, -0.000232251912742814, 0.00204979821318835, -0.000391011706139487, 0.00349248740788506, -0.0153079960375438, 0.00292009506579961, -0.019145254397281, 0.0515110081076783},
    {0.015232768070499, 0.0287678230747217, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.179978494886957, 0.485949924576904, -0.766229854663151, 1.01051141642987, -0.000673485269869341, -0.000520749400288615, -0.000669087236009717, -0.00183577670380722, -0.0864392103719312, 0.204225002221373, -0.260674168295516, 0.206085870657986, -0.000323458282953231, -0.000218849807463865, -0.000227625898028662, -0.00037439224751609, -0.00889568296255184, -0.00332750776727578, -0.00269364658708946, -0.00377742729515861, 0.00469595144355335, 0.00448735510346664, 0.0109135407614042, -0.0156696993884492, -0.0283431930980596, 0.0467680739919019, 0.00197351752822309, 0.0015266144386361, 0.00222573096474405, -0.00533088841509618, -0.00578037173244198, 0.009537981551628, 0.0542752718892442, 0.0232114501770191, 0.0263385347137, -0.146608993334406, -0.0878878170391838, 0.262311600776788, 0.000203099798998356, 8.6857987096841e-05, 9.8559637198711e-05, 0.000157107844851093, 9.41815724237142e-05, 0.000229055736824791, -0.00141674826780986, -0.000849299280487335, -0.00153620391228584, 0.00536437454800374},
    {0.0170982512251828, -0.0251141783214145, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, 0.0293790293907046, -0.114578371119061, 0.148172383047726, -0.0869289168370504, 0.163589384055956, -0.204331219412855, 0.180652919655244, -0.0841378732334324, -0.0033583906917504, -0.00254526063085193, -0.0036702849086763, -0.0177284701790032, -0.0187003136617076, -0.00453904348042322, -0.00447483985261548, -0.0171592587463129, -0.0893615104409752, 0.190336131394753, -0.212238483655012, 0.159427677701374, 0.189862433322843, -0.0548926656233986, 0.0191290770071509, -0.171395695833933, 0.0195319060365618, 0.0873642936180389, 0.00421763175802376, 0.00135971169586772, 0.00390122508841138, 0.00424553498359212, 0.00398337890666887, 0.0178172618556883, 0.0201544183268214, -0.0570169166961806, 0.185032341811612, 0.0202877569663798, -0.167035397269227, 0.0851417500342238, 0.11222456794757, -0.317483677185369, 1.03030384104418, 0.0361797962355778, -0.297879486990314, 0.103805482586355, -0.0336178884956983, 0.2767865057501, -0.0315420290818578, -0.0984861631531846},
    {0.0214382923559291, -0.00383082689433902, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, 0.013585892958652, -0.128120058977521, 0.160325430484325, -0.0905906908173124, 0.0132794918987442, -0.130660138804077, 0.165311291244429, -0.0939995744532915, -0.0209027123750645, -0.0060272824327623, -0.00589038572642292, -0.0184752602365972, -0.0204312959399314, -0.00614677799527285, -0.00607356716536572, -0.0191704752937162, -0.0976332000889081, 0.170518145142878, -0.133170339698606, 0.0129416622398116, 0.481495556956454, -0.240406207919515, 0.1049373819195, -0.230416174847411, 0.0396909506048684, 0.0994771630117902, 0.0226514859192027, 0.00883256817957513, 0.0214011552624065, 0.00846553253191371, 0.0080946577937206, 0.0202875864800224, 0.108242622668801, -0.245024815275157, 0.469246332285472, 0.0404534804829546, -0.224554398029832, 0.0969464685915433, 0.105801439419834, -0.23949879918387, 0.458663474463193, 0.0412555021999969, -0.229006363638902, 0.0999613464691265, -0.152030613093807, 0.843911139358477, -0.145370156280726, -0.139329327795018},
    {0.0272195064369147, 0.0115162223864431, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, -0.056836811610785, 0.109442245504126, -0.114072987754542, 0.0578058834528901, -0.0194120182105408, -0.0352876028153141, 0.111856327157735, -0.094617179025035, -0.0588573409883909, 0.024148842371253, 0.00787093469350944, 0.0117890561421181, -0.0201021088746973, -0.00778634204845769, -0.00771798708392595, -0.0192964308978, -0.0960601434065918, 0.112964564404558, -0.0353243681982651, -0.0189181773662323, 0.220716232256439, -0.3420507329146, 0.23044406538496, 0.362321701221159, -0.119340321283625, -0.080265473615362, 0.0487018653261889, 0.0236011963360776, 0.0469972581018547, -0.0249998751193356, -0.0243385216796769, -0.0163695132433427, 0.232727232578612, -0.342407108105344, 0.215101221529172, -0.119464659358852, 0.353104253921159, -0.0782235236836696, 0.0794855508053785, -0.116945564495709, 0.0734655711869931, 0.0385191424984336, -0.113851854988648, 0.0767034880809724, -0.240928805691316, 0.712118434341345, -0.23455521007949, 0.248455666275406},
    {0.0302616520385567, -0.00801784374588158, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, 0.0450891617645783, -0.110330824686386, 0.228755234415404, -0.0705796677815743, 0.0064396889922708, 0.00649089001066511, 0.0403972016220276, -0.0722518641953718, -0.105632026424745, 0.123383715498899, -0.0408731176137139, -0.0143941691791136, -0.0150864946514285, -0.00725880667245084, -0.00721801875870386, -0.0147352005106211, -0.0720924778963432, 0.0401671985659731, 0.00641766861494242, 0.00627586360252858, -0.0519109273669999, -0.188485078243955, 0.278998016488917, 0.457575033785653, -0.395146024404499, 0.225638708936902, 0.0580523449520112, 0.0336777988542344, 0.0568994552709835, -0.0817577714486637, -0.0805869296995663, 0.0460172433773116, 0.277409530310443, -0.186358845866078, -0.0505903157787711, -0.39068852421984, 0.445934346116379, 0.219898470630842, 0.0396199669450187, -0.0266159973122157, -0.00722537050781897, 0.0229846576996803, -0.0262348332920278, 0.0388331348008336, -0.183819922143654, 0.209813218721952, -0.181187462435565, 0.439859006441802},
    {0.0258677865545683, -0.000295237250846736, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, 0.00176428765404598, -0.00456258703054614, 0.00724460448462775, 0.353061458146974, 0.000103788161142508, 8.21838039899732e-05, 0.000147945230318303, -0.0347719661720228, -0.121961990153499, 0.2250337245264, -0.197896745384657, 0.072004112783863, -0.00717468642842263, -0.00405343007898565, -0.00404133581582036, -0.00709146953368316, -0.0342850300686168, 0.000145593936764003, 8.06363412489471e-05, 0.000101147795129473, -0.00074500280348023, -0.000887527786824184, 0.178424152469219, 0.00289858008214581, -0.385626002220497, 0.513979475619877, 0.0367446701898162, 0.0242440923895314, 0.0363882052297271, -0.079178865555816, -0.0786453959092756, 0.104822079207859, 0.17558845740332, -0.00087081626806934, -0.000726049966660681, -0.378364938100432, 0.00282484033908861, 0.500903861562424, 0.0103293831195581, -5.12277116195456e-05, -4.27115106566745e-05, 0.00681531545619465, -5.08825635930796e-05, 0.0102291763923665, -0.0617813836177233, 0.000461254537812495, -0.061365129953945, 0.200412591091128},
    {0.0137109026229979, 0.0299453386201052, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.184439512927778, 0.48729939001709, -0.741538613135989, 0.886876346755306, -0.00348612303332128, -0.00245735051523458, -0.00294386828509736, -0.00715988564968097, -0.0775772130015771, 0.182572154863325, -0.231653156327065, 0.180871468758637, -0.00146630027813822, -0.000920673795231219, -0.000919650531979752, -0.00146020247167449, -0.00700687753076351, -0.00287885247894108, -0.00240040868105136, -0.00339743622479544, 0.0237853312506589, 0.0204361518344422, 0.0435460183840249, -0.0765978577452825, -0.117058944746748, 0.207325437623335, 0.00891143980381039, 0.00638415719932239, 0.00888086860420258, -0.023928808561358, -0.0238732528442571, 0.0422823954558631, 0.04258429754058, 0.0199626044256029, 0.0231802335251374, -0.11434644973226, -0.0746492117914782, 0.202051088091407, 0.00080489314983259, 0.000377316628029146, 0.000438133590395028, 0.00057662560824257, 0.000376440608824126, 0.00080213191823719, -0.00558130841108436, -0.00364366602223485, -0.00556835024016819, 0.0208710379051662},
    {0.0254129579368256, 0.0107425993815028, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, -0.00527925397357766, -0.028919560674281, 0.0792937759693208, -0.0676531927685027, -0.0668972246841805, 0.26996967643304, -0.141961339914384, 0.057331901500994, -0.00476624355041164, -0.00338273614995224, -0.00435470127501972, -0.0137973375736295, -0.0603965005827019, 0.0315784943674165, 0.00779631465864151, 0.0116923912438846, -0.0987005432142832, 0.135372028365773, -0.0635582267339036, -0.0222957897716067, 0.109055095339958, 0.15377203670886, -0.0218610650020319, -0.208732280105511, -0.0795719254745864, 0.154730479224276, 0.0127562315865689, -0.00844494131011636, -0.00445839259329853, 0.0114632796231687, -0.0162280695445272, 0.0315560665716392, 0.0208463565738801, -0.0362021324157861, 0.0363463430762805, 0.0187334020168054, -0.0695671764823022, 0.0515692280558871, 0.264159179791141, -0.458743261526414, 0.460570658542209, -0.174879920823443, 0.649423009457741, -0.0923254899097837, -0.0706432910926394, 0.26233645625731, 0.10000665415058, -0.135750409459011},
    {0.0277849136316368, 0.0106226666604082, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, -0.0217181624512596, -0.0244158730639452, 0.0837575252759868, -0.0705030005191931, -0.0483096864799013, 0.0735262174169139, -0.100868692067401, 0.0557087659591239, -0.026019057404776, -0.00708763218492735, -0.00629024608249991, -0.0143785334928047, -0.057876558781076, 0.0213437702446786, 0.00757530613557582, 0.0113613654920687, -0.0945824300406851, 0.104754249861408, -0.0271010761760105, -0.01610085648206, 0.208816727025423, 0.370860928123472, -0.095386453682271, -0.273937984971186, -0.091213581742051, 0.176183523808719, 0.0606169663210654, -0.0278519033674183, -0.0194533184251785, 0.0205729256103858, -0.0186022939508754, 0.0359312466038147, 0.0990608304482568, -0.13669587008386, 0.0695953213086701, 0.0336204732668516, -0.0912992093798989, 0.0587191894223526, 0.220350026027013, -0.304065071880222, 0.154807210805021, -0.101245047457608, 0.27493940115423, -0.0707151723594294, -0.28753905994854, 0.780836385935844, 0.259996376636919, -0.19204741754843},
    {0.0300547935497049, -0.00262086915298648, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, 0.00953046266998917, -0.00904585198043086, -0.0556826593749891, 0.0449879363356469, 0.007407520112675, -0.00240693191785911, -0.0250468724285161, 0.0248177503627265, -0.0629779646757725, 0.0247338267998048, 0.007502151349126, 0.00917493645108297, -0.048949411602034, 0.00658120841508754, 0.00337457711054249, 0.00506138536202261, -0.0799936001014607, 0.0564773593641096, 0.00278290510283723, 0.00246880960967888, -0.0415161074774566, 0.137785921551927, -0.0822707305417843, 0.402484695490358, 0.0766458066681741, -0.14215779334252, 0.113516362413504, -0.0185639631595195, -0.0167784696518061, -0.054226955665696, 0.0156313105845951, -0.0289919659842307, 0.185509533264767, -0.159308678962164, -0.0138366637603083, -0.0886182134630823, 0.134141800340848, -0.0473789501690623, 0.144186661900357, -0.123822135860404, -0.0107545004524867, -0.0235796481027297, 0.0356926225918727, -0.0213117429016787, -0.406714954274354, 0.615646310841458, 0.117238515266376, 0.342463929443951},
    {0.0291131058185436, -0.0112132650061804, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, 0.0538868521712185, -0.101042221662702, 0.0849937731483468, -0.0549292461438858, 0.0175143255728477, 0.00367186688349742, 0.00664416170108384, -0.0205131183769428, -0.0994794309404827, 0.112846675863041, -0.0356794946677952, -0.0112023885451424, -0.0323328431907149, -0.00410083987857551, -0.00278914940712238, -0.00418348946077055, -0.0528386438915602, 0.0136495564365596, 0.0051305537291504, 0.00583724844800673, -0.108188894132857, -0.043258325000982, 0.096116508702793, 0.386897800957663, -0.189958312030145, 0.399627629543894, 0.120828272253816, 0.0181593912005341, 0.0196022074155316, -0.162415639580523, -0.0387405065266483, 0.0815009178862219, 0.197458726781112, -0.0604431390604203, -0.036057651877137, -0.265421203189447, 0.128946934255838, 0.133189585327345, 0.0641781118900005, -0.0196452524780157, -0.0117194719847802, 0.00964538694945499, -0.00468592208119782, 0.0104117408727183, -0.284194329656931, 0.138067294932717, -0.0677880055845984, 0.606288622857957},
    {0.0224445447174004, 0.0122972972658715, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.0683914171489397, 0.159071760349638, -0.206289585296184, 0.274773179699455, -0.00915583372768283, -0.00430258606699971, -0.00537660975155983, -0.0312130576026593, -0.104568501634171, 0.189850631265637, -0.162829463999104, 0.0560378329736125, -0.0139990053434686, -0.00513509550091865, -0.00424389085237583, -0.00636565806912721, -0.0228773094223895, -0.00349760168066441, -0.00231316749585576, -0.00305149496021585, 0.0591095569907136, 0.0379494934220748, 0.177224025148592, -0.187830363035947, -0.45066283116216, 0.910306571261337, 0.0705466934159361, 0.0299544723214309, 0.0361434486839319, -0.14825914401829, -0.0919091466194163, 0.185649879114551, 0.115288086146479, 0.0204025052145787, 0.0197002829695775, -0.242286521734026, -0.062600897223235, 0.303390821313913, 0.0154340791804502, 0.00273136532565302, 0.00263735601303524, 0.00655338578226161, 0.00169323422072118, 0.00790739894148365, -0.0900313728410427, -0.0232618994971415, -0.0558124539406064, 0.276242777973244},
    {0.0111030516956887, 0.0299283676160424, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.179896704701628, 0.459596310372118, -0.662594871472996, 0.69021930367927, -0.00773801956853015, -0.00465882113210352, -0.00499260080123181, -0.010188321625135, -0.0625327818570338, 0.146258539859398, -0.18384166808212, 0.140764808621599, -0.00268976516544266, -0.00148258887390955, -0.00138523266460881, -0.00207782821502176, -0.00439564015111299, -0.00206072672104513, -0.00179668352082423, -0.00257895986512169, 0.0510514100330864, 0.0367063907025685, 0.0643230528044015, -0.155757438084702, -0.183128903994627, 0.367193083012779, 0.016246224176946, 0.0101844496336541, 0.013118181670236, -0.0432160109691642, -0.0373477023700649, 0.0748861467390753, 0.0265497360935653, 0.0141558916760696, 0.0170146296952577, -0.0706240215419473, -0.0519114972451432, 0.122379662580786, 0.00114200189365372, 0.000608897016658338, 0.000731861863459781, 0.000715899315482731, 0.000526214799611886, 0.000922121235404441, -0.00784483208536711, -0.00576626720338039, -0.00677958116209392, 0.0287680203061016},
    {0.0302500012368685, -0.00674620730936924, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, 0.00197276041282771, 0.00282759490804098, 0.0246420043988713, -0.0450325661822801, 0.0414434833137068, -0.117441550053527, 0.394513248650746, -0.0700756553903234, -0.00538804273701239, -0.00355870072593606, -0.00406902438226493, -0.00918403835795024, -0.113191271384467, 0.147807356790049, -0.0651442148090814, -0.0142913798085192, -0.0742698835373354, 0.0442577376376678, 0.00580669741102554, 0.00554578525152284, -0.0176773769273057, 0.212615825443168, 0.130126061606394, -0.107540712446678, -0.235656571469202, 0.170749967708241, 0.0222480575010768, -0.0351083038449274, 0.0265381887482213, 0.0177577186477456, -0.0480603077984889, 0.0348231154916577, 0.0145979510551171, -0.0105124273528511, -0.00236550908394888, 0.0116516377961438, -0.0143906266881723, 0.0228490121220381, 0.306671776781995, -0.220843648702358, -0.0496942941533089, -0.483940043727634, 0.597701424519648, 0.365807823698724, -0.0728429636639771, 0.0899663991696785, 0.197145552539168, -0.0997158754837049},
    {0.0300983577029971, -0.0108682780791435, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, 0.0148432501155472, 0.00721310365350027, 0.0237118389394892, -0.0469295077882569, 0.054737695342548, -0.110840703140009, 0.115608731683717, -0.056088598307651, -0.026935005912887, -0.00688995031957134, -0.00551966637194172, -0.00957090470710666, -0.0993286602484081, 0.105874942979701, -0.0269115200303898, -0.0114388293177889, -0.0651740009484615, 0.028828893208499, 0.00702557127231332, 0.00732475842426729, -0.102273132930751, 0.535746834338047, 0.257050201911992, -0.128570110450796, -0.309816855637989, 0.194424079547109, 0.0976912073872445, -0.124711701733311, 0.0524233707828876, 0.0299286831739659, -0.0631847155811978, 0.0396512647545375, 0.0640995944875302, -0.0339579907193822, -0.0136857422900745, 0.0196375549684062, -0.0172046885375793, 0.0260169779825591, 0.236381119183878, -0.125227435768644, -0.0504691348713493, -0.301761974485488, 0.264377148370073, 0.126847598555409, -0.278436906801433, 0.243941787386094, 0.587829296106843, -0.141069013725581},
    {0.0286160770881657, -0.0100304424671004, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, 0.0278670398224955, -0.0165823879066066, -0.0112119814106074, 0.029945700085014, 0.0359083999511919, -0.0395715317875215, -0.00282231830132846, 0.00532721841410373, -0.0578628584901556, 0.0216383431733439, 0.00606898946781373, 0.00610719045242114, -0.0745598627704426, 0.0516368564971357, 0.00152770678244015, 0.00108644437579385, -0.0489220790330338, 0.00994877186000769, 0.00412692477588737, 0.00480510466139416, -0.126171301109485, 0.248821960746169, -0.0306460030495001, 0.134356329875994, 0.457560220603032, -0.15687561199579, 0.164640818162663, -0.134686083023702, -0.00625001174450551, -0.0727264094622995, 0.0933158150499534, -0.0319935495606553, 0.108028244942133, -0.0259497034408981, -0.0168836903877481, -0.0477190678644039, 0.0179789750546523, -0.0209924066648649, 0.139201057956504, -0.0334377937414931, -0.0217556766329357, -0.113874830422633, 0.0429042901956705, -0.00528428039161088, -0.363082622001919, 0.136797588383316, 0.465874103411458, 0.251557919288668},
    {0.0243807773710821, 0.0053786384813686, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, -0.02207903577152, 0.0324894082074784, -0.0161003738189843, -0.0365630181088649, -0.0118969892080668, 0.00420827497900536, 0.00240439388633079, 0.0195514382990293, -0.0812967864767634, 0.0892023530796897, -0.026772391802399, -0.00745674051607523, -0.0438056716503966, 0.0115541664574629, 0.00399812922953596, 0.00398736235826668, -0.0287428711768686, -0.00204387781190559, -0.00123786029074244, -0.00159200294020177, 0.0576723909467992, -0.0292076635307706, -0.122223005070747, -0.121504250912767, 0.450686934679817, 0.441001702974337, 0.15834431170101, -0.0485677550391039, -0.0249264224083987, -0.202042477253413, 0.0919140623426243, 0.0899388353673567, 0.103896823889261, 0.00859140789289648, 0.00771746652451487, -0.132569155480525, -0.0162591661904658, 0.059012914569434, 0.0559833955320349, 0.00462936371142344, 0.00415845224881614, -0.0171713641699439, -0.0021060107288467, -0.00881285693118505, -0.235325313207766, -0.0288618673204914, 0.107055238101477, 0.445351148958011},
    {0.0168888172596301, 0.0265225731168815, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.136406455745618, 0.28376541171853, -0.302860847075892, 0.182899592666262, -0.030274541866518, -0.00502674905678497, -0.00409850995120608, -0.00943905186116172, -0.0776057232015646, 0.138298675897828, -0.115271030719205, 0.0373009361247861, -0.0172240947344067, -0.00244988539799061, -0.00155992255535795, -0.0019250205285815, -0.011301503148731, -0.00374060763022846, -0.00292119558198596, -0.00405120647096811, 0.174811675791853, 0.0364890940310537, 0.0612509238451514, -0.457170278774762, -0.196463287614661, 1.00455203413528, 0.0851979215757075, 0.0138880133222226, 0.0124916450858425, -0.174002317425163, -0.0400671452317113, 0.204870501421384, 0.0559021878246979, 0.0212049137663457, 0.0233925320915247, -0.114170745608983, -0.0611765225010694, 0.134424749317638, 0.0124071336395172, 0.00470629521224695, 0.00519182313108002, 0.00202247231023234, 0.00108370863424559, 0.00181912313224389, -0.0703340806951783, -0.0376873641955272, -0.0161956798487153, 0.202914971390714},
    {0.00773818110957624, 0.026012438120785, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.152061844875105, 0.37398651422484, -0.50782563534139, 0.459436505525797, -0.010843593574508, -0.00531054391871697, -0.00498843785959964, -0.00844635187532087, -0.0433476663950499, 0.100657728235378, -0.125149498779013, 0.0936984686307274, -0.00309114016851075, -0.00142932235848187, -0.00122935995028987, -0.00172256715936872, -0.00202823607778981, -0.00108695820213258, -0.000995259096535668, -0.00145104215453643, 0.0688705436214521, 0.0394086713457842, 0.0558182505772273, -0.197907251068728, -0.170757133079534, 0.405209157119218, 0.0185363701620085, 0.0097119466274211, 0.0113836940204541, -0.0487726328729601, -0.0348245768128827, 0.0826392266190663, 0.0121625460717833, 0.00738565375592502, 0.00921595422346855, -0.0320019178067211, -0.0264830807255859, 0.0542233129952789, 0.000867316232694474, 0.000526674049477187, 0.000657193539133026, 0.000454421706483311, 0.000376055172972415, 0.000532642719457732, -0.00589323248953548, -0.00487692496111092, -0.00420787879224266, 0.0211316366719475},
    {0.02488002151319, 0.00349338776214515, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, -0.000737780502525509, -0.000621569734380754, -0.00109018984479883, -0.0235470671456199, -0.0213408121217802, 0.0567285276972925, -0.0929049606346429, 0.521879511054613, -0.00422947460640316, -0.0026207635923268, -0.00270891496297769, -0.00480223949501901, -0.122340482894467, 0.239188061792398, -0.23085120375936, 0.106433229417867, -0.0304844426488356, -0.00144195494716541, -0.000849780857684048, -0.00108449112971492, 0.00535047517400649, -0.0206694422318369, 0.362180965134431, 0.00655089853965156, -0.270767634055307, 0.122934171541447, 0.0225595452321251, -0.051359643098269, 0.0738639646439451, 0.0162777402116468, -0.0552209333838473, 0.0250714592272948, 0.00562132130380564, 0.000309623694824902, 0.000271898877739951, 0.00405603955611854, 0.000332901640170673, 0.00624723266456599, 0.162600612797479, 0.00895607985992303, 0.00786486339244146, -0.37018075297663, -0.0303827855030737, 0.532383334467843, -0.03491440742593, -0.00286561887202173, 0.118444338190402, -0.0375393217377864},
    {0.0233014374907499, 0.0093268697739225, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.00968427887924613, -0.00305739080499757, -0.00351420065220275, -0.0245389584623717, -0.0491729940243791, 0.106169413017208, -0.121847957868655, 0.123566481166195, -0.020009268681567, -0.00483826550316701, -0.00354803175299676, -0.00500452794251932, -0.101599268420437, 0.168011170718831, -0.123020984383693, 0.0252004138115011, -0.0253162076693629, -0.00300028765102177, -0.00191419023133727, -0.00249885878459788, 0.0596887115499931, -0.179428858511902, 0.955860192068403, 0.026236336835613, -0.366088874082172, 0.139978727185895, 0.0944563035738694, -0.181156214573332, 0.19494018247284, 0.0264889132374168, -0.0746609519959467, 0.0285475625477053, 0.0235363446423739, 0.00323502747564209, 0.00303324343285021, 0.006600429696788, 0.00133327046843722, 0.00711339789299568, 0.119508385589292, 0.0164262087773372, 0.0154016280466348, -0.229203196864413, -0.0462984786883526, 0.246643004355891, -0.128858614879586, -0.0260291213928506, 0.363197492232308, -0.0531072416281613},
    {0.0202336576842803, 0.0190977808372876, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.0433432647799655, 0.0190435548721708, 0.00697704744749568, 0.0156582995463821, -0.076900417711456, 0.111019355037725, -0.0569446628060189, -0.0272339425429253, -0.0395959199906359, 0.0141639916635121, 0.00370744537983264, 0.003193387271606, -0.0702518096504062, 0.0825726724762285, -0.0302591072534674, -0.00555414878956785, -0.0175051398490236, -0.00405247587043006, -0.00289524874373818, -0.00390790286721709, 0.19950941508979, -0.378262163481966, 0.519567159982301, -0.115119607905565, 0.584484870331949, -0.112945107132978, 0.148388770431383, -0.200999967524955, 0.105961643569101, -0.0611719587217116, 0.119201100977506, -0.0230342679574021, 0.0369750785261229, 0.00986461372661264, 0.0101386109265573, -0.0152426492298347, -0.00585011446225264, -0.00573961131991798, 0.0656018645113008, 0.0175019791423125, 0.0179881100148821, -0.0888609872432724, -0.034104763467522, 0.0468450635759485, -0.159689304474722, -0.0612886051163679, 0.311174291382681, 0.0947022088715305},
    {0.0156059973161049, 0.0283483789400613, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.102213293977142, 0.124878367918978, -0.0445130476343746, -0.0191184272948392, -0.0758343923526162, 0.0532647951908287, 0.00388900865659841, 0.00408265242310426, -0.0508705214556542, 0.0541344006325356, -0.015500258893724, -0.00389905316318793, -0.0377420092156797, 0.0230901301043676, 0.00135422408082092, 0.000832624912029, -0.00940444314233822, -0.0034292829565085, -0.0027546652140804, -0.00385372990326822, 0.305221577224944, -0.265912605385222, -0.0373890997493767, -0.462535110161498, 0.776025214555274, 0.317506232833688, 0.13231264484422, -0.0925956420784957, -0.00762521338174652, -0.161063201374777, 0.158264250550674, 0.0647529036970646, 0.0329692767107085, 0.0137520514519179, 0.0155106605694832, -0.04013325604888, -0.0235049735356562, 0.0161349385942961, 0.0244606642480473, 0.0102029630870849, 0.0115077156161066, -0.0171181742635491, -0.0100256563422968, -0.00140967467297046, -0.0980917344976773, -0.0574497025764961, 0.0963870996787595, 0.167658158602434},
    {0.00987675823579517, 0.0290142634016863, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.139268112846256, 0.263309019711057, -0.240581629561091, 0.0956363217673717, -0.0425594697223884, 0.00291910365758024, 0.00153171149747926, 0.00200693308424886, -0.0448012227061954, 0.0784639261814977, -0.0636937172730278, 0.019504277059619, -0.0136909752155198, 0.000869868924945503, 0.000405518905338827, 0.000409298247694111, -0.0034114770425107, -0.00168582891470648, -0.00149776380988469, -0.00216277464680903, 0.223346204549638, -0.0181400485021902, -0.0150679586141475, -0.500033591404991, 0.0642906130875655, 0.723243311516806, 0.0665553353467772, -0.0048025575465814, -0.00307299187277486, -0.132383333906543, 0.013111565844646, 0.147499795774797, 0.0165840632254412, 0.00930748316716323, 0.0113499419004008, -0.0329868908038959, -0.0254105603546718, 0.0367535664289513, 0.00506798665030028, 0.00284430900906845, 0.00346847170388703, -0.000365700171241742, -0.000281707249352436, -0.000233998998075191, -0.0279804196188502, -0.0215539605020872, 0.00277124849002858, 0.0763899465305751},
    {0.00422403562884648, 0.0171539738450264, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.0977269276576106, 0.232125215917279, -0.298701660335599, 0.240234638216595, -0.00959553257924239, -0.00374749699368052, -0.00309987463794561, -0.00445871865745549, -0.0235420783828842, 0.0542965286233309, -0.0668187951761429, 0.0489939685728514, -0.0023115305629733, -0.000876578948905482, -0.000693434004591491, -0.000909320668327681, -0.000575980404939047, -0.000344874274678614, -0.00032981625820244, -0.000487622959599505, 0.0588574919775217, 0.0263542534751362, 0.0308349249253131, -0.160282676136513, -0.101513754490212, 0.291736816703685, 0.0137673862153513, 0.00589537889744849, 0.00628854087800156, -0.0358548234884828, -0.0207029333243834, 0.0594974335725769, 0.00343051691130139, 0.00231943115192502, 0.00299100276046858, -0.00893419973878663, -0.00814519801425957, 0.0148253959652969, 0.000336832821567439, 0.00022773843112733, 0.000293678161388959, 0.000144236318875414, 0.000131498445572866, 0.000153855418475769, -0.00226534884361127, -0.00206529017058832, -0.00130803505644908, 0.00795527596810685},
    {0.0106036055567762, 0.0296266593660007, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.00517932982837492, -0.00333411005738352, -0.00365885144162162, -0.00745436569613294, -0.180531596982921, 0.469230738890095, -0.692276345467663, 0.744232604758411, -0.00174302461810546, -0.00103224751682514, -0.000995395188472116, -0.00152025936541925, -0.0607551610563969, 0.145274827975367, -0.188334660306985, 0.151780397361144, -0.00397712490619112, -0.0019061204268897, -0.00167493200389365, -0.0024101622015665, 0.0345842460403175, -0.106971053214144, 0.25456426498465, 0.0264935041720338, -0.132179922471374, 0.0468967101986917, 0.0107073556307267, -0.0291016110858972, 0.0519163834616734, 0.00720759150771053, -0.0269570575484029, 0.00956421589618278, 0.000700919724644976, 0.000381836111040659, 0.000461712209768647, 0.000471819861893931, 0.000353697875660709, 0.000626088065400591, 0.0244313765371233, 0.0133093441036109, 0.0160935189181038, -0.066402241860369, -0.0497781754902047, 0.118459567099648, -0.00489411984295714, -0.00366885739980157, 0.0183044599731066, -0.00453346276486167},
    {0.00958841840105434, 0.0287142087112329, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.0252758904406238, -0.00632110314145228, -0.00488566882918307, -0.00776837170631511, -0.154654198992137, 0.341911353913746, -0.398704725867906, 0.277425364104441, -0.0079916708400172, -0.00185631097078689, -0.0012801461629625, -0.00158429842618404, -0.0488981962979726, 0.100408707642264, -0.10446887474773, 0.0565787251628149, -0.00320095002602277, -0.00160037367631394, -0.00142790422348559, -0.00206468956655638, 0.148706520787247, -0.388563452590706, 0.71220317547873, 0.0439538129017003, -0.180523018821064, 0.0533988371215844, 0.043670470135928, -0.101811651647421, 0.145248246697175, 0.0115168069922355, -0.0368162525456528, 0.0108902736390702, 0.00285873514978348, 0.00162273463193135, 0.00198528590849279, 0.000753907637346349, 0.000586799320677633, 0.000712893814650363, 0.0174915853413356, 0.00992893703459043, 0.0121472595661698, -0.0407792081924058, -0.0317402430744738, 0.058177118196236, -0.0177359836148674, -0.0138046925395089, 0.0566973513015158, -0.00641353363141409},
    {0.00787931986789129, 0.0262660176362191, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.0524224823609094, 0.0192586102361637, 0.00525321344488664, 0.00495699486804396, -0.112078045039238, 0.179511848166742, -0.123767382336513, 0.0182909049745179, -0.0150561962143101, 0.00521607980877903, 0.00130030386482779, 0.00101094018990618, -0.0321897964657502, 0.0486197142564784, -0.0306355733076929, 0.00373028648217891, -0.00210719285445268, -0.00112365340857559, -0.00102691121281126, -0.00149628249178235, 0.243128686850451, -0.455369321869515, 0.474805099586672, -0.10444762263269, 0.295845278163647, -0.0430860995861485, 0.0658499558828107, -0.112715482697029, 0.096832772742813, -0.0258534416707461, 0.0603353220350686, -0.00878707177583326, 0.00431063789576678, 0.00260497492156442, 0.0032458560216409, -0.00169240546797394, -0.00139441358919908, -0.000575215033661146, 0.00921604331712913, 0.00556937564640985, 0.00693956449600762, -0.0157751171905968, -0.0129974986479508, 0.0135522494457505, -0.0213656288798232, -0.017603655752469, 0.049861914532044, 0.0114367792968683},
    {0.00569928745007787, 0.0214698480958179, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.0709478783134303, 0.0769033452699536, -0.0226501029881943, -0.00605237789102629, -0.0634299145349296, 0.0567537957659614, -0.00844642404705139, -0.00359533878904272, -0.0182709161061165, 0.0190137982809252, -0.00526293094004179, -0.00123433495846102, -0.0163348457295087, 0.0140319672776631, -0.00196259356847587, -0.000733241121874979, -0.00106930375395296, -0.000612888851787857, -0.000575990819905183, -0.000846812331002389, 0.226500485285503, -0.234109161969772, 0.0505207745986585, -0.283611242802991, 0.425056183742284, 0.121121715799416, 0.0560006137916714, -0.0543971191883836, 0.0103033153809035, -0.0658993199929181, 0.0866868718955917, 0.0247018231068586, 0.00366588503758733, 0.0023759596398863, 0.00302386350863138, -0.00431386934521678, -0.00378631280488679, 0.00161701877171279, 0.00327743098393693, 0.00212419201925483, 0.00270344101158935, -0.00318358660367824, -0.00279425586598692, 0.000603000624105062, -0.012705474602177, -0.0111516824754388, 0.0167133416449522, 0.0202473562137979},
    {0.00339108928439714, 0.0143344773818663, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.0655314248951063, 0.115979237022268, -0.0956568846043595, 0.0302758773259641, -0.0241318165707197, 0.00526310839581208, 0.00187632953336979, 0.00172722943069843, -0.0152353726346627, 0.0263431259843043, -0.0209745648569962, 0.00617452750875359, -0.00561039559867254, 0.00119544438383661, 0.000411420418441576, 0.000352254883283802, -0.000367264997427205, -0.000225042499060208, -0.000217247209950853, -0.000322168490867509, 0.118546565081049, -0.0295236807499633, -0.0146962544553078, -0.239579049519496, 0.0833104971211987, 0.275901578528232, 0.0269262600713354, -0.00647362037001903, -0.00299718572753378, -0.0525321970635782, 0.016990521883296, 0.0562679610565785, 0.00176263378613854, 0.00121865954262168, 0.00158263957699841, -0.00343883722280923, -0.00319846707772598, 0.00368338599466455, 0.000649086377665788, 0.000448768946986897, 0.000582803868995984, -0.000156053562032993, -0.000145145625740556, -7.22503764697708e-05, -0.00351495966953627, -0.00326926866673916, 0.00113684563986364, 0.00922528597146999},
    {0.00138044771170152, 0.00638882353038116, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.0357169332052307, 0.0827155276170147, -0.102424732574839, 0.076051800212317, -0.00422595518496764, -0.00135478401778058, -0.00101686811553731, -0.00130332461042045, -0.00766460049150867, 0.0175880306956039, -0.0214801029408935, 0.0155101676309956, -0.000906860003956168, -0.000288071461031691, -0.000213253491124377, -0.000265802822928497, -5.93644300410383e-05, -3.83065599430919e-05, -3.77810915961265e-05, -5.64180322034809e-05, 0.0252733238596131, 0.00916815545757771, 0.00933834822750545, -0.0662292251284658, -0.0326033938848813, 0.111291244539187, 0.00537393653439478, 0.00192270868623461, 0.00190448281304123, -0.0138893267054964, -0.00664920623945946, 0.022696975664559, 0.00035178602876871, 0.000255673905629298, 0.000337408026585682, -0.000909216372899935, -0.000884184141232339, 0.00148577842015631, 4.16226103100562e-05, 3.02508185951548e-05, 3.99214342173563e-05, 1.48919053798529e-05, 1.44819065758678e-05, 1.47507410000868e-05, -0.000277806604307253, -0.000270158128669332, -0.000132993732949124, 0.000960724534064027},
    {0.0224419087355453, 0.310703073843137, 0.0208770933958504, 0.0195251039488212, -0.00350519620228993, -0.00213578148775568, -0.00215103292273906, -0.00360148326124402, 0.354215091736513, -0.39327074269067, 0.286443388274844, -0.115220749339439, 0.390484209646641, -0.426933671469902, 0.308757369600584, -0.123622648285321, -0.00378445250751076, -0.00231961445844558, -0.0023575639501616, -0.00402640927558311, -0.00417195365419319, -0.00251816728181517, -0.00254121852244883, -0.00432001510649596, -0.13347157028838, 0.33533302108994, -0.46792562881181, 0.436556032512802, 0.129016952515557, -0.0645985164753272, 0.0224161618429517, -0.0655979383537519, 0.0157596925360572, 0.022925517042575, 0.000760975979021806, 0.000531676205177365, 0.000783336703543939, 0.000539901917789528, 0.000550725217214124, 0.000801136210248058, 0.0243455865742155, -0.0708009310625633, 0.144239197195842, 0.0172728564941385, -0.0733376023953635, 0.0256304160735921, 0.0268384022973472, -0.0780504452045668, 0.159008269921432, 0.0187513670337172, -0.0796151059527957, 0.0276270291882512, -0.00566655757523521, 0.024059236904103, -0.00578015385508088, -0.00586958024656279},
    {0.020831167572953, 0.0168212127674998, 0.0192875795853981, 0.0197079603842469, -0.0163810014243473, -0.0039024265717723, -0.00279689872237239, -0.00375319132544416, 0.762426252400217, -0.486472830393037, 0.315036567668793, -0.120074282056387, 0.147540025395148, -0.240094368128956, 0.21694135572351, -0.101414897218028, -0.01776085668669, -0.00425338581439367, -0.00307308040887687, -0.00419601682685228, -0.00343697142949147, -0.00209922099594011, -0.00211619316158233, -0.00354396135402678, -0.109957591036383, 0.236451671291947, -0.263802651514286, 0.164947740605516, 0.361953254691465, -0.228613371439197, 0.0928919182149795, -0.0896376076996039, 0.0254598197962893, 0.0261040901440186, 0.00316467178184316, 0.00223004992142876, 0.00324612435929958, 0.000874386037654768, 0.000889697864058354, 0.000912212004253194, 0.101246022171265, -0.251187955916102, 0.404658813134064, 0.0279738671992902, -0.10021362558217, 0.0291840175456564, 0.0195925056820641, -0.0486083437947556, 0.0783070774100661, 0.0138062550459613, -0.0494595496579395, 0.0200967791728531, -0.0208135617171249, 0.0745625360302079, -0.0211780387674463, -0.00830375195874435},
    {0.0178396083059577, -0.0155588635177619, 0.0163965439250798, -0.0116539403654932, -0.0318063021955915, 0.0112436886986537, 0.00289018334287364, 0.00239490987846171, 0.161426388204999, 0.609621358264413, -0.233929227326291, 0.0766193511896089, 0.0109152642713772, -0.0722517992667381, 0.107859002109445, -0.0688053487876893, -0.0347130258988214, 0.0123225323775471, 0.0031877643198873, 0.00267747665318659, -0.00234721135471129, -0.00146045594323529, -0.0014697995732854, -0.00240441497001842, -0.0750933522468873, 0.118208186061103, -0.0796910370126105, 0.0122031169159268, 0.243404271380666, -0.257835982891349, 0.143623705893241, 0.147100706594461, -0.0581440074053686, -0.0210626951480253, 0.0049200326961324, 0.0035135427754725, 0.00501895556935266, -0.0020045480817921, -0.002031852527246, -0.000736039572724779, 0.157404550542626, -0.284383462616916, 0.272122663056645, -0.0641306693151907, 0.164456588164782, -0.0235478065455438, 0.0106433172778929, -0.0192293260314474, 0.0184002802424234, 0.00760071179165122, -0.0194912534396814, 0.0108573133203485, -0.0256055314109387, 0.0656627847324157, -0.0259543106904582, 0.0148074655791839},
    {0.01354270014303, 0.00894872042728937, 0.0123418011338163, 0.0118223838397411, -0.0399845505836983, 0.0422013001459019, -0.0119330872043854, -0.00292413044299151, -0.0670830605102294, 0.297174981210494, 0.535772970512815, -0.0935504836114048, -0.00189681223432869, -0.00504670264847045, 0.0321772770214551, -0.0361703730372399, -0.0439702312640462, 0.0465429183672365, -0.0132189650130184, -0.00326913804247699, -0.00124328365422726, -0.000790403917700934, -0.000793900257330544, -0.0012639800238532, -0.0397758545272402, 0.0354876359854278, -0.00559052193272514, -0.00212061026536668, 0.0276817096582159, -0.127430920717604, 0.125763840462251, 0.212173344440878, -0.151186193020126, 0.0592105064091018, 0.00433545094422103, 0.00314406469764707, 0.00439483944231579, -0.00523488897578126, -0.00528322800716215, 0.00206912152181234, 0.13870227078189, -0.141162538552777, 0.030947774693624, -0.167477615955912, 0.237206911741454, 0.0661965404040856, 0.00392188671994371, -0.00399145221042715, 0.000875066182395735, 0.00284414833496885, -0.00402830933090291, 0.00397561007306033, -0.0156004611164019, 0.0220957122063312, -0.0157445159727601, 0.0262147255291865},
    {0.00844321113047124, -0.0109738205691141, 0.00763236993753089, -0.0295941247801589, -0.0344990911194155, 0.0601371945948341, -0.0484704728084979, 0.0146274102792549, 0.0736287355315532, -0.227812559637077, 0.539364215954557, 0.467968625984661, 0.000857520491375035, 0.000986133972089288, 0.00289671851242868, -0.0128544681648156, -0.0382116443014456, 0.066719641601018, -0.0539112807906323, 0.0163532456363012, -0.00044503369181973, -0.000288809823712974, -0.000289536829614551, -0.000449201642483951, -0.0142377769749928, 0.003213785117021, 0.00109682745775004, 0.000958696239860428, -0.00736449804673692, -0.0158793451087478, 0.0621953543792269, 0.0427239595603108, -0.122833242483405, 0.134874841195124, 0.00215684627323647, 0.00158719434401868, 0.00217342755715761, -0.0042704045099973, -0.0042924291824222, 0.00471322495942977, 0.069003081726509, -0.0176618007484953, -0.00823340859708799, -0.136621267387052, 0.0477648053829498, 0.150788237023004, 0.000803647599287486, -0.000205698983515876, -9.58907759978515e-05, 0.000591393526743606, -0.000206759878969829, 0.00080982583701443, -0.00441655656921426, 0.00154409316372146, -0.00443933502297684, 0.0119441934599608},
    {0.00356846422868537, 0.0261188035535263, 0.00320507108782465, 0.192230415140459, -0.0178382131382485, 0.0410650708630083, -0.0503948504088262, 0.0367434731025108, -0.166915283235763, 0.464278848231276, -0.769187724303446, 1.17551858417977, -0.000624602315104146, -0.000497526431336791, -0.000671670106945964, -0.00213554205983525, -0.0198704873172242, 0.0457735732543993, -0.0562285998280998, 0.0410787029080856, -7.43559974856489e-05, -4.90514755034869e-05, -4.90999381123077e-05, -7.46268914880562e-05, -0.00237884036290432, -0.000748683496630217, -0.000555120501094584, -0.000698296888437414, 0.00448653414127225, 0.00450467759663892, 0.0126956210248065, -0.015730188976282, -0.0329713743754396, 0.0544048679014512, 0.000442330508822997, 0.000329297655088506, 0.000443650701341704, -0.00114989679790894, -0.0011521904550621, 0.00190118764207866, 0.0141512951707229, 0.00502614278802671, 0.0050158841153129, -0.0367881678484824, -0.0175861372125051, 0.0608239019496676, 5.29545980093216e-05, 1.8807986666365e-05, 1.87695983854607e-05, 3.9422614092375e-05, 1.88455022701892e-05, 5.31126478446887e-05, -0.000355500518009513, -0.000169942708606415, -0.000356209621910502, 0.00124387251864919},
    {0.0206121464512043, 0.00186778322923238, 0.0160091858217585, 0.0195251039488212, -0.00316207558373217, -0.00241577235429516, -0.00353354291864171, -0.0181912548602126, 0.132011178619608, -0.227738706732716, 0.212018681376458, -0.101123604922342, 0.735069464402224, -0.406133611428703, 0.258494822208368, -0.0978768097135354, -0.00345830596482612, -0.00210523271754565, -0.00211720616941685, -0.00353378209371142, -0.0192566655330664, -0.00375432783799061, -0.00258131419735665, -0.00342032226620991, -0.107046130267054, 0.22526615807223, -0.243344599888121, 0.142792530306415, 0.377375106660751, -0.0785454775264236, 0.0222526783512816, -0.245248734459552, 0.0227212856352968, 0.101630074704723, 0.00348848218525225, 0.000784350551183178, 0.000777623744280717, 0.0024490395387256, 0.00079399930793385, 0.0035514807690044, 0.0193921693138195, -0.0470623884943941, 0.0733078286670003, 0.0136139979708023, -0.0476413305733009, 0.0197423729662324, 0.107980185164328, -0.262054509821075, 0.408195327988218, 0.0242782715384178, -0.0849602859197397, 0.0240700543779732, -0.0225591161468235, 0.0789442096360894, -0.00731385603414833, -0.0228366290826984},
    {0.0190287287217083, -0.029511852567589, 0.0205403356838656, 0.0197079603842469, -0.0201247738104083, -0.00584323645333998, -0.00577935460978646, -0.0189575391547736, 0.228014045330251, -0.2717151045485, 0.231653750460453, -0.105383312724627, 0.222871671150233, -0.277102067847941, 0.238857806241638, -0.109348835528473, -0.0161511787365527, -0.00384447375345898, -0.00275184717215834, -0.00368263832928289, -0.0157869230855842, -0.00392069343601918, -0.00283742515434128, -0.00382121421853464, -0.0877581335269887, 0.157153073341715, -0.131942507994805, 0.0432944250827254, 1.02114857456485, -0.347362233990544, 0.122072685786528, -0.332927664119839, 0.0461721157239614, 0.115720863634553, 0.0144481437637405, 0.00412636436673907, 0.00426585139537875, 0.00395489410044261, 0.00161349267462766, 0.00404388585725968, 0.0803159756186618, -0.165396976974351, 0.198365455024694, 0.0219849126185114, -0.0646735932737142, 0.0224796100611515, 0.0785046187846292, -0.161666798236396, 0.193891742045088, 0.0224207806119899, -0.065955797566285, 0.0231786894608933, -0.0826227979472472, 0.243053648758979, -0.033707926396861, -0.0323072000911191},
    {0.0161577642134767, 0.00567780449458317, 0.0267098865309274, -0.0116539403654932, -0.0579732173172456, 0.0239119304978303, 0.00786274267358258, 0.012096798126249, -0.0380248596464324, 0.301987998765445, -0.169129303002116, 0.0672450495550814, -0.012986992883495, -0.0973703756382163, 0.165842790839071, -0.110067289214354, -0.0313276643913105, 0.011067146833095, 0.00284192495165214, 0.00234989003992667, -0.0106996359300077, -0.00356839426992839, -0.00278670080802813, -0.00384632070848093, -0.0594783463215326, 0.0767569359401082, -0.0351937372957314, -0.0025228167740769, 0.609030388285103, -0.507138483772254, 0.268073449809222, 0.537193055045898, -0.138827491931281, -0.0933720830549342, 0.0223195251484257, 0.00852158369598118, 0.00936787367759251, -0.00902659870223757, -0.00485135103202017, -0.00326290380377055, 0.124072300702037, -0.183301116519788, 0.118308533258758, -0.0501780777616425, 0.104353614600787, -0.0181381986942383, 0.0423755958927613, -0.0626045781079559, 0.0404070414401217, 0.0161789816165828, -0.0336468690624238, 0.0177857381237385, -0.10119598893832, 0.210453801737447, -0.0543878465817399, 0.057611036033569},
    {0.0121457494920626, 0.000689573107347559, 0.0302516266319403, 0.0118223838397411, -0.105865563934372, 0.12409022809239, -0.0413394531163358, -0.0147699151361853, -0.00443360677459498, 0.0139910499734393, 0.368517130449206, -0.0821046747156991, -0.000633213118742201, -0.00082310965017658, 0.0650785581277397, -0.084049925337174, -0.0393358416198599, 0.041497453639969, -0.0117258358154838, -0.00286916224498887, -0.00561799280287625, -0.00244134318822823, -0.0020707327412003, -0.00293713936881881, -0.0312299337797292, 0.021763151622634, -0.000233473059959236, -0.000123006202579699, 0.0065828238030827, -0.303643238348031, 0.324555812036961, 0.7371382729091, -0.459669715353957, 0.262483423099521, 0.0195246551264626, 0.00966161533660799, 0.0113416597229395, -0.0234549811860992, -0.0160632387501087, 0.00917252921469209, 0.108535861128071, -0.0861276695976375, 0.00127876086944784, -0.13038420214274, 0.143194411238384, 0.0509892927988106, 0.0155012238600132, -0.0123008586572029, 0.000182634184634476, 0.00767065339756551, -0.0084242928132939, 0.00900449227761782, -0.0613460913255659, 0.0673733265593304, -0.0420131188138631, 0.10199297705579},
    {0.00750148626092431, -0.00713114387718262, 0.0261981528295216, -0.0295941247801589, -0.123694165861968, 0.228667944176925, -0.201694509957146, 0.07388371096938, 0.0450881185414647, -0.127068618871477, 0.241702073048266, 0.4107131286806, 0.00265240926107725, 0.00228882920954537, 0.00493590353226538, -0.0404499066305402, -0.0339007738939034, 0.0590785907491447, -0.047598198198489, 0.0143524422502372, -0.00199428872932866, -0.00106415577163223, -0.000972023581156913, -0.00141352907516577, -0.0110860777398482, 0.00127523875639666, 0.000540144332047403, 0.000515249575909656, -0.0207484211610252, -0.0296106304241311, 0.207559166263658, 0.0967054607656749, -0.448595161601129, 0.597907570023055, 0.00964665779284906, 0.00583119804449743, 0.0072531914352881, -0.0190441299503526, -0.0156762365286432, 0.0208939848046812, 0.0536249323623461, -0.00698785830119748, -0.00403053003957297, -0.105864663432388, 0.0187857312892301, 0.116147845812617, 0.00315460639795218, -0.000411076369401695, -0.000237104930297318, 0.00190689200901607, -0.000338378829323381, 0.00237190585575591, -0.0172861296713002, 0.00306743134590158, -0.0142291329716041, 0.0464709748021349},
    {0.00314688918138771, 0.0284903632108101, 0.014002682081672, 0.192230415140459, -0.0792712548026677, 0.186695351837455, -0.237148368754726, 0.185592944676423, -0.178725093630068, 0.48438729810939, -0.768528380851087, 1.03169505116885, -0.00337811380894425, -0.00244266543518647, -0.00305101620671752, -0.00832902875213202, -0.0175130233754286, 0.040312242117173, -0.0494632043101814, 0.0360527643450898, -0.000331016674263784, -0.000203286338883849, -0.000196366252368593, -0.000291059369223437, -0.0018400929264185, -0.000658791463301671, -0.000509478771102116, -0.000656222903823772, 0.0236431905624578, 0.0211799660893324, 0.0506566804146619, -0.0793857886114535, -0.136173587707137, 0.241179763965931, 0.001967661055722, 0.00136316239720281, 0.00177020657356558, -0.00510934349238263, -0.00475860988386894, 0.00842806911326747, 0.0109380568162513, 0.00441760993533482, 0.00459285981587529, -0.0284023964650367, -0.0154212604048486, 0.0468509037896229, 0.000206742097729608, 8.34980070344268e-05, 8.68104352412857e-05, 0.000143227438853993, 7.77662418171786e-05, 0.000185995560246199, -0.00138633542761004, -0.0007527195694196, -0.00129116969293883, 0.00483950370236165},
    {0.0172198053622791, -0.00652877742132647, -0.0100835618309505, 0.0195251039488212, 0.00276855422334097, 0.00354739278284661, 0.0184970121822559, -0.041398111534134, 0.00480559727387789, -0.0696229490571688, 0.116257872529598, -0.0787003334009247, 0.0608951799214984, 0.649943657200637, -0.208138951111157, 0.0666936707344561, -0.00286607158261654, -0.00172596335485692, -0.00170726307853513, -0.00275019694120754, -0.0363180547067536, 0.0161122007935753, 0.00305654953686338, 0.00233062201042245, -0.0690428357230214, 0.10126879776982, -0.0599894079180597, 0.00404544389461591, 0.262546773541793, 0.225455398280341, -0.0254307747166693, -0.306036262199291, -0.0925652849176253, 0.179996535328407, 0.00650857391428436, -0.00331084397955433, -0.000888682878661062, 0.00449418520894309, -0.00323471010148826, 0.00629001046750751, 0.0123731957337331, -0.0208093974068783, 0.0174417456922689, 0.0085437200201195, -0.0203308788978238, 0.0119576932991251, 0.156789663691808, -0.26369084359981, 0.221016906233311, -0.0797572741627935, 0.189792675603336, -0.0214081135912333, -0.0322182004023548, 0.0766673450374755, 0.0231891952485375, -0.0314773329510054},
    {0.0157648753004524, 0.00858574731449896, -0.0118196797021562, 0.0197079603842469, 0.0153251463175155, 0.00682473684164892, 0.0170656692030985, -0.0431419561966854, -0.0231797827124803, -0.0726756131892212, 0.124780298683106, -0.0820154883984919, -0.0515609015277078, 0.218856107347192, -0.150272175335546, 0.0648054921715141, -0.0132859312546023, -0.00313228338759689, -0.00220943154814907, -0.00286604561350593, -0.0295531067577097, 0.00943259119854767, 0.00266080533945908, 0.00226463927967851, -0.0561822573222246, 0.068968965301209, -0.028334522503821, -0.00342534063541722, 0.621558100379749, 0.552501249632886, -0.110962179307842, -0.408107372713324, -0.106107915976052, 0.204952663667212, 0.0267888501632131, -0.0097829040658953, -0.00387759279960761, 0.00722618325024968, -0.00370795971687467, 0.00716210674532244, 0.050927237043988, -0.0715303734534461, 0.0412919121935719, 0.0137374148224589, -0.0271117596075609, 0.0136156014808827, 0.113282090987397, -0.159111523503952, 0.0918493604928062, -0.0413689957486712, 0.0816446385611458, -0.0163971882951675, -0.117489224878567, 0.231873293669398, 0.0602870558259823, -0.0445312874461568},
    {0.0132117409898728, 0.00728244989005009, -0.00729939888431997, -0.0116539403654932, 0.0195387056426204, -0.0109690858690785, -0.00648860340814748, 0.0275288649345272, -0.0311859124881201, 0.0417262619381514, -0.0868398367617212, 0.0523340502310094, -0.0242391457778128, 0.0111025773900735, -0.0390618253060839, 0.0288702594494081, -0.0254704298617906, 0.00892944871598907, 0.00226644479881698, 0.00182882255572042, -0.0197968060956589, 0.00237595918769125, 0.00101947993108488, 0.00100887627534099, -0.0376349350795189, 0.0317985080969108, -0.00387808858029441, -0.00161027694513697, 0.191503462471457, 0.214883898684752, -0.0957047798901592, 0.627694611711972, 0.089161357974763, -0.165370846131076, 0.0409818725101211, -0.00560828431610167, -0.00334442030343116, -0.0163822876805221, 0.00311575927800621, -0.00577891319567487, 0.0779090376449026, -0.07505813869161, 0.0127221319331294, -0.0311437274442793, 0.0416995784872784, -0.0109860662320211, 0.0605545379377077, -0.0583386862978686, 0.00988823433174055, -0.00828676301457331, 0.01109547742318, -0.0049416928446534, -0.142934721751187, 0.19138099827276, 0.0271848592901343, 0.0794093452371631},
    {0.00978040546374062, -0.0111121414793536, 0.00962857943557124, 0.0118223838397411, -0.0386200930353359, 0.0549301045311348, -0.0255353246076023, -0.0336121174078449, 0.0582572468288329, -0.126131012729572, 0.160899807538945, -0.0638986839804833, 0.0189347929379126, 0.00458359170060358, 0.0125779136442869, -0.0238627208753058, -0.0315495982714478, 0.03310637696547, -0.00927948168620295, -0.002232950708545, -0.0102542626550717, -0.00120308329737533, -0.00072539875030355, -0.000833886962407566, -0.0194939783441421, 0.00758070923223653, 0.00166566730191945, 0.00125789336011884, -0.135052204499447, -0.0818913657941363, 0.111811445560696, 0.732427557989167, -0.220976747397641, 0.464883125160772, 0.0354479766349184, 0.00472287345005615, 0.00390727055762897, -0.0422408716007057, -0.00772207115915281, 0.0162454222693437, 0.0673887642738489, -0.0297591450597261, -0.00897191069721777, -0.0803024716569532, 0.0486572926877848, 0.0308835379551549, 0.0219027222761857, -0.00967232885842999, -0.00291605389125922, 0.00291818589781649, -0.00176820242786567, 0.00241423827269637, -0.0859822306134804, 0.0520988018747551, -0.0157184470409661, 0.140584097846635},
    {0.00595231255869335, 0.00476412582200836, 0.0280757815135756, -0.0295941247801589, -0.142669865790111, 0.291843625603676, -0.302869456861528, 0.168138269227149, -0.0275920932079783, 0.0681032668396038, -0.0986835027874707, 0.319641098476688, -0.00369386434939363, -0.00184206276700017, -0.00257202845525818, -0.0363098612093178, -0.0268382683375481, 0.0466279404547274, -0.0373939339722441, 0.0111699141963798, -0.00359294678603303, -0.00126119637132601, -0.000974613380291213, -0.00126885446246872, -0.00683041084421033, -0.000410933730046616, -0.000227431231249652, -0.000245394151048703, 0.0253065278441706, 0.0181540378518066, 0.206163069251945, -0.0898530971770408, -0.524251903161903, 1.05895121462285, 0.017326500301564, 0.00687907171497645, 0.00720440458057826, -0.0340478467842396, -0.0183200746196735, 0.0370052357530364, 0.0329387331902804, 0.00224139766285654, 0.00168118623991423, -0.0647270320843953, -0.0059692025519225, 0.0703492087783397, 0.00440964052015398, 0.000300064908350429, 0.000225067154909313, 0.0017507420914462, 0.000161455481944365, 0.00183354017309736, -0.0240519510403535, -0.00221809903691554, -0.0129415977638837, 0.0640542148802876},
    {0.00246776876963692, 0.0302538880961421, 0.0249036082205117, 0.192230415140459, -0.14494000231401, 0.354346112869683, -0.476703569824698, 0.422356647889497, -0.184397876468037, 0.480186648330888, -0.713797405978018, 0.802925731904299, -0.00793163153750734, -0.00486754060925032, -0.00537840791474988, -0.0118519803113753, -0.0137211579663081, 0.0315457931627567, -0.0386364416503134, 0.0280583803965702, -0.000590197519305825, -0.00031977238393545, -0.000291122581603076, -0.0004141695287814, -0.001122001459015, -0.000478814744853801, -0.000394510258857428, -0.000526921349425656, 0.0533385602171292, 0.0395429056190285, 0.0748264123822477, -0.167793715365594, -0.213032160197368, 0.427152317178935, 0.00350406908242341, 0.00214037926285283, 0.00261482209238979, -0.00908234190642522, -0.00744444616732396, 0.0149269125729187, 0.00666144891220982, 0.00320492075650954, 0.00354343567185677, -0.0172660855678773, -0.0111470244813413, 0.0283769706540013, 0.000286533442193646, 0.000137855440824548, 0.000152416213594019, 0.000175022302174765, 0.000112994800092528, 0.000213818265916777, -0.00191789619302738, -0.00123819818524033, -0.00157202570775267, 0.00667062852425425},
    {0.0124299526187294, 0.00254449201900164, 0.0100401662714875, 0.0195251039488212, -0.00508376488671095, -0.0317222402070973, 0.0822967853898158, -0.0686320373360359, -0.000856872010174007, -0.00161605386869101, 0.0393067632837015, -0.0523859677188017, -0.0180010510271378, 0.0671213089149899, 0.629292918952211, -0.0815183617627336, -0.00204964204175442, -0.0012189336202151, -0.00118292063155356, -0.00183063682142867, -0.043058602151674, 0.050627285175583, -0.0189383076837506, -0.00284867343610899, -0.0328660874700562, 0.0241807101537084, -0.000964790796582509, -0.000480145834420634, 0.0101031421758621, 0.339146109455535, 0.151374443887892, -0.171539508681194, -0.274137109924834, 0.198631858112276, 0.0076204512154946, -0.0102064605800902, 0.00528980646672305, 0.00516240990083421, -0.00957976934285656, 0.00694122508762263, 0.00581659421565801, -0.00487483111382485, 0.000269483244227681, 0.00394040230937931, -0.0045755095303968, 0.00529814948649656, 0.122194222750899, -0.102409791178522, 0.00566126746200277, -0.163660980479209, 0.190039573917172, 0.0848222462719287, -0.0246343550379299, 0.0286048777260458, 0.045713425261963, -0.0231217705022783},
    {0.0112741294025221, -0.00481040329364095, 0.0110939404354585, 0.0197079603842469, -0.0231802053744836, -0.0276298646655858, 0.0870824133797188, -0.0715230777133197, 0.00736457670424289, 0.00438882359425989, 0.0397000546457263, -0.0545926623435965, 0.0271584695282763, -0.0674411898835215, 0.19356039727999, -0.0652473476293612, -0.00942285779415133, -0.00219692843858383, -0.00152363049106581, -0.0019077501517671, -0.0347488262460901, 0.0337592671031061, -0.00742856718436147, -0.0022800799960788, -0.0265233404201762, 0.0153905329075907, 0.0011799793927646, 0.000724403591411502, -0.0622282391086318, 0.896985621982871, 0.299024122342194, -0.215261263528709, -0.360407082565477, 0.22617173344477, 0.0311498025027811, -0.0344250066126233, 0.0104494503526857, 0.00826141494223303, -0.0125944886537097, 0.00790361085687722, 0.0237762510293563, -0.015694037299372, -0.00165982695934209, 0.0063058337370412, -0.00574170912796157, 0.00603272639544608, 0.0876800683880992, -0.0578751571051009, -0.00612097092715922, -0.0968990713114821, 0.0882304078161748, 0.0294129801131074, -0.0894091368997128, 0.0814105285467179, 0.136303813341331, -0.0327105924159354},
    {0.00930958844834861, -0.0117698440494143, -0.00170955493305552, -0.0116539403654932, 0.00630079692715626, -0.00613847546289073, -0.0581932607657199, 0.0456388471838218, 0.0354164151936632, -0.023983238734191, -0.0228191073912387, 0.0348355559312484, 0.0456362358439275, -0.0572326192875783, -0.00574410374506537, 0.00619710390792819, -0.0178289300066307, 0.00619513050775137, 0.00155135505195028, 0.00121733460618679, -0.0229736761944516, 0.0147838058786252, 0.000390512398712383, 0.000216558881969396, -0.0175355170299285, 0.00579711893708319, 0.00152574562586521, 0.00121726495336648, -0.182482550339248, 0.506413169593175, -0.035650211892502, 0.273447788383992, 0.532275572502242, -0.18249194844047, 0.0471372205926181, -0.0344284557477549, -0.0012458029015035, -0.0185903243576045, 0.0186004631507439, -0.00637721311597531, 0.0359792454393945, -0.0135003025897688, -0.00486739559083196, -0.0141897599063139, 0.00729373058973934, -0.00486764626837002, 0.0463614773369987, -0.0173959727313479, -0.00627193949230206, -0.0338618622572619, 0.0174054601488664, -0.00122530056414627, -0.107966384569832, 0.0554961977510376, 0.108025267288505, 0.0583303756759747},
    {0.00677269421349486, -0.00224468746929319, -0.0114222456646249, 0.0118223838397411, 0.0552995939385816, -0.104936601954282, 0.091016399340666, -0.055723993471933, 0.00967279417619884, -0.015304353365906, 0.00875331817503951, -0.042533420782639, 0.00521205405511998, -0.00198233611792224, -0.00130720099680889, 0.0227440073355649, -0.0217460457985153, 0.0226775867458485, -0.00629687867371579, -0.00148633784230119, -0.0117175620738284, 0.002937373321094, 0.000940361805028003, 0.000794793321731082, -0.00894386721374988, 0.00028249593990386, 0.000137145944198035, 0.000139022218178683, -0.027166966073064, 0.015879381119268, -0.142180891317948, 0.0660584269543606, 0.524279942561052, 0.513013202099967, 0.0402552930537987, -0.0114231579753206, -0.00496853616119742, -0.0475204821291951, 0.0183210544613896, 0.0179273362417271, 0.0307263570233539, -0.00109859912110437, -0.000724630221544316, -0.0362717841321435, 0.00176199036837877, 0.0136837094467269, 0.0165564810752096, -0.000591965248075886, -0.000390457174614161, -0.00469819704416931, 0.000228226378675281, -0.00204349462353745, -0.0643865379587114, 0.00312773309752828, 0.024823596387655, 0.103266475966666},
    {0.00405256796561405, 0.0225257270787523, 0.0116134748343783, -0.0295941247801589, -0.0648165501864932, 0.151531129548398, -0.198356641546219, 0.278748753109168, -0.118755279768057, 0.25582760745598, -0.289712660115728, 0.212765404450057, -0.0263569760650688, -0.00453184613547787, -0.00392058013420648, -0.0109803617251882, -0.018223677561725, 0.0315481269099228, -0.02516441184838, 0.0074351243409912, -0.00404462887250186, -0.000558857812258999, -0.000340541187058891, -0.000383710664555015, -0.00308721416081532, -0.000816247856153973, -0.000574930295742466, -0.000703025187056429, 0.157600788983966, 0.0349049822683104, 0.0712526331790853, -0.43732301110713, -0.228543925328445, 1.16858608987677, 0.0194350005513992, 0.00303184316836326, 0.00248993575190873, -0.0379858317474887, -0.00798650751792726, 0.0408364456798986, 0.0148344905822272, 0.00442820236576486, 0.00420371911717637, -0.0289941058569007, -0.0116648090026963, 0.0311699434866482, 0.00329242046313149, 0.000982811240003288, 0.000932988616355402, 0.000513614726283411, 0.000206635711155769, 0.000421811946945231, -0.0178616139374967, -0.00718602312101334, -0.00375539793211271, 0.0470512180454073},
    {0.00165731029056227, 0.0278235382849625, 0.0299947250976383, 0.192230415140459, -0.180516285730209, 0.461954122435896, -0.667777779660335, 0.700205786033841, -0.164115051478879, 0.408587395180543, -0.565496681950334, 0.534458237398517, -0.0117031127641394, -0.00580187045310394, -0.00555494811880189, -0.00982556301346886, -0.00920510912404723, 0.0211331468589321, -0.0258282524615989, 0.0186767367580078, -0.000656420170570432, -0.000300087035939466, -0.000253714313457566, -0.000343356021220727, -0.000501037229845097, -0.000254123794305306, -0.000224404254493844, -0.00031215959751377, 0.075242381617107, 0.0438841037852108, 0.0649328546150946, -0.220382521134524, -0.198640193522426, 0.471376064563759, 0.00389172137830513, 0.00200434369960644, 0.00226908998258686, -0.0100656565735356, -0.00694151636999031, 0.0164723191745253, 0.00297050180073002, 0.00169734565320795, 0.00200695593001032, -0.00768298859828438, -0.00587830951327851, 0.012573113286809, 0.000211827722239706, 0.000121038426398258, 0.000143116864357792, 0.000109097111329768, 8.34709799704963e-05, 0.000123507341827678, -0.00141484139474394, -0.00108250526785396, -0.000975708303854574, 0.00489993043831973},
    {0.00700570982272348, -0.00396719586028164, -0.0283386095943201, 0.0195251039488212, 0.0724066424646238, -0.168855440911288, 0.180838102102827, -0.0944993352356273, 0.000881675779233191, 0.00080195935721927, 0.00164117293051681, -0.0273920854159158, 0.0255030826818176, -0.0731920669423039, 0.139859224732048, 0.607097608174253, -0.00114511302775321, -0.000673043912202277, -0.00064163166281104, -0.000957221224723076, -0.0331231875874077, 0.061426398524528, -0.0546792511962841, 0.0212151322982274, -0.00960126525101313, 0.000557467377202777, 0.000259692769779503, 0.000258330833524202, -0.00690326988915832, 0.0311157999146767, 0.421321766809783, -0.00986172950072093, -0.314981484277462, 0.143008184695501, 0.00579356513688973, -0.0121650083715791, 0.014723162968593, 0.00385553391728583, -0.0110070831616924, 0.00499744607324118, 0.00167935394145003, -0.000110401968428172, -6.99259570600276e-05, 0.00111758579171933, -9.98933671546724e-05, 0.00144858658908371, 0.0485764761033608, -0.00319345341606722, -0.0020226567481074, -0.101998203955028, 0.00911692338278994, 0.123447196538076, -0.00962018371015547, 0.000859882570603936, 0.0274644613171983, -0.00870448740305289},
    {0.00630096536900626, 0.00163104362451025, -0.0195929661997852, 0.0197079603842469, 0.0976637162240657, -0.196492083346238, 0.196789453010076, -0.0984800038037923, -0.00176946150425569, -0.000595996850338291, -0.000775277112656327, -0.0285459434103636, -0.00898463593005338, 0.0206962864077096, -0.0268812006793827, 0.14374374463353, -0.0052253220280552, -0.00120559810201229, -0.000822987370205655, -0.000997542994527456, -0.0265321488636247, 0.0418649924033504, -0.0285354595072404, 0.0050231503441661, -0.00769075132780617, -0.000164932469374706, -8.65533292724027e-05, -9.10089387106368e-05, 0.0116355043739915, -0.039584275663694, 1.11194332036726, 0.00578806775186368, -0.425867801143153, 0.162835958625975, 0.0235366042308364, -0.0420202768766616, 0.0388570541739823, 0.00614426323170681, -0.014882024934966, 0.00569033110762514, 0.0068224466540862, 0.000165544232333859, 0.000117860635943879, 0.00178100917684909, 5.86296325620855e-05, 0.00164942997065816, 0.034641725288599, 0.000840569096452956, 0.000598450377074195, -0.0618464275405143, -0.00203594308727178, 0.0571907222901661, -0.0347702174190693, -0.00114461233433296, 0.0842169716874307, -0.012314322538702},
    {0.00513339611045787, 0.0126104679035145, 0.010730605592219, -0.0116539403654932, -0.0616020791184595, 0.199029865952139, -0.142163327346853, 0.0628400509032688, -0.0295896009607121, 0.0136392839755108, 0.00544335694053326, 0.0182151550335338, -0.0524984143521611, 0.0795137525688746, -0.044427120188602, -0.0316809934644757, -0.00976967983719914, 0.003366415574993, 0.000832405683526354, 0.000636531784454365, -0.0173335456893195, 0.0196253949660864, -0.0067938567600306, -0.00110709786801743, -0.00502439475260475, -0.000751445762371026, -0.000465575059279214, -0.000531777248558373, 0.14289168101562, -0.295112794978876, 0.604407671559529, -0.0898140827333987, 0.679925843563978, -0.131387998461278, 0.0352681842662438, -0.0451290574006877, 0.0211211319918735, -0.0137344939427508, 0.0237601277454771, -0.00459137662910276, 0.0102230255215699, 0.00172796720790301, 0.00144740647712983, -0.00398115426194411, -0.000909762444964004, -0.00133088111664927, 0.0181378799422367, 0.00306579120779279, 0.00256801519808446, -0.023209173992647, -0.00530369673915513, 0.0108622704650948, -0.0417084816104069, -0.0095311077413747, 0.0721540127553239, 0.0219592189204033},
    {0.00367511242526284, 0.0253972624653879, -0.00366448453027245, 0.0118223838397411, 0.0220838867907563, -0.0613915956629151, 0.299716318033461, -0.076726271638846, -0.0936105122386033, 0.117950744221066, -0.0442674609131471, -0.0222402896394521, -0.06945179083084, 0.0503099322824041, 0.00386755227615364, 0.0047493118019995, -0.0117484678910898, 0.012180006156454, -0.003352220481887, -0.000777190818575083, -0.0087164583874409, 0.00519517947069488, 0.000292876250126906, 0.000165965533133739, -0.00252659949488241, -0.000767316927102067, -0.000562698709719879, -0.000703504718975491, 0.288289419424248, -0.264445516332456, -0.043494393914345, -0.45998321836361, 0.902742954379208, 0.36935206393565, 0.0297697731931801, -0.0200255369950425, -0.00151991921677815, -0.0348329254516791, 0.0315465107267405, 0.0129070725951026, 0.00862922652404638, 0.00295772910200314, 0.0029201978029571, -0.0100968590612783, -0.00465935234926477, 0.0037413134612316, 0.00640222151602378, 0.0021944072093425, 0.00216656187585756, -0.00430664765188609, -0.0019873694118625, -0.000326870461831681, -0.024678247314225, -0.011388160308213, 0.0223499055425405, 0.0388759908814471},
    {0.00216464827329582, 0.0300055156673333, -0.00428139506100081, -0.0295941247801589, 0.0263560489909356, -0.0712908034861193, 0.124137438646549, 0.383808683073226, -0.145766077772663, 0.28016483684933, -0.262749987106196, 0.111252848540127, -0.0445452074184814, 0.00310597107865768, 0.00167285081968775, 0.00233464669412122, -0.00970937438415828, 0.0167516558155947, -0.0132940824930269, 0.00388775028686344, -0.00296712446719301, 0.000185712664972437, 8.46394591312488e-05, 8.15846378217418e-05, -0.000860066651710836, -0.000393080450660091, -0.000332623551692547, -0.000451216062995007, 0.237643788379266, -0.0198115605034005, -0.017528416887323, -0.54610911038394, 0.074788675559698, 0.841342254771773, 0.0142092312312, -0.00100238451978037, -0.000612533599599346, -0.0276309035962132, 0.00261350337251347, 0.0294008525198299, 0.00411876416494393, 0.00212165260149834, 0.00240718813093273, -0.00800924228238451, -0.00553175564855279, 0.00852228919405461, 0.00125866873032955, 0.000648363848762868, 0.000735621731929619, -8.87922808971194e-05, -6.13263008014448e-05, -5.42588740761078e-05, -0.00679366725474128, -0.00469219258024673, 0.00064258746443784, 0.0177130351991939},
    {0.000873918129073642, 0.0191690324088709, 0.0293017672320873, 0.192230415140459, -0.182241449919052, 0.488039973885573, -0.759220407776989, 0.964112153400919, -0.109706187629544, 0.262185091653748, -0.340572586312385, 0.279462732628028, -0.0107717424744171, -0.00423279236974588, -0.0035344039316794, -0.00518678617405979, -0.00484906798185348, 0.0111175665009612, -0.0135601345036643, 0.00976587416141791, -0.000476116367454605, -0.000179485226862425, -0.000140724751873965, -0.000181253151723385, -0.000138009650255373, -8.05138366819909e-05, -7.56002252730339e-05, -0.000109111249280821, 0.0664794510482461, 0.0300484980775636, 0.0358699829632348, -0.182750526031733, -0.118090011664295, 0.339374740501439, 0.00281896164772151, 0.00119640185951775, 0.00125348284007991, -0.00727633935672254, -0.00412667615030015, 0.0118595097748224, 0.000817119380216213, 0.000536684303254971, 0.000673396711126433, -0.00210915884939885, -0.00185115251774706, 0.00343766126960363, 8.02306572192806e-05, 5.2695524561312e-05, 6.61189319591221e-05, 3.40508738617893e-05, 2.9885544608778e-05, 3.56754594920352e-05, -0.000534796702578252, -0.000469376814715937, -0.000303302620945667, 0.0018446417315659},
    {0.00234316248688227, 0.0302387678330058, 0.259211232824318, 0.0195251039488212, 0.326169225832269, -0.374897896525802, 0.278859093198178, -0.113874016814714, -0.00535611326543893, -0.00351055389355499, -0.00396473437419397, -0.0086715946664266, -0.186693590381845, 0.494062814074892, -0.750151206494618, 0.865758905462842, -0.000380508993873716, -0.000221704125817876, -0.000208599314241407, -0.000303030395125598, -0.0132630858830495, 0.0312018466643448, -0.0394682247241074, 0.0302540966567129, -0.00100999427280179, -0.000443618433201086, -0.000369581508087748, -0.000496810721561461, 0.0364144726787386, -0.115913919569766, 0.296132254907867, 0.0287083824964372, -0.153763681235287, 0.0545545092110109, 0.00229970513974527, -0.00609865929245069, 0.0103483935384566, 0.00151045400183998, -0.00537329878448945, 0.00190641688386354, 0.000175124329342117, 8.6708896080594e-05, 9.69026328638305e-05, 0.000115022243288035, 7.63959394308065e-05, 0.000145175123742231, 0.00610416325940183, 0.00302233995531938, 0.0033776545696934, -0.0161878196213958, -0.0107516916029521, 0.0274679925437245, -0.00119310925359803, -0.00079244413660028, 0.00424437453528185, -0.00105120358339451},
    {0.00209472514255056, 0.0298426277029343, 0.00525730855264612, 0.0197079603842469, 0.692635678336204, -0.462466964864017, 0.306530718648313, -0.118670820076184, -0.0265751876169889, -0.00675219580951266, -0.00535145363896167, -0.00903687495372644, -0.162604137077821, 0.365229353082629, -0.43671602204642, 0.32272636006408, -0.00172706393075763, -0.000395389812588245, -0.000266770877594565, -0.000315795178772715, -0.0105672909703012, 0.021386815421382, -0.0217703682626929, 0.0112777292031759, -0.00080470740015903, -0.000373373839063302, -0.000317855761650219, -0.000432706224703747, 0.158848151032726, -0.425607910612668, 0.828499366632536, 0.048144235768509, -0.210000758077653, 0.0621183733200974, 0.00930170605810038, -0.0212166270111522, 0.0289520555433695, 0.00239999837307297, -0.00733851328906408, 0.00217073744055724, 0.000708332127892991, 0.000370402667393234, 0.000422711162026886, 0.000182761736817021, 0.000128116731068698, 0.000165303339061029, 0.00433403278578912, 0.00226636240431712, 0.00258641951000194, -0.00988566575807082, -0.00692989245680966, 0.0134899078897138, -0.00429954414710395, -0.00301399817492431, 0.0131467846872089, -0.0014871478790602},
    {0.00169002122151252, 0.0280378223106107, -0.0132573892568216, -0.0116539403654932, 0.130691148487769, 0.574537076169525, -0.227302951843894, 0.0757238026633067, -0.0564738728270903, 0.0210073440323393, 0.00584313287859409, 0.00576642628111647, -0.120739823396357, 0.195812008554932, -0.137666072131895, 0.0212776405782489, -0.00320141581284016, 0.00109628782576121, 0.00026854825948334, 0.00020150877683367, -0.00684455236573057, 0.0102186321500795, -0.00632708254785078, 0.0007435508784479, -0.000521217969199429, -0.000262683898321744, -0.000231343120081773, -0.00032130100803178, 0.265205427918547, -0.506505871964673, 0.552336380720342, -0.116176763860625, 0.3441540757173, -0.0501216611310328, 0.0138399924095758, -0.0232788254452491, 0.0193014916091434, -0.0053394417644461, 0.0120265244814159, -0.00175151023094892, 0.00105392615206975, 0.00059841400752063, 0.000705738744092678, -0.000406602630006449, -0.000309158240324295, -0.000133378862024143, 0.00225326954047052, 0.00127939519584897, 0.0015088529803262, -0.00378999256368266, -0.00288170155665656, 0.00314244848129001, -0.00513312031819339, -0.00390294190895998, 0.0115618073754226, 0.00265192061850382},
    {0.00119584539165622, 0.0235888506057286, 0.00832487477036397, 0.0118223838397411, -0.0614326220634958, 0.26203544501963, 0.51856956288066, -0.0924570392473858, -0.0784456611970351, 0.085762169265203, -0.0255955981627665, -0.00704067522019325, -0.0701331978298506, 0.0632915073048822, -0.0095448252899044, -0.00418242435882014, -0.00381032346110899, 0.00393303420879111, -0.0010753656842844, -0.000246037629294061, -0.00340656404721311, 0.00290253459641737, -0.000401013389645667, -0.000146155552097576, -0.000259412493288283, -0.000143263535890448, -0.000131248572870788, -0.00018663160608785, 0.252592041211182, -0.26455350066724, 0.0587703498073264, -0.320492997714484, 0.494463927062682, 0.140899771694796, 0.0115838154219246, -0.0111148703955157, 0.00205374017223555, -0.0134650954278903, 0.0172791285751941, 0.00492376721147822, 0.00088211652525685, 0.000548608666298242, 0.000672173233147192, -0.00102537745625856, -0.000852864616960295, 0.000374948690527646, 0.00078864339761773, 0.000490475566622459, 0.000600946663166401, -0.000756716922147295, -0.000629404405192849, 0.00013982168812788, -0.0030200050547621, -0.0025119095787866, 0.0038754315495525, 0.00469488656026294},
    {0.000696217557866043, 0.0161601125382385, -0.0107414954878784, -0.0295941247801589, 0.0716512169321643, -0.219640225699807, 0.508137289414865, 0.462498877065499, -0.0741443373095674, 0.131860036949593, -0.10956139003762, 0.0352196480617275, -0.0273035043961888, 0.00598377507353533, 0.00214906927708225, 0.00200927002101727, -0.00311691852162229, 0.00536405680022603, -0.00424076416664777, 0.0012307567729902, -0.00114779903153438, 0.000243419538752949, 8.31834643458343e-05, 7.02142929649534e-05, -8.74057861345111e-05, -5.24846012754023e-05, -4.9938824490435e-05, -7.2657415246489e-05, 0.134778903993248, -0.033815187640404, -0.017096016877359, -0.274403811056705, 0.0969143307348483, 0.320953754397271, 0.00548279610120537, -0.00130887565395655, -0.000597423305482543, -0.0106212767903115, 0.00338668826964637, 0.0112157851875391, 0.000417519173892697, 0.000282211597182745, 0.000358660436103927, -0.000808818462207916, -0.000730216581573679, 0.000854090737576376, 0.000153750603397662, 0.000103923858030999, 0.000132075990550932, -3.67039769222752e-05, -3.31370434908545e-05, -1.67531660864908e-05, -0.000826722549058069, -0.000746380729286416, 0.000263607814241949, 0.0021391272354127},
    {0.000278404956314754, 0.00734348804657586, 0.0263784345157958, 0.192230415140459, -0.168273534214414, 0.466883678827404, -0.770250380155342, 1.16177879234705, -0.0411121542477164, 0.0953904978590445, -0.11845780646441, 0.0884703557588258, -0.00486430680960264, -0.00156238526998143, -0.00117604374843875, -0.0015161454644233, -0.00154360799326942, 0.00353550741513474, -0.00430576776528859, 0.00309161208448682, -0.000182636570873348, -5.79074942609307e-05, -4.27474677587255e-05, -5.29819689256468e-05, -1.3907916469301e-05, -8.90566876009043e-06, -8.73387187564409e-06, -1.29444174866314e-05, 0.0291460988640959, 0.0106032943169836, 0.010863214119597, -0.0765964287661009, -0.0379272265467481, 0.12946407540304, 0.00108025695398435, 0.000385414218265742, 0.000379616920949663, -0.00278416799838646, -0.00132537357759257, 0.00452414480070575, 8.22624045640044e-05, 5.92733532525035e-05, 7.75607474136575e-05, -0.000212016551629297, -0.000203830924063635, 0.00034451713412149, 9.73312106879685e-06, 7.01310308699197e-06, 9.1768305189657e-06, 3.47258421647299e-06, 3.33851316932844e-06, 3.42035053586783e-06, -6.47806177062393e-05, -6.22795393426944e-05, -3.08381243861555e-05, 0.00022276946458923}};
    
    // Compute element tensor using UFL quadrature representation
    // Optimisations: ('simplify expressions', True), ('ignore zero tables', True), ('non zero columns', True), ('remove zero terms', True), ('ignore ones', True)
    // Total number of operations to compute element tensor: 48816
    
    // Loop quadrature points for integral
    // Number of operations to compute element tensor for following IP loop = 48816
    for (unsigned int ip = 0; ip < 216; ip++)
    {
      
      // Function declarations
      double F0 = 0;
      
      // Total number of operations to compute function values = 112
      for (unsigned int r = 0; r < 56; r++)
      {
        F0 += FE0[ip][r]*w[0][r];
      }// end loop over 'r'
      
      // Number of operations to compute ip constants: 2
      // Number of operations: 2
      const double Gip0 = F0*W216[ip]*det;
      
      
      // Number of operations for primary indices = 112
      for (unsigned int j = 0; j < 56; j++)
      {
        // Number of operations to compute entry = 2
        A[j] += FE0[ip][j]*Gip0;
      }// end loop over 'j'
    }// end loop over 'ip'
  }

};

/// This class defines the interface for the tabulation of the cell
/// tensor corresponding to the local contribution to a form from
/// the integral over a cell.

class poisson3d_5_1_cell_integral_0: public ufc::cell_integral
{
private:

  poisson3d_5_1_cell_integral_0_quadrature integral_0_quadrature;

public:

  /// Constructor
  poisson3d_5_1_cell_integral_0() : ufc::cell_integral()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_1_cell_integral_0()
  {
    // Do nothing
  }

  /// Tabulate the tensor for the contribution from a local cell
  virtual void tabulate_tensor(double* A,
                               const double * const * w,
                               const ufc::cell& c) const
  {
    // Reset values of the element tensor block
    A[0] = 0;
    A[1] = 0;
    A[2] = 0;
    A[3] = 0;
    A[4] = 0;
    A[5] = 0;
    A[6] = 0;
    A[7] = 0;
    A[8] = 0;
    A[9] = 0;
    A[10] = 0;
    A[11] = 0;
    A[12] = 0;
    A[13] = 0;
    A[14] = 0;
    A[15] = 0;
    A[16] = 0;
    A[17] = 0;
    A[18] = 0;
    A[19] = 0;
    A[20] = 0;
    A[21] = 0;
    A[22] = 0;
    A[23] = 0;
    A[24] = 0;
    A[25] = 0;
    A[26] = 0;
    A[27] = 0;
    A[28] = 0;
    A[29] = 0;
    A[30] = 0;
    A[31] = 0;
    A[32] = 0;
    A[33] = 0;
    A[34] = 0;
    A[35] = 0;
    A[36] = 0;
    A[37] = 0;
    A[38] = 0;
    A[39] = 0;
    A[40] = 0;
    A[41] = 0;
    A[42] = 0;
    A[43] = 0;
    A[44] = 0;
    A[45] = 0;
    A[46] = 0;
    A[47] = 0;
    A[48] = 0;
    A[49] = 0;
    A[50] = 0;
    A[51] = 0;
    A[52] = 0;
    A[53] = 0;
    A[54] = 0;
    A[55] = 0;
    
    // Add all contributions to element tensor
    integral_0_quadrature.tabulate_tensor(A, w, c);
  }

};

/// This class defines the interface for the assembly of the global
/// tensor corresponding to a form with r + n arguments, that is, a
/// mapping
///
///     a : V1 x V2 x ... Vr x W1 x W2 x ... x Wn -> R
///
/// with arguments v1, v2, ..., vr, w1, w2, ..., wn. The rank r
/// global tensor A is defined by
///
///     A = a(V1, V2, ..., Vr, w1, w2, ..., wn),
///
/// where each argument Vj represents the application to the
/// sequence of basis functions of Vj and w1, w2, ..., wn are given
/// fixed functions (coefficients).

class poisson3d_5_form_1: public ufc::form
{
public:

  /// Constructor
  poisson3d_5_form_1() : ufc::form()
  {
    // Do nothing
  }

  /// Destructor
  virtual ~poisson3d_5_form_1()
  {
    // Do nothing
  }

  /// Return a string identifying the form
  virtual const char* signature() const
  {
    return "Form([Integral(Product(BasisFunction(FiniteElement('Lagrange', Cell('tetrahedron', 1), 5), 0), Function(FiniteElement('Lagrange', Cell('tetrahedron', 1), 5), 0)), Measure('cell', 0, None))])";
  }

  /// Return the rank of the global tensor (r)
  virtual unsigned int rank() const
  {
    return 1;
  }

  /// Return the number of coefficients (n)
  virtual unsigned int num_coefficients() const
  {
    return 1;
  }

  /// Return the number of cell integrals
  virtual unsigned int num_cell_integrals() const
  {
    return 1;
  }
  
  /// Return the number of exterior facet integrals
  virtual unsigned int num_exterior_facet_integrals() const
  {
    return 0;
  }
  
  /// Return the number of interior facet integrals
  virtual unsigned int num_interior_facet_integrals() const
  {
    return 0;
  }
    
  /// Create a new finite element for argument function i
  virtual ufc::finite_element* create_finite_element(unsigned int i) const
  {
    switch ( i )
    {
    case 0:
      return new poisson3d_5_1_finite_element_0();
      break;
    case 1:
      return new poisson3d_5_1_finite_element_1();
      break;
    }
    return 0;
  }
  
  /// Create a new dof map for argument function i
  virtual ufc::dof_map* create_dof_map(unsigned int i) const
  {
    switch ( i )
    {
    case 0:
      return new poisson3d_5_1_dof_map_0();
      break;
    case 1:
      return new poisson3d_5_1_dof_map_1();
      break;
    }
    return 0;
  }

  /// Create a new cell integral on sub domain i
  virtual ufc::cell_integral* create_cell_integral(unsigned int i) const
  {
    return new poisson3d_5_1_cell_integral_0();
  }

  /// Create a new exterior facet integral on sub domain i
  virtual ufc::exterior_facet_integral* create_exterior_facet_integral(unsigned int i) const
  {
    return 0;
  }

  /// Create a new interior facet integral on sub domain i
  virtual ufc::interior_facet_integral* create_interior_facet_integral(unsigned int i) const
  {
    return 0;
  }

};

// DOLFIN wrappers

// Standard library includes
#include <string>

// DOLFIN includes
#include <dolfin/common/NoDeleter.h>
#include <dolfin/fem/FiniteElement.h>
#include <dolfin/fem/DofMap.h>
#include <dolfin/fem/Form.h>
#include <dolfin/function/FunctionSpace.h>
#include <dolfin/function/Function.h>
#include <dolfin/function/Coefficient.h>

namespace Poisson3D_5
{

class CoefficientReference
{
public:
  
  CoefficientReference(const std::string & name):
    _name(name)
  {}
  
  ~CoefficientReference()
  {}

  CoefficientReference& operator=(dolfin::Function & f)
  {
    _function_pointer = dolfin::reference_to_no_delete_pointer(f);
    return *this;
  }
  
  CoefficientReference& operator=(const boost::shared_ptr<dolfin::Function> f)
  {
    _function_pointer = f;
    return *this;
  }

  std::string name() const
  {
    return _name;
  }

  dolfin::Function & function() const
  {
    return *_function_pointer;
  }

  boost::shared_ptr<dolfin::Function> function_pointer() const
  {
    return _function_pointer;
  }

private:

  boost::shared_ptr<dolfin::Function> _function_pointer;
  std::string _name;

};

class CoefficientSet
{
public:

  CoefficientSet():
    f("f")
  {}
  
  ~CoefficientSet()
  {}

  dolfin::uint num_coefficients() const
  {
    return 1;
  }

  std::string name(dolfin::uint i) const
  {
    switch(i)
    {
    case 0: return "f";
    default:
        throw std::runtime_error("Invalid coefficient number.");
    }
  }

  void disp() const
  {
    for(dolfin::uint i = 0; i < num_coefficients(); ++i)
    {
        dolfin::cout << "Coefficient " << i << ": \t" << name(i) << dolfin::endl;
    }
  }

  CoefficientReference f;
};

class CoefficientSpace_f: public dolfin::FunctionSpace
{
public:


  CoefficientSpace_f(const dolfin::Mesh & mesh):
      dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_1()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  CoefficientSpace_f(dolfin::Mesh & mesh):
    dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                          boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_1()))),
                          boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_1()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  CoefficientSpace_f(boost::shared_ptr<dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_1()), mesh)))
  {
      // Do nothing
  }

  CoefficientSpace_f(boost::shared_ptr<const dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_1()), mesh)))
  {
      // Do nothing
  }
 

  ~CoefficientSpace_f()
  {
  }
  
};

class Form_0_FunctionSpace_0: public dolfin::FunctionSpace
{
public:


  Form_0_FunctionSpace_0(const dolfin::Mesh & mesh):
      dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_0()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_0_FunctionSpace_0(dolfin::Mesh & mesh):
    dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                          boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_0()))),
                          boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_0()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_0_FunctionSpace_0(boost::shared_ptr<dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_0()), mesh)))
  {
      // Do nothing
  }

  Form_0_FunctionSpace_0(boost::shared_ptr<const dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_0()), mesh)))
  {
      // Do nothing
  }
 

  ~Form_0_FunctionSpace_0()
  {
  }
  
};

class Form_0_FunctionSpace_1: public dolfin::FunctionSpace
{
public:


  Form_0_FunctionSpace_1(const dolfin::Mesh & mesh):
      dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_1()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_0_FunctionSpace_1(dolfin::Mesh & mesh):
    dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                          boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_1()))),
                          boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_1()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_0_FunctionSpace_1(boost::shared_ptr<dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_1()), mesh)))
  {
      // Do nothing
  }

  Form_0_FunctionSpace_1(boost::shared_ptr<const dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_0_finite_element_1()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_0_dof_map_1()), mesh)))
  {
      // Do nothing
  }
 

  ~Form_0_FunctionSpace_1()
  {
  }
  
};

class Form_0: public dolfin::Form
{
public:

  // Constructor
  Form_0(const dolfin::FunctionSpace & _V0, const dolfin::FunctionSpace & _V1):
    dolfin::Form(2, 0)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);
    boost::shared_ptr<const dolfin::FunctionSpace> _pV1 = dolfin::reference_to_no_delete_pointer(_V1);

    _function_spaces[0] = _pV0;
    _function_spaces[1] = _pV1;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_0());
  }

  // Constructor
  Form_0(const dolfin::FunctionSpace & _V0, const dolfin::FunctionSpace & _V1, const CoefficientSet & coefficients):
    dolfin::Form(2, 0)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);
    boost::shared_ptr<const dolfin::FunctionSpace> _pV1 = dolfin::reference_to_no_delete_pointer(_V1);

    _function_spaces[0] = _pV0;
    _function_spaces[1] = _pV1;

    update_coefficients(coefficients);

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_0());
  }

  // Constructor
  Form_0(boost::shared_ptr<const dolfin::FunctionSpace> _pV0, boost::shared_ptr<const dolfin::FunctionSpace> _pV1):
    dolfin::Form(2, 0)
  {
    _function_spaces[0] = _pV0;
    _function_spaces[1] = _pV1;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_0());
  }

  // Constructor
  Form_0(boost::shared_ptr<const dolfin::FunctionSpace> _pV0, boost::shared_ptr<const dolfin::FunctionSpace> _pV1, const CoefficientSet & coefficients):
    dolfin::Form(2, 0)
  {
    _function_spaces[0] = _pV0;
    _function_spaces[1] = _pV1;

    update_coefficients(coefficients);

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_0());
  }

  // Destructor
  ~Form_0()
  {}

  void update_coefficients(const CoefficientSet & coefficients)
  {

  }

  /// Return the number of the coefficient with this name
  virtual dolfin::uint coefficient_number(const std::string & name) const
  {
    dolfin::error("No coefficients.");
    return 0;
  }
  
  /// Return the name of the coefficient with this number
  virtual std::string coefficient_name(dolfin::uint i) const
  {
    dolfin::error("No coefficients.");
    return "unnamed";
  }

  // Typedefs
  typedef Form_0_FunctionSpace_0 TestSpace;
  typedef Form_0_FunctionSpace_1 TrialSpace;

  // Coefficients
};

class Form_1_FunctionSpace_0: public dolfin::FunctionSpace
{
public:


  Form_1_FunctionSpace_0(const dolfin::Mesh & mesh):
      dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_0()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_1_FunctionSpace_0(dolfin::Mesh & mesh):
    dolfin::FunctionSpace(dolfin::reference_to_no_delete_pointer(mesh),
                          boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_0()))),
                          boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_0()), dolfin::reference_to_no_delete_pointer(mesh))))
  {
    // Do nothing
  }

  Form_1_FunctionSpace_0(boost::shared_ptr<dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_0()), mesh)))
  {
      // Do nothing
  }

  Form_1_FunctionSpace_0(boost::shared_ptr<const dolfin::Mesh> mesh):
      dolfin::FunctionSpace(mesh,
                            boost::shared_ptr<const dolfin::FiniteElement>(new dolfin::FiniteElement(boost::shared_ptr<ufc::finite_element>(new poisson3d_5_1_finite_element_0()))),
                            boost::shared_ptr<const dolfin::DofMap>(new dolfin::DofMap(boost::shared_ptr<ufc::dof_map>(new poisson3d_5_1_dof_map_0()), mesh)))
  {
      // Do nothing
  }
 

  ~Form_1_FunctionSpace_0()
  {
  }
  
};

typedef CoefficientSpace_f Form_1_FunctionSpace_1;

class Form_1_Coefficient_f: public dolfin::Coefficient
{
public:

  Form_1_Coefficient_f(dolfin::Form & form):
    dolfin::Coefficient(form)
  {}
  
  ~Form_1_Coefficient_f()
  {}

  const Form_1_Coefficient_f& operator=(dolfin::Function & f)
  {
    attach(f);
    return *this;
  }
  
  const Form_1_Coefficient_f& operator=(boost::shared_ptr<dolfin::Function> f)
  {
    attach(f);
    return *this;
  }
  
  const dolfin::FunctionSpace * create_function_space() const
  {
    return new Form_1_FunctionSpace_1(form.mesh());
  }
  
  dolfin::uint number() const
  {
    return 0;
  }

  std::string name() const
  {
    return "f";
  }

};

class Form_1: public dolfin::Form
{
public:

  // Constructor
  Form_1(const dolfin::FunctionSpace & _V0):
    dolfin::Form(1, 1), f(*this)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);

    _function_spaces[0] = _pV0;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(const dolfin::FunctionSpace & _V0, const CoefficientSet & coefficients):
    dolfin::Form(1, 1), f(*this)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);

    _function_spaces[0] = _pV0;

    update_coefficients(coefficients);

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(const dolfin::FunctionSpace & _V0, dolfin::Function & _f):
    dolfin::Form(1, 1), f(*this)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);

    _function_spaces[0] = _pV0;

    boost::shared_ptr<dolfin::Function> _pf = dolfin::reference_to_no_delete_pointer(_f);

    f = _pf;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(const dolfin::FunctionSpace & _V0, boost::shared_ptr<dolfin::Function> _pf):
    dolfin::Form(1, 1), f(*this)
  {
    boost::shared_ptr<const dolfin::FunctionSpace> _pV0 = dolfin::reference_to_no_delete_pointer(_V0);

    _function_spaces[0] = _pV0;

    f = _pf;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(boost::shared_ptr<const dolfin::FunctionSpace> _pV0):
    dolfin::Form(1, 1), f(*this)
  {
    _function_spaces[0] = _pV0;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(boost::shared_ptr<const dolfin::FunctionSpace> _pV0, const CoefficientSet & coefficients):
    dolfin::Form(1, 1), f(*this)
  {
    _function_spaces[0] = _pV0;

    update_coefficients(coefficients);

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(boost::shared_ptr<const dolfin::FunctionSpace> _pV0, dolfin::Function & _f):
    dolfin::Form(1, 1), f(*this)
  {
    _function_spaces[0] = _pV0;

    boost::shared_ptr<dolfin::Function> _pf = dolfin::reference_to_no_delete_pointer(_f);

    f = _pf;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Constructor
  Form_1(boost::shared_ptr<const dolfin::FunctionSpace> _pV0, boost::shared_ptr<dolfin::Function> _pf):
    dolfin::Form(1, 1), f(*this)
  {
    _function_spaces[0] = _pV0;

    f = _pf;

    _ufc_form = boost::shared_ptr<const ufc::form>(new poisson3d_5_form_1());
  }

  // Destructor
  ~Form_1()
  {}

  void update_coefficients(const CoefficientSet & coefficients)
  {
    f = coefficients.f.function_pointer();
  }

  /// Return the number of the coefficient with this name
  virtual dolfin::uint coefficient_number(const std::string & name) const
  {
    if(name == "f") return 0;
    dolfin::error("Invalid coefficient.");
    return 0;
  }
  
  /// Return the name of the coefficient with this number
  virtual std::string coefficient_name(dolfin::uint i) const
  {
    switch(i)
    {
      case 0: return "f";
    }
    dolfin::error("Invalid coefficient.");
    return "unnamed";
  }

  // Typedefs
  typedef Form_1_FunctionSpace_0 TestSpace;
  typedef Form_1_FunctionSpace_1 CoefficientSpace_f;

  // Coefficients
  Form_1_Coefficient_f f;
};

// Class typedefs
typedef Form_0 BilinearForm;
typedef Form_1 LinearForm;
typedef Form_0::TestSpace FunctionSpace;

} // namespace Poisson3D_5

#endif
